package com.taobao.weex.bridge;

import android.content.Context;
import android.net.Uri;
import android.os.Handler;
import android.os.Looper;
import android.os.Message;
import android.text.TextUtils;
import android.util.Log;
import android.util.Pair;
import androidx.collection.ArrayMap;
import com.alibaba.fastjson.JSON;
import com.alibaba.fastjson.JSONArray;
import com.alibaba.fastjson.JSONObject;
import com.taobao.weex.Script;
import com.taobao.weex.WXEnvironment;
import com.taobao.weex.WXSDKEngine;
import com.taobao.weex.WXSDKInstance;
import com.taobao.weex.WXSDKManager;
import com.taobao.weex.adapter.IWXConfigAdapter;
import com.taobao.weex.adapter.IWXJSExceptionAdapter;
import com.taobao.weex.adapter.IWXJsFileLoaderAdapter;
import com.taobao.weex.adapter.IWXJscProcessManager;
import com.taobao.weex.adapter.IWXUserTrackAdapter;
import com.taobao.weex.bridge.WXValidateProcessor;
import com.taobao.weex.common.Constants;
import com.taobao.weex.common.IWXBridge;
import com.taobao.weex.common.IWXDebugConfig;
import com.taobao.weex.common.WXConfig;
import com.taobao.weex.common.WXErrorCode;
import com.taobao.weex.common.WXException;
import com.taobao.weex.common.WXJSExceptionInfo;
import com.taobao.weex.common.WXRefreshData;
import com.taobao.weex.common.WXRenderStrategy;
import com.taobao.weex.common.WXRuntimeException;
import com.taobao.weex.common.WXThread;
import com.taobao.weex.dom.CSSShorthand;
import com.taobao.weex.el.parse.Operators;
import com.taobao.weex.layout.ContentBoxMeasurement;
import com.taobao.weex.performance.WXInstanceApm;
import com.taobao.weex.performance.WXStateRecord;
import com.taobao.weex.ui.WXComponentRegistry;
import com.taobao.weex.ui.WXRenderManager;
import com.taobao.weex.ui.action.ActionReloadPage;
import com.taobao.weex.ui.action.GraphicActionAddChildToRichtext;
import com.taobao.weex.ui.action.GraphicActionAddElement;
import com.taobao.weex.ui.action.GraphicActionAddEvent;
import com.taobao.weex.ui.action.GraphicActionAppendTreeCreateFinish;
import com.taobao.weex.ui.action.GraphicActionBatchBegin;
import com.taobao.weex.ui.action.GraphicActionBatchEnd;
import com.taobao.weex.ui.action.GraphicActionCreateBody;
import com.taobao.weex.ui.action.GraphicActionCreateFinish;
import com.taobao.weex.ui.action.GraphicActionLayout;
import com.taobao.weex.ui.action.GraphicActionMoveElement;
import com.taobao.weex.ui.action.GraphicActionRefreshFinish;
import com.taobao.weex.ui.action.GraphicActionRemoveChildFromRichtext;
import com.taobao.weex.ui.action.GraphicActionRemoveElement;
import com.taobao.weex.ui.action.GraphicActionRemoveEvent;
import com.taobao.weex.ui.action.GraphicActionRenderSuccess;
import com.taobao.weex.ui.action.GraphicActionUpdateAttr;
import com.taobao.weex.ui.action.GraphicActionUpdateRichtextAttr;
import com.taobao.weex.ui.action.GraphicActionUpdateRichtextStyle;
import com.taobao.weex.ui.action.GraphicActionUpdateStyle;
import com.taobao.weex.ui.action.GraphicPosition;
import com.taobao.weex.ui.action.GraphicSize;
import com.taobao.weex.ui.component.WXComponent;
import com.taobao.weex.ui.module.WXDomModule;
import com.taobao.weex.utils.WXExceptionUtils;
import com.taobao.weex.utils.WXFileUtils;
import com.taobao.weex.utils.WXJsonUtils;
import com.taobao.weex.utils.WXLogUtils;
import com.taobao.weex.utils.WXUtils;
import com.taobao.weex.utils.WXViewUtils;
import com.taobao.weex.utils.WXWsonJSONSwitch;
import com.taobao.weex.utils.batch.BactchExecutor;
import com.taobao.weex.utils.batch.Interceptor;
import com.taobao.weex.utils.tools.LogDetail;
import io.dcloud.common.adapter.ui.webview.WebLoadEvent;
import io.dcloud.common.adapter.util.UEH;
import io.dcloud.common.constant.AbsoluteConst;
import io.dcloud.common.util.AppRuntime;
import io.dcloud.common.util.BaseInfo;
import io.dcloud.common.util.ExifInterface;
import io.dcloud.common.util.JSONUtil;
import io.dcloud.common.util.PdrUtil;
import io.dcloud.common.util.RuningAcitvityUtil;
import io.dcloud.common.util.StringUtil;
import io.dcloud.weex.WXDotDataUtil;
import java.io.BufferedReader;
import java.io.File;
import java.io.FileInputStream;
import java.io.FileReader;
import java.io.InputStreamReader;
import java.lang.reflect.Constructor;
import java.lang.reflect.Method;
import java.text.SimpleDateFormat;
import java.util.ArrayList;
import java.util.Date;
import java.util.HashMap;
import java.util.HashSet;
import java.util.List;
import java.util.Locale;
import java.util.Map;
import java.util.Stack;
import java.util.concurrent.CountDownLatch;
import java.util.concurrent.TimeUnit;
/* loaded from: classes18.dex */
public class WXBridgeManager implements Handler.Callback, BactchExecutor {
    public static final String ARGS = "args";
    private static final boolean BRIDGE_LOG_SWITCH = false;
    private static final String BUNDLE_TYPE = "bundleType";
    public static final String COMPONENT = "component";
    private static final int CRASHREINIT = 50;
    private static String GLOBAL_CONFIG_KEY = "global_switch_config";
    public static final String INITLOGFILE = "/jsserver_start.log";
    private static final int INIT_FRAMEWORK_OK = 1;
    public static final String KEY_ARGS = "args";
    public static final String KEY_METHOD = "method";
    public static final String KEY_PARAMS = "params";
    private static long LOW_MEM_VALUE = 120;
    public static final String METHD_COMPONENT_HOOK_SYNC = "componentHook";
    public static final String METHD_FIRE_EVENT_SYNC = "fireEventSync";
    public static final String METHOD = "method";
    public static final String METHOD_CALLBACK = "callback";
    public static final String METHOD_CALL_JS = "callJS";
    public static final String METHOD_CHECK_APPKEY = "dc_checkappkey";
    public static final String METHOD_CREATE_INSTANCE = "createInstance";
    public static final String METHOD_CREATE_INSTANCE_CONTEXT = "createInstanceContext";
    public static final String METHOD_CREATE_PAGE_WITH_CONTENT = "CreatePageWithContent";
    public static final String METHOD_DESTROY_INSTANCE = "destroyInstance";
    public static final String METHOD_FIRE_EVENT = "fireEvent";
    public static final String METHOD_FIRE_EVENT_ON_DATA_RENDER_NODE = "fireEventOnDataRenderNode";
    private static final String METHOD_JSFM_NOT_INIT_IN_EAGLE_MODE = "JsfmNotInitInEagleMode";
    public static final String METHOD_NOTIFY_SERIALIZE_CODE_CACHE = "notifySerializeCodeCache";
    public static final String METHOD_NOTIFY_TRIM_MEMORY = "notifyTrimMemory";
    private static final String METHOD_POST_TASK_TO_MSG_LOOP = "PostTaskToMsgLoop";
    public static final String METHOD_REFRESH_INSTANCE = "refreshInstance";
    public static final String METHOD_REGISTER_COMPONENTS = "registerComponents";
    public static final String METHOD_REGISTER_MODULES = "registerModules";
    public static final String METHOD_SET_TIMEOUT = "setTimeoutCallback";
    public static final String METHOD_UPDATE_COMPONENT_WITH_DATA = "UpdateComponentData";
    public static final String MODULE = "module";
    private static final String NON_CALLBACK = "-1";
    public static final String OPTIONS = "options";
    public static final String REF = "ref";
    private static final String RENDER_STRATEGY = "renderStrategy";
    private static final String UNDEFINED = "undefined";
    private static Class clazz_debugProxy = null;
    private static String crashUrl = null;
    private static String globalConfig = "none";
    private static volatile boolean isJsEngineMultiThreadEnable = false;
    private static volatile boolean isSandBoxContext = true;
    private static boolean isUseSingleProcess = false;
    private static long lastCrashTime = 0;
    static volatile WXBridgeManager mBridgeManager = null;
    private static volatile boolean mInit = false;
    private static String mRaxApi = null;
    public static volatile int reInitCount = 1;
    public static long sInitFrameWorkTimeOrigin;
    private WXParams mInitParams;
    private Interceptor mInterceptor;
    Handler mJSHandler;
    private WXThread mJSThread;
    private IWXBridge mWXBridge;
    private Object mWxDebugProxy;
    private static Map<String, String> mWeexCoreEnvOptions = new HashMap();
    public static StringBuilder sInitFrameWorkMsg = new StringBuilder();
    private WXHashMap<String, ArrayList<WXHashMap<String, Object>>> mNextTickTasks = new WXHashMap<>();
    private boolean mMock = false;
    private List<Map<String, Object>> mRegisterComponentFailList = new ArrayList(8);
    private List<Map<String, Object>> mRegisterModuleFailList = new ArrayList(8);
    private List<String> mRegisterServiceFailList = new ArrayList(8);
    private HashSet<String> mDestroyedInstanceId = new HashSet<>();
    private StringBuilder mLodBuilder = new StringBuilder(50);

    /* loaded from: classes8.dex */
    public enum BundType {
        Vue,
        Rax,
        Others
    }

    /* loaded from: classes8.dex */
    public static class TimerInfo {
        public String callbackId;
        public String instanceId;
        public long time;
    }

    private void mock(String instanceId) {
    }

    @Deprecated
    public void notifyTrimMemory() {
    }

    private WXBridgeManager() {
        initWXBridge(WXEnvironment.sRemoteDebugMode);
        WXThread wXThread = new WXThread("WeexJSBridgeThread", this);
        this.mJSThread = wXThread;
        this.mJSHandler = wXThread.getHandler();
    }

    public static WXBridgeManager getInstance() {
        if (mBridgeManager == null) {
            synchronized (WXBridgeManager.class) {
                if (mBridgeManager == null) {
                    mBridgeManager = new WXBridgeManager();
                }
            }
        }
        return mBridgeManager;
    }

    public void setUseSingleProcess(final boolean flag) {
        if (flag != isUseSingleProcess) {
            isUseSingleProcess = flag;
        }
    }

    public void onInteractionTimeUpdate(final String instanceId) {
        post(new Runnable() { // from class: com.taobao.weex.bridge.WXBridgeManager.1
            @Override // java.lang.Runnable
            public void run() {
                if (WXBridgeManager.this.mWXBridge instanceof WXBridge) {
                    ((WXBridge) WXBridgeManager.this.mWXBridge).nativeOnInteractionTimeUpdate(instanceId);
                }
            }
        });
    }

    public boolean jsEngineMultiThreadEnable() {
        return isJsEngineMultiThreadEnable;
    }

    public void checkJsEngineMultiThread() {
        IWXJscProcessManager wXJscProcessManager = WXSDKManager.getInstance().getWXJscProcessManager();
        boolean enableBackupThread = wXJscProcessManager != null ? wXJscProcessManager.enableBackupThread() : false;
        if (enableBackupThread == isJsEngineMultiThreadEnable) {
            return;
        }
        isJsEngineMultiThreadEnable = enableBackupThread;
        if (isJSFrameworkInit()) {
            if (isJSThread()) {
                WXSDKEngine.reload();
            } else {
                post(new Runnable() { // from class: com.taobao.weex.bridge.WXBridgeManager.2
                    @Override // java.lang.Runnable
                    public void run() {
                        WXSDKEngine.reload();
                    }
                });
            }
        }
    }

    public void setSandBoxContext(final boolean flag) {
        String loadAsset;
        if (flag != isSandBoxContext) {
            isSandBoxContext = flag;
            if (isJSThread()) {
                setJSFrameworkInit(false);
                WXModuleManager.resetAllModuleState();
                if (!isSandBoxContext) {
                    loadAsset = WXFileUtils.loadAsset("main.js", WXEnvironment.getApplication());
                } else {
                    loadAsset = WXFileUtils.loadAsset("weex-main-jsfm.js", WXEnvironment.getApplication());
                }
                initFramework(loadAsset);
                WXServiceManager.reload();
                WXModuleManager.reload();
                WXComponentRegistry.reload();
                return;
            }
            post(new Runnable() { // from class: com.taobao.weex.bridge.WXBridgeManager.3
                @Override // java.lang.Runnable
                public void run() {
                    String loadAsset2;
                    WXBridgeManager.this.setJSFrameworkInit(false);
                    WXModuleManager.resetAllModuleState();
                    if (!WXBridgeManager.isSandBoxContext) {
                        loadAsset2 = WXFileUtils.loadAsset("main.js", WXEnvironment.getApplication());
                    } else {
                        loadAsset2 = WXFileUtils.loadAsset("weex-main-jsfm.js", WXEnvironment.getApplication());
                    }
                    WXBridgeManager.this.initFramework(loadAsset2);
                    WXServiceManager.reload();
                    WXModuleManager.reload();
                    WXComponentRegistry.reload();
                }
            });
        }
    }

    public boolean isJSFrameworkInit() {
        return mInit;
    }

    /* JADX INFO: Access modifiers changed from: private */
    public void setJSFrameworkInit(boolean init) {
        mInit = init;
        if (init) {
            onJsFrameWorkInitSuccees();
        }
    }

    private void initWXBridge(boolean remoteDebug) {
        Method method;
        boolean z;
        Constructor constructor;
        Object newInstance;
        Method method2;
        if (remoteDebug && WXEnvironment.isApkDebugable()) {
            WXEnvironment.sDebugServerConnectable = true;
        }
        if (WXEnvironment.sDebugServerConnectable) {
            WXEnvironment.isApkDebugable();
            if (WXEnvironment.getApplication() != null) {
                try {
                    if (clazz_debugProxy == null) {
                        clazz_debugProxy = Class.forName("com.taobao.weex.devtools.debug.DebugServerProxy");
                    }
                    Class cls = clazz_debugProxy;
                    if (cls != null) {
                        if (this.mWxDebugProxy != null) {
                            Method method3 = cls.getMethod("isActive", new Class[0]);
                            if (method3 != null ? ((Boolean) method3.invoke(this.mWxDebugProxy, new Object[0])).booleanValue() : false) {
                                z = false;
                                if (z && (constructor = clazz_debugProxy.getConstructor(Context.class, IWXDebugConfig.class)) != null) {
                                    newInstance = constructor.newInstance(WXEnvironment.getApplication(), new IWXDebugConfig() { // from class: com.taobao.weex.bridge.WXBridgeManager.4
                                        @Override // com.taobao.weex.common.IWXDebugConfig
                                        public WXBridgeManager getWXJSManager() {
                                            return WXBridgeManager.this;
                                        }

                                        @Override // com.taobao.weex.common.IWXDebugConfig
                                        public WXDebugJsBridge getWXDebugJsBridge() {
                                            return new WXDebugJsBridge();
                                        }
                                    });
                                    this.mWxDebugProxy = newInstance;
                                    if (newInstance != null && (method2 = clazz_debugProxy.getMethod("start", new Class[0])) != null) {
                                        method2.invoke(this.mWxDebugProxy, new Object[0]);
                                    }
                                }
                            }
                        }
                        z = true;
                        if (z) {
                            newInstance = constructor.newInstance(WXEnvironment.getApplication(), new IWXDebugConfig() { // from class: com.taobao.weex.bridge.WXBridgeManager.4
                                @Override // com.taobao.weex.common.IWXDebugConfig
                                public WXBridgeManager getWXJSManager() {
                                    return WXBridgeManager.this;
                                }

                                @Override // com.taobao.weex.common.IWXDebugConfig
                                public WXDebugJsBridge getWXDebugJsBridge() {
                                    return new WXDebugJsBridge();
                                }
                            });
                            this.mWxDebugProxy = newInstance;
                            if (newInstance != null) {
                                method2.invoke(this.mWxDebugProxy, new Object[0]);
                            }
                        }
                    }
                } catch (Throwable unused) {
                }
                WXServiceManager.execAllCacheJsService();
            } else {
                WXLogUtils.e("WXBridgeManager", "WXEnvironment.sApplication is null, skip init Inspector");
            }
        }
        if (remoteDebug && this.mWxDebugProxy != null) {
            try {
                if (clazz_debugProxy == null) {
                    clazz_debugProxy = Class.forName("com.taobao.weex.devtools.debug.DebugServerProxy");
                }
                Class cls2 = clazz_debugProxy;
                if (cls2 == null || (method = cls2.getMethod("getWXBridge", new Class[0])) == null) {
                    return;
                }
                this.mWXBridge = (IWXBridge) method.invoke(this.mWxDebugProxy, new Object[0]);
                return;
            } catch (Throwable unused2) {
                return;
            }
        }
        this.mWXBridge = new WXBridge();
    }

    public String dumpIpcPageInfo() {
        IWXBridge iWXBridge = this.mWXBridge;
        return iWXBridge instanceof WXBridge ? ((WXBridge) iWXBridge).nativeDumpIpcPageQueueInfo() : "";
    }

    public void stopRemoteDebug() {
        Method method;
        if (this.mWxDebugProxy != null) {
            try {
                if (clazz_debugProxy == null) {
                    clazz_debugProxy = Class.forName("com.taobao.weex.devtools.debug.DebugServerProxy");
                }
                Class cls = clazz_debugProxy;
                if (cls == null || (method = cls.getMethod(Constants.Value.STOP, Boolean.TYPE)) == null) {
                    return;
                }
                method.invoke(this.mWxDebugProxy, false);
                this.mWxDebugProxy = null;
            } catch (Throwable unused) {
            }
        }
    }

    public Object callModuleMethod(String instanceId, String moduleStr, String methodStr, JSONArray args) {
        return callModuleMethod(instanceId, moduleStr, methodStr, args, null);
    }

    public Object callModuleMethod(String instanceId, String moduleStr, String methodStr, JSONArray args, JSONObject options) {
        WXSDKInstance sDKInstance = WXSDKManager.getInstance().getSDKInstance(instanceId);
        if (sDKInstance == null) {
            return null;
        }
        if (sDKInstance.isNeedValidate() && WXSDKManager.getInstance().getValidateProcessor() != null) {
            WXValidateProcessor.WXModuleValidateResult onModuleValidate = WXSDKManager.getInstance().getValidateProcessor().onModuleValidate(sDKInstance, moduleStr, methodStr, args, options);
            if (onModuleValidate == null) {
                return null;
            }
            if (onModuleValidate.isSuccess) {
                return WXModuleManager.callModuleMethod(instanceId, moduleStr, methodStr, args);
            }
            JSONObject jSONObject = onModuleValidate.validateInfo;
            if (jSONObject != null) {
                WXLogUtils.e("[WXBridgeManager] module validate fail. >>> " + jSONObject.toJSONString());
            }
            return jSONObject;
        }
        try {
            return WXModuleManager.callModuleMethod(instanceId, moduleStr, methodStr, args);
        } catch (NumberFormatException unused) {
            ArrayMap arrayMap = new ArrayMap();
            arrayMap.put("moduleName", moduleStr);
            arrayMap.put("methodName", methodStr);
            arrayMap.put("args", args.toJSONString());
            WXLogUtils.e("[WXBridgeManager] callNative : numberFormatException when parsing string to numbers in args", arrayMap.toString());
            return null;
        }
    }

    public void restart() {
        setJSFrameworkInit(false);
        WXModuleManager.resetAllModuleState();
        initWXBridge(WXEnvironment.sRemoteDebugMode);
        this.mWXBridge.resetWXBridge(WXEnvironment.sRemoteDebugMode);
    }

    public synchronized void setStackTopInstance(final String instanceId) {
        post(new Runnable() { // from class: com.taobao.weex.bridge.WXBridgeManager.5
            @Override // java.lang.Runnable
            public void run() {
                WXBridgeManager.this.mNextTickTasks.setStackTopInstance(instanceId);
            }
        }, instanceId, null, null);
    }

    @Override // com.taobao.weex.utils.batch.BactchExecutor
    public void post(Runnable r) {
        postWithName(r, null, null);
    }

    public void postWithName(Runnable r, WXSDKInstance instance, String runnableName) {
        Handler handler;
        Runnable secure = WXThread.secure(r, instance, runnableName);
        Interceptor interceptor = this.mInterceptor;
        if ((interceptor == null || !interceptor.take(secure)) && (handler = this.mJSHandler) != null) {
            handler.post(secure);
        }
    }

    @Override // com.taobao.weex.utils.batch.BactchExecutor
    public void setInterceptor(Interceptor interceptor) {
        this.mInterceptor = interceptor;
    }

    public void post(Runnable r, Object token, WXSDKInstance instance, String runnableName) {
        Handler handler = this.mJSHandler;
        if (handler == null) {
            return;
        }
        Message obtain = Message.obtain(handler, WXThread.secure(r, instance, runnableName));
        obtain.obj = token;
        obtain.sendToTarget();
    }

    public void post(Runnable r, Object token) {
        post(r, token, null, null);
    }

    public void postDelay(Runnable r, long delayMillis) {
        Handler handler = this.mJSHandler;
        if (handler == null) {
            return;
        }
        handler.postDelayed(WXThread.secure(r), delayMillis);
    }

    public void setLogLevel(final int level, final boolean isPerf) {
        post(new Runnable() { // from class: com.taobao.weex.bridge.WXBridgeManager.6
            @Override // java.lang.Runnable
            public void run() {
                if (WXBridgeManager.this.mWXBridge != null) {
                    WXBridgeManager.this.mWXBridge.setLogType(level, isPerf);
                }
            }
        });
    }

    /* JADX INFO: Access modifiers changed from: package-private */
    public void setTimeout(String callbackId, String time) {
        Message obtain = Message.obtain();
        obtain.what = 1;
        TimerInfo timerInfo = new TimerInfo();
        timerInfo.callbackId = callbackId;
        timerInfo.time = Float.parseFloat(time);
        obtain.obj = timerInfo;
        this.mJSHandler.sendMessageDelayed(obtain, timerInfo.time);
    }

    public void sendMessageDelayed(Message message, long delayMillis) {
        WXThread wXThread;
        if (message == null || this.mJSHandler == null || (wXThread = this.mJSThread) == null || !wXThread.isWXThreadAlive() || this.mJSThread.getLooper() == null) {
            return;
        }
        this.mJSHandler.sendMessageDelayed(message, delayMillis);
    }

    public void removeMessage(int what, Object obj) {
        WXThread wXThread;
        if (this.mJSHandler == null || (wXThread = this.mJSThread) == null || !wXThread.isWXThreadAlive() || this.mJSThread.getLooper() == null) {
            return;
        }
        this.mJSHandler.removeMessages(what, obj);
    }

    public Object callNativeModule(String instanceId, String module, String method, JSONArray arguments, Object options) {
        if (TextUtils.isEmpty(instanceId) || TextUtils.isEmpty(module) || TextUtils.isEmpty(method)) {
            WXLogUtils.d("[WXBridgeManager] call callNativeModule arguments is null");
            WXExceptionUtils.commitCriticalExceptionRT(instanceId, WXErrorCode.WX_RENDER_ERR_BRIDGE_ARG_NULL, "callNativeModule", "arguments is empty, INSTANCE_RENDERING_ERROR will be set", null);
            return 0;
        }
        WXEnvironment.isApkDebugable();
        try {
            if (WXDomModule.WXDOM.equals(module)) {
                return WXModuleManager.getDomModule(instanceId).callDomMethod(method, arguments, new long[0]);
            }
            return callModuleMethod(instanceId, module, method, arguments);
        } catch (Exception e) {
            String str = "[WXBridgeManager] callNative exception: " + WXLogUtils.getStackTrace(e);
            WXLogUtils.e(str);
            WXExceptionUtils.commitCriticalExceptionRT(instanceId, WXErrorCode.WX_KEY_EXCEPTION_INVOKE_BRIDGE, "callNativeModule", str, null);
            return null;
        }
    }

    public Object callNativeModule(String instanceId, String module, String method, JSONArray arguments, JSONObject options) {
        if (TextUtils.isEmpty(instanceId) || TextUtils.isEmpty(module) || TextUtils.isEmpty(method)) {
            WXLogUtils.d("[WXBridgeManager] call callNativeModule arguments is null");
            WXExceptionUtils.commitCriticalExceptionRT(instanceId, WXErrorCode.WX_RENDER_ERR_BRIDGE_ARG_NULL, "callNativeModule", "arguments is empty, INSTANCE_RENDERING_ERROR will be set", null);
            return 0;
        }
        WXStateRecord wXStateRecord = WXStateRecord.getInstance();
        wXStateRecord.recordAction(instanceId, "callNativeModule:" + module + Operators.DOT_STR + method);
        WXEnvironment.isApkDebugable();
        try {
        } catch (Exception e) {
            WXLogUtils.e("[WXBridgeManager] callNativeModule exception: " + WXLogUtils.getStackTrace(e));
        }
        if (WXDomModule.WXDOM.equals(module)) {
            WXDomModule domModule = WXModuleManager.getDomModule(instanceId);
            if (domModule != null) {
                return domModule.callDomMethod(method, arguments, new long[0]);
            }
            WXModuleManager.createDomModule(WXSDKManager.getInstance().getSDKInstance(instanceId));
            return null;
        }
        return callModuleMethod(instanceId, module, method, arguments, options);
    }

    public Object callNativeComponent(String instanceId, String componentRef, String method, JSONArray arguments, Object options) {
        if (TextUtils.isEmpty(instanceId) || TextUtils.isEmpty(componentRef) || TextUtils.isEmpty(method)) {
            WXLogUtils.d("[WXBridgeManager] call callNativeComponent arguments is null");
            WXExceptionUtils.commitCriticalExceptionRT(instanceId, WXErrorCode.WX_RENDER_ERR_BRIDGE_ARG_NULL, "callNativeComponent", "arguments is empty, INSTANCE_RENDERING_ERROR will be set", null);
            return 0;
        }
        WXEnvironment.isApkDebugable();
        try {
            WXDomModule domModule = WXModuleManager.getDomModule(instanceId);
            if (domModule != null) {
                domModule.invokeMethod(componentRef, method, arguments);
            } else {
                WXSDKInstance sDKInstance = WXSDKManager.getInstance().getSDKInstance(instanceId);
                if (sDKInstance == null || !sDKInstance.isDestroy()) {
                    WXLogUtils.e("WXBridgeManager", "callNativeComponent exception :null == dom ,method:" + method);
                }
            }
        } catch (Exception e) {
            WXLogUtils.e("[WXBridgeManager] callNativeComponent exception: ", e);
            WXExceptionUtils.commitCriticalExceptionRT(instanceId, WXErrorCode.WX_KEY_EXCEPTION_INVOKE_BRIDGE, "callNativeComponent", WXLogUtils.getStackTrace(e), null);
        }
        return null;
    }

    public int callNative(String instanceId, JSONArray tasks, String callback) {
        int i;
        int i2;
        if (TextUtils.isEmpty(instanceId) || tasks == null) {
            WXLogUtils.d("[WXBridgeManager] call callNative arguments is null");
            WXExceptionUtils.commitCriticalExceptionRT(instanceId, WXErrorCode.WX_RENDER_ERR_BRIDGE_ARG_NULL, "callNative", "arguments is empty, INSTANCE_RENDERING_ERROR will be set", null);
            return 0;
        }
        WXEnvironment.isApkDebugable();
        HashSet<String> hashSet = this.mDestroyedInstanceId;
        if (hashSet == null || !hashSet.contains(instanceId)) {
            long nanoTime = System.nanoTime() - System.nanoTime();
            if (tasks != null && tasks.size() > 0) {
                int size = tasks.size();
                int i3 = 0;
                while (i3 < size) {
                    try {
                        JSONObject jSONObject = (JSONObject) tasks.get(i3);
                        if (jSONObject != null && WXSDKManager.getInstance().getSDKInstance(instanceId) != null) {
                            Object obj = jSONObject.get("module");
                            if (obj != null) {
                                if (WXDomModule.WXDOM.equals(obj)) {
                                    WXModuleManager.getDomModule(instanceId).callDomMethod(jSONObject, nanoTime);
                                } else {
                                    i = i3;
                                    i2 = size;
                                    callModuleMethod(instanceId, (String) obj, (String) jSONObject.get("method"), (JSONArray) jSONObject.get("args"), jSONObject.getJSONObject("options"));
                                }
                            } else {
                                i = i3;
                                i2 = size;
                                if (jSONObject.get(COMPONENT) != null) {
                                    WXModuleManager.getDomModule(instanceId).invokeMethod((String) jSONObject.get("ref"), (String) jSONObject.get("method"), (JSONArray) jSONObject.get("args"));
                                } else {
                                    throw new IllegalArgumentException("unknown callNative");
                                }
                            }
                            i3 = i + 1;
                            size = i2;
                        }
                        i = i3;
                        i2 = size;
                        i3 = i + 1;
                        size = i2;
                    } catch (Exception e) {
                        WXLogUtils.e("[WXBridgeManager] callNative exception: ", e);
                        WXExceptionUtils.commitCriticalExceptionRT(instanceId, WXErrorCode.WX_KEY_EXCEPTION_INVOKE_BRIDGE, "callNative", WXLogUtils.getStackTrace(e), null);
                    }
                }
            }
            if ("undefined".equals(callback) || NON_CALLBACK.equals(callback)) {
                return 0;
            }
            getNextTick(instanceId, callback);
            return 1;
        }
        return -1;
    }

    public int callUpdateFinish(String instanceId, String callback) {
        if (TextUtils.isEmpty(instanceId)) {
            WXLogUtils.d("[WXBridgeManager] call callUpdateFinish arguments is null");
            WXExceptionUtils.commitCriticalExceptionRT(instanceId, WXErrorCode.WX_RENDER_ERR_BRIDGE_ARG_NULL, "callUpdateFinish", "arguments is empty, INSTANCE_RENDERING_ERROR will be set", null);
            return 0;
        }
        WXEnvironment.isApkDebugable();
        HashSet<String> hashSet = this.mDestroyedInstanceId;
        if (hashSet == null || !hashSet.contains(instanceId)) {
            try {
                WXSDKManager.getInstance().getSDKInstance(instanceId);
            } catch (Exception e) {
                WXLogUtils.e("[WXBridgeManager] callUpdateFinish exception: ", e);
                WXExceptionUtils.commitCriticalExceptionRT(instanceId, WXErrorCode.WX_KEY_EXCEPTION_INVOKE_BRIDGE, "callUpdateFinish", WXLogUtils.getStackTrace(e), null);
            }
            if (callback == null || callback.isEmpty() || "undefined".equals(callback) || NON_CALLBACK.equals(callback)) {
                return 0;
            }
            getNextTick(instanceId, callback);
            return 1;
        }
        return -1;
    }

    public int callRefreshFinish(String instanceId, String callback) {
        if (TextUtils.isEmpty(instanceId)) {
            WXLogUtils.d("[WXBridgeManager] call callRefreshFinish arguments is null");
            WXExceptionUtils.commitCriticalExceptionRT(instanceId, WXErrorCode.WX_RENDER_ERR_BRIDGE_ARG_NULL, "callRefreshFinish", "arguments is empty, INSTANCE_RENDERING_ERROR will be set", null);
            return 0;
        }
        WXEnvironment.isApkDebugable();
        HashSet<String> hashSet = this.mDestroyedInstanceId;
        if (hashSet == null || !hashSet.contains(instanceId)) {
            try {
                WXSDKInstance sDKInstance = WXSDKManager.getInstance().getSDKInstance(instanceId);
                if (sDKInstance != null) {
                    WXSDKManager.getInstance().getWXRenderManager().postGraphicAction(instanceId, new GraphicActionRefreshFinish(sDKInstance));
                }
            } catch (Exception e) {
                WXLogUtils.e("[WXBridgeManager] callRefreshFinish exception: ", e);
                WXExceptionUtils.commitCriticalExceptionRT(instanceId, WXErrorCode.WX_KEY_EXCEPTION_INVOKE_BRIDGE, "callRefreshFinish", WXLogUtils.getStackTrace(e), null);
            }
            if ("undefined".equals(callback) || NON_CALLBACK.equals(callback)) {
                return 0;
            }
            getNextTick(instanceId, callback);
            return 1;
        }
        return -1;
    }

    public int callReportCrashReloadPage(String instanceId, String crashFile) {
        String str;
        HashMap hashMap;
        boolean isEmpty = TextUtils.isEmpty(crashFile);
        try {
            WXSDKInstance sDKInstance = WXSDKManager.getInstance().getSDKInstance(instanceId);
            if (sDKInstance != null) {
                String bundleUrl = sDKInstance.getBundleUrl();
                sDKInstance.setHasException(true);
                str = bundleUrl;
            } else {
                str = null;
            }
            hashMap = new HashMap(2);
            hashMap.put("weexCoreThreadStackTrace:", getInstance().getWeexCoreThreadStackTrace());
            hashMap.put("wxStateInfo", WXStateRecord.getInstance().getStateInfo().toString());
            String str2 = "null";
            if (!isEmpty) {
                if (WXEnvironment.getApplication() != null) {
                    crashFile = this.mInitParams.getCrashFilePath() + crashFile;
                    Log.d("jsengine", "callReportCrashReloadPage crashFile:" + crashFile);
                }
                WXStateRecord wXStateRecord = WXStateRecord.getInstance();
                if (!TextUtils.isEmpty(instanceId)) {
                    str2 = instanceId;
                }
                wXStateRecord.onJSCCrash(str2);
                callReportCrash(crashFile, instanceId, str, hashMap);
            } else {
                WXStateRecord wXStateRecord2 = WXStateRecord.getInstance();
                if (!TextUtils.isEmpty(instanceId)) {
                    str2 = instanceId;
                }
                wXStateRecord2.onJSEngineReload(str2);
                commitJscCrashAlarmMonitor(IWXUserTrackAdapter.JS_BRIDGE, WXErrorCode.WX_ERR_RELOAD_PAGE, "reboot jsc Engine", instanceId, str, hashMap);
            }
        } catch (Exception e) {
            WXLogUtils.e("[WXBridgeManager] callReportCrashReloadPage exception: ", e);
        }
        if (reInitCount > 50) {
            WXExceptionUtils.commitCriticalExceptionRT("jsEngine", WXErrorCode.WX_ERR_RELOAD_PAGE_EXCEED_LIMIT, "callReportCrashReloadPage", "reInitCount:" + reInitCount, hashMap);
            return 0;
        }
        reInitCount++;
        setJSFrameworkInit(false);
        WXModuleManager.resetAllModuleState();
        initScriptsFramework("");
        HashSet<String> hashSet = this.mDestroyedInstanceId;
        if (hashSet != null && hashSet.contains(instanceId)) {
            return -1;
        }
        try {
            if (WXSDKManager.getInstance().getSDKInstance(instanceId) != null) {
                new ActionReloadPage(instanceId, shouldReloadCurrentInstance(WXSDKManager.getInstance().getSDKInstance(instanceId).getBundleUrl())).executeAction();
            }
        } catch (Exception e2) {
            WXLogUtils.e("[WXBridgeManager] callReloadPage exception: ", e2);
            WXExceptionUtils.commitCriticalExceptionRT(instanceId, WXErrorCode.WX_KEY_EXCEPTION_INVOKE_BRIDGE, "callReportCrashReloadPage", WXLogUtils.getStackTrace(e2), null);
        }
        return 0;
    }

    public boolean shouldReloadCurrentInstance(String aUrl) {
        Uri parse;
        long currentTimeMillis = System.currentTimeMillis();
        IWXConfigAdapter wxConfigAdapter = WXSDKManager.getInstance().getWxConfigAdapter();
        if (wxConfigAdapter != null) {
            boolean parseBoolean = Boolean.parseBoolean(wxConfigAdapter.getConfig("android_weex_ext_config", "check_biz_url", AbsoluteConst.TRUE));
            WXLogUtils.e("check_biz_url : " + parseBoolean);
            if (parseBoolean && !TextUtils.isEmpty(aUrl) && (parse = Uri.parse(aUrl)) != null) {
                aUrl = parse.buildUpon().clearQuery().build().toString();
            }
        }
        String str = crashUrl;
        if (str == null || ((str != null && !str.equals(aUrl)) || currentTimeMillis - lastCrashTime > 15000)) {
            crashUrl = aUrl;
            lastCrashTime = currentTimeMillis;
            return true;
        }
        lastCrashTime = currentTimeMillis;
        return false;
    }

    public void callReportCrash(String crashFile, final String instanceId, final String url, final Map<String, String> extInfo) {
        final String str = crashFile + Operators.DOT_STR + new SimpleDateFormat("yyyyMMddHHmmss", Locale.US).format(new Date());
        File file = new File(crashFile);
        File file2 = new File(str);
        if (file.exists()) {
            file.renameTo(file2);
        }
        new Thread(new Runnable() { // from class: com.taobao.weex.bridge.WXBridgeManager.7
            @Override // java.lang.Runnable
            public void run() {
                try {
                    File file3 = new File(str);
                    if (file3.exists()) {
                        if (file3.length() > 0) {
                            StringBuilder sb = new StringBuilder();
                            try {
                                BufferedReader bufferedReader = new BufferedReader(new FileReader(str));
                                while (true) {
                                    String readLine = bufferedReader.readLine();
                                    if (readLine == null) {
                                        break;
                                    } else if (!"".equals(readLine)) {
                                        sb.append(readLine + "\n");
                                    }
                                }
                                WXBridgeManager.this.commitJscCrashAlarmMonitor(IWXUserTrackAdapter.JS_BRIDGE, WXErrorCode.WX_ERR_JSC_CRASH, sb.toString(), instanceId, url, extInfo);
                                bufferedReader.close();
                            } catch (Exception e) {
                                WXLogUtils.e(WXLogUtils.getStackTrace(e));
                            }
                        } else {
                            WXLogUtils.e("[WXBridgeManager] callReportCrash crash file is empty");
                        }
                        if (WXEnvironment.isApkDebugable()) {
                            return;
                        }
                        file3.delete();
                    }
                } catch (Throwable th) {
                    WXLogUtils.e("[WXBridgeManager] callReportCrash exception: ", th);
                }
            }
        }).start();
    }

    private void getNextTick(final String instanceId, final String callback) {
        addJSTask(METHOD_CALLBACK, instanceId, callback, "{}");
        sendMessage(instanceId, 6);
    }

    private void getNextTick(final String instanceId) {
        addJSTask(METHOD_CALLBACK, instanceId, "", "{}");
        sendMessage(instanceId, 6);
    }

    public String syncExecJsOnInstanceWithResult(final String instanceId, final String js, final int type) {
        final CountDownLatch countDownLatch = new CountDownLatch(1);
        EventResult eventResult = new EventResult() { // from class: com.taobao.weex.bridge.WXBridgeManager.8
            @Override // com.taobao.weex.bridge.EventResult
            public void onCallback(Object result) {
                super.onCallback(result);
                countDownLatch.countDown();
            }
        };
        try {
            execJSOnInstance(eventResult, instanceId, js, type);
            countDownLatch.await(100L, TimeUnit.MILLISECONDS);
            return eventResult.getResult() != null ? eventResult.getResult().toString() : "";
        } catch (Throwable th) {
            WXLogUtils.e("syncCallExecJsOnInstance", th);
            return "";
        }
    }

    public void loadJsBundleInPreInitMode(final String instanceId, final String js) {
        post(new Runnable() { // from class: com.taobao.weex.bridge.WXBridgeManager.9
            @Override // java.lang.Runnable
            public void run() {
                WXBridgeManager.this.invokeExecJSOnInstance(instanceId, js, -1);
                WXSDKInstance wXSDKInstance = WXSDKManager.getInstance().getAllInstanceMap().get(instanceId);
                if (wXSDKInstance == null || !wXSDKInstance.isPreInitMode()) {
                    return;
                }
                wXSDKInstance.getApmForInstance().onStage(WXInstanceApm.KEY_PAGE_STAGES_LOAD_BUNDLE_END);
                wXSDKInstance.getApmForInstance().onStageWithTime(WXInstanceApm.KEY_PAGE_STAGES_END_EXCUTE_BUNDLE, WXUtils.getFixUnixTime() + 600);
            }
        });
    }

    public EventResult syncCallJSEventWithResult(final String method, final String instanceId, final List<Object> params, final Object... args) {
        final CountDownLatch countDownLatch = new CountDownLatch(1);
        EventResult eventResult = new EventResult() { // from class: com.taobao.weex.bridge.WXBridgeManager.10
            @Override // com.taobao.weex.bridge.EventResult
            public void onCallback(Object result) {
                super.onCallback(result);
                countDownLatch.countDown();
            }
        };
        try {
            asyncCallJSEventWithResult(eventResult, method, instanceId, params, args);
            countDownLatch.await(100L, TimeUnit.MILLISECONDS);
            return eventResult;
        } catch (Exception e) {
            WXLogUtils.e("syncCallJSEventWithResult", e);
            return eventResult;
        }
    }

    public void asyncCallJSEventVoidResult(final String method, final String instanceId, final List<Object> params, final Object... args) {
        post(new Runnable() { // from class: com.taobao.weex.bridge.WXBridgeManager.11
            @Override // java.lang.Runnable
            public void run() {
                try {
                    Object[] objArr = args;
                    if (objArr != null && objArr.length != 0) {
                        ArrayList arrayList = new ArrayList();
                        for (Object obj : args) {
                            arrayList.add(obj);
                        }
                        if (params != null) {
                            ArrayMap arrayMap = new ArrayMap(4);
                            arrayMap.put("params", params);
                            arrayList.add(arrayMap);
                        }
                        WXHashMap wXHashMap = new WXHashMap();
                        wXHashMap.put("method", method);
                        wXHashMap.put("args", arrayList);
                        WXJSObject[] wXJSObjectArr = {new WXJSObject(2, instanceId), WXWsonJSONSwitch.toWsonOrJsonWXJSObject(new Object[]{wXHashMap})};
                        WXBridgeManager.this.invokeExecJS(String.valueOf(instanceId), null, WXBridgeManager.METHOD_CALL_JS, wXJSObjectArr, true);
                        wXJSObjectArr[0] = null;
                    }
                } catch (Exception e) {
                    WXLogUtils.e("asyncCallJSEventVoidResult", e);
                }
            }
        });
    }

    private void asyncCallJSEventWithResult(final EventResult eventCallback, final String method, final String instanceId, final List<Object> params, final Object... args) {
        post(new Runnable() { // from class: com.taobao.weex.bridge.WXBridgeManager.12
            @Override // java.lang.Runnable
            public void run() {
                try {
                    Object[] objArr = args;
                    if (objArr != null && objArr.length != 0) {
                        ArrayList arrayList = new ArrayList();
                        for (Object obj : args) {
                            arrayList.add(obj);
                        }
                        if (params != null) {
                            ArrayMap arrayMap = new ArrayMap(4);
                            arrayMap.put("params", params);
                            arrayList.add(arrayMap);
                        }
                        WXHashMap wXHashMap = new WXHashMap();
                        wXHashMap.put("method", method);
                        wXHashMap.put("args", arrayList);
                        WXJSObject[] wXJSObjectArr = {new WXJSObject(2, instanceId), WXWsonJSONSwitch.toWsonOrJsonWXJSObject(new Object[]{wXHashMap})};
                        WXBridgeManager.this.invokeExecJSWithCallback(String.valueOf(instanceId), null, WXBridgeManager.METHOD_CALL_JS, wXJSObjectArr, eventCallback != null ? new ResultCallback<byte[]>() { // from class: com.taobao.weex.bridge.WXBridgeManager.12.1
                            @Override // com.taobao.weex.bridge.ResultCallback
                            public void onReceiveResult(byte[] result) {
                                JSONArray jSONArray = (JSONArray) WXWsonJSONSwitch.parseWsonOrJSON(result);
                                if (jSONArray == null || jSONArray.size() <= 0) {
                                    return;
                                }
                                eventCallback.onCallback(jSONArray.get(0));
                            }
                        } : null, true);
                        wXJSObjectArr[0] = null;
                    }
                } catch (Exception e) {
                    WXLogUtils.e("asyncCallJSEventWithResult", e);
                }
            }
        });
    }

    private void addJSEventTask(final String method, final String instanceId, final List<Object> params, final Object... args) {
        post(new Runnable() { // from class: com.taobao.weex.bridge.WXBridgeManager.13
            @Override // java.lang.Runnable
            public void run() {
                Object[] objArr = args;
                if (objArr == null || objArr.length == 0) {
                    return;
                }
                ArrayList arrayList = new ArrayList();
                for (Object obj : args) {
                    arrayList.add(obj);
                }
                if (params != null) {
                    ArrayMap arrayMap = new ArrayMap(4);
                    arrayMap.put("params", params);
                    arrayList.add(arrayMap);
                }
                WXHashMap wXHashMap = new WXHashMap();
                wXHashMap.put("method", method);
                wXHashMap.put("args", arrayList);
                if (WXBridgeManager.this.mNextTickTasks.get(instanceId) != 0) {
                    ((ArrayList) WXBridgeManager.this.mNextTickTasks.get(instanceId)).add(wXHashMap);
                    return;
                }
                ArrayList arrayList2 = new ArrayList();
                arrayList2.add(wXHashMap);
                WXBridgeManager.this.mNextTickTasks.put(instanceId, arrayList2);
            }
        });
    }

    private void addJSTask(final String method, final String instanceId, final Object... args) {
        addJSEventTask(method, instanceId, null, args);
    }

    private void sendMessage(String instanceId, int what) {
        Message obtain = Message.obtain(this.mJSHandler);
        obtain.obj = instanceId;
        obtain.what = what;
        obtain.sendToTarget();
    }

    public synchronized void initScriptsFramework(String framework) {
        Message obtainMessage = this.mJSHandler.obtainMessage();
        obtainMessage.obj = framework;
        obtainMessage.what = 7;
        obtainMessage.setTarget(this.mJSHandler);
        obtainMessage.sendToTarget();
    }

    @Deprecated
    public void fireEvent(final String instanceId, final String ref, final String type, final Map<String, Object> data) {
        fireEvent(instanceId, ref, type, data, null);
    }

    @Deprecated
    public void fireEvent(final String instanceId, final String ref, final String type, final Map<String, Object> data, final Map<String, Object> domChanges) {
        fireEventOnNode(instanceId, ref, type, data, domChanges);
    }

    public void fireEventOnNode(final String instanceId, final String ref, final String type, final Map<String, Object> data, final Map<String, Object> domChanges) {
        fireEventOnNode(instanceId, ref, type, data, domChanges, null, null);
    }

    public void fireEventOnNode(final String instanceId, final String ref, final String type, final Map<String, Object> data, final Map<String, Object> domChanges, List<Object> params) {
        fireEventOnNode(instanceId, ref, type, data, domChanges, params, null);
    }

    public void fireEventOnNode(final String instanceId, final String ref, final String type, final Map<String, Object> data, final Map<String, Object> domChanges, List<Object> params, EventResult callback) {
        if (TextUtils.isEmpty(instanceId) || TextUtils.isEmpty(ref) || TextUtils.isEmpty(type) || this.mJSHandler == null) {
            return;
        }
        if (!checkMainThread()) {
            throw new WXRuntimeException("fireEvent must be called by main thread");
        }
        WXSDKInstance wXSDKInstance = WXSDKManager.getInstance().getAllInstanceMap().get(instanceId);
        if (wXSDKInstance != null && (wXSDKInstance.getRenderStrategy() == WXRenderStrategy.DATA_RENDER || wXSDKInstance.getRenderStrategy() == WXRenderStrategy.DATA_RENDER_BINARY)) {
            fireEventOnDataRenderNode(instanceId, ref, type, data, domChanges);
        } else if (callback == null) {
            addJSEventTask(METHOD_FIRE_EVENT, instanceId, params, ref, type, data, domChanges);
            sendMessage(instanceId, 6);
        } else {
            asyncCallJSEventWithResult(callback, METHD_FIRE_EVENT_SYNC, instanceId, params, ref, type, data, domChanges);
        }
    }

    private void fireEventOnDataRenderNode(final String instanceId, final String ref, final String type, final Map<String, Object> data, final Map<String, Object> domChanges) {
        this.mJSHandler.postDelayed(WXThread.secure(new Runnable() { // from class: com.taobao.weex.bridge.WXBridgeManager.14
            @Override // java.lang.Runnable
            public void run() {
                String str;
                Map map;
                try {
                    WXSDKManager.getInstance().getSDKInstance(instanceId);
                    long currentTimeMillis = System.currentTimeMillis();
                    if (WXEnvironment.isApkDebugable()) {
                        WXLogUtils.d("fireEventOnDataRenderNode >>>> instanceId:" + instanceId + ", data:" + data);
                    }
                    if (WXBridgeManager.this.mWXBridge instanceof WXBridge) {
                        WXBridge wXBridge = (WXBridge) WXBridgeManager.this.mWXBridge;
                        String str2 = instanceId;
                        String str3 = ref;
                        String str4 = type;
                        Map map2 = data;
                        String str5 = "{}";
                        if (map2 != null && !map2.isEmpty()) {
                            str = JSON.toJSONString(data);
                            map = domChanges;
                            if (map != null && !map.isEmpty()) {
                                str5 = JSON.toJSONString(domChanges);
                            }
                            wXBridge.fireEventOnDataRenderNode(str2, str3, str4, str, str5);
                        }
                        str = "{}";
                        map = domChanges;
                        if (map != null) {
                            str5 = JSON.toJSONString(domChanges);
                        }
                        wXBridge.fireEventOnDataRenderNode(str2, str3, str4, str, str5);
                    }
                    WXLogUtils.renderPerformanceLog(WXBridgeManager.METHOD_FIRE_EVENT_ON_DATA_RENDER_NODE, System.currentTimeMillis() - currentTimeMillis);
                } catch (Throwable th) {
                    String str6 = "[WXBridgeManager] fireEventOnDataRenderNode " + WXLogUtils.getStackTrace(th);
                    WXExceptionUtils.commitCriticalExceptionRT(instanceId, WXErrorCode.WX_KEY_EXCEPTION_INVOKE_BRIDGE, WXBridgeManager.METHOD_FIRE_EVENT_ON_DATA_RENDER_NODE, str6, null);
                    WXLogUtils.e(str6);
                }
            }
        }), 0L);
    }

    private boolean checkMainThread() {
        return Looper.myLooper() == Looper.getMainLooper();
    }

    @Deprecated
    public void callback(String instanceId, String callback, String data) {
        callback(instanceId, callback, data, false);
    }

    @Deprecated
    public void callback(final String instanceId, final String callback, final Map<String, Object> data) {
        callback(instanceId, callback, data, false);
    }

    @Deprecated
    public void callback(final String instanceId, final String callback, final Object data, boolean keepAlive) {
        callbackJavascript(instanceId, callback, data, keepAlive);
    }

    /* JADX INFO: Access modifiers changed from: package-private */
    public void callbackJavascript(final String instanceId, final String callback, final Object data, boolean keepAlive) {
        if (TextUtils.isEmpty(instanceId) || TextUtils.isEmpty(callback) || this.mJSHandler == null || !RuningAcitvityUtil.isRuningActivity) {
            return;
        }
        WXSDKInstance wXSDKInstance = WXSDKManager.getInstance().getAllInstanceMap().get(instanceId);
        if (wXSDKInstance != null && wXSDKInstance.getRenderStrategy() == WXRenderStrategy.DATA_RENDER_BINARY) {
            callbackJavascriptOnDataRender(instanceId, callback, data, keepAlive);
            return;
        }
        addJSTask(METHOD_CALLBACK, instanceId, callback, data, Boolean.valueOf(keepAlive));
        sendMessage(instanceId, 6);
    }

    void callbackJavascriptOnDataRender(final String instanceId, final String callback, final Object data, final boolean keepAlive) {
        this.mJSHandler.postDelayed(WXThread.secure(new Runnable() { // from class: com.taobao.weex.bridge.WXBridgeManager.15
            @Override // java.lang.Runnable
            public void run() {
                try {
                    long currentTimeMillis = System.currentTimeMillis();
                    String jSONString = JSON.toJSONString(data);
                    if (WXEnvironment.isApkDebugable()) {
                        WXLogUtils.d("callbackJavascriptOnDataRender >>>> instanceId:" + instanceId + ", data:" + jSONString);
                    }
                    if (WXBridgeManager.this.mWXBridge instanceof WXBridge) {
                        ((WXBridge) WXBridgeManager.this.mWXBridge).invokeCallbackOnDataRender(instanceId, callback, jSONString, keepAlive);
                    }
                    WXLogUtils.renderPerformanceLog("callbackJavascriptOnDataRender", System.currentTimeMillis() - currentTimeMillis);
                } catch (Throwable th) {
                    String str = "[WXBridgeManager] callbackJavascriptOnDataRender " + WXLogUtils.getStackTrace(th);
                    WXExceptionUtils.commitCriticalExceptionRT(instanceId, WXErrorCode.WX_KEY_EXCEPTION_INVOKE_BRIDGE, "callbackJavascriptOnDataRender", str, null);
                    WXLogUtils.e(str);
                }
            }
        }), 0L);
    }

    public void refreshInstance(final String instanceId, final WXRefreshData jsonData) {
        if (TextUtils.isEmpty(instanceId) || jsonData == null) {
            return;
        }
        this.mJSHandler.postDelayed(WXThread.secure(new Runnable() { // from class: com.taobao.weex.bridge.WXBridgeManager.16
            @Override // java.lang.Runnable
            public void run() {
                WXBridgeManager.this.invokeRefreshInstance(instanceId, jsonData);
            }
        }), 0L);
    }

    /* JADX INFO: Access modifiers changed from: private */
    public void invokeRefreshInstance(String instanceId, WXRefreshData refreshData) {
        try {
            WXSDKInstance sDKInstance = WXSDKManager.getInstance().getSDKInstance(instanceId);
            if (!isSkipFrameworkInit(instanceId) && !isJSFrameworkInit()) {
                if (sDKInstance != null) {
                    sDKInstance.onRenderError(WXErrorCode.WX_DEGRAD_ERR_INSTANCE_CREATE_FAILED.getErrorCode(), WXErrorCode.WX_DEGRAD_ERR_INSTANCE_CREATE_FAILED.getErrorMsg() + "invokeRefreshInstance FAILED for JSFrameworkInit FAILED, intance will invoke instance.onRenderError");
                }
                WXLogUtils.e("[WXBridgeManager] invokeRefreshInstance: framework.js uninitialized.");
                return;
            }
            System.currentTimeMillis();
            if (WXEnvironment.isApkDebugable()) {
                WXLogUtils.d("refreshInstance >>>> instanceId:" + instanceId + ", data:" + refreshData.data + ", isDirty:" + refreshData.isDirty);
            }
            if (refreshData.isDirty) {
                return;
            }
            this.mWXBridge.refreshInstance(instanceId, null, METHOD_REFRESH_INSTANCE, new WXJSObject[]{new WXJSObject(2, instanceId), new WXJSObject(3, refreshData.data == null ? "{}" : refreshData.data)});
        } catch (Throwable th) {
            String str = "[WXBridgeManager] invokeRefreshInstance " + WXLogUtils.getStackTrace(th);
            WXExceptionUtils.commitCriticalExceptionRT(instanceId, WXErrorCode.WX_KEY_EXCEPTION_INVOKE_BRIDGE, "invokeRefreshInstance", str, null);
            WXLogUtils.e(str);
        }
    }

    public void commitJscCrashAlarmMonitor(final String type, final WXErrorCode errorCode, String errMsg, String instanceId, String url, Map<String, String> extInfo) {
        if (TextUtils.isEmpty(type) || errorCode == null) {
            return;
        }
        Log.d("ReportCrash", " commitJscCrashAlarmMonitor errMsg " + errMsg);
        HashMap hashMap = new HashMap();
        hashMap.put("jscCrashStack", errMsg);
        if (extInfo != null) {
            hashMap.putAll(extInfo);
        }
        IWXJSExceptionAdapter iWXJSExceptionAdapter = WXSDKManager.getInstance().getIWXJSExceptionAdapter();
        if (iWXJSExceptionAdapter != null) {
            WXJSExceptionInfo wXJSExceptionInfo = new WXJSExceptionInfo(instanceId, url, errorCode, "callReportCrash", "weex core process crash and restart exception", hashMap);
            iWXJSExceptionAdapter.onJSException(wXJSExceptionInfo);
            WXLogUtils.e(wXJSExceptionInfo.toString());
        }
    }

    private boolean isSkipFrameworkInit(String instanceId) {
        return isSkipFrameworkInit(WXSDKManager.getInstance().getSDKInstance(instanceId));
    }

    private boolean isSkipFrameworkInit(WXSDKInstance instance) {
        if (instance == null) {
            return false;
        }
        return instance.skipFrameworkInit();
    }

    public void createInstance(final String instanceId, final String template, final Map<String, Object> options, final String data) {
        createInstance(instanceId, new Script(template), options, data);
    }

    public void createInstance(final String instanceId, final Script template, final Map<String, Object> options, final String data) {
        final WXSDKInstance sDKInstance = WXSDKManager.getInstance().getSDKInstance(instanceId);
        if (sDKInstance == null) {
            WXLogUtils.e("WXBridgeManager", "createInstance failed, SDKInstance does not exist");
        } else if (TextUtils.isEmpty(instanceId) || template == null || template.isEmpty() || this.mJSHandler == null) {
            String errorCode = WXErrorCode.WX_DEGRAD_ERR_INSTANCE_CREATE_FAILED.getErrorCode();
            sDKInstance.onRenderError(errorCode, WXErrorCode.WX_DEGRAD_ERR_INSTANCE_CREATE_FAILED.getErrorMsg() + " instanceId==" + instanceId + " template ==" + template + " mJSHandler== " + this.mJSHandler.toString());
        } else if (!isSkipFrameworkInit(instanceId) && !isJSFrameworkInit() && reInitCount == 1 && !WXEnvironment.sDebugServerConnectable) {
            String errorCode2 = WXErrorCode.WX_DEGRAD_ERR_INSTANCE_CREATE_FAILED.getErrorCode();
            sDKInstance.onRenderError(errorCode2, WXErrorCode.WX_DEGRAD_ERR_INSTANCE_CREATE_FAILED.getErrorMsg() + " isJSFrameworkInit==" + isJSFrameworkInit() + " reInitCount == 1");
            post(new Runnable() { // from class: com.taobao.weex.bridge.WXBridgeManager.17
                @Override // java.lang.Runnable
                public void run() {
                    WXBridgeManager.this.initFramework("");
                }
            }, instanceId, sDKInstance, "initFrameworkInCreateInstance");
        } else {
            WXModuleManager.createDomModule(sDKInstance);
            sDKInstance.getApmForInstance().onStage(WXInstanceApm.KEY_PAGE_STAGES_LOAD_BUNDLE_START);
            post(new Runnable() { // from class: com.taobao.weex.bridge.WXBridgeManager.18
                @Override // java.lang.Runnable
                public void run() {
                    long currentTimeMillis = System.currentTimeMillis();
                    WXBridgeManager.this.mWXBridge.setPageArgument(instanceId, "renderTimeOrigin", String.valueOf(sDKInstance.getWXPerformance().renderTimeOrigin));
                    WXBridgeManager.this.mWXBridge.setInstanceRenderType(sDKInstance.getInstanceId(), sDKInstance.getRenderType());
                    WXBridgeManager.this.invokeCreateInstance(sDKInstance, template, options, data);
                    sDKInstance.getWXPerformance().callCreateInstanceTime = System.currentTimeMillis() - currentTimeMillis;
                    sDKInstance.getWXPerformance().communicateTime = sDKInstance.getWXPerformance().callCreateInstanceTime;
                }
            }, instanceId, sDKInstance, METHOD_CREATE_INSTANCE);
        }
    }

    /* JADX INFO: Access modifiers changed from: private */
    /* JADX WARN: Removed duplicated region for block: B:53:0x010e A[Catch: all -> 0x02c9, TryCatch #2 {all -> 0x02c9, blocks: (B:15:0x0048, B:51:0x00f3, B:53:0x010e, B:55:0x0114, B:57:0x011d, B:62:0x012a, B:66:0x0138, B:70:0x0148, B:72:0x014f, B:75:0x0158, B:85:0x018a, B:87:0x0192, B:94:0x01cb, B:97:0x01f5, B:99:0x0227, B:101:0x022b, B:103:0x022f, B:105:0x0237, B:107:0x023f, B:110:0x0248, B:112:0x025d, B:114:0x0277, B:88:0x019e, B:90:0x01a6, B:91:0x01b8, B:93:0x01c0, B:76:0x015e, B:78:0x0162, B:80:0x0168, B:81:0x016e, B:83:0x0176, B:84:0x0183, B:65:0x0134, B:61:0x0126, B:50:0x00ec, B:16:0x004a, B:18:0x0060), top: B:121:0x0048 }] */
    /* JADX WARN: Removed duplicated region for block: B:60:0x0124  */
    /* JADX WARN: Removed duplicated region for block: B:61:0x0126 A[Catch: all -> 0x02c9, TRY_ENTER, TryCatch #2 {all -> 0x02c9, blocks: (B:15:0x0048, B:51:0x00f3, B:53:0x010e, B:55:0x0114, B:57:0x011d, B:62:0x012a, B:66:0x0138, B:70:0x0148, B:72:0x014f, B:75:0x0158, B:85:0x018a, B:87:0x0192, B:94:0x01cb, B:97:0x01f5, B:99:0x0227, B:101:0x022b, B:103:0x022f, B:105:0x0237, B:107:0x023f, B:110:0x0248, B:112:0x025d, B:114:0x0277, B:88:0x019e, B:90:0x01a6, B:91:0x01b8, B:93:0x01c0, B:76:0x015e, B:78:0x0162, B:80:0x0168, B:81:0x016e, B:83:0x0176, B:84:0x0183, B:65:0x0134, B:61:0x0126, B:50:0x00ec, B:16:0x004a, B:18:0x0060), top: B:121:0x0048 }] */
    /* JADX WARN: Removed duplicated region for block: B:64:0x0132  */
    /* JADX WARN: Removed duplicated region for block: B:65:0x0134 A[Catch: all -> 0x02c9, TryCatch #2 {all -> 0x02c9, blocks: (B:15:0x0048, B:51:0x00f3, B:53:0x010e, B:55:0x0114, B:57:0x011d, B:62:0x012a, B:66:0x0138, B:70:0x0148, B:72:0x014f, B:75:0x0158, B:85:0x018a, B:87:0x0192, B:94:0x01cb, B:97:0x01f5, B:99:0x0227, B:101:0x022b, B:103:0x022f, B:105:0x0237, B:107:0x023f, B:110:0x0248, B:112:0x025d, B:114:0x0277, B:88:0x019e, B:90:0x01a6, B:91:0x01b8, B:93:0x01c0, B:76:0x015e, B:78:0x0162, B:80:0x0168, B:81:0x016e, B:83:0x0176, B:84:0x0183, B:65:0x0134, B:61:0x0126, B:50:0x00ec, B:16:0x004a, B:18:0x0060), top: B:121:0x0048 }] */
    /* JADX WARN: Removed duplicated region for block: B:68:0x0145  */
    /* JADX WARN: Removed duplicated region for block: B:69:0x0146  */
    /* JADX WARN: Removed duplicated region for block: B:72:0x014f A[Catch: all -> 0x02c9, TryCatch #2 {all -> 0x02c9, blocks: (B:15:0x0048, B:51:0x00f3, B:53:0x010e, B:55:0x0114, B:57:0x011d, B:62:0x012a, B:66:0x0138, B:70:0x0148, B:72:0x014f, B:75:0x0158, B:85:0x018a, B:87:0x0192, B:94:0x01cb, B:97:0x01f5, B:99:0x0227, B:101:0x022b, B:103:0x022f, B:105:0x0237, B:107:0x023f, B:110:0x0248, B:112:0x025d, B:114:0x0277, B:88:0x019e, B:90:0x01a6, B:91:0x01b8, B:93:0x01c0, B:76:0x015e, B:78:0x0162, B:80:0x0168, B:81:0x016e, B:83:0x0176, B:84:0x0183, B:65:0x0134, B:61:0x0126, B:50:0x00ec, B:16:0x004a, B:18:0x0060), top: B:121:0x0048 }] */
    /* JADX WARN: Removed duplicated region for block: B:78:0x0162 A[Catch: all -> 0x02c9, TryCatch #2 {all -> 0x02c9, blocks: (B:15:0x0048, B:51:0x00f3, B:53:0x010e, B:55:0x0114, B:57:0x011d, B:62:0x012a, B:66:0x0138, B:70:0x0148, B:72:0x014f, B:75:0x0158, B:85:0x018a, B:87:0x0192, B:94:0x01cb, B:97:0x01f5, B:99:0x0227, B:101:0x022b, B:103:0x022f, B:105:0x0237, B:107:0x023f, B:110:0x0248, B:112:0x025d, B:114:0x0277, B:88:0x019e, B:90:0x01a6, B:91:0x01b8, B:93:0x01c0, B:76:0x015e, B:78:0x0162, B:80:0x0168, B:81:0x016e, B:83:0x0176, B:84:0x0183, B:65:0x0134, B:61:0x0126, B:50:0x00ec, B:16:0x004a, B:18:0x0060), top: B:121:0x0048 }] */
    /* JADX WARN: Removed duplicated region for block: B:87:0x0192 A[Catch: all -> 0x02c9, TryCatch #2 {all -> 0x02c9, blocks: (B:15:0x0048, B:51:0x00f3, B:53:0x010e, B:55:0x0114, B:57:0x011d, B:62:0x012a, B:66:0x0138, B:70:0x0148, B:72:0x014f, B:75:0x0158, B:85:0x018a, B:87:0x0192, B:94:0x01cb, B:97:0x01f5, B:99:0x0227, B:101:0x022b, B:103:0x022f, B:105:0x0237, B:107:0x023f, B:110:0x0248, B:112:0x025d, B:114:0x0277, B:88:0x019e, B:90:0x01a6, B:91:0x01b8, B:93:0x01c0, B:76:0x015e, B:78:0x0162, B:80:0x0168, B:81:0x016e, B:83:0x0176, B:84:0x0183, B:65:0x0134, B:61:0x0126, B:50:0x00ec, B:16:0x004a, B:18:0x0060), top: B:121:0x0048 }] */
    /* JADX WARN: Removed duplicated region for block: B:88:0x019e A[Catch: all -> 0x02c9, TryCatch #2 {all -> 0x02c9, blocks: (B:15:0x0048, B:51:0x00f3, B:53:0x010e, B:55:0x0114, B:57:0x011d, B:62:0x012a, B:66:0x0138, B:70:0x0148, B:72:0x014f, B:75:0x0158, B:85:0x018a, B:87:0x0192, B:94:0x01cb, B:97:0x01f5, B:99:0x0227, B:101:0x022b, B:103:0x022f, B:105:0x0237, B:107:0x023f, B:110:0x0248, B:112:0x025d, B:114:0x0277, B:88:0x019e, B:90:0x01a6, B:91:0x01b8, B:93:0x01c0, B:76:0x015e, B:78:0x0162, B:80:0x0168, B:81:0x016e, B:83:0x0176, B:84:0x0183, B:65:0x0134, B:61:0x0126, B:50:0x00ec, B:16:0x004a, B:18:0x0060), top: B:121:0x0048 }] */
    /* JADX WARN: Removed duplicated region for block: B:97:0x01f5 A[Catch: all -> 0x02c9, TRY_ENTER, TryCatch #2 {all -> 0x02c9, blocks: (B:15:0x0048, B:51:0x00f3, B:53:0x010e, B:55:0x0114, B:57:0x011d, B:62:0x012a, B:66:0x0138, B:70:0x0148, B:72:0x014f, B:75:0x0158, B:85:0x018a, B:87:0x0192, B:94:0x01cb, B:97:0x01f5, B:99:0x0227, B:101:0x022b, B:103:0x022f, B:105:0x0237, B:107:0x023f, B:110:0x0248, B:112:0x025d, B:114:0x0277, B:88:0x019e, B:90:0x01a6, B:91:0x01b8, B:93:0x01c0, B:76:0x015e, B:78:0x0162, B:80:0x0168, B:81:0x016e, B:83:0x0176, B:84:0x0183, B:65:0x0134, B:61:0x0126, B:50:0x00ec, B:16:0x004a, B:18:0x0060), top: B:121:0x0048 }] */
    /* JADX WARN: Removed duplicated region for block: B:99:0x0227 A[Catch: all -> 0x02c9, TryCatch #2 {all -> 0x02c9, blocks: (B:15:0x0048, B:51:0x00f3, B:53:0x010e, B:55:0x0114, B:57:0x011d, B:62:0x012a, B:66:0x0138, B:70:0x0148, B:72:0x014f, B:75:0x0158, B:85:0x018a, B:87:0x0192, B:94:0x01cb, B:97:0x01f5, B:99:0x0227, B:101:0x022b, B:103:0x022f, B:105:0x0237, B:107:0x023f, B:110:0x0248, B:112:0x025d, B:114:0x0277, B:88:0x019e, B:90:0x01a6, B:91:0x01b8, B:93:0x01c0, B:76:0x015e, B:78:0x0162, B:80:0x0168, B:81:0x016e, B:83:0x0176, B:84:0x0183, B:65:0x0134, B:61:0x0126, B:50:0x00ec, B:16:0x004a, B:18:0x0060), top: B:121:0x0048 }] */
    /*
        Code decompiled incorrectly, please refer to instructions dump.
    */
    public void invokeCreateInstance(WXSDKInstance instance, Script template, Map<String, Object> options, String data) {
        HashMap hashMap;
        Object obj;
        WXJSObject wXJSObject;
        if (!isSkipFrameworkInit(instance)) {
            initFramework("");
        }
        if (this.mMock) {
            mock(instance.getInstanceId());
        } else if (!isSkipFrameworkInit(instance) && !isJSFrameworkInit()) {
            instance.onRenderError(WXErrorCode.WX_DEGRAD_ERR_INSTANCE_CREATE_FAILED.getErrorCode(), WXErrorCode.WX_DEGRAD_ERR_INSTANCE_CREATE_FAILED.getErrorMsg());
            WXLogUtils.e("[WXBridgeManager] invokeCreateInstance: framework.js uninitialized.");
        } else {
            WXModuleManager.registerWhenCreateInstance();
            try {
                BundType bundType = BundType.Others;
                long currentTimeMillis = System.currentTimeMillis();
                BundType bundleType = getBundleType(instance.getBundleUrl(), template.getContent());
                if (WXEnvironment.isOpenDebugLog()) {
                    long currentTimeMillis2 = System.currentTimeMillis();
                    WXLogUtils.e("end getBundleType type:" + bundleType.toString() + " time:" + (currentTimeMillis2 - currentTimeMillis));
                }
                if (options == null) {
                    try {
                        hashMap = new HashMap();
                    } catch (Throwable th) {
                        th = th;
                        hashMap = options;
                        WXLogUtils.e(WXLogUtils.getStackTrace(th));
                        instance.bundleType = bundleType;
                        WXEnvironment.isApkDebugable();
                        WXJSObject wXJSObject2 = new WXJSObject(2, instance.getInstanceId());
                        WXJSObject wXJSObject3 = new WXJSObject(2, template.getContent());
                        WXJSObject wXJSObject4 = null;
                        if (hashMap == null) {
                        }
                        obj = null;
                        String str = "{}";
                        WXJSObject wXJSObject5 = new WXJSObject(3, obj == null ? "{}" : WXJsonUtils.fromObjectToJSONString(obj));
                        WXJSObject optionObjConvert = optionObjConvert(isSandBoxContext, bundleType, new WXJSObject(3, hashMap == null ? "{}" : WXJsonUtils.fromObjectToJSONString(hashMap)));
                        if (data != null) {
                        }
                        WXJSObject wXJSObject6 = new WXJSObject(3, str);
                        if (bundleType != BundType.Rax) {
                            wXJSObject = new WXJSObject(2, "");
                            if (instance.getRenderStrategy() == WXRenderStrategy.DATA_RENDER) {
                            }
                            WXJSObject[] wXJSObjectArr = {wXJSObject2, wXJSObject3, optionObjConvert, wXJSObject6, wXJSObject, wXJSObject4, wXJSObject5};
                            instance.setTemplate(template.getContent());
                            instance.getApmForInstance().onStage(WXInstanceApm.KEY_PAGE_STAGES_LOAD_BUNDLE_END);
                            if (!isSandBoxContext) {
                            }
                        }
                        if (mRaxApi == null) {
                        }
                        wXJSObject = new WXJSObject(2, mRaxApi);
                        if (instance.getRenderStrategy() == WXRenderStrategy.DATA_RENDER) {
                        }
                        WXJSObject[] wXJSObjectArr2 = {wXJSObject2, wXJSObject3, optionObjConvert, wXJSObject6, wXJSObject, wXJSObject4, wXJSObject5};
                        instance.setTemplate(template.getContent());
                        instance.getApmForInstance().onStage(WXInstanceApm.KEY_PAGE_STAGES_LOAD_BUNDLE_END);
                        if (!isSandBoxContext) {
                        }
                    }
                } else {
                    hashMap = options;
                }
                try {
                    if (hashMap.get(BUNDLE_TYPE) == null) {
                        if (bundleType == BundType.Vue) {
                            hashMap.put(BUNDLE_TYPE, "Vue");
                        } else if (bundleType == BundType.Rax) {
                            hashMap.put(BUNDLE_TYPE, "Rax");
                        } else {
                            hashMap.put(BUNDLE_TYPE, "Others");
                        }
                        Object obj2 = hashMap.get(BUNDLE_TYPE);
                        if ((obj2 instanceof String) && "Others".equalsIgnoreCase((String) obj2)) {
                            obj2 = "other";
                        }
                        if (obj2 != null) {
                            instance.getApmForInstance().addProperty(WXInstanceApm.KEY_PAGE_PROPERTIES_BUNDLE_TYPE, obj2);
                        }
                    }
                    if (hashMap.get("env") == null) {
                        hashMap.put("env", this.mInitParams.toMap());
                    }
                } catch (Throwable th2) {
                    th = th2;
                    WXLogUtils.e(WXLogUtils.getStackTrace(th));
                    instance.bundleType = bundleType;
                    WXEnvironment.isApkDebugable();
                    WXJSObject wXJSObject22 = new WXJSObject(2, instance.getInstanceId());
                    WXJSObject wXJSObject32 = new WXJSObject(2, template.getContent());
                    WXJSObject wXJSObject42 = null;
                    if (hashMap == null) {
                    }
                    obj = null;
                    String str2 = "{}";
                    WXJSObject wXJSObject52 = new WXJSObject(3, obj == null ? "{}" : WXJsonUtils.fromObjectToJSONString(obj));
                    WXJSObject optionObjConvert2 = optionObjConvert(isSandBoxContext, bundleType, new WXJSObject(3, hashMap == null ? "{}" : WXJsonUtils.fromObjectToJSONString(hashMap)));
                    if (data != null) {
                    }
                    WXJSObject wXJSObject62 = new WXJSObject(3, str2);
                    if (bundleType != BundType.Rax) {
                    }
                    if (mRaxApi == null) {
                    }
                    wXJSObject = new WXJSObject(2, mRaxApi);
                    if (instance.getRenderStrategy() == WXRenderStrategy.DATA_RENDER) {
                    }
                    WXJSObject[] wXJSObjectArr22 = {wXJSObject22, wXJSObject32, optionObjConvert2, wXJSObject62, wXJSObject, wXJSObject42, wXJSObject52};
                    instance.setTemplate(template.getContent());
                    instance.getApmForInstance().onStage(WXInstanceApm.KEY_PAGE_STAGES_LOAD_BUNDLE_END);
                    if (!isSandBoxContext) {
                    }
                }
                instance.bundleType = bundleType;
                WXEnvironment.isApkDebugable();
                WXJSObject wXJSObject222 = new WXJSObject(2, instance.getInstanceId());
                WXJSObject wXJSObject322 = new WXJSObject(2, template.getContent());
                WXJSObject wXJSObject422 = null;
                if (hashMap == null && hashMap.containsKey("extraOption")) {
                    obj = hashMap.get("extraOption");
                    hashMap.remove("extraOption");
                } else {
                    obj = null;
                }
                String str22 = "{}";
                WXJSObject wXJSObject522 = new WXJSObject(3, obj == null ? "{}" : WXJsonUtils.fromObjectToJSONString(obj));
                WXJSObject optionObjConvert22 = optionObjConvert(isSandBoxContext, bundleType, new WXJSObject(3, hashMap == null ? "{}" : WXJsonUtils.fromObjectToJSONString(hashMap)));
                if (data != null) {
                    str22 = data;
                }
                WXJSObject wXJSObject622 = new WXJSObject(3, str22);
                if (bundleType != BundType.Rax && instance.getRenderStrategy() != WXRenderStrategy.DATA_RENDER) {
                    wXJSObject = new WXJSObject(2, "");
                    if (instance.getRenderStrategy() == WXRenderStrategy.DATA_RENDER) {
                        wXJSObject422 = new WXJSObject(2, WXRenderStrategy.DATA_RENDER.getFlag());
                    } else if (instance.getRenderStrategy() == WXRenderStrategy.DATA_RENDER_BINARY) {
                        wXJSObject422 = new WXJSObject(2, WXRenderStrategy.DATA_RENDER_BINARY.getFlag());
                        wXJSObject322.data = template.getBinary();
                    } else if (instance.getRenderStrategy() == WXRenderStrategy.JSON_RENDER) {
                        wXJSObject422 = new WXJSObject(2, WXRenderStrategy.JSON_RENDER.getFlag());
                    }
                    WXJSObject[] wXJSObjectArr222 = {wXJSObject222, wXJSObject322, optionObjConvert22, wXJSObject622, wXJSObject, wXJSObject422, wXJSObject522};
                    instance.setTemplate(template.getContent());
                    instance.getApmForInstance().onStage(WXInstanceApm.KEY_PAGE_STAGES_LOAD_BUNDLE_END);
                    if (!isSandBoxContext) {
                        instance.getApmForInstance().onStage("!isSandBoxContext,and excute");
                        WXLogUtils.e("Instance " + instance.getInstanceId() + " Did Not Render in SandBox Mode");
                        invokeExecJS(instance.getInstanceId(), null, METHOD_CREATE_INSTANCE, wXJSObjectArr222, false);
                        return;
                    }
                    if (bundleType != BundType.Vue && bundleType != BundType.Rax && instance.getRenderStrategy() != WXRenderStrategy.DATA_RENDER && instance.getRenderStrategy() != WXRenderStrategy.DATA_RENDER_BINARY && instance.getRenderStrategy() != WXRenderStrategy.JSON_RENDER) {
                        invokeExecJS(instance.getInstanceId(), null, METHOD_CREATE_INSTANCE, wXJSObjectArr222, false);
                        instance.getApmForInstance().onStage(WXInstanceApm.KEY_PAGE_STAGES_LOAD_BUNDLE_END);
                        return;
                    }
                    int invokeCreateInstanceContext = invokeCreateInstanceContext(instance.getInstanceId(), instance.getUniPagePath(), METHOD_CREATE_INSTANCE_CONTEXT, wXJSObjectArr222, false);
                    instance.getApmForInstance().onStage(WXInstanceApm.KEY_PAGE_STAGES_LOAD_BUNDLE_END);
                    if (invokeCreateInstanceContext == 0) {
                        String str3 = "[WXBridgeManager] invokeCreateInstance : " + instance.getTemplateInfo();
                        WXLogUtils.e("Instance " + instance.getInstanceId() + "Render error : " + str3);
                        String errorCode = WXErrorCode.WX_DEGRAD_ERR_INSTANCE_CREATE_FAILED.getErrorCode();
                        StringBuilder sb = new StringBuilder();
                        sb.append(WXErrorCode.WX_DEGRAD_ERR_INSTANCE_CREATE_FAILED.getErrorMsg());
                        sb.append(str3);
                        instance.onRenderError(errorCode, sb.toString());
                        return;
                    }
                    return;
                }
                if (mRaxApi == null) {
                    IWXJsFileLoaderAdapter iWXJsFileLoaderAdapter = WXSDKEngine.getIWXJsFileLoaderAdapter();
                    if (iWXJsFileLoaderAdapter != null) {
                        mRaxApi = iWXJsFileLoaderAdapter.loadRaxApi();
                    }
                    if (TextUtils.isEmpty(mRaxApi)) {
                        mRaxApi = WXFileUtils.loadAsset("weex-rax-api.js", WXEnvironment.getApplication());
                    }
                }
                wXJSObject = new WXJSObject(2, mRaxApi);
                if (instance.getRenderStrategy() == WXRenderStrategy.DATA_RENDER) {
                }
                WXJSObject[] wXJSObjectArr2222 = {wXJSObject222, wXJSObject322, optionObjConvert22, wXJSObject622, wXJSObject, wXJSObject422, wXJSObject522};
                instance.setTemplate(template.getContent());
                instance.getApmForInstance().onStage(WXInstanceApm.KEY_PAGE_STAGES_LOAD_BUNDLE_END);
                if (!isSandBoxContext) {
                }
            } catch (Throwable th3) {
                String str4 = "[WXBridgeManager] invokeCreateInstance " + th3.getCause() + instance.getTemplateInfo();
                instance.onRenderError(WXErrorCode.WX_DEGRAD_ERR_INSTANCE_CREATE_FAILED.getErrorCode(), WXErrorCode.WX_DEGRAD_ERR_INSTANCE_CREATE_FAILED.getErrorMsg() + str4);
                WXLogUtils.e(str4);
            }
        }
    }

    public WXJSObject optionObjConvert(boolean useSandBox, BundType type, WXJSObject opt) {
        JSONObject jSONObject;
        if (useSandBox) {
            try {
                JSONObject parseObject = JSON.parseObject(opt.data.toString());
                JSONObject jSONObject2 = parseObject.getJSONObject("env");
                if (jSONObject2 != null && (jSONObject = jSONObject2.getJSONObject("options")) != null) {
                    for (String str : jSONObject.keySet()) {
                        jSONObject2.put(str, (Object) jSONObject.getString(str));
                    }
                }
                return new WXJSObject(3, parseObject.toString());
            } catch (Throwable th) {
                WXLogUtils.e(WXLogUtils.getStackTrace(th));
                return opt;
            }
        }
        return opt;
    }

    public BundType getBundleType(String url, String temp) {
        if (url != null) {
            try {
                String queryParameter = Uri.parse(url).getQueryParameter(BUNDLE_TYPE);
                if (!"Vue".equals(queryParameter) && !"vue".equals(queryParameter)) {
                    if ("Rax".equals(queryParameter) || "rax".equals(queryParameter)) {
                        return BundType.Rax;
                    }
                }
                return BundType.Vue;
            } catch (Throwable th) {
                WXLogUtils.e(WXLogUtils.getStackTrace(th));
                return BundType.Others;
            }
        }
        if (temp != null) {
            return BundType.Vue;
        }
        return BundType.Others;
    }

    public void destroyInstance(final String instanceId) {
        if (this.mJSHandler == null || TextUtils.isEmpty(instanceId)) {
            return;
        }
        HashSet<String> hashSet = this.mDestroyedInstanceId;
        if (hashSet != null) {
            hashSet.add(instanceId);
        }
        this.mJSHandler.removeCallbacksAndMessages(instanceId);
        post(new Runnable() { // from class: com.taobao.weex.bridge.WXBridgeManager.19
            @Override // java.lang.Runnable
            public void run() {
                WXBridgeManager.this.removeTaskByInstance(instanceId);
                WXBridgeManager.this.invokeDestroyInstance(instanceId);
            }
        }, instanceId, null, METHOD_DESTROY_INSTANCE);
    }

    /* JADX INFO: Access modifiers changed from: private */
    public void removeTaskByInstance(String instanceId) {
        this.mNextTickTasks.removeFromMapAndStack(instanceId);
    }

    /* JADX INFO: Access modifiers changed from: private */
    public void invokeDestroyInstance(String instanceId) {
        try {
            WXEnvironment.isApkDebugable();
            WXJSObject[] wXJSObjectArr = {new WXJSObject(2, instanceId)};
            if (isSkipFrameworkInit(instanceId) || isJSFrameworkInit()) {
                invokeDestoryInstance(instanceId, null, METHOD_DESTROY_INSTANCE, wXJSObjectArr, true);
            }
        } catch (Throwable th) {
            String str = "[WXBridgeManager] invokeDestroyInstance " + th.getCause();
            WXExceptionUtils.commitCriticalExceptionRT(instanceId, WXErrorCode.WX_KEY_EXCEPTION_INVOKE_BRIDGE, "invokeDestroyInstance", str, null);
            WXLogUtils.e(str);
        }
    }

    @Override // android.os.Handler.Callback
    public boolean handleMessage(Message msg) {
        if (msg == null) {
            return false;
        }
        int i = msg.what;
        if (i == 1) {
            TimerInfo timerInfo = (TimerInfo) msg.obj;
            if (timerInfo != null) {
                invokeExecJS("", null, METHOD_SET_TIMEOUT, new WXJSObject[]{new WXJSObject(2, timerInfo.callbackId)});
            }
        } else if (i != 13) {
            if (i == 6) {
                invokeCallJSBatch(msg);
            } else if (i == 7) {
                invokeInitFramework(msg);
            }
        } else if (msg.obj != null) {
            this.mWXBridge.takeHeapSnapshot((String) msg.obj);
        }
        return false;
    }

    /* JADX INFO: Access modifiers changed from: private */
    public void invokeExecJS(String instanceId, String namespace, String function, WXJSObject[] args) {
        invokeExecJS(instanceId, namespace, function, args, true);
    }

    public void invokeExecJS(final String instanceId, final String namespace, final String function, final WXJSObject[] args, boolean logTaskDetail) {
        Pair<Pair<String, Object>, Boolean> extractCallbackArgs;
        WXEnvironment.isOpenDebugLog();
        if (RuningAcitvityUtil.isRuningActivity) {
            long currentTimeMillis = System.currentTimeMillis();
            WXSDKInstance sDKInstance = WXSDKManager.getInstance().getSDKInstance(instanceId);
            if (sDKInstance != null && sDKInstance.getRenderStrategy() == WXRenderStrategy.DATA_RENDER_BINARY) {
                if (args.length != 2 || !(args[0].data instanceof String) || !(args[1].data instanceof String) || (extractCallbackArgs = extractCallbackArgs((String) args[1].data)) == null) {
                    WXLogUtils.w("invokeExecJS on data render that is not a callback call");
                    return;
                }
                callbackJavascriptOnDataRender(instanceId, (String) ((Pair) extractCallbackArgs.first).first, ((Pair) extractCallbackArgs.first).second, ((Boolean) extractCallbackArgs.second).booleanValue());
            } else {
                WXThread.secure(new Runnable() { // from class: com.taobao.weex.bridge.WXBridgeManager.20
                    @Override // java.lang.Runnable
                    public void run() {
                        WXBridgeManager.this.mWXBridge.execJS(instanceId, namespace, function, args);
                    }
                }, sDKInstance, "ExecJs").run();
            }
            if (sDKInstance != null) {
                long currentTimeMillis2 = System.currentTimeMillis() - currentTimeMillis;
                sDKInstance.getApmForInstance().updateFSDiffStats(WXInstanceApm.KEY_PAGE_STATS_FS_CALL_JS_NUM, 1.0d);
                sDKInstance.getApmForInstance().updateFSDiffStats(WXInstanceApm.KEY_PAGE_STATS_FS_CALL_JS_TIME, currentTimeMillis2);
                sDKInstance.callJsTime(currentTimeMillis2);
            }
        }
    }

    private Pair<Pair<String, Object>, Boolean> extractCallbackArgs(String data) {
        try {
            JSONObject jSONObject = JSON.parseArray(data).getJSONObject(0);
            JSONArray jSONArray = jSONObject.getJSONArray("args");
            if (jSONArray.size() == 3 && METHOD_CALLBACK.equals(jSONObject.getString("method"))) {
                return new Pair<>(new Pair(jSONArray.getString(0), jSONArray.getJSONObject(1)), Boolean.valueOf(jSONArray.getBooleanValue(2)));
            }
            return null;
        } catch (Exception unused) {
            return null;
        }
    }

    public int invokeCreateInstanceContext(String instanceId, String namespace, String function, WXJSObject[] args, boolean logTaskDetail) {
        WXLogUtils.d("invokeCreateInstanceContext instanceId:" + instanceId + " function:" + function + StringUtil.format(" isJSFrameworkInit：%b", Boolean.valueOf(isJSFrameworkInit())));
        StringBuilder sb = this.mLodBuilder;
        sb.append("createInstanceContext >>>> instanceId:");
        sb.append(instanceId);
        sb.append("function:");
        sb.append(function);
        if (logTaskDetail) {
            StringBuilder sb2 = this.mLodBuilder;
            sb2.append(" tasks:");
            sb2.append(WXJsonUtils.fromObjectToJSONString(args));
        }
        WXLogUtils.d(this.mLodBuilder.substring(0));
        this.mLodBuilder.setLength(0);
        return this.mWXBridge.createInstanceContext(instanceId, namespace, function, args);
    }

    public void invokeDestoryInstance(String instanceId, String namespace, String function, WXJSObject[] args, boolean logTaskDetail) {
        StringBuilder sb = this.mLodBuilder;
        sb.append("callJS >>>> instanceId:");
        sb.append(instanceId);
        sb.append("function:");
        sb.append(function);
        if (logTaskDetail) {
            StringBuilder sb2 = this.mLodBuilder;
            sb2.append(" tasks:");
            sb2.append(WXJsonUtils.fromObjectToJSONString(args));
        }
        WXLogUtils.d(this.mLodBuilder.substring(0));
        this.mLodBuilder.setLength(0);
        this.mWXBridge.removeInstanceRenderType(instanceId);
        this.mWXBridge.destoryInstance(instanceId, namespace, function, args);
    }

    private void execJSOnInstance(final EventResult eventCallback, final String instanceId, final String js, final int type) {
        post(new Runnable() { // from class: com.taobao.weex.bridge.WXBridgeManager.21
            @Override // java.lang.Runnable
            public void run() {
                eventCallback.onCallback(WXBridgeManager.this.invokeExecJSOnInstance(instanceId, js, type));
            }
        });
    }

    /* JADX INFO: Access modifiers changed from: private */
    public String invokeExecJSOnInstance(String instanceId, String js, int type) {
        StringBuilder sb = this.mLodBuilder;
        sb.append("execJSOnInstance >>>> instanceId:");
        sb.append(instanceId);
        WXLogUtils.d(this.mLodBuilder.substring(0));
        this.mLodBuilder.setLength(0);
        if (isSkipFrameworkInit(instanceId) || isJSFrameworkInit()) {
            return this.mWXBridge.execJSOnInstance(instanceId, js, type);
        }
        return null;
    }

    /* JADX INFO: Access modifiers changed from: private */
    public void invokeExecJSWithCallback(String instanceId, String namespace, String function, WXJSObject[] args, ResultCallback callback, boolean logTaskDetail) {
        WXEnvironment.isOpenDebugLog();
        if (isSkipFrameworkInit(instanceId) || isJSFrameworkInit()) {
            this.mWXBridge.execJSWithCallback(instanceId, namespace, function, args, callback);
        }
    }

    public static String argsToJSON(WXJSObject[] args) {
        StringBuilder sb = new StringBuilder();
        sb.append(Operators.ARRAY_START_STR);
        for (WXJSObject wXJSObject : args) {
            sb.append(WXWsonJSONSwitch.fromObjectToJSONString(wXJSObject));
            sb.append(",");
        }
        sb.append(Operators.ARRAY_END_STR);
        return sb.toString();
    }

    private void invokeInitFramework(Message msg) {
        String str = msg.obj != null ? (String) msg.obj : "";
        if (WXUtils.getAvailMemory(WXEnvironment.getApplication()) > LOW_MEM_VALUE) {
            initFramework(str);
        }
    }

    /* JADX INFO: Access modifiers changed from: private */
    /* JADX WARN: Code restructure failed: missing block: B:42:0x0123, code lost:
        if (android.os.Build.VERSION.SDK_INT < 16) goto L46;
     */
    /*
        Code decompiled incorrectly, please refer to instructions dump.
    */
    public void initFramework(String framework) {
        boolean z;
        long currentTimeMillis;
        String path;
        LogDetail logDetail = new LogDetail();
        logDetail.name(IWXUserTrackAdapter.INIT_FRAMEWORK);
        logDetail.taskStart();
        if (!WXSDKEngine.isSoInitialized() || isJSFrameworkInit()) {
            return;
        }
        sInitFrameWorkTimeOrigin = System.currentTimeMillis();
        if (TextUtils.isEmpty(framework)) {
            WXLogUtils.d("weex JS framework from assets");
            LogDetail logDetail2 = new LogDetail();
            logDetail2.name("loadJSFramework");
            logDetail2.taskStart();
            IWXJsFileLoaderAdapter iWXJsFileLoaderAdapter = WXSDKEngine.getIWXJsFileLoaderAdapter();
            if (!isSandBoxContext) {
                if (iWXJsFileLoaderAdapter != null) {
                    framework = iWXJsFileLoaderAdapter.loadJsFramework();
                }
                if (TextUtils.isEmpty(framework)) {
                    framework = WXFileUtils.loadAsset("main.js", WXEnvironment.getApplication());
                }
            } else {
                if (iWXJsFileLoaderAdapter != null) {
                    framework = iWXJsFileLoaderAdapter.loadJsFrameworkForSandBox();
                }
                if (TextUtils.isEmpty(framework)) {
                    framework = WXFileUtils.loadAsset("weex-main-jsfm.js", WXEnvironment.getApplication());
                }
            }
            StringBuilder sb = sInitFrameWorkMsg;
            sb.append("| weex JS framework from assets, isSandBoxContext: ");
            sb.append(isSandBoxContext);
            logDetail2.taskEnd();
            WXDotDataUtil.setValue(logDetail2.info.taskName, Long.valueOf(logDetail2.time.execTime));
        }
        WXDotDataUtil.setValue("jsEngine", Constants.CodeCache.SAVE_PATH);
        z = false;
        if (TextUtils.isEmpty(framework)) {
            setJSFrameworkInit(false);
            sInitFrameWorkMsg.append("| framework isEmpty ");
            WXExceptionUtils.commitCriticalExceptionRT(null, WXErrorCode.WX_ERR_JS_FRAMEWORK, IWXUserTrackAdapter.INIT_FRAMEWORK, "framework is empty!! ", null);
            return;
        }
        try {
            if (WXSDKManager.getInstance().getWXStatisticsListener() != null) {
                long currentTimeMillis2 = System.currentTimeMillis();
                WXSDKManager.getInstance().getWXStatisticsListener().onJsFrameworkStart();
                WXEnvironment.sJSFMStartListenerTime = System.currentTimeMillis() - currentTimeMillis2;
                try {
                    IWXUserTrackAdapter iWXUserTrackAdapter = WXSDKManager.getInstance().getIWXUserTrackAdapter();
                    if (iWXUserTrackAdapter != null) {
                        HashMap hashMap = new HashMap(1);
                        hashMap.put(Constants.Value.TIME, String.valueOf(WXEnvironment.sJSFMStartListenerTime));
                        iWXUserTrackAdapter.commit(WXEnvironment.getApplication(), "sJSFMStartListener", IWXUserTrackAdapter.COUNTER, null, hashMap);
                    }
                } catch (Exception e) {
                    WXLogUtils.e(WXLogUtils.getStackTrace(e));
                }
            }
            currentTimeMillis = System.currentTimeMillis();
            try {
                path = WXEnvironment.getApplication().getApplicationContext().getCacheDir().getPath();
            } catch (Exception e2) {
                WXLogUtils.e(WXLogUtils.getStackTrace(e2));
            }
            try {
            } catch (Exception e3) {
                WXLogUtils.e(WXLogUtils.getStackTrace(e3));
            }
        } catch (Throwable th) {
            StringBuilder sb2 = sInitFrameWorkMsg;
            sb2.append(" | invokeInitFramework exception ");
            sb2.append(th.toString());
            if (reInitCount > 1) {
                WXLogUtils.e("[WXBridgeManager] invokeInitFramework ", th);
                return;
            } else {
                WXLogUtils.e("[WXBridgeManager] invokeInitFramework ", th);
                return;
            }
        }
        z = true;
        StringBuilder sb3 = sInitFrameWorkMsg;
        sb3.append(" | pieSupport:");
        sb3.append(z);
        WXLogUtils.d("[WXBridgeManager] initFrameworkEnv crashFile:" + path + " pieSupport:" + z);
        LogDetail logDetail3 = new LogDetail();
        logDetail3.name("native initFrameworkEnv");
        logDetail3.taskStart();
        if (this.mWXBridge.initFrameworkEnv(framework, assembleDefaultOptions(), path, z) == 1) {
            logDetail3.taskEnd();
            WXDotDataUtil.setValue(logDetail3.info.taskName, Long.valueOf(logDetail3.time.execTime));
            WXEnvironment.sJSLibInitTime = System.currentTimeMillis() - currentTimeMillis;
            WXEnvironment.sSDKInitTime = System.currentTimeMillis() - WXEnvironment.sSDKInitStart;
            setJSFrameworkInit(true);
            logDetail.taskEnd();
            WXDotDataUtil.setValue(logDetail.info.taskName, Long.valueOf(logDetail.time.execTime));
            if (WXSDKManager.getInstance().getWXStatisticsListener() != null) {
                WXSDKManager.getInstance().getWXStatisticsListener().onJsFrameworkReady();
            }
            execRegisterFailTask();
            WXEnvironment.JsFrameworkInit = true;
            registerDomModule();
            trackComponentAndModulesTime();
            return;
        }
        StringBuilder sb4 = sInitFrameWorkMsg;
        sb4.append(" | ExecuteJavaScript fail, reInitCount");
        sb4.append(reInitCount);
        if (reInitCount > 1) {
            WXLogUtils.e("[WXBridgeManager] invokeReInitFramework  ExecuteJavaScript fail");
        } else {
            WXLogUtils.e("[WXBridgeManager] invokeInitFramework  ExecuteJavaScript fail");
        }
    }

    private void trackComponentAndModulesTime() {
        post(new Runnable() { // from class: com.taobao.weex.bridge.WXBridgeManager.22
            @Override // java.lang.Runnable
            public void run() {
                WXEnvironment.sComponentsAndModulesReadyTime = System.currentTimeMillis() - WXEnvironment.sSDKInitStart;
            }
        });
    }

    private void invokeCallJSBatch(Message message) {
        if (this.mNextTickTasks.isEmpty() || !isJSFrameworkInit()) {
            if (isJSFrameworkInit()) {
                return;
            }
            WXLogUtils.e("[WXBridgeManager] invokeCallJSBatch: framework.js uninitialized!!  message:" + message.toString());
            return;
        }
        try {
            Object obj = message.obj;
            Stack<String> instanceStack = this.mNextTickTasks.getInstanceStack();
            ArrayList<WXHashMap<String, Object>> arrayList = null;
            for (int size = instanceStack.size() - 1; size >= 0; size--) {
                obj = instanceStack.get(size);
                arrayList = this.mNextTickTasks.remove(obj);
                if (arrayList != null && !arrayList.isEmpty()) {
                    break;
                }
            }
            if (arrayList != null) {
                invokeExecJS(String.valueOf(obj), null, METHOD_CALL_JS, new WXJSObject[]{new WXJSObject(2, obj), WXWsonJSONSwitch.toWsonOrJsonWXJSObject(arrayList.toArray())});
            }
        } catch (Throwable th) {
            WXLogUtils.e("WXBridgeManager", th);
            WXExceptionUtils.commitCriticalExceptionRT(null, WXErrorCode.WX_ERR_JS_FRAMEWORK, "invokeCallJSBatch", "invokeCallJSBatch#" + WXLogUtils.getStackTrace(th), null);
        }
        if (this.mNextTickTasks.isEmpty()) {
            return;
        }
        this.mJSHandler.sendEmptyMessage(6);
    }

    private WXParams assembleDefaultOptions() {
        checkJsEngineMultiThread();
        Map<String, String> config = WXEnvironment.getConfig();
        WXParams wXParams = new WXParams();
        wXParams.setPlatform(config.get(WXConfig.os));
        wXParams.setCacheDir(config.get(WXConfig.cacheDir));
        wXParams.setOsVersion(config.get(WXConfig.sysVersion));
        wXParams.setAppVersion(config.get(WXConfig.appVersion));
        wXParams.setWeexVersion(config.get(WXConfig.weexVersion));
        wXParams.setDeviceModel(config.get(WXConfig.sysModel));
        wXParams.setShouldInfoCollect(config.get("infoCollect"));
        wXParams.setLogLevel(config.get(WXConfig.logLevel));
        wXParams.setLayoutDirection(config.get(WXConfig.layoutDirection));
        wXParams.setUseSingleProcess(isUseSingleProcess ? AbsoluteConst.TRUE : AbsoluteConst.FALSE);
        wXParams.setCrashFilePath(WXEnvironment.getCrashFilePath(WXEnvironment.getApplication().getApplicationContext()));
        wXParams.setLibJsbPath(WXEnvironment.CORE_JSB_SO_PATH);
        wXParams.setLibJssPath(WXEnvironment.getLibJssRealPath());
        wXParams.setLibIcuPath(WXEnvironment.getLibJssIcuPath());
        wXParams.setLibLdPath(WXEnvironment.getLibLdPath());
        String libJScRealPath = WXEnvironment.getLibJScRealPath();
        wXParams.setLibJscPath(TextUtils.isEmpty(libJScRealPath) ? "" : new File(libJScRealPath).getParent());
        String str = config.get(WXConfig.appName);
        if (!TextUtils.isEmpty(str)) {
            wXParams.setAppName(str);
        }
        wXParams.setDeviceWidth(TextUtils.isEmpty(config.get(WXConfig.deviceWidth)) ? String.valueOf(WXViewUtils.getScreenWidth(WXEnvironment.sApplication)) : config.get(WXConfig.deviceWidth));
        wXParams.setDeviceHeight(TextUtils.isEmpty(config.get(WXConfig.deviceHeight)) ? String.valueOf(WXViewUtils.getScreenHeight(WXEnvironment.sApplication)) : config.get(WXConfig.deviceHeight));
        Map<String, String> customOptions = WXEnvironment.getCustomOptions();
        customOptions.put("enableBackupThread", String.valueOf(jsEngineMultiThreadEnable()));
        IWXJscProcessManager wXJscProcessManager = WXSDKManager.getInstance().getWXJscProcessManager();
        if (wXJscProcessManager != null) {
            customOptions.put("enableBackupThreadCache", String.valueOf(wXJscProcessManager.enableBackUpThreadCache()));
        }
        if (!WXEnvironment.sUseRunTimeApi) {
            customOptions.put("__enable_native_promise__", AbsoluteConst.TRUE);
        }
        wXParams.setOptions(customOptions);
        wXParams.setNeedInitV8(WXSDKManager.getInstance().needInitV8());
        this.mInitParams = wXParams;
        return wXParams;
    }

    public WXParams getInitParams() {
        return this.mInitParams;
    }

    private void execRegisterFailTask() {
        if (this.mRegisterModuleFailList.size() > 0) {
            ArrayList arrayList = new ArrayList();
            int size = this.mRegisterModuleFailList.size();
            for (int i = 0; i < size; i++) {
                invokeRegisterModules(this.mRegisterModuleFailList.get(i), arrayList);
            }
            this.mRegisterModuleFailList.clear();
            if (arrayList.size() > 0) {
                this.mRegisterModuleFailList.addAll(arrayList);
            }
        }
        if (this.mRegisterComponentFailList.size() > 0) {
            ArrayList arrayList2 = new ArrayList();
            invokeRegisterComponents(this.mRegisterComponentFailList, arrayList2);
            this.mRegisterComponentFailList.clear();
            if (arrayList2.size() > 0) {
                this.mRegisterComponentFailList.addAll(arrayList2);
            }
        }
        if (this.mRegisterServiceFailList.size() > 0) {
            ArrayList arrayList3 = new ArrayList();
            for (String str : this.mRegisterServiceFailList) {
                invokeExecJSService(str, arrayList3);
            }
            this.mRegisterServiceFailList.clear();
            if (arrayList3.size() > 0) {
                this.mRegisterServiceFailList.addAll(arrayList3);
            }
        }
    }

    public void registerModules(final Map<String, Object> modules) {
        if (modules == null || modules.size() == 0) {
            return;
        }
        if (isJSThread()) {
            invokeRegisterModules(modules, this.mRegisterModuleFailList);
        } else {
            post(new Runnable() { // from class: com.taobao.weex.bridge.WXBridgeManager.23
                @Override // java.lang.Runnable
                public void run() {
                    WXBridgeManager wXBridgeManager = WXBridgeManager.this;
                    wXBridgeManager.invokeRegisterModules(modules, wXBridgeManager.mRegisterModuleFailList);
                }
            }, null);
        }
    }

    public void registerComponents(final List<Map<String, Object>> components) {
        if (this.mJSHandler == null || components == null || components.size() == 0) {
            return;
        }
        Runnable runnable = new Runnable() { // from class: com.taobao.weex.bridge.WXBridgeManager.24
            @Override // java.lang.Runnable
            public void run() {
                WXBridgeManager wXBridgeManager = WXBridgeManager.this;
                wXBridgeManager.invokeRegisterComponents(components, wXBridgeManager.mRegisterComponentFailList);
            }
        };
        if (isJSThread() && isJSFrameworkInit()) {
            runnable.run();
        } else {
            post(runnable);
        }
    }

    public void execJSService(final String service) {
        postWithName(new Runnable() { // from class: com.taobao.weex.bridge.WXBridgeManager.25
            @Override // java.lang.Runnable
            public void run() {
                WXBridgeManager wXBridgeManager = WXBridgeManager.this;
                wXBridgeManager.invokeExecJSService(service, wXBridgeManager.mRegisterServiceFailList);
            }
        }, null, "execJSService");
    }

    /* JADX INFO: Access modifiers changed from: private */
    public void invokeExecJSService(String service, List<String> receiver) {
        try {
            if (!isJSFrameworkInit()) {
                WXLogUtils.e("[WXBridgeManager] invoke execJSService: framework.js uninitialized.");
                receiver.add(service);
                return;
            }
            this.mWXBridge.execJSService(service);
        } catch (Throwable th) {
            WXLogUtils.e("[WXBridgeManager] invokeRegisterService:", th);
            HashMap hashMap = new HashMap();
            hashMap.put("inputParams", service + Operators.OR + receiver.toString());
            WXErrorCode wXErrorCode = WXErrorCode.WX_KEY_EXCEPTION_INVOKE_JSSERVICE_EXECUTE;
            WXExceptionUtils.commitCriticalExceptionRT("invokeExecJSService", wXErrorCode, "invokeExecJSService", WXErrorCode.WX_KEY_EXCEPTION_INVOKE_JSSERVICE_EXECUTE.getErrorMsg() + "[WXBridgeManager] invokeRegisterService:" + WXLogUtils.getStackTrace(th), hashMap);
        }
    }

    public boolean isJSThread() {
        WXThread wXThread = this.mJSThread;
        return wXThread != null && wXThread.getId() == Thread.currentThread().getId();
    }

    /* JADX INFO: Access modifiers changed from: private */
    public void invokeRegisterModules(Map<String, Object> modules, List<Map<String, Object>> failReceiver) {
        String str;
        if (modules == null || !isJSFrameworkInit()) {
            if (!isJSFrameworkInit()) {
                WXLogUtils.d("[WXinvokeRegisterModulesBridgeManager] invokeRegisterModules: framework.js uninitialized.");
            }
            failReceiver.add(modules);
            return;
        }
        WXJSObject[] wXJSObjectArr = {WXWsonJSONSwitch.toWsonOrJsonWXJSObject(modules)};
        try {
            IWXBridge iWXBridge = this.mWXBridge;
            if (iWXBridge instanceof WXBridge) {
                ((WXBridge) iWXBridge).registerModuleOnDataRenderNode(WXJsonUtils.fromObjectToJSONString(modules));
            }
        } catch (Throwable th) {
            WXLogUtils.e("Weex [data_render register err]", th);
        }
        try {
            str = this.mWXBridge.execJS("", null, METHOD_REGISTER_MODULES, wXJSObjectArr) == 0 ? "execJS error" : null;
            for (String str2 : modules.keySet()) {
                if (str2 != null) {
                    WXModuleManager.resetModuleState(str2, true);
                }
            }
        } catch (Throwable th2) {
            str = WXErrorCode.WX_KEY_EXCEPTION_INVOKE_REGISTER_MODULES.getErrorMsg() + " \n " + th2.getMessage() + modules.entrySet().toString();
        }
        if (TextUtils.isEmpty(str)) {
            return;
        }
        WXLogUtils.e("[WXBridgeManager] invokeRegisterModules:", str);
        WXExceptionUtils.commitCriticalExceptionRT(null, WXErrorCode.WX_KEY_EXCEPTION_INVOKE_REGISTER_MODULES, "invokeRegisterModules", str, null);
    }

    /* JADX INFO: Access modifiers changed from: private */
    public void invokeRegisterComponents(List<Map<String, Object>> components, List<Map<String, Object>> failReceiver) {
        WXJSObject[] wXJSObjectArr;
        String str;
        if (components == failReceiver) {
            throw new RuntimeException("Fail receiver should not use source.");
        }
        if (!isJSFrameworkInit()) {
            for (Map<String, Object> map : components) {
                failReceiver.add(map);
            }
        } else if (components != null) {
            try {
                IWXBridge iWXBridge = this.mWXBridge;
                if (iWXBridge instanceof WXBridge) {
                    ((WXBridge) iWXBridge).registerComponentOnDataRenderNode(WXJsonUtils.fromObjectToJSONString(components));
                }
            } catch (Throwable th) {
                WXLogUtils.e("Weex [data_render register err]", th);
            }
            try {
                str = this.mWXBridge.execJS("", null, METHOD_REGISTER_COMPONENTS, new WXJSObject[]{WXWsonJSONSwitch.toWsonOrJsonWXJSObject(components)}) == 0 ? "execJS error" : null;
            } catch (Throwable th2) {
                str = WXErrorCode.WX_KEY_EXCEPTION_INVOKE_REGISTER_COMPONENT + wXJSObjectArr.toString() + WXLogUtils.getStackTrace(th2);
            }
            if (TextUtils.isEmpty(str)) {
                return;
            }
            WXLogUtils.e("[WXBridgeManager] invokeRegisterComponents ", str);
            WXExceptionUtils.commitCriticalExceptionRT(null, WXErrorCode.WX_KEY_EXCEPTION_INVOKE_REGISTER_COMPONENT, METHOD_REGISTER_COMPONENTS, str, null);
        }
    }

    public void destroy() {
        WXThread wXThread = this.mJSThread;
        if (wXThread != null) {
            wXThread.quit();
        }
        mBridgeManager = null;
        HashSet<String> hashSet = this.mDestroyedInstanceId;
        if (hashSet != null) {
            hashSet.clear();
        }
    }

    /* JADX WARN: Code restructure failed: missing block: B:36:0x0070, code lost:
        if (r6 == "app-service.js") goto L30;
     */
    /*
        Code decompiled incorrectly, please refer to instructions dump.
    */
    public void reportJSException(String instanceId, String function, String exception) {
        WXSDKInstance sDKInstance;
        if (function.startsWith("jsscope::")) {
            Context applicationContext = WXEnvironment.getApplication().getApplicationContext();
            if (applicationContext != null && !BaseInfo.isBase(applicationContext)) {
                instanceId.hashCode();
                char c = 65535;
                int i = 4;
                String str = "uni-jsframework.js";
                boolean z = false;
                switch (instanceId.hashCode()) {
                    case -2076326187:
                        if (instanceId.equals("jsframework")) {
                            c = 0;
                            break;
                        }
                        break;
                    case -518688385:
                        if (instanceId.equals("uni-jsframework.js")) {
                            c = 1;
                            break;
                        }
                        break;
                    case 3271632:
                        if (instanceId.equals("jsfm")) {
                            c = 2;
                            break;
                        }
                        break;
                    case 293174862:
                        if (instanceId.equals("app-service.js")) {
                            c = 3;
                            break;
                        }
                        break;
                    case 1984153269:
                        if (instanceId.equals("service")) {
                            c = 4;
                            break;
                        }
                        break;
                }
                switch (c) {
                    case 0:
                    case 1:
                    case 2:
                    case 4:
                        break;
                    case 3:
                        str = instanceId;
                        i = 5;
                        break;
                    default:
                        i = 6;
                        WXSDKInstance sDKInstance2 = WXSDKManager.getInstance().getSDKInstance(instanceId);
                        if (sDKInstance2 == null) {
                            str = instanceId;
                            break;
                        } else {
                            str = sDKInstance2.getUniPagePath();
                            break;
                        }
                }
                org.json.JSONObject createJSONObject = JSONUtil.createJSONObject(AppRuntime.getUniStatistics());
                if (createJSONObject != null) {
                    String string = JSONUtil.getString(createJSONObject, "version");
                    boolean z2 = JSONUtil.getBoolean(createJSONObject, WebLoadEvent.ENABLE);
                    if (PdrUtil.isEquals(ExifInterface.GPS_MEASUREMENT_2D, string) && z2) {
                        z = true;
                    }
                }
                if (z) {
                    UEH.commitUncatchException(applicationContext, str, exception, i);
                }
            }
            function = function.substring(9);
        }
        WXLogUtils.e("reportJSException >>>> instanceId:" + instanceId + ", exception function:" + function + ", exception:" + exception);
        WXErrorCode wXErrorCode = WXErrorCode.WX_ERR_JS_EXECUTE;
        if (instanceId != null && (sDKInstance = WXSDKManager.getInstance().getSDKInstance(instanceId)) != null) {
            sDKInstance.setHasException(true);
            if (METHOD_CREATE_INSTANCE.equals(function) || !sDKInstance.isContentMd5Match()) {
                try {
                    if (!isSkipFrameworkInit(instanceId) && isJSFrameworkInit() && reInitCount > 1 && reInitCount < 10 && !sDKInstance.isNeedReLoad()) {
                        new ActionReloadPage(instanceId, true).executeAction();
                        sDKInstance.setNeedLoad(true);
                        return;
                    }
                    sDKInstance.onRenderError(WXErrorCode.WX_DEGRAD_ERR_INSTANCE_CREATE_FAILED.getErrorCode(), WXErrorCode.WX_DEGRAD_ERR_INSTANCE_CREATE_FAILED.getErrorMsg() + ", reportJSException >>>> instanceId:" + instanceId + ", exception function:" + function + ", exception:" + exception + ", extInitTime:" + (System.currentTimeMillis() - sInitFrameWorkTimeOrigin) + "ms, extInitErrorMsg:" + sInitFrameWorkMsg.toString());
                    if (WXEnvironment.sInAliWeex) {
                        return;
                    }
                    WXExceptionUtils.commitCriticalExceptionRT(instanceId, WXErrorCode.WX_RENDER_ERR_JS_CREATE_INSTANCE, function, exception, null);
                    return;
                } catch (Exception e) {
                    WXLogUtils.e(WXLogUtils.getStackTrace(e));
                }
            }
            if (METHOD_CREATE_INSTANCE.equals(function) && !sDKInstance.getApmForInstance().hasAddView) {
                wXErrorCode = WXErrorCode.WX_RENDER_ERR_JS_CREATE_INSTANCE;
            } else if (METHOD_CREATE_INSTANCE_CONTEXT.equals(function) && !sDKInstance.getApmForInstance().hasAddView) {
                wXErrorCode = WXErrorCode.WX_RENDER_ERR_JS_CREATE_INSTANCE_CONTEXT;
            } else if ((METHOD_UPDATE_COMPONENT_WITH_DATA.equals(function) || METHOD_CREATE_PAGE_WITH_CONTENT.equals(function) || METHOD_POST_TASK_TO_MSG_LOOP.equals(function) || METHOD_JSFM_NOT_INIT_IN_EAGLE_MODE.equals(function)) && !sDKInstance.getApmForInstance().hasAddView) {
                wXErrorCode = WXErrorCode.WX_DEGRAD_EAGLE_RENDER_ERROR;
            } else if (METHOD_CHECK_APPKEY.equals(function)) {
                wXErrorCode = WXErrorCode.WX_KEY_EXCEPTION_VALIDAPPKEY;
            }
            sDKInstance.onJSException(wXErrorCode.getErrorCode(), function, exception);
        }
        doReportJSException(instanceId, function, wXErrorCode, exception);
    }

    private void doReportJSException(String instanceId, String function, WXErrorCode reportCode, String exception) {
        String str;
        String str2;
        File file;
        WXSDKInstance wXSDKInstance = WXSDKManager.getInstance().getAllInstanceMap().get(instanceId);
        if (WXSDKManager.getInstance().getIWXJSExceptionAdapter() != null) {
            if (TextUtils.isEmpty(instanceId)) {
                instanceId = "instanceIdisNull";
            }
            if (wXSDKInstance == null && IWXUserTrackAdapter.INIT_FRAMEWORK.equals(function)) {
                try {
                } catch (Throwable th) {
                    th = th;
                    str = null;
                }
                if (WXEnvironment.getApplication() != null) {
                    try {
                        file = new File(WXEnvironment.getApplication().getApplicationContext().getCacheDir().getPath() + INITLOGFILE);
                    } catch (Throwable th2) {
                        th = th2;
                        str = null;
                    }
                    if (file.exists()) {
                        if (file.length() > 0) {
                            StringBuilder sb = new StringBuilder();
                            try {
                                BufferedReader bufferedReader = new BufferedReader(new InputStreamReader(new FileInputStream(file), "UTF-8"));
                                while (true) {
                                    String readLine = bufferedReader.readLine();
                                    if (readLine == null) {
                                        break;
                                    }
                                    sb.append(readLine + "\n");
                                }
                                str2 = sb.toString();
                                try {
                                    try {
                                        bufferedReader.close();
                                    } catch (Exception e) {
                                        str = str2;
                                        e = e;
                                        try {
                                            WXLogUtils.e(WXLogUtils.getStackTrace(e));
                                            str2 = str;
                                            file.delete();
                                        } catch (Throwable th3) {
                                            th = th3;
                                            try {
                                                WXLogUtils.e(WXLogUtils.getStackTrace(th));
                                            } catch (Throwable th4) {
                                                th = th4;
                                                WXLogUtils.e(WXLogUtils.getStackTrace(th));
                                                str2 = str;
                                                exception = exception + "\n" + str2;
                                                WXLogUtils.e("reportJSException:" + exception);
                                                WXExceptionUtils.commitCriticalExceptionRT(instanceId, reportCode, function, reportCode.getErrorMsg() + exception, null);
                                            }
                                            str2 = str;
                                            exception = exception + "\n" + str2;
                                            WXLogUtils.e("reportJSException:" + exception);
                                            WXExceptionUtils.commitCriticalExceptionRT(instanceId, reportCode, function, reportCode.getErrorMsg() + exception, null);
                                        }
                                        exception = exception + "\n" + str2;
                                        WXLogUtils.e("reportJSException:" + exception);
                                        WXExceptionUtils.commitCriticalExceptionRT(instanceId, reportCode, function, reportCode.getErrorMsg() + exception, null);
                                    }
                                } catch (Throwable th5) {
                                    str = str2;
                                    th = th5;
                                    WXLogUtils.e(WXLogUtils.getStackTrace(th));
                                    str2 = str;
                                    exception = exception + "\n" + str2;
                                    WXLogUtils.e("reportJSException:" + exception);
                                    WXExceptionUtils.commitCriticalExceptionRT(instanceId, reportCode, function, reportCode.getErrorMsg() + exception, null);
                                }
                            } catch (Exception e2) {
                                e = e2;
                                str = null;
                            }
                        } else {
                            str2 = null;
                        }
                        file.delete();
                        exception = exception + "\n" + str2;
                        WXLogUtils.e("reportJSException:" + exception);
                    }
                }
                str2 = null;
                exception = exception + "\n" + str2;
                WXLogUtils.e("reportJSException:" + exception);
            }
            WXExceptionUtils.commitCriticalExceptionRT(instanceId, reportCode, function, reportCode.getErrorMsg() + exception, null);
        }
    }

    private void registerDomModule() throws WXException {
        HashMap hashMap = new HashMap();
        hashMap.put(WXDomModule.WXDOM, WXDomModule.METHODS);
        registerModules(hashMap);
    }

    public static void updateGlobalConfig(String config) {
        if (TextUtils.isEmpty(config)) {
            config = "none";
        }
        if (TextUtils.equals(config, globalConfig)) {
            return;
        }
        globalConfig = config;
        WXEnvironment.addCustomOptions(GLOBAL_CONFIG_KEY, config);
        Runnable runnable = new Runnable() { // from class: com.taobao.weex.bridge.WXBridgeManager.26
            @Override // java.lang.Runnable
            public void run() {
                if (WXBridgeManager.mBridgeManager != null && WXBridgeManager.mBridgeManager.isJSFrameworkInit() && (WXBridgeManager.mBridgeManager.mWXBridge instanceof WXBridge)) {
                    ((WXBridge) WXBridgeManager.mBridgeManager.mWXBridge).nativeUpdateGlobalConfig(WXBridgeManager.globalConfig);
                }
                if (WXBridgeManager.globalConfig.contains(WXWsonJSONSwitch.WSON_OFF)) {
                    WXWsonJSONSwitch.USE_WSON = false;
                } else {
                    WXWsonJSONSwitch.USE_WSON = true;
                }
            }
        };
        if (mBridgeManager != null && mBridgeManager.isJSFrameworkInit()) {
            mBridgeManager.post(runnable);
        } else {
            runnable.run();
        }
    }

    public Looper getJSLooper() {
        WXThread wXThread = this.mJSThread;
        if (wXThread != null) {
            return wXThread.getLooper();
        }
        return null;
    }

    public void notifySerializeCodeCache() {
        post(new Runnable() { // from class: com.taobao.weex.bridge.WXBridgeManager.27
            @Override // java.lang.Runnable
            public void run() {
                if (WXBridgeManager.this.isJSFrameworkInit()) {
                    WXBridgeManager.this.invokeExecJS("", null, WXBridgeManager.METHOD_NOTIFY_SERIALIZE_CODE_CACHE, new WXJSObject[0]);
                }
            }
        });
    }

    public void takeJSHeapSnapshot(String filename) {
        Message obtainMessage = this.mJSHandler.obtainMessage();
        obtainMessage.obj = filename;
        obtainMessage.what = 13;
        obtainMessage.setTarget(this.mJSHandler);
        obtainMessage.sendToTarget();
    }

    public int callCreateBody(String pageId, String componentType, String ref, HashMap<String, String> styles, HashMap<String, String> attributes, HashSet<String> events, float[] margins, float[] paddings, float[] borders) {
        if (TextUtils.isEmpty(pageId) || TextUtils.isEmpty(componentType) || TextUtils.isEmpty(ref)) {
            WXLogUtils.d("[WXBridgeManager] call callCreateBody arguments is null");
            WXExceptionUtils.commitCriticalExceptionRT(pageId, WXErrorCode.WX_RENDER_ERR_BRIDGE_ARG_NULL, "callCreateBody", "arguments is empty, INSTANCE_RENDERING_ERROR will be set", null);
            return 0;
        }
        WXEnvironment.isApkDebugable();
        HashSet<String> hashSet = this.mDestroyedInstanceId;
        if (hashSet == null || !hashSet.contains(pageId)) {
            try {
                WXSDKInstance sDKInstance = WXSDKManager.getInstance().getSDKInstance(pageId);
                if (sDKInstance != null) {
                    GraphicActionCreateBody graphicActionCreateBody = new GraphicActionCreateBody(sDKInstance, ref, componentType, styles, attributes, events, margins, paddings, borders);
                    WXSDKManager.getInstance().getWXRenderManager().postGraphicAction(graphicActionCreateBody.getPageId(), graphicActionCreateBody);
                    return 1;
                }
                return 1;
            } catch (Exception e) {
                WXLogUtils.e("[WXBridgeManager] callCreateBody exception: ", e);
                WXExceptionUtils.commitCriticalExceptionRT(pageId, WXErrorCode.WX_KEY_EXCEPTION_INVOKE_BRIDGE, "callCreateBody", WXLogUtils.getStackTrace(e), null);
                return 1;
            }
        }
        return -1;
    }

    public int callAddElement(String pageId, String componentType, String ref, int index, String parentRef, HashMap<String, String> styles, HashMap<String, String> attributes, HashSet<String> events, float[] margins, float[] paddings, float[] borders, boolean willLayout) {
        if (TextUtils.isEmpty(pageId) || TextUtils.isEmpty(componentType) || TextUtils.isEmpty(ref)) {
            if (WXEnvironment.isApkDebugable()) {
                WXLogUtils.d("[WXBridgeManager] call callAddElement arguments is null");
            }
            WXExceptionUtils.commitCriticalExceptionRT(pageId, WXErrorCode.WX_RENDER_ERR_BRIDGE_ARG_NULL, "callAddElement", "arguments is empty, INSTANCE_RENDERING_ERROR will be set", null);
            return 0;
        }
        WXEnvironment.isApkDebugable();
        HashSet<String> hashSet = this.mDestroyedInstanceId;
        if (hashSet == null || !hashSet.contains(pageId)) {
            try {
                WXSDKInstance sDKInstance = WXSDKManager.getInstance().getSDKInstance(pageId);
                if (sDKInstance != null) {
                    GraphicActionAddElement graphicActionAddElement = new GraphicActionAddElement(sDKInstance, ref, componentType, parentRef, index, styles, attributes, events, margins, paddings, borders);
                    if (willLayout) {
                        sDKInstance.addInActiveAddElementAction(ref, graphicActionAddElement);
                        return 1;
                    }
                    WXSDKManager.getInstance().getWXRenderManager().postGraphicAction(pageId, graphicActionAddElement);
                    return 1;
                }
                return 1;
            } catch (Exception e) {
                WXLogUtils.e("[WXBridgeManager] callAddElement exception: ", e);
                WXExceptionUtils.commitCriticalExceptionRT(pageId, WXErrorCode.WX_KEY_EXCEPTION_INVOKE_BRIDGE, "callAddElement", WXLogUtils.getStackTrace(e), null);
                return 1;
            }
        }
        return -1;
    }

    public int callRemoveElement(String instanceId, String ref) {
        if (TextUtils.isEmpty(instanceId) || TextUtils.isEmpty(ref)) {
            if (WXEnvironment.isApkDebugable()) {
                WXLogUtils.d("[WXBridgeManager] call callRemoveElement arguments is null");
            }
            WXExceptionUtils.commitCriticalExceptionRT(instanceId, WXErrorCode.WX_RENDER_ERR_BRIDGE_ARG_NULL, "callRemoveElement", "arguments is empty, INSTANCE_RENDERING_ERROR will be set", null);
            return 0;
        }
        WXEnvironment.isApkDebugable();
        HashSet<String> hashSet = this.mDestroyedInstanceId;
        if (hashSet == null || !hashSet.contains(instanceId)) {
            try {
                WXSDKInstance sDKInstance = WXSDKManager.getInstance().getSDKInstance(instanceId);
                if (sDKInstance != null) {
                    GraphicActionRemoveElement graphicActionRemoveElement = new GraphicActionRemoveElement(sDKInstance, ref);
                    if (sDKInstance.getInActiveAddElementAction(ref) != null) {
                        sDKInstance.removeInActiveAddElmentAction(ref);
                        return 1;
                    }
                    WXSDKManager.getInstance().getWXRenderManager().postGraphicAction(graphicActionRemoveElement.getPageId(), graphicActionRemoveElement);
                    return 1;
                }
                return 1;
            } catch (Exception e) {
                WXLogUtils.e("[WXBridgeManager] callRemoveElement exception: ", e);
                WXExceptionUtils.commitCriticalExceptionRT(instanceId, WXErrorCode.WX_KEY_EXCEPTION_INVOKE_BRIDGE, "callRemoveElement", WXLogUtils.getStackTrace(e), null);
                return 1;
            }
        }
        return -1;
    }

    public int callMoveElement(String instanceId, String ref, String parentref, int index) {
        if (TextUtils.isEmpty(instanceId) || TextUtils.isEmpty(ref) || TextUtils.isEmpty(parentref)) {
            if (WXEnvironment.isApkDebugable()) {
                WXLogUtils.d("[WXBridgeManager] call callMoveElement arguments is null");
            }
            WXExceptionUtils.commitCriticalExceptionRT(instanceId, WXErrorCode.WX_RENDER_ERR_BRIDGE_ARG_NULL, "callMoveElement", "arguments is empty, INSTANCE_RENDERING_ERROR will be set", null);
            return 0;
        }
        WXEnvironment.isApkDebugable();
        HashSet<String> hashSet = this.mDestroyedInstanceId;
        if (hashSet == null || !hashSet.contains(instanceId)) {
            try {
                WXSDKInstance sDKInstance = WXSDKManager.getInstance().getSDKInstance(instanceId);
                if (sDKInstance != null) {
                    GraphicActionMoveElement graphicActionMoveElement = new GraphicActionMoveElement(sDKInstance, ref, parentref, index);
                    WXSDKManager.getInstance().getWXRenderManager().postGraphicAction(graphicActionMoveElement.getPageId(), graphicActionMoveElement);
                    return 1;
                }
                return 1;
            } catch (Exception e) {
                WXLogUtils.e("[WXBridgeManager] callMoveElement exception: ", e);
                WXExceptionUtils.commitCriticalExceptionRT(instanceId, WXErrorCode.WX_KEY_EXCEPTION_INVOKE_BRIDGE, "callMoveElement", WXLogUtils.getStackTrace(e), null);
                return 1;
            }
        }
        return -1;
    }

    public int callAddEvent(String instanceId, String ref, String event) {
        if (TextUtils.isEmpty(instanceId) || TextUtils.isEmpty(ref) || TextUtils.isEmpty(event)) {
            if (WXEnvironment.isApkDebugable()) {
                WXLogUtils.d("[WXBridgeManager] call callAddEvent arguments is null");
            }
            WXExceptionUtils.commitCriticalExceptionRT(instanceId, WXErrorCode.WX_RENDER_ERR_BRIDGE_ARG_NULL, "callAddEvent", "arguments is empty, INSTANCE_RENDERING_ERROR will be set", null);
            return 0;
        }
        WXEnvironment.isApkDebugable();
        HashSet<String> hashSet = this.mDestroyedInstanceId;
        if (hashSet == null || !hashSet.contains(instanceId)) {
            try {
                WXSDKInstance sDKInstance = WXSDKManager.getInstance().getSDKInstance(instanceId);
                if (sDKInstance != null) {
                    new GraphicActionAddEvent(sDKInstance, ref, event).executeActionOnRender();
                }
            } catch (Exception e) {
                WXLogUtils.e("[WXBridgeManager] callAddEvent exception: ", e);
                WXExceptionUtils.commitCriticalExceptionRT(instanceId, WXErrorCode.WX_KEY_EXCEPTION_INVOKE_BRIDGE, "callAddEvent", WXLogUtils.getStackTrace(e), null);
            }
            getNextTick(instanceId);
            return 1;
        }
        return -1;
    }

    public int callRemoveEvent(String instanceId, String ref, String event) {
        if (TextUtils.isEmpty(instanceId) || TextUtils.isEmpty(ref) || TextUtils.isEmpty(event)) {
            if (WXEnvironment.isApkDebugable()) {
                WXLogUtils.d("[WXBridgeManager] call callRemoveEvent arguments is null");
            }
            WXExceptionUtils.commitCriticalExceptionRT(instanceId, WXErrorCode.WX_RENDER_ERR_BRIDGE_ARG_NULL, "callRemoveEvent", "arguments is empty, INSTANCE_RENDERING_ERROR will be set", null);
            return 0;
        }
        WXEnvironment.isApkDebugable();
        HashSet<String> hashSet = this.mDestroyedInstanceId;
        if (hashSet == null || !hashSet.contains(instanceId)) {
            try {
                WXSDKInstance sDKInstance = WXSDKManager.getInstance().getSDKInstance(instanceId);
                if (sDKInstance != null) {
                    new GraphicActionRemoveEvent(sDKInstance, ref, event).executeActionOnRender();
                }
            } catch (Exception e) {
                WXLogUtils.e("[WXBridgeManager] callRemoveEvent exception: ", e);
                WXExceptionUtils.commitCriticalExceptionRT(instanceId, WXErrorCode.WX_KEY_EXCEPTION_INVOKE_BRIDGE, "callRemoveEvent", WXLogUtils.getStackTrace(e), null);
            }
            getNextTick(instanceId);
            return 1;
        }
        return -1;
    }

    public int callUpdateStyle(String instanceId, String ref, HashMap<String, Object> styles, HashMap<String, String> paddings, HashMap<String, String> margins, HashMap<String, String> borders) {
        if (TextUtils.isEmpty(instanceId) || TextUtils.isEmpty(ref)) {
            if (WXEnvironment.isApkDebugable()) {
                WXLogUtils.d("[WXBridgeManager] call callUpdateStyle arguments is null");
            }
            WXExceptionUtils.commitCriticalExceptionRT(instanceId, WXErrorCode.WX_RENDER_ERR_BRIDGE_ARG_NULL, "callUpdateStyle", "arguments is empty, INSTANCE_RENDERING_ERROR will be set", null);
            return 0;
        }
        WXEnvironment.isApkDebugable();
        HashSet<String> hashSet = this.mDestroyedInstanceId;
        if (hashSet == null || !hashSet.contains(instanceId)) {
            try {
                WXSDKInstance sDKInstance = WXSDKManager.getInstance().getSDKInstance(instanceId);
                if (sDKInstance != null) {
                    GraphicActionUpdateStyle graphicActionUpdateStyle = new GraphicActionUpdateStyle(sDKInstance, ref, styles, paddings, margins, borders);
                    WXSDKManager.getInstance().getWXRenderManager().postGraphicAction(graphicActionUpdateStyle.getPageId(), graphicActionUpdateStyle);
                    return 1;
                }
                return 1;
            } catch (Exception e) {
                WXLogUtils.e("[WXBridgeManager] callUpdateStyle exception: ", e);
                WXExceptionUtils.commitCriticalExceptionRT(instanceId, WXErrorCode.WX_KEY_EXCEPTION_INVOKE_BRIDGE, "callUpdateStyle", WXLogUtils.getStackTrace(e), null);
                return 1;
            }
        }
        return -1;
    }

    public int callUpdateAttrs(String instanceId, String ref, HashMap<String, String> attrs) {
        if (TextUtils.isEmpty(instanceId) || TextUtils.isEmpty(ref)) {
            if (WXEnvironment.isApkDebugable()) {
                WXLogUtils.d("[WXBridgeManager] call callUpdateAttrs arguments is null");
            }
            WXExceptionUtils.commitCriticalExceptionRT(instanceId, WXErrorCode.WX_RENDER_ERR_BRIDGE_ARG_NULL, "callUpdateAttrs", "arguments is empty, INSTANCE_RENDERING_ERROR will be set", null);
            return 0;
        }
        WXEnvironment.isApkDebugable();
        HashSet<String> hashSet = this.mDestroyedInstanceId;
        if (hashSet == null || !hashSet.contains(instanceId)) {
            try {
                WXSDKInstance sDKInstance = WXSDKManager.getInstance().getSDKInstance(instanceId);
                if (sDKInstance != null) {
                    GraphicActionUpdateAttr graphicActionUpdateAttr = new GraphicActionUpdateAttr(sDKInstance, ref, attrs);
                    WXSDKManager.getInstance().getWXRenderManager().postGraphicAction(graphicActionUpdateAttr.getPageId(), graphicActionUpdateAttr);
                    return 1;
                }
                return 1;
            } catch (Exception e) {
                WXLogUtils.e("[WXBridgeManager] callUpdateAttrs exception: ", e);
                WXExceptionUtils.commitCriticalExceptionRT(instanceId, WXErrorCode.WX_KEY_EXCEPTION_INVOKE_BRIDGE, "callUpdateAttrs", WXLogUtils.getStackTrace(e), null);
                return 1;
            }
        }
        return -1;
    }

    private void setExceedGPULimitComponentsInfo(String instanceId, String ref, GraphicSize layoutSize) {
        float openGLRenderLimitValue = WXRenderManager.getOpenGLRenderLimitValue();
        if (openGLRenderLimitValue > 0.0f) {
            if (layoutSize.getHeight() > openGLRenderLimitValue || layoutSize.getWidth() > openGLRenderLimitValue) {
                JSONObject jSONObject = new JSONObject();
                WXComponent wXComponent = WXSDKManager.getInstance().getWXRenderManager().getWXComponent(instanceId, ref);
                jSONObject.put("GPU limit", (Object) String.valueOf(openGLRenderLimitValue));
                jSONObject.put("component.width", (Object) String.valueOf(layoutSize.getWidth()));
                jSONObject.put("component.height", (Object) String.valueOf(layoutSize.getHeight()));
                if (wXComponent.getComponentType() != null && !wXComponent.getComponentType().isEmpty()) {
                    jSONObject.put("component.type", (Object) wXComponent.getComponentType());
                }
                if (wXComponent.getStyles() != null && !wXComponent.getStyles().isEmpty()) {
                    jSONObject.put("component.style", (Object) wXComponent.getStyles().toString());
                }
                if (wXComponent.getAttrs() != null && !wXComponent.getAttrs().isEmpty()) {
                    jSONObject.put("component.attr", (Object) wXComponent.getAttrs().toString());
                }
                if (wXComponent.getEvents() != null && !wXComponent.getEvents().isEmpty()) {
                    jSONObject.put("component.event", (Object) wXComponent.getEvents().toString());
                }
                if (wXComponent.getMargin() != null) {
                    jSONObject.put("component.margin", (Object) wXComponent.getMargin().toString());
                }
                if (wXComponent.getPadding() != null) {
                    jSONObject.put("component.padding", (Object) wXComponent.getPadding().toString());
                }
                if (wXComponent.getBorder() != null) {
                    jSONObject.put("component.border", (Object) wXComponent.getBorder().toString());
                }
                WXSDKManager.getInstance().getSDKInstance(instanceId).setComponentsInfoExceedGPULimit(jSONObject);
            }
        }
    }

    public int callAddChildToRichtext(String instanceId, String nodeType, String ref, String parentRef, String richTextRef, HashMap<String, String> styles, HashMap<String, String> attrs) {
        if (TextUtils.isEmpty(instanceId) || TextUtils.isEmpty(ref)) {
            if (WXEnvironment.isApkDebugable()) {
                WXLogUtils.d("[WXBridgeManager] call callAddChildToRichtext arguments is null");
            }
            WXExceptionUtils.commitCriticalExceptionRT(instanceId, WXErrorCode.WX_RENDER_ERR_BRIDGE_ARG_NULL, "callAddChildToRichtext", "arguments is empty, INSTANCE_RENDERING_ERROR will be set", null);
            return 0;
        }
        WXEnvironment.isApkDebugable();
        HashSet<String> hashSet = this.mDestroyedInstanceId;
        if (hashSet == null || !hashSet.contains(instanceId)) {
            try {
                WXSDKInstance sDKInstance = WXSDKManager.getInstance().getSDKInstance(instanceId);
                if (sDKInstance != null) {
                    GraphicActionAddChildToRichtext graphicActionAddChildToRichtext = new GraphicActionAddChildToRichtext(sDKInstance, nodeType, ref, parentRef, richTextRef, styles, attrs);
                    WXSDKManager.getInstance().getWXRenderManager().postGraphicAction(graphicActionAddChildToRichtext.getPageId(), graphicActionAddChildToRichtext);
                    return 1;
                }
                return 1;
            } catch (Exception e) {
                WXLogUtils.e("[WXBridgeManager] callAddChildToRichtext exception: ", WXLogUtils.getStackTrace(e));
                WXExceptionUtils.commitCriticalExceptionRT(instanceId, WXErrorCode.WX_KEY_EXCEPTION_INVOKE_BRIDGE, "callAddChildToRichtext", WXLogUtils.getStackTrace(e), null);
                return 1;
            }
        }
        return -1;
    }

    public int callRemoveChildFromRichtext(String instanceId, String ref, String parentRef, String richTextRef) {
        if (TextUtils.isEmpty(instanceId) || TextUtils.isEmpty(ref)) {
            if (WXEnvironment.isApkDebugable()) {
                WXLogUtils.d("[WXBridgeManager] call callRemoveChildFromRichtext arguments is null");
            }
            WXExceptionUtils.commitCriticalExceptionRT(instanceId, WXErrorCode.WX_RENDER_ERR_BRIDGE_ARG_NULL, "callRemoveChildFromRichtext", "arguments is empty, INSTANCE_RENDERING_ERROR will be set", null);
            return 0;
        }
        WXEnvironment.isApkDebugable();
        HashSet<String> hashSet = this.mDestroyedInstanceId;
        if (hashSet == null || !hashSet.contains(instanceId)) {
            try {
                WXSDKInstance sDKInstance = WXSDKManager.getInstance().getSDKInstance(instanceId);
                if (sDKInstance != null) {
                    GraphicActionRemoveChildFromRichtext graphicActionRemoveChildFromRichtext = new GraphicActionRemoveChildFromRichtext(sDKInstance, ref, parentRef, richTextRef);
                    WXSDKManager.getInstance().getWXRenderManager().postGraphicAction(graphicActionRemoveChildFromRichtext.getPageId(), graphicActionRemoveChildFromRichtext);
                    return 1;
                }
                return 1;
            } catch (Exception e) {
                WXLogUtils.e("[WXBridgeManager] callRemoveChildFromRichtext exception: ", e);
                WXExceptionUtils.commitCriticalExceptionRT(instanceId, WXErrorCode.WX_KEY_EXCEPTION_INVOKE_BRIDGE, "callRemoveChildFromRichtext", WXLogUtils.getStackTrace(e), null);
                return 1;
            }
        }
        return -1;
    }

    public void callBacthStart(String instanceId) {
        if (TextUtils.isEmpty(instanceId)) {
            if (WXEnvironment.isApkDebugable()) {
                WXLogUtils.d("[WXBridgeManager] call callRemoveChildFromRichtext arguments is null");
            }
            WXExceptionUtils.commitCriticalExceptionRT(instanceId, WXErrorCode.WX_RENDER_ERR_BRIDGE_ARG_NULL, "callRemoveChildFromRichtext", "arguments is empty, INSTANCE_RENDERING_ERROR will be set", null);
            return;
        }
        try {
            WXSDKInstance sDKInstance = WXSDKManager.getInstance().getSDKInstance(instanceId);
            if (sDKInstance != null) {
                GraphicActionBatchBegin graphicActionBatchBegin = new GraphicActionBatchBegin(sDKInstance, "");
                WXSDKManager.getInstance().getWXRenderManager().postGraphicAction(graphicActionBatchBegin.getPageId(), graphicActionBatchBegin);
            }
        } catch (Exception e) {
            WXLogUtils.e("[WXBridgeManager] callRemoveChildFromRichtext exception: ", e);
            WXExceptionUtils.commitCriticalExceptionRT(instanceId, WXErrorCode.WX_KEY_EXCEPTION_INVOKE_BRIDGE, "callRemoveChildFromRichtext", WXLogUtils.getStackTrace(e), null);
        }
    }

    public void callBacthEnd(String instanceId) {
        if (TextUtils.isEmpty(instanceId)) {
            if (WXEnvironment.isApkDebugable()) {
                WXLogUtils.d("[WXBridgeManager] call callRemoveChildFromRichtext arguments is null");
            }
            WXExceptionUtils.commitCriticalExceptionRT(instanceId, WXErrorCode.WX_RENDER_ERR_BRIDGE_ARG_NULL, "callRemoveChildFromRichtext", "arguments is empty, INSTANCE_RENDERING_ERROR will be set", null);
            return;
        }
        try {
            WXSDKInstance sDKInstance = WXSDKManager.getInstance().getSDKInstance(instanceId);
            if (sDKInstance != null) {
                GraphicActionBatchEnd graphicActionBatchEnd = new GraphicActionBatchEnd(sDKInstance, "");
                WXSDKManager.getInstance().getWXRenderManager().postGraphicAction(graphicActionBatchEnd.getPageId(), graphicActionBatchEnd);
            }
        } catch (Exception e) {
            WXLogUtils.e("[WXBridgeManager] callRemoveChildFromRichtext exception: ", e);
            WXExceptionUtils.commitCriticalExceptionRT(instanceId, WXErrorCode.WX_KEY_EXCEPTION_INVOKE_BRIDGE, "callRemoveChildFromRichtext", WXLogUtils.getStackTrace(e), null);
        }
    }

    public int callUpdateRichtextStyle(String instanceId, String ref, HashMap<String, String> styles, String parentRef, String richTextRef) {
        if (TextUtils.isEmpty(instanceId) || TextUtils.isEmpty(ref)) {
            if (WXEnvironment.isApkDebugable()) {
                WXLogUtils.d("[WXBridgeManager] call callUpdateRichtextStyle arguments is null");
            }
            WXExceptionUtils.commitCriticalExceptionRT(instanceId, WXErrorCode.WX_RENDER_ERR_BRIDGE_ARG_NULL, "callUpdateRichtextStyle", "arguments is empty, INSTANCE_RENDERING_ERROR will be set", null);
            return 0;
        }
        WXEnvironment.isApkDebugable();
        HashSet<String> hashSet = this.mDestroyedInstanceId;
        if (hashSet == null || !hashSet.contains(instanceId)) {
            try {
                WXSDKInstance sDKInstance = WXSDKManager.getInstance().getSDKInstance(instanceId);
                if (sDKInstance != null) {
                    GraphicActionUpdateRichtextStyle graphicActionUpdateRichtextStyle = new GraphicActionUpdateRichtextStyle(sDKInstance, ref, styles, parentRef, richTextRef);
                    WXSDKManager.getInstance().getWXRenderManager().postGraphicAction(graphicActionUpdateRichtextStyle.getPageId(), graphicActionUpdateRichtextStyle);
                    return 1;
                }
                return 1;
            } catch (Exception e) {
                WXLogUtils.e("[WXBridgeManager] callUpdateRichtextStyle exception: ", e);
                WXExceptionUtils.commitCriticalExceptionRT(instanceId, WXErrorCode.WX_KEY_EXCEPTION_INVOKE_BRIDGE, "callUpdateRichtextStyle", WXLogUtils.getStackTrace(e), null);
                return 1;
            }
        }
        return -1;
    }

    public int callUpdateRichtextChildAttr(String instanceId, String ref, HashMap<String, String> attrs, String parentRef, String richTextRef) {
        if (TextUtils.isEmpty(instanceId) || TextUtils.isEmpty(ref)) {
            if (WXEnvironment.isApkDebugable()) {
                WXLogUtils.d("[WXBridgeManager] call callUpdateRichtextChildAttr arguments is null");
            }
            WXExceptionUtils.commitCriticalExceptionRT(instanceId, WXErrorCode.WX_RENDER_ERR_BRIDGE_ARG_NULL, "callUpdateRichtextChildAttr", "arguments is empty, INSTANCE_RENDERING_ERROR will be set", null);
            return 0;
        }
        WXEnvironment.isApkDebugable();
        HashSet<String> hashSet = this.mDestroyedInstanceId;
        if (hashSet == null || !hashSet.contains(instanceId)) {
            try {
                WXSDKInstance sDKInstance = WXSDKManager.getInstance().getSDKInstance(instanceId);
                if (sDKInstance != null) {
                    GraphicActionUpdateRichtextAttr graphicActionUpdateRichtextAttr = new GraphicActionUpdateRichtextAttr(sDKInstance, ref, attrs, parentRef, richTextRef);
                    WXSDKManager.getInstance().getWXRenderManager().postGraphicAction(graphicActionUpdateRichtextAttr.getPageId(), graphicActionUpdateRichtextAttr);
                    return 1;
                }
                return 1;
            } catch (Exception e) {
                WXLogUtils.e("[WXBridgeManager] callUpdateRichtextChildAttr exception: ", e);
                WXExceptionUtils.commitCriticalExceptionRT(instanceId, WXErrorCode.WX_KEY_EXCEPTION_INVOKE_BRIDGE, "callUpdateRichtextChildAttr", WXLogUtils.getStackTrace(e), null);
                return 1;
            }
        }
        return -1;
    }

    public int callLayout(String pageId, String ref, int top, int bottom, int left, int right, int height, int width, boolean isRTL, int index) {
        if (TextUtils.isEmpty(pageId) || TextUtils.isEmpty(ref)) {
            if (WXEnvironment.isApkDebugable()) {
                WXLogUtils.d("[WXBridgeManager] call callLayout arguments is null");
            }
            WXExceptionUtils.commitCriticalExceptionRT(pageId, WXErrorCode.WX_RENDER_ERR_BRIDGE_ARG_NULL, "callLayout", "arguments is empty, INSTANCE_RENDERING_ERROR will be set", null);
            return 0;
        }
        WXEnvironment.isApkDebugable();
        HashSet<String> hashSet = this.mDestroyedInstanceId;
        if (hashSet == null || !hashSet.contains(pageId)) {
            try {
                WXSDKInstance sDKInstance = WXSDKManager.getInstance().getSDKInstance(pageId);
                if (sDKInstance != null) {
                    GraphicSize graphicSize = new GraphicSize(width, height);
                    GraphicPosition graphicPosition = new GraphicPosition(left, top, right, bottom);
                    setExceedGPULimitComponentsInfo(pageId, ref, graphicSize);
                    GraphicActionAddElement inActiveAddElementAction = sDKInstance.getInActiveAddElementAction(ref);
                    if (inActiveAddElementAction != null) {
                        inActiveAddElementAction.setRTL(isRTL);
                        inActiveAddElementAction.setSize(graphicSize);
                        inActiveAddElementAction.setPosition(graphicPosition);
                        if (!TextUtils.equals(ref, WXComponent.ROOT)) {
                            inActiveAddElementAction.setIndex(index);
                        }
                        WXSDKManager.getInstance().getWXRenderManager().postGraphicAction(pageId, inActiveAddElementAction);
                        sDKInstance.removeInActiveAddElmentAction(ref);
                        return 1;
                    }
                    GraphicActionLayout graphicActionLayout = new GraphicActionLayout(sDKInstance, ref, graphicPosition, graphicSize, isRTL);
                    WXSDKManager.getInstance().getWXRenderManager().postGraphicAction(graphicActionLayout.getPageId(), graphicActionLayout);
                    return 1;
                }
                return 1;
            } catch (Exception e) {
                WXLogUtils.e("[WXBridgeManager] callLayout exception: ", e);
                WXExceptionUtils.commitCriticalExceptionRT(pageId, WXErrorCode.WX_KEY_EXCEPTION_INVOKE_BRIDGE, "callLayout", WXLogUtils.getStackTrace(e), null);
                return 1;
            }
        }
        return -1;
    }

    public int callAppendTreeCreateFinish(String instanceId, String ref) {
        if (TextUtils.isEmpty(instanceId) || TextUtils.isEmpty(ref)) {
            WXLogUtils.d("[WXBridgeManager] call callAppendTreeCreateFinish arguments is null");
            WXExceptionUtils.commitCriticalExceptionRT(instanceId, WXErrorCode.WX_RENDER_ERR_BRIDGE_ARG_NULL, "callAppendTreeCreateFinish", "arguments is empty, INSTANCE_RENDERING_ERROR will be set", null);
            return 0;
        }
        WXEnvironment.isApkDebugable();
        HashSet<String> hashSet = this.mDestroyedInstanceId;
        if (hashSet == null || !hashSet.contains(instanceId)) {
            try {
                WXSDKManager.getInstance().getWXRenderManager().postGraphicAction(instanceId, new GraphicActionAppendTreeCreateFinish(WXSDKManager.getInstance().getSDKInstance(instanceId), ref));
                return 1;
            } catch (Exception e) {
                WXLogUtils.e("[WXBridgeManager] callAppendTreeCreateFinish exception: ", e);
                WXExceptionUtils.commitCriticalExceptionRT(instanceId, WXErrorCode.WX_KEY_EXCEPTION_INVOKE_BRIDGE, "callAppendTreeCreateFinish", WXLogUtils.getStackTrace(e), null);
                return 1;
            }
        }
        return -1;
    }

    public int callCreateFinish(String instanceId) {
        if (TextUtils.isEmpty(instanceId)) {
            WXLogUtils.d("[WXBridgeManager] call callCreateFinish arguments is null");
            WXExceptionUtils.commitCriticalExceptionRT(instanceId, WXErrorCode.WX_RENDER_ERR_BRIDGE_ARG_NULL, "callCreateFinish", "arguments is empty, INSTANCE_RENDERING_ERROR will be set", null);
            return 0;
        }
        WXEnvironment.isApkDebugable();
        HashSet<String> hashSet = this.mDestroyedInstanceId;
        if (hashSet == null || !hashSet.contains(instanceId)) {
            try {
                long currentTimeMillis = System.currentTimeMillis();
                WXSDKInstance sDKInstance = WXSDKManager.getInstance().getSDKInstance(instanceId);
                if (sDKInstance != null) {
                    sDKInstance.firstScreenCreateInstanceTime(currentTimeMillis);
                    WXSDKManager.getInstance().getWXRenderManager().postGraphicAction(instanceId, new GraphicActionCreateFinish(sDKInstance));
                    return 1;
                }
                return 1;
            } catch (Exception e) {
                WXLogUtils.e("[WXBridgeManager] callCreateFinish exception: ", e);
                WXExceptionUtils.commitCriticalExceptionRT(instanceId, WXErrorCode.WX_KEY_EXCEPTION_INVOKE_BRIDGE, "callCreateFinish", WXLogUtils.getStackTrace(e), null);
                return 1;
            }
        }
        return -1;
    }

    public int callRenderSuccess(String instanceId) {
        if (TextUtils.isEmpty(instanceId)) {
            WXLogUtils.d("[WXBridgeManager] call callRenderSuccess arguments is null");
            WXExceptionUtils.commitCriticalExceptionRT(instanceId, WXErrorCode.WX_RENDER_ERR_BRIDGE_ARG_NULL, "callRenderSuccess", "arguments is empty, INSTANCE_RENDERING_ERROR will be set", null);
            return 0;
        }
        WXEnvironment.isApkDebugable();
        HashSet<String> hashSet = this.mDestroyedInstanceId;
        if (hashSet == null || !hashSet.contains(instanceId)) {
            try {
                WXSDKInstance sDKInstance = WXSDKManager.getInstance().getSDKInstance(instanceId);
                if (sDKInstance != null) {
                    WXSDKManager.getInstance().getWXRenderManager().postGraphicAction(instanceId, new GraphicActionRenderSuccess(sDKInstance));
                    return 1;
                }
                return 1;
            } catch (Exception e) {
                WXLogUtils.e("[WXBridgeManager] callRenderSuccess exception: ", e);
                WXExceptionUtils.commitCriticalExceptionRT(instanceId, WXErrorCode.WX_KEY_EXCEPTION_INVOKE_BRIDGE, "callRenderSuccess", WXLogUtils.getStackTrace(e), null);
                return 1;
            }
        }
        return -1;
    }

    public ContentBoxMeasurement getMeasurementFunc(String instanceId, long renderObjectPtr) {
        WXSDKInstance sDKInstance = WXSDKManager.getInstance().getSDKInstance(instanceId);
        if (sDKInstance != null) {
            return sDKInstance.getContentBoxMeasurement(renderObjectPtr);
        }
        return null;
    }

    public void bindMeasurementToRenderObject(long ptr) {
        if (isJSFrameworkInit()) {
            this.mWXBridge.bindMeasurementToRenderObject(ptr);
        }
    }

    public boolean notifyLayout(String instanceId) {
        if (isSkipFrameworkInit(instanceId) || isJSFrameworkInit()) {
            return this.mWXBridge.notifyLayout(instanceId);
        }
        return false;
    }

    public void forceLayout(String instanceId) {
        if (isSkipFrameworkInit(instanceId) || isJSFrameworkInit()) {
            this.mWXBridge.forceLayout(instanceId);
        }
    }

    public void onInstanceClose(String instanceId) {
        if (isSkipFrameworkInit(instanceId) || isJSFrameworkInit()) {
            this.mWXBridge.onInstanceClose(instanceId);
        }
    }

    public void setDefaultRootSize(final String instanceId, final float defaultWidth, final float defaultHeight, final boolean isWidthWrapContent, final boolean isHeightWrapContent) {
        if (isSkipFrameworkInit(instanceId) || isJSFrameworkInit()) {
            this.mWXBridge.setDefaultHeightAndWidthIntoRootDom(instanceId, defaultWidth, defaultHeight, isWidthWrapContent, isHeightWrapContent);
        }
    }

    public void setRenderContentWrapContentToCore(boolean wrap, final String instanceId) {
        if (isJSFrameworkInit()) {
            this.mWXBridge.setRenderContainerWrapContent(wrap, instanceId);
        }
    }

    public void setStyleWidth(String instanceId, String ref, float value) {
        setStyleWidth(instanceId, ref, value, false);
    }

    public void setStyleWidth(String instanceId, String ref, float value, boolean update) {
        if (isSkipFrameworkInit(instanceId) || isJSFrameworkInit()) {
            this.mWXBridge.setStyleWidth(instanceId, ref, value, update);
        }
    }

    public void setStyleHeight(String instanceId, String ref, float value) {
        setStyleHeight(instanceId, ref, value, false);
    }

    public void setStyleHeight(String instanceId, String ref, float value, boolean update) {
        if (isSkipFrameworkInit(instanceId) || isJSFrameworkInit()) {
            this.mWXBridge.setStyleHeight(instanceId, ref, value, update);
        }
    }

    public long[] getFirstScreenRenderTime(String instanceId) {
        return isJSFrameworkInit() ? this.mWXBridge.getFirstScreenRenderTime(instanceId) : new long[]{0, 0, 0};
    }

    public long[] getRenderFinishTime(String instanceId) {
        return isJSFrameworkInit() ? this.mWXBridge.getRenderFinishTime(instanceId) : new long[]{0, 0, 0};
    }

    public void setDeviceDisplay(final String instanceId, final float deviceWidth, final float deviceHeight, final float scale) {
        post(new Runnable() { // from class: com.taobao.weex.bridge.WXBridgeManager.28
            @Override // java.lang.Runnable
            public void run() {
                WXBridgeManager.this.mWXBridge.setDeviceDisplay(instanceId, deviceWidth, deviceHeight, scale);
            }
        });
    }

    public void updateInitDeviceParams(final String width, final String height, final String density, final String statusHeight) {
        if (isJSFrameworkInit()) {
            post(new Runnable() { // from class: com.taobao.weex.bridge.WXBridgeManager.29
                @Override // java.lang.Runnable
                public void run() {
                    WXBridgeManager.this.mWXBridge.updateInitFrameworkParams(WXConfig.deviceWidth, width, WXConfig.deviceWidth);
                }
            });
            post(new Runnable() { // from class: com.taobao.weex.bridge.WXBridgeManager.30
                @Override // java.lang.Runnable
                public void run() {
                    WXBridgeManager.this.mWXBridge.updateInitFrameworkParams(WXConfig.deviceHeight, height, WXConfig.deviceHeight);
                }
            });
            post(new Runnable() { // from class: com.taobao.weex.bridge.WXBridgeManager.31
                @Override // java.lang.Runnable
                public void run() {
                    WXBridgeManager.this.mWXBridge.updateInitFrameworkParams("scale", density, "scale");
                }
            });
            if (statusHeight != null) {
                post(new Runnable() { // from class: com.taobao.weex.bridge.WXBridgeManager.32
                    @Override // java.lang.Runnable
                    public void run() {
                        WXBridgeManager.this.mWXBridge.updateInitFrameworkParams(WXConfig.androidStatusBarHeight, statusHeight, WXConfig.androidStatusBarHeight);
                    }
                });
            }
        }
    }

    public void setMargin(String instanceId, String ref, CSSShorthand.EDGE edge, float value) {
        if (isSkipFrameworkInit(instanceId) || isJSFrameworkInit()) {
            this.mWXBridge.setMargin(instanceId, ref, edge, value);
        }
    }

    public void setPadding(String instanceId, String ref, CSSShorthand.EDGE edge, float value) {
        if (isSkipFrameworkInit(instanceId) || isJSFrameworkInit()) {
            this.mWXBridge.setPadding(instanceId, ref, edge, value);
        }
    }

    public void setPosition(String instanceId, String ref, CSSShorthand.EDGE edge, float value) {
        if (isSkipFrameworkInit(instanceId) || isJSFrameworkInit()) {
            this.mWXBridge.setPosition(instanceId, ref, edge, value);
        }
    }

    public void markDirty(String instanceId, String ref, boolean dirty) {
        if (isSkipFrameworkInit(instanceId) || isJSFrameworkInit()) {
            this.mWXBridge.markDirty(instanceId, ref, dirty);
        }
    }

    public void setPageArgument(String instanceId, String key, String value) {
        if (isSkipFrameworkInit(instanceId) || isJSFrameworkInit()) {
            this.mWXBridge.setPageArgument(instanceId, key, value);
        }
    }

    public void reloadPageLayout(String instanceId) {
        if (isSkipFrameworkInit(instanceId) || isJSFrameworkInit()) {
            this.mWXBridge.reloadPageLayout(instanceId);
        }
    }

    public void setDeviceDisplayOfPage(String instanceId, float width, float height) {
        if (isSkipFrameworkInit(instanceId) || isJSFrameworkInit()) {
            this.mWXBridge.setDeviceDisplayOfPage(instanceId, width, height);
        }
    }

    public int callHasTransitionPros(String instanceId, String ref, HashMap<String, String> styles) {
        WXComponent wXComponent = WXSDKManager.getInstance().getWXRenderManager().getWXComponent(instanceId, ref);
        if (wXComponent == null || wXComponent.getTransition() == null || wXComponent.getTransition().getProperties() == null) {
            return -1;
        }
        for (String str : wXComponent.getTransition().getProperties()) {
            if (styles.containsKey(str)) {
                return 1;
            }
        }
        return 0;
    }

    public void registerCoreEnv(String key, String value) {
        if (isJSFrameworkInit()) {
            this.mWXBridge.registerCoreEnv(key, value);
        } else {
            mWeexCoreEnvOptions.put(key, value);
        }
    }

    private void onJsFrameWorkInitSuccees() {
        for (Map.Entry<String, String> entry : mWeexCoreEnvOptions.entrySet()) {
            this.mWXBridge.registerCoreEnv(entry.getKey(), entry.getValue());
        }
        mWeexCoreEnvOptions.clear();
    }

    public void setViewPortWidth(String instanceId, float value) {
        if (isJSFrameworkInit()) {
            this.mWXBridge.setViewPortWidth(instanceId, value);
        }
    }

    public void setFlexDirectionDef(String def) {
        if (isJSFrameworkInit()) {
            this.mWXBridge.setFlexDirectionDef(def);
        }
    }

    public String getWeexCoreThreadStackTrace() {
        if (this.mJSThread == null) {
            return "null == mJSThread";
        }
        StringBuilder sb = new StringBuilder();
        try {
            sb.append(StringUtil.format("Thread Name: '%s'\n", this.mJSThread.getName()));
            sb.append(String.format(Locale.ENGLISH, "\"%s\" prio=%d tid=%d %s\n", this.mJSThread.getName(), Integer.valueOf(this.mJSThread.getPriority()), Long.valueOf(this.mJSThread.getId()), this.mJSThread.getState()));
            StackTraceElement[] stackTrace = this.mJSThread.getStackTrace();
            int length = stackTrace.length;
            for (int i = 0; i < length; i++) {
                sb.append(StringUtil.format("\tat %s\n", stackTrace[i].toString()));
            }
        } catch (Exception e) {
            Log.e("weex", "getJSThreadStackTrace error:", e);
        }
        return sb.toString();
    }

    public String encryptGetClientKeyPayload(String appId, String data, String appKey) {
        IWXBridge iWXBridge = this.mWXBridge;
        return iWXBridge instanceof WXBridge ? ((WXBridge) iWXBridge).encryptGetClientKeyPayload(appId, data, appKey) : "";
    }

    public String encrypt(String appId, String data, String appKey, String clientKeyData) {
        IWXBridge iWXBridge = this.mWXBridge;
        return iWXBridge instanceof WXBridge ? ((WXBridge) iWXBridge).encrypt(appId, data, appKey, clientKeyData) : "";
    }

    public String decrypt(String appId, String data, String appKey, String clientKeyData) {
        IWXBridge iWXBridge = this.mWXBridge;
        return iWXBridge instanceof WXBridge ? ((WXBridge) iWXBridge).decrypt(appId, data, appKey, clientKeyData) : "";
    }

    public boolean verifyClientKeyPayload(String appId, String appKey, String clientKeyData) {
        IWXBridge iWXBridge = this.mWXBridge;
        if (iWXBridge instanceof WXBridge) {
            return ((WXBridge) iWXBridge).verifyClientKeyPayload(appId, appKey, clientKeyData);
        }
        return false;
    }
}
