package com.alibaba.fastjson;

import java.io.Closeable;
import java.io.IOException;
import java.io.InputStream;
import java.io.Reader;
/* loaded from: classes4.dex */
public abstract class JSONValidator implements Cloneable, Closeable {
    protected char ch;
    protected boolean eof;
    protected Type type;
    private Boolean validateResult;
    protected int pos = -1;
    protected int count = 0;
    protected boolean supportMultiValue = false;

    /* loaded from: classes4.dex */
    public enum Type {
        Object,
        Array,
        Value
    }

    static final boolean isWhiteSpace(char c) {
        return c == ' ' || c == '\t' || c == '\r' || c == '\n' || c == '\f' || c == '\b';
    }

    @Override // java.io.Closeable, java.lang.AutoCloseable
    public void close() throws IOException {
    }

    abstract void next();

    public static JSONValidator fromUtf8(byte[] bArr) {
        return new UTF8Validator(bArr);
    }

    public static JSONValidator fromUtf8(InputStream inputStream) {
        return new UTF8InputStreamValidator(inputStream);
    }

    public static JSONValidator from(String str) {
        return new UTF16Validator(str);
    }

    public static JSONValidator from(Reader reader) {
        return new ReaderValidator(reader);
    }

    public boolean isSupportMultiValue() {
        return this.supportMultiValue;
    }

    public JSONValidator setSupportMultiValue(boolean z) {
        this.supportMultiValue = z;
        return this;
    }

    public Type getType() {
        if (this.type == null) {
            validate();
        }
        return this.type;
    }

    public boolean validate() {
        Boolean bool = this.validateResult;
        if (bool != null) {
            return bool.booleanValue();
        }
        while (any()) {
            skipWhiteSpace();
            this.count++;
            if (this.eof) {
                this.validateResult = true;
                return true;
            } else if (this.supportMultiValue) {
                skipWhiteSpace();
                if (this.eof) {
                    this.validateResult = true;
                    return true;
                }
            } else {
                this.validateResult = false;
                return false;
            }
        }
        this.validateResult = false;
        return false;
    }

    /* JADX WARN: Code restructure failed: missing block: B:123:0x0173, code lost:
        if (r0 <= '9') goto L125;
     */
    /* JADX WARN: Removed duplicated region for block: B:130:0x0183  */
    /*
        Code decompiled incorrectly, please refer to instructions dump.
    */
    private boolean any() {
        char c;
        char c2;
        char c3;
        char c4;
        char c5;
        char c6;
        char c7;
        char c8;
        char c9 = this.ch;
        if (c9 != '\"') {
            if (c9 != '+' && c9 != '-') {
                if (c9 == '[') {
                    next();
                    skipWhiteSpace();
                    if (this.ch == ']') {
                        next();
                        this.type = Type.Array;
                        return true;
                    }
                    while (any()) {
                        skipWhiteSpace();
                        char c10 = this.ch;
                        if (c10 != ',') {
                            if (c10 == ']') {
                                next();
                                this.type = Type.Array;
                                return true;
                            }
                            return false;
                        }
                        next();
                        skipWhiteSpace();
                    }
                    return false;
                } else if (c9 == 'f') {
                    next();
                    if (this.ch != 'a') {
                        return false;
                    }
                    next();
                    if (this.ch != 'l') {
                        return false;
                    }
                    next();
                    if (this.ch != 's') {
                        return false;
                    }
                    next();
                    if (this.ch != 'e') {
                        return false;
                    }
                    next();
                    if (isWhiteSpace(this.ch) || (c6 = this.ch) == ',' || c6 == ']' || c6 == '}' || c6 == 0) {
                        this.type = Type.Value;
                        return true;
                    }
                    return false;
                } else if (c9 == 'n') {
                    next();
                    if (this.ch != 'u') {
                        return false;
                    }
                    next();
                    if (this.ch != 'l') {
                        return false;
                    }
                    next();
                    if (this.ch != 'l') {
                        return false;
                    }
                    next();
                    if (isWhiteSpace(this.ch) || (c7 = this.ch) == ',' || c7 == ']' || c7 == '}' || c7 == 0) {
                        this.type = Type.Value;
                        return true;
                    }
                    return false;
                } else if (c9 == 't') {
                    next();
                    if (this.ch != 'r') {
                        return false;
                    }
                    next();
                    if (this.ch != 'u') {
                        return false;
                    }
                    next();
                    if (this.ch != 'e') {
                        return false;
                    }
                    next();
                    if (isWhiteSpace(this.ch) || (c8 = this.ch) == ',' || c8 == ']' || c8 == '}' || c8 == 0) {
                        this.type = Type.Value;
                        return true;
                    }
                    return false;
                } else if (c9 == '{') {
                    next();
                    while (isWhiteSpace(this.ch)) {
                        next();
                    }
                    if (this.ch == '}') {
                        next();
                        this.type = Type.Object;
                        return true;
                    }
                    while (true) {
                        if (this.ch != '\"') {
                            break;
                        }
                        fieldName();
                        skipWhiteSpace();
                        if (this.ch != ':') {
                            break;
                        }
                        next();
                        skipWhiteSpace();
                        if (!any()) {
                            return false;
                        }
                        skipWhiteSpace();
                        char c11 = this.ch;
                        if (c11 == ',') {
                            next();
                            skipWhiteSpace();
                        } else if (c11 == '}') {
                            next();
                            this.type = Type.Object;
                            return true;
                        }
                    }
                    return false;
                } else {
                    switch (c9) {
                        case '0':
                        case '1':
                        case '2':
                        case '3':
                        case '4':
                        case '5':
                        case '6':
                        case '7':
                        case '8':
                        case '9':
                            break;
                        default:
                            return false;
                    }
                }
            }
            if (c9 == '-' || c9 == '+') {
                next();
                skipWhiteSpace();
                char c12 = this.ch;
                if (c12 >= '0') {
                }
                return false;
            }
            do {
                next();
                c = this.ch;
                if (c >= '0') {
                }
                if (c == '.') {
                    next();
                    char c13 = this.ch;
                    if (c13 < '0' || c13 > '9') {
                        return false;
                    }
                    while (true) {
                        char c14 = this.ch;
                        if (c14 >= '0' && c14 <= '9') {
                            next();
                        }
                    }
                }
                c2 = this.ch;
                if (c2 != 'e' || c2 == 'E') {
                    next();
                    c3 = this.ch;
                    if (c3 != '-' || c3 == '+') {
                        next();
                    }
                    c4 = this.ch;
                    if (c4 >= '0' && c4 <= '9') {
                        next();
                        while (true) {
                            c5 = this.ch;
                            if (c5 >= '0' && c5 <= '9') {
                                next();
                            }
                        }
                    }
                    return false;
                }
                this.type = Type.Value;
                return true;
            } while (c <= '9');
            if (c == '.') {
            }
            c2 = this.ch;
            if (c2 != 'e') {
            }
            next();
            c3 = this.ch;
            if (c3 != '-') {
            }
            next();
            c4 = this.ch;
            if (c4 >= '0') {
                next();
                while (true) {
                    c5 = this.ch;
                    if (c5 >= '0') {
                        next();
                    }
                }
                this.type = Type.Value;
                return true;
            }
            return false;
        }
        next();
        while (!this.eof) {
            char c15 = this.ch;
            if (c15 == '\\') {
                next();
                if (this.ch == 'u') {
                    next();
                    next();
                    next();
                    next();
                    next();
                } else {
                    next();
                }
            } else if (c15 == '\"') {
                next();
                this.type = Type.Value;
                return true;
            } else {
                next();
            }
        }
        return false;
    }

    protected void fieldName() {
        next();
        while (true) {
            char c = this.ch;
            if (c == '\\') {
                next();
                if (this.ch == 'u') {
                    next();
                    next();
                    next();
                    next();
                    next();
                } else {
                    next();
                }
            } else if (c == '\"') {
                next();
                return;
            } else {
                next();
            }
        }
    }

    protected boolean string() {
        next();
        while (!this.eof) {
            char c = this.ch;
            if (c == '\\') {
                next();
                if (this.ch == 'u') {
                    next();
                    next();
                    next();
                    next();
                    next();
                } else {
                    next();
                }
            } else if (c == '\"') {
                next();
                return true;
            } else {
                next();
            }
        }
        return false;
    }

    void skipWhiteSpace() {
        while (isWhiteSpace(this.ch)) {
            next();
        }
    }

    /* loaded from: classes16.dex */
    static class UTF8Validator extends JSONValidator {
        private final byte[] bytes;

        public UTF8Validator(byte[] bArr) {
            this.bytes = bArr;
            next();
            skipWhiteSpace();
        }

        @Override // com.alibaba.fastjson.JSONValidator
        void next() {
            this.pos++;
            int i = this.pos;
            byte[] bArr = this.bytes;
            if (i >= bArr.length) {
                this.ch = (char) 0;
                this.eof = true;
                return;
            }
            this.ch = (char) bArr[this.pos];
        }
    }

    /* loaded from: classes16.dex */
    static class UTF8InputStreamValidator extends JSONValidator {
        private static final ThreadLocal<byte[]> bufLocal = new ThreadLocal<>();
        private byte[] buf;
        private final InputStream is;
        private int end = -1;
        private int readCount = 0;

        public UTF8InputStreamValidator(InputStream inputStream) {
            this.is = inputStream;
            ThreadLocal<byte[]> threadLocal = bufLocal;
            byte[] bArr = threadLocal.get();
            this.buf = bArr;
            if (bArr != null) {
                threadLocal.set(null);
            } else {
                this.buf = new byte[8192];
            }
            next();
            skipWhiteSpace();
        }

        @Override // com.alibaba.fastjson.JSONValidator
        void next() {
            if (this.pos < this.end) {
                byte[] bArr = this.buf;
                int i = this.pos + 1;
                this.pos = i;
                this.ch = (char) bArr[i];
            } else if (this.eof) {
            } else {
                try {
                    InputStream inputStream = this.is;
                    byte[] bArr2 = this.buf;
                    int read = inputStream.read(bArr2, 0, bArr2.length);
                    this.readCount++;
                    if (read > 0) {
                        this.ch = (char) this.buf[0];
                        this.pos = 0;
                        this.end = read - 1;
                    } else if (read == -1) {
                        this.pos = 0;
                        this.end = 0;
                        this.buf = null;
                        this.ch = (char) 0;
                        this.eof = true;
                    } else {
                        this.pos = 0;
                        this.end = 0;
                        this.buf = null;
                        this.ch = (char) 0;
                        this.eof = true;
                        throw new JSONException("read error");
                    }
                } catch (IOException unused) {
                    throw new JSONException("read error");
                }
            }
        }

        @Override // com.alibaba.fastjson.JSONValidator, java.io.Closeable, java.lang.AutoCloseable
        public void close() throws IOException {
            bufLocal.set(this.buf);
            this.is.close();
        }
    }

    /* loaded from: classes16.dex */
    static class UTF16Validator extends JSONValidator {
        private final String str;

        public UTF16Validator(String str) {
            this.str = str;
            next();
            skipWhiteSpace();
        }

        @Override // com.alibaba.fastjson.JSONValidator
        void next() {
            this.pos++;
            if (this.pos >= this.str.length()) {
                this.ch = (char) 0;
                this.eof = true;
                return;
            }
            this.ch = this.str.charAt(this.pos);
        }

        @Override // com.alibaba.fastjson.JSONValidator
        protected final void fieldName() {
            char charAt;
            int i = this.pos;
            do {
                i++;
                if (i >= this.str.length() || (charAt = this.str.charAt(i)) == '\\') {
                    next();
                    while (true) {
                        if (this.ch == '\\') {
                            next();
                            if (this.ch == 'u') {
                                next();
                                next();
                                next();
                                next();
                                next();
                            } else {
                                next();
                            }
                        } else if (this.ch == '\"') {
                            next();
                            return;
                        } else if (this.eof) {
                            return;
                        } else {
                            next();
                        }
                    }
                }
            } while (charAt != '\"');
            int i2 = i + 1;
            this.ch = this.str.charAt(i2);
            this.pos = i2;
        }
    }

    /* loaded from: classes16.dex */
    static class ReaderValidator extends JSONValidator {
        private static final ThreadLocal<char[]> bufLocal = new ThreadLocal<>();
        private char[] buf;
        final Reader r;
        private int end = -1;
        private int readCount = 0;

        ReaderValidator(Reader reader) {
            this.r = reader;
            ThreadLocal<char[]> threadLocal = bufLocal;
            char[] cArr = threadLocal.get();
            this.buf = cArr;
            if (cArr != null) {
                threadLocal.set(null);
            } else {
                this.buf = new char[8192];
            }
            next();
            skipWhiteSpace();
        }

        @Override // com.alibaba.fastjson.JSONValidator
        void next() {
            if (this.pos < this.end) {
                char[] cArr = this.buf;
                int i = this.pos + 1;
                this.pos = i;
                this.ch = cArr[i];
            } else if (this.eof) {
            } else {
                try {
                    Reader reader = this.r;
                    char[] cArr2 = this.buf;
                    int read = reader.read(cArr2, 0, cArr2.length);
                    this.readCount++;
                    if (read > 0) {
                        this.ch = this.buf[0];
                        this.pos = 0;
                        this.end = read - 1;
                    } else if (read == -1) {
                        this.pos = 0;
                        this.end = 0;
                        this.buf = null;
                        this.ch = (char) 0;
                        this.eof = true;
                    } else {
                        this.pos = 0;
                        this.end = 0;
                        this.buf = null;
                        this.ch = (char) 0;
                        this.eof = true;
                        throw new JSONException("read error");
                    }
                } catch (IOException unused) {
                    throw new JSONException("read error");
                }
            }
        }

        @Override // com.alibaba.fastjson.JSONValidator, java.io.Closeable, java.lang.AutoCloseable
        public void close() throws IOException {
            bufLocal.set(this.buf);
            this.r.close();
        }
    }
}
