package com.taobao.weex;

import android.net.Uri;
import android.text.TextUtils;
import com.taobao.weex.adapter.IWXHttpAdapter;
import com.taobao.weex.adapter.IWXUserTrackAdapter;
import com.taobao.weex.common.WXErrorCode;
import com.taobao.weex.common.WXPerformance;
import com.taobao.weex.common.WXRenderStrategy;
import com.taobao.weex.common.WXResponse;
import com.taobao.weex.performance.WXInstanceApm;
import com.taobao.weex.tracing.WXTracing;
import com.taobao.weex.utils.WXLogUtils;
import com.taobao.weex.utils.tools.LogDetail;
import io.dcloud.common.util.ExifInterface;
import java.util.HashMap;
import java.util.List;
import java.util.Map;
/* loaded from: classes18.dex */
public class WXHttpListener implements IWXHttpAdapter.OnHttpListener {
    private WXRenderStrategy flag;
    private WXSDKInstance instance;
    private boolean isInstanceReady;
    public boolean isPreDownLoadMode;
    private boolean isResponseHasWait;
    private String jsonInitData;
    private WXInstanceApm mApmForInstance;
    private String mBundleUrl;
    private LogDetail mLogDetail;
    private WXResponse mResponse;
    private IWXUserTrackAdapter mUserTrackAdapter;
    private WXPerformance mWXPerformance;
    private Map<String, Object> options;
    private String pageName;
    private long startRequestTime;
    private int traceId;

    public void onFail(WXResponse response) {
    }

    @Override // com.taobao.weex.adapter.IWXHttpAdapter.OnHttpListener
    public void onHttpUploadProgress(int uploadProgress) {
    }

    public WXHttpListener(WXSDKInstance instance) {
        this.isPreDownLoadMode = false;
        this.isInstanceReady = false;
        this.isResponseHasWait = false;
        if (instance != null) {
            this.mLogDetail = instance.mTimeCalculator.createLogDetail("downloadBundleJS");
        }
        this.instance = instance;
        this.traceId = WXTracing.nextId();
        this.mWXPerformance = instance.getWXPerformance();
        this.mApmForInstance = instance.getApmForInstance();
        this.mUserTrackAdapter = WXSDKManager.getInstance().getIWXUserTrackAdapter();
        if (WXTracing.isAvailable()) {
            WXTracing.TraceEvent newEvent = WXTracing.newEvent("downloadBundleJS", instance.getInstanceId(), -1);
            newEvent.iid = instance.getInstanceId();
            newEvent.tname = "Network";
            newEvent.ph = "B";
            newEvent.traceId = this.traceId;
            newEvent.submit();
        }
    }

    public WXHttpListener(WXSDKInstance instance, String bundleUrl) {
        this(instance);
        this.startRequestTime = System.currentTimeMillis();
        this.mBundleUrl = bundleUrl;
    }

    public WXHttpListener(WXSDKInstance instance, String pageName, Map<String, Object> options, String jsonInitData, WXRenderStrategy flag, long startRequestTime) {
        this(instance);
        this.pageName = pageName;
        this.options = options;
        this.jsonInitData = jsonInitData;
        this.flag = flag;
        this.startRequestTime = startRequestTime;
        this.mBundleUrl = instance.getBundleUrl();
    }

    public void setSDKInstance(WXSDKInstance instance) {
        this.instance = instance;
    }

    /* JADX INFO: Access modifiers changed from: protected */
    public WXSDKInstance getInstance() {
        return this.instance;
    }

    @Override // com.taobao.weex.adapter.IWXHttpAdapter.OnHttpListener
    public void onHttpStart() {
        WXSDKInstance wXSDKInstance = this.instance;
        if (wXSDKInstance == null || wXSDKInstance.getWXStatisticsListener() == null) {
            return;
        }
        this.instance.getWXStatisticsListener().onHttpStart();
        LogDetail logDetail = this.mLogDetail;
        if (logDetail != null) {
            logDetail.taskStart();
        }
    }

    @Override // com.taobao.weex.adapter.IWXHttpAdapter.OnHttpListener
    public void onHeadersReceived(int statusCode, Map<String, List<String>> headers) {
        WXSDKInstance wXSDKInstance = this.instance;
        if (wXSDKInstance != null && wXSDKInstance.getWXStatisticsListener() != null) {
            this.instance.getWXStatisticsListener().onHeadersReceived();
            this.instance.onHttpStart();
        }
        WXSDKInstance wXSDKInstance2 = this.instance;
        if (wXSDKInstance2 == null || wXSDKInstance2.responseHeaders == null || headers == null) {
            return;
        }
        this.instance.responseHeaders.putAll(headers);
    }

    @Override // com.taobao.weex.adapter.IWXHttpAdapter.OnHttpListener
    public void onHttpResponseProgress(int loadedLength) {
        this.instance.getApmForInstance().extInfo.put(WXInstanceApm.VALUE_BUNDLE_LOAD_LENGTH, Integer.valueOf(loadedLength));
    }

    @Override // com.taobao.weex.adapter.IWXHttpAdapter.OnHttpListener
    public void onHttpFinish(WXResponse response) {
        LogDetail logDetail = this.mLogDetail;
        if (logDetail != null) {
            logDetail.taskEnd();
        }
        WXSDKInstance wXSDKInstance = this.instance;
        if (wXSDKInstance != null && wXSDKInstance.getWXStatisticsListener() != null) {
            this.instance.getWXStatisticsListener().onHttpFinish();
        }
        if (WXTracing.isAvailable()) {
            WXTracing.TraceEvent newEvent = WXTracing.newEvent("downloadBundleJS", this.instance.getInstanceId(), -1);
            newEvent.traceId = this.traceId;
            newEvent.tname = "Network";
            newEvent.ph = ExifInterface.LONGITUDE_EAST;
            newEvent.extParams = new HashMap();
            if (response != null && response.originalData != null) {
                newEvent.extParams.put("BundleSize", Integer.valueOf(response.originalData.length));
            }
            newEvent.submit();
        }
        this.mWXPerformance.networkTime = System.currentTimeMillis() - this.startRequestTime;
        if (response != null && response.extendParams != null) {
            this.mApmForInstance.updateRecordInfo(response.extendParams);
            Object obj = response.extendParams.get("actualNetworkTime");
            this.mWXPerformance.actualNetworkTime = obj instanceof Long ? ((Long) obj).longValue() : 0L;
            Object obj2 = response.extendParams.get("pureNetworkTime");
            this.mWXPerformance.pureNetworkTime = obj2 instanceof Long ? ((Long) obj2).longValue() : 0L;
            Object obj3 = response.extendParams.get("connectionType");
            this.mWXPerformance.connectionType = obj3 instanceof String ? (String) obj3 : "";
            Object obj4 = response.extendParams.get("packageSpendTime");
            this.mWXPerformance.packageSpendTime = obj4 instanceof Long ? ((Long) obj4).longValue() : 0L;
            Object obj5 = response.extendParams.get("syncTaskTime");
            this.mWXPerformance.syncTaskTime = obj5 instanceof Long ? ((Long) obj5).longValue() : 0L;
            Object obj6 = response.extendParams.get("requestType");
            this.mWXPerformance.requestType = obj6 instanceof String ? (String) obj6 : "none";
            Object obj7 = response.extendParams.get(WXPerformance.Dimension.cacheType.toString());
            if (obj7 instanceof String) {
                this.mWXPerformance.cacheType = (String) obj7;
            }
            Object obj8 = response.extendParams.get("zCacheInfo");
            this.mWXPerformance.zCacheInfo = obj8 instanceof String ? (String) obj8 : "";
            if (isNet(this.mWXPerformance.requestType) && this.mUserTrackAdapter != null) {
                WXPerformance wXPerformance = new WXPerformance(this.instance.getInstanceId());
                if (!TextUtils.isEmpty(this.mBundleUrl)) {
                    try {
                        wXPerformance.args = Uri.parse(this.mBundleUrl).buildUpon().clearQuery().toString();
                    } catch (Exception unused) {
                        wXPerformance.args = this.pageName;
                    }
                }
                if (!"200".equals(response.statusCode)) {
                    wXPerformance.errCode = WXErrorCode.WX_ERR_JSBUNDLE_DOWNLOAD.getErrorCode();
                    wXPerformance.appendErrMsg(response.errorCode);
                    wXPerformance.appendErrMsg("|");
                    wXPerformance.appendErrMsg(response.errorMsg);
                } else if ("200".equals(response.statusCode) && (response.originalData == null || response.originalData.length <= 0)) {
                    wXPerformance.errCode = WXErrorCode.WX_ERR_JSBUNDLE_DOWNLOAD.getErrorCode();
                    wXPerformance.appendErrMsg(response.statusCode);
                    wXPerformance.appendErrMsg("|template is null!");
                } else {
                    wXPerformance.errCode = WXErrorCode.WX_SUCCESS.getErrorCode();
                }
                IWXUserTrackAdapter iWXUserTrackAdapter = this.mUserTrackAdapter;
                if (iWXUserTrackAdapter != null) {
                    iWXUserTrackAdapter.commit(this.instance.getContext(), null, IWXUserTrackAdapter.JS_DOWNLOAD, wXPerformance, null);
                }
            }
        }
        if (this.isPreDownLoadMode) {
            if (this.isInstanceReady) {
                WXLogUtils.e("test->", "DownLoad didHttpFinish on http");
                didHttpFinish(response);
                return;
            }
            WXLogUtils.e("test->", "DownLoad end before activity created");
            this.mResponse = response;
            this.isResponseHasWait = true;
            return;
        }
        didHttpFinish(response);
    }

    public void onInstanceReady() {
        if (this.isPreDownLoadMode) {
            this.isInstanceReady = true;
            if (this.isResponseHasWait) {
                WXLogUtils.e("test->", "preDownLoad didHttpFinish on ready");
                didHttpFinish(this.mResponse);
            }
        }
    }

    private void didHttpFinish(WXResponse response) {
        String errorCode;
        if (response != null && response.originalData != null && TextUtils.equals("200", response.statusCode)) {
            this.mApmForInstance.onStage(WXInstanceApm.KEY_PAGE_STAGES_DOWN_BUNDLE_END);
            onSuccess(response);
            errorCode = WXInstanceApm.VALUE_ERROR_CODE_DEFAULT;
        } else if (TextUtils.equals(WXErrorCode.WX_DEGRAD_ERR_BUNDLE_CONTENTTYPE_ERROR.getErrorCode(), response.statusCode)) {
            WXLogUtils.e("user intercept: WX_DEGRAD_ERR_BUNDLE_CONTENTTYPE_ERROR");
            errorCode = WXErrorCode.WX_DEGRAD_ERR_BUNDLE_CONTENTTYPE_ERROR.getErrorCode();
            WXSDKInstance wXSDKInstance = this.instance;
            wXSDKInstance.onRenderError(errorCode, "|response.errorMsg==" + response.errorMsg + "|instance bundleUrl = \n" + this.instance.getBundleUrl() + "|instance requestUrl = \n" + Uri.decode(WXSDKInstance.requestUrl));
            onFail(response);
        } else if (response != null && response.originalData != null && TextUtils.equals("-206", response.statusCode)) {
            WXLogUtils.e("user intercept: WX_DEGRAD_ERR_NETWORK_CHECK_CONTENT_LENGTH_FAILED");
            errorCode = WXErrorCode.WX_DEGRAD_ERR_NETWORK_CHECK_CONTENT_LENGTH_FAILED.getErrorCode();
            WXSDKInstance wXSDKInstance2 = this.instance;
            wXSDKInstance2.onRenderError(errorCode, WXErrorCode.WX_DEGRAD_ERR_NETWORK_CHECK_CONTENT_LENGTH_FAILED.getErrorCode() + "|response.errorMsg==" + response.errorMsg);
            onFail(response);
        } else {
            errorCode = WXErrorCode.WX_DEGRAD_ERR_NETWORK_BUNDLE_DOWNLOAD_FAILED.getErrorCode();
            this.instance.onRenderError(errorCode, response.errorMsg);
            onFail(response);
        }
        if (WXInstanceApm.VALUE_ERROR_CODE_DEFAULT.equals(errorCode)) {
            return;
        }
        this.mApmForInstance.addProperty(WXInstanceApm.KEY_PROPERTIES_ERROR_CODE, errorCode);
    }

    private boolean isNet(String requestType) {
        return "network".equals(requestType) || "2g".equals(requestType) || "3g".equals(requestType) || "4g".equals(requestType) || "wifi".equals(requestType) || "other".equals(requestType) || "unknown".equals(requestType);
    }

    public void onSuccess(WXResponse response) {
        if (this.flag == WXRenderStrategy.DATA_RENDER_BINARY) {
            this.instance.render(this.pageName, response.originalData, this.options, this.jsonInitData);
            return;
        }
        this.instance.render(this.pageName, new String(response.originalData), this.options, this.jsonInitData, this.flag);
    }
}
