package com.taobao.weex;

import android.os.Looper;
import android.text.TextUtils;
import com.taobao.weex.adapter.ClassLoaderAdapter;
import com.taobao.weex.adapter.DefaultUriAdapter;
import com.taobao.weex.adapter.DefaultWXHttpAdapter;
import com.taobao.weex.adapter.ICrashInfoReporter;
import com.taobao.weex.adapter.IDrawableLoader;
import com.taobao.weex.adapter.ITracingAdapter;
import com.taobao.weex.adapter.IWXAccessibilityRoleAdapter;
import com.taobao.weex.adapter.IWXConfigAdapter;
import com.taobao.weex.adapter.IWXHttpAdapter;
import com.taobao.weex.adapter.IWXImgLoaderAdapter;
import com.taobao.weex.adapter.IWXJSExceptionAdapter;
import com.taobao.weex.adapter.IWXJsFileLoaderAdapter;
import com.taobao.weex.adapter.IWXJscProcessManager;
import com.taobao.weex.adapter.IWXSoLoaderAdapter;
import com.taobao.weex.adapter.IWXUserTrackAdapter;
import com.taobao.weex.adapter.URIAdapter;
import com.taobao.weex.appfram.navigator.IActivityNavBarSetter;
import com.taobao.weex.appfram.navigator.INavigator;
import com.taobao.weex.appfram.storage.DefaultWXStorage;
import com.taobao.weex.appfram.storage.IWXStorageAdapter;
import com.taobao.weex.appfram.websocket.IWebSocketAdapter;
import com.taobao.weex.appfram.websocket.IWebSocketAdapterFactory;
import com.taobao.weex.bridge.IDCVueBridgeAdapter;
import com.taobao.weex.bridge.WXBridgeManager;
import com.taobao.weex.bridge.WXModuleManager;
import com.taobao.weex.bridge.WXValidateProcessor;
import com.taobao.weex.common.WXRefreshData;
import com.taobao.weex.common.WXRuntimeException;
import com.taobao.weex.common.WXThread;
import com.taobao.weex.common.WXWorkThreadManager;
import com.taobao.weex.font.FontAdapter;
import com.taobao.weex.performance.IApmGenerator;
import com.taobao.weex.performance.IWXAnalyzer;
import com.taobao.weex.ui.WXRenderManager;
import com.taobao.weex.utils.WXLogUtils;
import com.taobao.weex.utils.WXUtils;
import java.io.File;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;
import java.util.concurrent.CopyOnWriteArrayList;
import java.util.concurrent.atomic.AtomicInteger;
/* loaded from: classes8.dex */
public class WXSDKManager {
    private static final int DEFAULT_VIEWPORT_WIDTH = 750;
    private static AtomicInteger sInstanceId = new AtomicInteger(0);
    private static volatile WXSDKManager sManager;
    private IActivityNavBarSetter mActivityNavBarSetter;
    private Map<String, WXSDKInstance> mAllInstanceMap;
    private IApmGenerator mApmGenerater;
    private WXBridgeManager mBridgeManager;
    private ClassLoaderAdapter mClassLoaderAdapter;
    private IWXConfigAdapter mConfigAdapter;
    private ICrashInfoReporter mCrashInfo;
    private IDrawableLoader mDrawableLoader;
    private FontAdapter mFontAdapter;
    private IWXHttpAdapter mIWXHttpAdapter;
    private IWXImgLoaderAdapter mIWXImgLoaderAdapter;
    private IWXJSExceptionAdapter mIWXJSExceptionAdapter;
    private IWXSoLoaderAdapter mIWXSoLoaderAdapter;
    private IWXStorageAdapter mIWXStorageAdapter;
    private IWXUserTrackAdapter mIWXUserTrackAdapter;
    private IWebSocketAdapterFactory mIWebSocketAdapterFactory;
    private List<InstanceLifeCycleCallbacks> mLifeCycleCallbacks;
    private INavigator mNavigator;
    private boolean mNeedInitV8;
    private IWXAccessibilityRoleAdapter mRoleAdapter;
    private IWXStatisticsListener mStatisticsListener;
    private ITracingAdapter mTracingAdapter;
    private URIAdapter mURIAdapter;
    private IDCVueBridgeAdapter mVueBridgeAdapter;
    private List<IWXAnalyzer> mWXAnalyzerList;
    private IWXJsFileLoaderAdapter mWXJsFileLoaderAdapter;
    private IWXJscProcessManager mWXJscProcessManager;
    WXRenderManager mWXRenderManager;
    private WXValidateProcessor mWXValidateProcessor;
    private final WXWorkThreadManager mWXWorkThreadManager;

    /* loaded from: classes8.dex */
    public interface InstanceLifeCycleCallbacks {
        void onInstanceCreated(String instanceId);

        void onInstanceDestroyed(String instanceId);
    }

    private WXSDKManager() {
        this(new WXRenderManager());
    }

    private WXSDKManager(WXRenderManager renderManager) {
        this.mNeedInitV8 = true;
        this.mWXRenderManager = renderManager;
        this.mBridgeManager = WXBridgeManager.getInstance();
        this.mWXWorkThreadManager = new WXWorkThreadManager();
        this.mWXAnalyzerList = new CopyOnWriteArrayList();
        this.mAllInstanceMap = new HashMap();
    }

    static void initInstance(WXRenderManager renderManager) {
        sManager = new WXSDKManager(renderManager);
    }

    public void registerStatisticsListener(IWXStatisticsListener listener) {
        this.mStatisticsListener = listener;
    }

    public IWXStatisticsListener getWXStatisticsListener() {
        return this.mStatisticsListener;
    }

    public void onSDKEngineInitialize() {
        IWXStatisticsListener iWXStatisticsListener = this.mStatisticsListener;
        if (iWXStatisticsListener != null) {
            iWXStatisticsListener.onSDKEngineInitialize();
        }
    }

    public void setNeedInitV8(boolean need) {
        this.mNeedInitV8 = need;
    }

    public boolean needInitV8() {
        return this.mNeedInitV8;
    }

    public void takeJSHeapSnapshot(String path) {
        File file = new File(path);
        if (file.exists() || file.mkdir()) {
            String valueOf = String.valueOf(sInstanceId.get());
            if (!path.endsWith(File.separator)) {
                path = path + File.separator;
            }
            this.mBridgeManager.takeJSHeapSnapshot((path + valueOf) + ".heapsnapshot");
        }
    }

    public static WXSDKManager getInstance() {
        if (sManager == null) {
            synchronized (WXSDKManager.class) {
                if (sManager == null) {
                    sManager = new WXSDKManager();
                }
            }
        }
        return sManager;
    }

    public static float getInstanceViewPortWidth(String instanceId) {
        WXSDKInstance sDKInstance = getInstance().getSDKInstance(instanceId);
        if (sDKInstance == null) {
            return 750.0f;
        }
        return sDKInstance.getInstanceViewPortWidthWithFloat();
    }

    static void setInstance(WXSDKManager manager) {
        sManager = manager;
    }

    public IActivityNavBarSetter getActivityNavBarSetter() {
        return this.mActivityNavBarSetter;
    }

    public void setActivityNavBarSetter(IActivityNavBarSetter mActivityNavBarSetter) {
        this.mActivityNavBarSetter = mActivityNavBarSetter;
    }

    public void restartBridge() {
        this.mBridgeManager.restart();
    }

    public WXBridgeManager getWXBridgeManager() {
        return this.mBridgeManager;
    }

    public WXRenderManager getWXRenderManager() {
        return this.mWXRenderManager;
    }

    public IWXJscProcessManager getWXJscProcessManager() {
        return this.mWXJscProcessManager;
    }

    public WXWorkThreadManager getWXWorkThreadManager() {
        return this.mWXWorkThreadManager;
    }

    public void setWxConfigAdapter(IWXConfigAdapter mConfigAdapter) {
        this.mConfigAdapter = mConfigAdapter;
    }

    public IWXConfigAdapter getWxConfigAdapter() {
        return this.mConfigAdapter;
    }

    public WXSDKInstance getSDKInstance(String instanceId) {
        if (instanceId == null) {
            return null;
        }
        return this.mWXRenderManager.getWXSDKInstance(instanceId);
    }

    public void postOnUiThread(Runnable runnable, long delayMillis) {
        this.mWXRenderManager.postOnUiThread(WXThread.secure(runnable), delayMillis);
    }

    public Map<String, WXSDKInstance> getAllInstanceMap() {
        return this.mAllInstanceMap;
    }

    public void destroy() {
        WXWorkThreadManager wXWorkThreadManager = this.mWXWorkThreadManager;
        if (wXWorkThreadManager != null) {
            wXWorkThreadManager.destroy();
        }
        this.mAllInstanceMap.clear();
    }

    @Deprecated
    public void callback(String instanceId, String funcId, Map<String, Object> data) {
        this.mBridgeManager.callback(instanceId, funcId, data);
    }

    @Deprecated
    public void callback(String instanceId, String funcId, Map<String, Object> data, boolean keepAlive) {
        this.mBridgeManager.callback(instanceId, funcId, data, keepAlive);
    }

    public void initScriptsFramework(String framework) {
        this.mBridgeManager.initScriptsFramework(framework);
    }

    public void registerComponents(List<Map<String, Object>> components) {
        this.mBridgeManager.registerComponents(components);
    }

    public void registerModules(Map<String, Object> modules) {
        this.mBridgeManager.registerModules(modules);
    }

    @Deprecated
    public void fireEvent(final String instanceId, String ref, String type) {
        fireEvent(instanceId, ref, type, new HashMap());
    }

    @Deprecated
    public void fireEvent(final String instanceId, String ref, String type, Map<String, Object> params) {
        fireEvent(instanceId, ref, type, params, null);
    }

    @Deprecated
    public void fireEvent(final String instanceId, String ref, String type, Map<String, Object> params, Map<String, Object> domChanges) {
        if (WXEnvironment.isApkDebugable() && Looper.getMainLooper().getThread().getId() != Thread.currentThread().getId()) {
            throw new WXRuntimeException("[WXSDKManager]  fireEvent error");
        }
        this.mBridgeManager.fireEventOnNode(instanceId, ref, type, params, domChanges);
    }

    /* JADX INFO: Access modifiers changed from: package-private */
    public void createInstance(WXSDKInstance instance, Script code, Map<String, Object> options, String jsonInitData) {
        this.mWXRenderManager.registerInstance(instance);
        this.mBridgeManager.createInstance(instance.getInstanceId(), code, options, jsonInitData);
        List<InstanceLifeCycleCallbacks> list = this.mLifeCycleCallbacks;
        if (list != null) {
            for (InstanceLifeCycleCallbacks instanceLifeCycleCallbacks : list) {
                instanceLifeCycleCallbacks.onInstanceCreated(instance.getInstanceId());
            }
        }
    }

    /* JADX INFO: Access modifiers changed from: package-private */
    public void refreshInstance(String instanceId, WXRefreshData jsonData) {
        this.mBridgeManager.refreshInstance(instanceId, jsonData);
    }

    /* JADX INFO: Access modifiers changed from: package-private */
    public void destroyInstance(String instanceId) {
        setCrashInfo(WXEnvironment.WEEX_CURRENT_KEY, "");
        if (TextUtils.isEmpty(instanceId)) {
            return;
        }
        if (!WXUtils.isUiThread()) {
            throw new WXRuntimeException("[WXSDKManager] destroyInstance error");
        }
        List<InstanceLifeCycleCallbacks> list = this.mLifeCycleCallbacks;
        if (list != null) {
            for (InstanceLifeCycleCallbacks instanceLifeCycleCallbacks : list) {
                instanceLifeCycleCallbacks.onInstanceDestroyed(instanceId);
            }
        }
        this.mWXRenderManager.removeRenderStatement(instanceId);
        this.mBridgeManager.destroyInstance(instanceId);
        WXModuleManager.destroyInstanceModules(instanceId);
    }

    /* JADX INFO: Access modifiers changed from: package-private */
    public String generateInstanceId() {
        return String.valueOf(sInstanceId.incrementAndGet());
    }

    public IWXUserTrackAdapter getIWXUserTrackAdapter() {
        return this.mIWXUserTrackAdapter;
    }

    public IWXImgLoaderAdapter getIWXImgLoaderAdapter() {
        return this.mIWXImgLoaderAdapter;
    }

    public IWXJsFileLoaderAdapter getIWXJsFileLoaderAdapter() {
        return this.mWXJsFileLoaderAdapter;
    }

    public IDrawableLoader getDrawableLoader() {
        return this.mDrawableLoader;
    }

    public IWXJSExceptionAdapter getIWXJSExceptionAdapter() {
        return this.mIWXJSExceptionAdapter;
    }

    public void setIWXJSExceptionAdapter(IWXJSExceptionAdapter IWXJSExceptionAdapter) {
        this.mIWXJSExceptionAdapter = IWXJSExceptionAdapter;
    }

    public IWXHttpAdapter getIWXHttpAdapter() {
        if (this.mIWXHttpAdapter == null) {
            this.mIWXHttpAdapter = new DefaultWXHttpAdapter();
        }
        return this.mIWXHttpAdapter;
    }

    public IApmGenerator getApmGenerater() {
        return this.mApmGenerater;
    }

    public URIAdapter getURIAdapter() {
        if (this.mURIAdapter == null) {
            this.mURIAdapter = new DefaultUriAdapter();
        }
        return this.mURIAdapter;
    }

    public IDCVueBridgeAdapter getVueBridgeAdapter() {
        return this.mVueBridgeAdapter;
    }

    public ClassLoaderAdapter getClassLoaderAdapter() {
        if (this.mClassLoaderAdapter == null) {
            this.mClassLoaderAdapter = new ClassLoaderAdapter();
        }
        return this.mClassLoaderAdapter;
    }

    public IWXSoLoaderAdapter getIWXSoLoaderAdapter() {
        return this.mIWXSoLoaderAdapter;
    }

    public List<IWXAnalyzer> getWXAnalyzerList() {
        return this.mWXAnalyzerList;
    }

    public void addWXAnalyzer(IWXAnalyzer analyzer) {
        if (this.mWXAnalyzerList.contains(analyzer)) {
            return;
        }
        this.mWXAnalyzerList.add(analyzer);
    }

    public void rmWXAnalyzer(IWXAnalyzer analyzer) {
        this.mWXAnalyzerList.remove(analyzer);
    }

    /* JADX INFO: Access modifiers changed from: package-private */
    public void setInitConfig(InitConfig config) {
        this.mIWXHttpAdapter = config.getHttpAdapter();
        this.mIWXImgLoaderAdapter = config.getImgAdapter();
        this.mDrawableLoader = config.getDrawableLoader();
        this.mIWXStorageAdapter = config.getStorageAdapter();
        this.mVueBridgeAdapter = config.getVueBridgeAdaper();
        this.mIWXUserTrackAdapter = config.getUtAdapter();
        this.mURIAdapter = config.getURIAdapter();
        this.mIWebSocketAdapterFactory = config.getWebSocketAdapterFactory();
        this.mIWXJSExceptionAdapter = config.getJSExceptionAdapter();
        this.mIWXSoLoaderAdapter = config.getIWXSoLoaderAdapter();
        this.mClassLoaderAdapter = config.getClassLoaderAdapter();
        this.mApmGenerater = config.getApmGenerater();
        this.mWXJsFileLoaderAdapter = config.getJsFileLoaderAdapter();
        this.mWXJscProcessManager = config.getJscProcessManager();
    }

    public IWXStorageAdapter getIWXStorageAdapter() {
        if (this.mIWXStorageAdapter == null) {
            if (WXEnvironment.sApplication != null) {
                this.mIWXStorageAdapter = new DefaultWXStorage(WXEnvironment.sApplication);
            } else {
                WXLogUtils.e("WXStorageModule", "No Application context found,you should call WXSDKEngine#initialize() method in your application");
            }
        }
        return this.mIWXStorageAdapter;
    }

    public void notifyTrimMemory() {
        this.mBridgeManager.notifyTrimMemory();
    }

    public void notifySerializeCodeCache() {
        this.mBridgeManager.notifySerializeCodeCache();
    }

    public IWebSocketAdapter getIWXWebSocketAdapter() {
        IWebSocketAdapterFactory iWebSocketAdapterFactory = this.mIWebSocketAdapterFactory;
        if (iWebSocketAdapterFactory != null) {
            return iWebSocketAdapterFactory.createWebSocketAdapter();
        }
        return null;
    }

    public void registerValidateProcessor(WXValidateProcessor processor) {
        this.mWXValidateProcessor = processor;
    }

    public WXValidateProcessor getValidateProcessor() {
        return this.mWXValidateProcessor;
    }

    public void setCrashInfoReporter(ICrashInfoReporter mCrashInfo) {
        this.mCrashInfo = mCrashInfo;
    }

    public void setCrashInfo(String key, String value) {
        ICrashInfoReporter iCrashInfoReporter = this.mCrashInfo;
        if (iCrashInfoReporter != null) {
            iCrashInfoReporter.addCrashInfo(key, value);
        }
    }

    public void setTracingAdapter(ITracingAdapter adapter) {
        this.mTracingAdapter = adapter;
    }

    public ITracingAdapter getTracingAdapter() {
        return this.mTracingAdapter;
    }

    public void registerInstanceLifeCycleCallbacks(InstanceLifeCycleCallbacks callbacks) {
        if (this.mLifeCycleCallbacks == null) {
            this.mLifeCycleCallbacks = new ArrayList();
        }
        this.mLifeCycleCallbacks.add(callbacks);
    }

    public void setAccessibilityRoleAdapter(IWXAccessibilityRoleAdapter adapter) {
        this.mRoleAdapter = adapter;
    }

    public IWXAccessibilityRoleAdapter getAccessibilityRoleAdapter() {
        return this.mRoleAdapter;
    }

    public INavigator getNavigator() {
        return this.mNavigator;
    }

    public void setNavigator(INavigator mNavigator) {
        this.mNavigator = mNavigator;
    }

    public FontAdapter getFontAdapter() {
        if (this.mFontAdapter == null) {
            synchronized (this) {
                if (this.mFontAdapter == null) {
                    this.mFontAdapter = new FontAdapter();
                }
            }
        }
        return this.mFontAdapter;
    }
}
