package com.taobao.weex.appfram.navigator;

import android.app.ActionBar;
import android.app.Activity;
import android.content.Context;
import android.content.Intent;
import android.net.Uri;
import android.text.TextUtils;
import androidx.appcompat.app.AppCompatActivity;
import com.alibaba.fastjson.JSON;
import com.alibaba.fastjson.JSONException;
import com.alibaba.fastjson.JSONObject;
import com.taobao.weex.WXSDKEngine;
import com.taobao.weex.annotation.JSMethod;
import com.taobao.weex.bridge.JSCallback;
import com.taobao.weex.bridge.WXBridgeManager;
import com.taobao.weex.common.WXModule;
import com.taobao.weex.utils.WXLogUtils;
/* loaded from: classes23.dex */
public class WXNavigatorModule extends WXModule {
    public static final String CALLBACK_MESSAGE = "message";
    public static final String CALLBACK_RESULT = "result";
    private static final String INSTANCE_ID = "instanceId";
    public static final String MSG_FAILED = "WX_FAILED";
    public static final String MSG_PARAM_ERR = "WX_PARAM_ERR";
    public static final String MSG_SUCCESS = "WX_SUCCESS";
    private static final String TAG = "Navigator";
    private static final String URL = "url";
    private static final String WEEX = "com.taobao.android.intent.category.WEEX";

    @JSMethod(uiThread = true)
    public void open(JSONObject options, JSCallback success, JSCallback failure) {
        if (options != null) {
            String string = options.getString("url");
            JSONObject jSONObject = new JSONObject();
            if (!TextUtils.isEmpty(string)) {
                Uri parse = Uri.parse(string);
                String scheme = parse.getScheme();
                if (TextUtils.isEmpty(scheme) || "http".equalsIgnoreCase(scheme) || "https".equalsIgnoreCase(scheme)) {
                    push(options.toJSONString(), success);
                } else {
                    try {
                        this.mWXSDKInstance.getContext().startActivity(new Intent("android.intent.action.VIEW", parse));
                        jSONObject.put("result", (Object) MSG_SUCCESS);
                    } catch (Throwable th) {
                        th.printStackTrace();
                        jSONObject.put("result", (Object) MSG_FAILED);
                        jSONObject.put("message", (Object) "Open page failed.");
                        success = failure;
                    }
                }
                failure = success;
            } else {
                jSONObject.put("result", (Object) MSG_PARAM_ERR);
                jSONObject.put("message", (Object) "The URL parameter is empty.");
            }
            if (failure != null) {
                failure.invoke(jSONObject);
            }
        }
    }

    @JSMethod(uiThread = true)
    public void close(JSONObject options, JSCallback success, JSCallback failure) {
        JSONObject jSONObject = new JSONObject();
        if (this.mWXSDKInstance.getContext() instanceof Activity) {
            ((Activity) this.mWXSDKInstance.getContext()).finish();
        } else {
            jSONObject.put("result", (Object) MSG_FAILED);
            jSONObject.put("message", (Object) "Close page failed.");
            success = failure;
        }
        if (success != null) {
            success.invoke(jSONObject);
        }
    }

    @JSMethod(uiThread = true)
    public void push(String param, JSCallback callback) {
        if (TextUtils.isEmpty(param)) {
            if (callback != null) {
                callback.invoke(MSG_FAILED);
            }
        } else if (WXSDKEngine.getActivityNavBarSetter() != null && WXSDKEngine.getActivityNavBarSetter().push(param)) {
            if (callback != null) {
                callback.invoke(MSG_SUCCESS);
            }
        } else {
            if (this.mWXSDKInstance.getContext() instanceof Activity) {
                Activity activity = (Activity) this.mWXSDKInstance.getContext();
                if (WXSDKEngine.getNavigator() != null && WXSDKEngine.getNavigator().push(activity, param)) {
                    if (callback != null) {
                        callback.invoke(MSG_SUCCESS);
                        return;
                    }
                    return;
                }
            }
            try {
                String string = JSON.parseObject(param).getString("url");
                if (TextUtils.isEmpty(string)) {
                    return;
                }
                Uri parse = Uri.parse(string);
                String scheme = parse.getScheme();
                Uri.Builder buildUpon = parse.buildUpon();
                if (TextUtils.isEmpty(scheme)) {
                    buildUpon.scheme("http");
                }
                Intent intent = new Intent("android.intent.action.VIEW", buildUpon.build());
                intent.addCategory(WEEX);
                intent.putExtra("instanceId", this.mWXSDKInstance.getInstanceId());
                this.mWXSDKInstance.getContext().startActivity(intent);
                if (callback != null) {
                    callback.invoke(MSG_SUCCESS);
                }
            } catch (Exception e) {
                WXLogUtils.eTag("Navigator", e);
                if (callback != null) {
                    callback.invoke(MSG_FAILED);
                }
            }
        }
    }

    @JSMethod(uiThread = true)
    public void pop(String param, JSCallback callback) {
        if (WXSDKEngine.getActivityNavBarSetter() != null && WXSDKEngine.getActivityNavBarSetter().pop(param)) {
            if (callback != null) {
                callback.invoke(MSG_SUCCESS);
            }
        } else if (this.mWXSDKInstance.getContext() instanceof Activity) {
            Activity activity = (Activity) this.mWXSDKInstance.getContext();
            if (WXSDKEngine.getNavigator() == null || !WXSDKEngine.getNavigator().pop(activity, param)) {
                if (callback != null) {
                    callback.invoke(MSG_SUCCESS);
                }
                ((Activity) this.mWXSDKInstance.getContext()).finish();
            } else if (callback != null) {
                callback.invoke(MSG_SUCCESS);
            }
        }
    }

    @JSMethod(uiThread = true)
    public void setNavBarRightItem(String param, JSCallback callback) {
        if (TextUtils.isEmpty(param) || WXSDKEngine.getActivityNavBarSetter() == null || !WXSDKEngine.getActivityNavBarSetter().setNavBarRightItem(param)) {
            if (callback != null) {
                callback.invoke(MSG_FAILED);
            }
        } else if (callback != null) {
            callback.invoke(MSG_SUCCESS);
        }
    }

    @JSMethod(uiThread = true)
    public void clearNavBarRightItem(String param, JSCallback callback) {
        if (WXSDKEngine.getActivityNavBarSetter() == null || !WXSDKEngine.getActivityNavBarSetter().clearNavBarRightItem(param)) {
            if (callback != null) {
                callback.invoke(MSG_FAILED);
            }
        } else if (callback != null) {
            callback.invoke(MSG_SUCCESS);
        }
    }

    @JSMethod(uiThread = true)
    public void setNavBarLeftItem(String param, JSCallback callback) {
        if (TextUtils.isEmpty(param) || WXSDKEngine.getActivityNavBarSetter() == null || !WXSDKEngine.getActivityNavBarSetter().setNavBarLeftItem(param)) {
            if (callback != null) {
                callback.invoke(MSG_FAILED);
            }
        } else if (callback != null) {
            callback.invoke(MSG_SUCCESS);
        }
    }

    @JSMethod(uiThread = true)
    public void clearNavBarLeftItem(String param, JSCallback callback) {
        if (WXSDKEngine.getActivityNavBarSetter() == null || !WXSDKEngine.getActivityNavBarSetter().clearNavBarLeftItem(param)) {
            if (callback != null) {
                callback.invoke(MSG_FAILED);
            }
        } else if (callback != null) {
            callback.invoke(MSG_SUCCESS);
        }
    }

    @JSMethod(uiThread = true)
    public void setNavBarMoreItem(String param, JSCallback callback) {
        if (TextUtils.isEmpty(param) || WXSDKEngine.getActivityNavBarSetter() == null || !WXSDKEngine.getActivityNavBarSetter().setNavBarMoreItem(param)) {
            if (callback != null) {
                callback.invoke(MSG_FAILED);
            }
        } else if (callback != null) {
            callback.invoke(MSG_SUCCESS);
        }
    }

    @JSMethod(uiThread = true)
    public void clearNavBarMoreItem(String param, JSCallback callback) {
        if (WXSDKEngine.getActivityNavBarSetter() == null || !WXSDKEngine.getActivityNavBarSetter().clearNavBarMoreItem(param)) {
            if (callback != null) {
                callback.invoke(MSG_FAILED);
            }
        } else if (callback != null) {
            callback.invoke(MSG_SUCCESS);
        }
    }

    @JSMethod(uiThread = true)
    public void setNavBarTitle(String param, JSCallback callback) {
        if (TextUtils.isEmpty(param) || WXSDKEngine.getActivityNavBarSetter() == null || !WXSDKEngine.getActivityNavBarSetter().setNavBarTitle(param)) {
            if (callback != null) {
                callback.invoke(MSG_FAILED);
            }
        } else if (callback != null) {
            callback.invoke(MSG_SUCCESS);
        }
    }

    @JSMethod
    public void setNavBarHidden(String param, final String callback) {
        String str = MSG_FAILED;
        try {
            if (changeVisibilityOfActionBar(this.mWXSDKInstance.getContext(), JSON.parseObject(param).getInteger("hidden").intValue())) {
                str = MSG_SUCCESS;
            }
        } catch (JSONException e) {
            WXLogUtils.e("Navigator", WXLogUtils.getStackTrace(e));
        }
        WXBridgeManager.getInstance().callback(this.mWXSDKInstance.getInstanceId(), callback, str);
    }

    private boolean changeVisibilityOfActionBar(Context context, int visibility) {
        boolean z;
        ActionBar actionBar;
        try {
            Class.forName("android.support.v7.app.AppCompatActivity");
            z = true;
        } catch (ClassNotFoundException e) {
            e.printStackTrace();
            z = false;
        }
        if (z && (this.mWXSDKInstance.getContext() instanceof AppCompatActivity)) {
            androidx.appcompat.app.ActionBar supportActionBar = ((AppCompatActivity) this.mWXSDKInstance.getContext()).getSupportActionBar();
            if (supportActionBar == null) {
                return false;
            }
            if (visibility == 0) {
                supportActionBar.show();
            } else if (visibility != 1) {
                return false;
            } else {
                supportActionBar.hide();
            }
        } else if (!(this.mWXSDKInstance.getContext() instanceof Activity) || (actionBar = ((Activity) this.mWXSDKInstance.getContext()).getActionBar()) == null) {
            return false;
        } else {
            if (visibility == 0) {
                actionBar.show();
            } else if (visibility != 1) {
                return false;
            } else {
                actionBar.hide();
            }
        }
        return true;
    }
}
