package com.taobao.weex.appfram.pickers;

import android.app.AlertDialog;
import android.content.Context;
import android.content.DialogInterface;
import android.os.Build;
import android.view.View;
import android.view.ViewGroup;
import android.widget.AdapterView;
import android.widget.ArrayAdapter;
import android.widget.Button;
import android.widget.Checkable;
import android.widget.TextView;
import com.taobao.weex.annotation.JSMethod;
import com.taobao.weex.appfram.pickers.DatePickerImpl;
import com.taobao.weex.bridge.JSCallback;
import com.taobao.weex.common.WXModule;
import com.taobao.weex.common.WXThread;
import com.taobao.weex.utils.WXResourceUtils;
import com.taobao.weex.utils.WXViewUtils;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;
/* loaded from: classes23.dex */
public class WXPickersModule extends WXModule {
    private static final String CANCEL = "cancel";
    private static final String DATA = "data";
    private static final String ERROR = "error";
    private static final String KEY_CANCEL_TITLE = "cancelTitle";
    private static final String KEY_CANCEL_TITLE_COLOR = "cancelTitleColor";
    private static final String KEY_CONFIRM_TITLE = "confirmTitle";
    private static final String KEY_CONFIRM_TITLE_COLOR = "confirmTitleColor";
    private static final String KEY_INDEX = "index";
    private static final String KEY_ITEMS = "items";
    private static final String KEY_MAX = "max";
    private static final String KEY_MIN = "min";
    private static final String KEY_SELECTION_COLOR = "selectionColor";
    private static final String KEY_TEXT_COLOR = "textColor";
    private static final String KEY_TITLE = "title";
    private static final String KEY_TITLE_BACKGROUND_COLOR = "titleBackgroundColor";
    private static final String KEY_TITLE_COLOR = "titleColor";
    private static final String KEY_VALUE = "value";
    private static final String RESULT = "result";
    private static final String SUCCESS = "success";
    private int selected;

    @JSMethod
    public void pick(Map<String, Object> options, JSCallback callback) {
        try {
            performSinglePick(safeConvert((List) getOption(options, KEY_ITEMS, new ArrayList())), options, callback);
        } catch (Throwable th) {
            th.printStackTrace();
        }
    }

    @JSMethod
    public void pickDate(Map<String, Object> options, JSCallback callback) {
        performPickDate(options, callback);
    }

    @JSMethod
    public void pickTime(Map<String, Object> options, JSCallback callback) {
        performPickTime(options, callback);
    }

    private List<String> safeConvert(List src) {
        ArrayList arrayList = new ArrayList(src.size());
        for (Object obj : src) {
            arrayList.add(String.valueOf(obj));
        }
        return arrayList;
    }

    /* JADX INFO: Access modifiers changed from: private */
    public <T> T getOption(Map<String, Object> options, String key, T defValue) {
        T t = (T) options.get(key);
        return t == null ? defValue : t;
    }

    /* JADX INFO: Access modifiers changed from: private */
    public int getColor(Map<String, Object> options, String key, int defValue) {
        Object option = getOption(options, key, null);
        return option == null ? defValue : WXResourceUtils.getColor(option.toString(), defValue);
    }

    private void performPickTime(Map<String, Object> options, final JSCallback callback) {
        DatePickerImpl.pickTime(this.mWXSDKInstance.getContext(), (String) getOption(options, "value", ""), new DatePickerImpl.OnPickListener() { // from class: com.taobao.weex.appfram.pickers.WXPickersModule.1
            @Override // com.taobao.weex.appfram.pickers.DatePickerImpl.OnPickListener
            public void onPick(boolean set, String result) {
                if (set) {
                    HashMap hashMap = new HashMap(2);
                    hashMap.put("result", "success");
                    hashMap.put("data", result);
                    callback.invoke(hashMap);
                    return;
                }
                HashMap hashMap2 = new HashMap(2);
                hashMap2.put("result", "cancel");
                hashMap2.put("data", null);
                callback.invoke(hashMap2);
            }
        }, options);
    }

    private void performPickDate(Map<String, Object> options, final JSCallback callback) {
        DatePickerImpl.pickDate(this.mWXSDKInstance.getContext(), (String) getOption(options, "value", ""), (String) getOption(options, "max", ""), (String) getOption(options, "min", ""), new DatePickerImpl.OnPickListener() { // from class: com.taobao.weex.appfram.pickers.WXPickersModule.2
            @Override // com.taobao.weex.appfram.pickers.DatePickerImpl.OnPickListener
            public void onPick(boolean set, String result) {
                if (set) {
                    HashMap hashMap = new HashMap(2);
                    hashMap.put("result", "success");
                    hashMap.put("data", result);
                    callback.invoke(hashMap);
                    return;
                }
                HashMap hashMap2 = new HashMap(2);
                hashMap2.put("result", "cancel");
                hashMap2.put("data", null);
                callback.invoke(hashMap2);
            }
        }, options);
    }

    private void performSinglePick(final List<String> items, final Map<String, Object> options, final JSCallback callback) {
        this.selected = ((Integer) getOption(options, "index", 0)).intValue();
        final int color = getColor(options, KEY_TEXT_COLOR, 0);
        final int color2 = getColor(options, KEY_SELECTION_COLOR, 0);
        final ArrayAdapter<String> arrayAdapter = new ArrayAdapter<String>(this.mWXSDKInstance.getContext(), 17367055, items) { // from class: com.taobao.weex.appfram.pickers.WXPickersModule.3
            @Override // android.widget.ArrayAdapter, android.widget.Adapter
            public View getView(int position, View convertView, ViewGroup parent) {
                int i;
                View view = super.getView(position, convertView, parent);
                if (view != null && (view instanceof Checkable)) {
                    boolean z = position == WXPickersModule.this.selected;
                    ((Checkable) view).setChecked(z);
                    if (z) {
                        view.setBackgroundColor(color2);
                    } else {
                        view.setBackgroundColor(0);
                    }
                }
                if ((view instanceof TextView) && (i = color) != 0) {
                    ((TextView) view).setTextColor(i);
                }
                return view;
            }
        };
        final AlertDialog create = new AlertDialog.Builder(this.mWXSDKInstance.getContext()).setAdapter(arrayAdapter, null).setPositiveButton(17039370, new DialogInterface.OnClickListener() { // from class: com.taobao.weex.appfram.pickers.WXPickersModule.5
            @Override // android.content.DialogInterface.OnClickListener
            public void onClick(DialogInterface dialog, int which) {
                HashMap hashMap = new HashMap(2);
                hashMap.put("result", "success");
                hashMap.put("data", Integer.valueOf(WXPickersModule.this.selected));
                callback.invoke(hashMap);
            }
        }).setNegativeButton(17039360, new DialogInterface.OnClickListener() { // from class: com.taobao.weex.appfram.pickers.WXPickersModule.4
            @Override // android.content.DialogInterface.OnClickListener
            public void onClick(DialogInterface dialog, int which) {
                HashMap hashMap = new HashMap(2);
                hashMap.put("result", "cancel");
                hashMap.put("data", -1);
                callback.invoke(hashMap);
            }
        }).setCustomTitle(makeTitleView(this.mWXSDKInstance.getContext(), options)).create();
        if (Build.VERSION.SDK_INT >= 21) {
            create.create();
        }
        create.getListView().setOnItemClickListener(new AdapterView.OnItemClickListener() { // from class: com.taobao.weex.appfram.pickers.WXPickersModule.6
            @Override // android.widget.AdapterView.OnItemClickListener
            public void onItemClick(AdapterView<?> parent, View view, int position, long id) {
                WXPickersModule.this.selected = position;
                arrayAdapter.notifyDataSetChanged();
            }
        });
        create.getWindow().getDecorView().post(WXThread.secure(new Runnable() { // from class: com.taobao.weex.appfram.pickers.WXPickersModule.7
            @Override // java.lang.Runnable
            public void run() {
                Button button = create.getButton(-1);
                Button button2 = create.getButton(-2);
                if (button != null) {
                    String str = (String) WXPickersModule.this.getOption(options, WXPickersModule.KEY_CONFIRM_TITLE, null);
                    int color3 = WXPickersModule.this.getColor(options, WXPickersModule.KEY_CONFIRM_TITLE_COLOR, 0);
                    if (str != null) {
                        button.setText(str);
                        button.setAllCaps(false);
                    }
                    if (color3 != 0) {
                        button.setTextColor(color3);
                        button.setAllCaps(false);
                    }
                }
                if (button2 != null) {
                    String str2 = (String) WXPickersModule.this.getOption(options, "cancelTitle", null);
                    int color4 = WXPickersModule.this.getColor(options, WXPickersModule.KEY_CANCEL_TITLE_COLOR, 0);
                    if (str2 != null) {
                        button2.setText(str2);
                    }
                    if (color4 != 0) {
                        button2.setTextColor(color4);
                    }
                }
            }
        }));
        create.show();
    }

    private TextView makeTitleView(Context context, Map<String, Object> options) {
        String str = (String) getOption(options, "title", null);
        if (str == null) {
            return null;
        }
        TextView textView = new TextView(context);
        textView.setLayoutParams(new ViewGroup.LayoutParams(-1, -2));
        textView.setTextSize(2, 20.0f);
        int dip2px = WXViewUtils.dip2px(12.0f);
        textView.setPadding(dip2px, dip2px, dip2px, dip2px);
        textView.getPaint().setFakeBoldText(true);
        textView.setBackgroundColor(getColor(options, KEY_TITLE_BACKGROUND_COLOR, 0));
        textView.setTextColor(getColor(options, KEY_TITLE_COLOR, -16777216));
        textView.setText(str);
        return textView;
    }
}
