package com.taobao.weex.bridge;

import android.util.Log;
import com.alibaba.fastjson.JSON;
import com.alibaba.fastjson.JSONArray;
import com.alibaba.fastjson.JSONObject;
import com.taobao.weex.WXSDKInstance;
import com.taobao.weex.WXSDKManager;
import com.taobao.weex.bridge.SimpleJSCallback;
import com.taobao.weex.performance.WXAnalyzerDataTransfer;
import com.taobao.weex.utils.WXLogUtils;
import com.taobao.weex.utils.WXReflectionUtils;
import io.dcloud.feature.uniapp.bridge.UniJSCallback;
import java.lang.reflect.Type;
/* loaded from: classes8.dex */
public class NativeInvokeHelper {
    private String mInstanceId;

    public NativeInvokeHelper(String instanceId) {
        this.mInstanceId = instanceId;
    }

    public Object invoke(final Object target, final Invoker invoker, JSONArray args) throws Exception {
        final Object[] prepareArguments = prepareArguments(invoker.getParameterTypes(), args);
        if (WXAnalyzerDataTransfer.isInteractionLogOpen() && (invoker instanceof MethodInvoker)) {
            int i = 0;
            while (true) {
                if (i >= prepareArguments.length) {
                    break;
                } else if (prepareArguments[i] instanceof SimpleJSCallback) {
                    final String callbackId = ((SimpleJSCallback) prepareArguments[i]).getCallbackId();
                    StringBuilder sb = new StringBuilder();
                    sb.append("[client][callNativeModuleStart],");
                    sb.append(this.mInstanceId);
                    sb.append(",");
                    MethodInvoker methodInvoker = (MethodInvoker) invoker;
                    sb.append(methodInvoker.mMethod.getDeclaringClass());
                    sb.append(",");
                    sb.append(methodInvoker.mMethod.getName());
                    sb.append(",");
                    sb.append(callbackId);
                    Log.d(WXAnalyzerDataTransfer.INTERACTION_TAG, sb.toString());
                    ((SimpleJSCallback) prepareArguments[i]).setInvokerCallback(new SimpleJSCallback.InvokerCallback() { // from class: com.taobao.weex.bridge.NativeInvokeHelper.1
                        @Override // com.taobao.weex.bridge.SimpleJSCallback.InvokerCallback
                        public void onInvokeSuccess() {
                            Log.d(WXAnalyzerDataTransfer.INTERACTION_TAG, "[client][callNativeModuleEnd]," + NativeInvokeHelper.this.mInstanceId + "," + ((MethodInvoker) invoker).mMethod.getDeclaringClass() + "," + ((MethodInvoker) invoker).mMethod.getName() + "," + callbackId);
                        }
                    });
                    break;
                } else {
                    i++;
                }
            }
        }
        if (invoker.isRunOnUIThread()) {
            WXSDKManager.getInstance().postOnUiThread(new Runnable() { // from class: com.taobao.weex.bridge.NativeInvokeHelper.2
                @Override // java.lang.Runnable
                public void run() {
                    if (invoker != null) {
                        try {
                            WXSDKInstance sDKInstance = WXSDKManager.getInstance().getSDKInstance(NativeInvokeHelper.this.mInstanceId);
                            if (sDKInstance != null && !sDKInstance.isDestroy()) {
                                invoker.invoke(target, prepareArguments);
                            }
                        } catch (Exception e) {
                            WXLogUtils.e("NativeInvokeHelper", target + " Invoker " + invoker.toString() + " exception:" + e);
                        }
                    }
                }
            }, 0L);
            return null;
        }
        return invoker.invoke(target, prepareArguments);
    }

    protected Object[] prepareArguments(Type[] paramClazzs, JSONArray args) throws Exception {
        Object[] objArr = new Object[paramClazzs.length];
        for (int i = 0; i < paramClazzs.length; i++) {
            Type type = paramClazzs[i];
            if (i >= args.size()) {
                if (!type.getClass().isPrimitive()) {
                    objArr[i] = null;
                } else {
                    throw new Exception("[prepareArguments] method argument list not match.");
                }
            } else {
                Object obj = args.get(i);
                if (type == JSONObject.class) {
                    if ((obj instanceof JSONObject) || obj == null) {
                        objArr[i] = obj;
                    } else if (obj instanceof String) {
                        objArr[i] = JSON.parseObject(obj.toString());
                    }
                } else if (JSCallback.class == type || UniJSCallback.class == type) {
                    if (obj instanceof String) {
                        objArr[i] = new SimpleJSCallback(this.mInstanceId, (String) obj);
                    } else {
                        throw new Exception("Parameter type not match.");
                    }
                } else {
                    objArr[i] = WXReflectionUtils.parseArgument(type, obj);
                }
            }
        }
        return objArr;
    }
}
