package com.taobao.weex.bridge;

import android.net.Uri;
import android.text.TextUtils;
import com.taobao.weex.WXEnvironment;
import com.taobao.weex.WXHttpListener;
import com.taobao.weex.WXSDKInstance;
import com.taobao.weex.WXSDKManager;
import com.taobao.weex.adapter.IWXHttpAdapter;
import com.taobao.weex.bridge.WXBridgeManager;
import com.taobao.weex.common.WXErrorCode;
import com.taobao.weex.common.WXRequest;
import com.taobao.weex.common.WXResponse;
import com.taobao.weex.http.WXHttpUtil;
import com.taobao.weex.utils.WXExceptionUtils;
import com.taobao.weex.utils.WXLogUtils;
import io.dcloud.common.constant.AbsoluteConst;
import io.dcloud.feature.uniapp.adapter.AbsURIAdapter;
import java.util.HashMap;
import java.util.Locale;
/* loaded from: classes8.dex */
public class RequestHandler {
    native void nativeInvokeOnFailed(long callback);

    native void nativeInvokeOnSuccess(long callback, String script, String bundleType);

    public static RequestHandler create() {
        return new RequestHandler();
    }

    public void send(String instanceId, String url, long nativeCallback) {
        if (TextUtils.isEmpty(instanceId) || TextUtils.isEmpty(url) || nativeCallback == 0 || !WXSDKManager.getInstance().getAllInstanceMap().containsKey(instanceId)) {
            return;
        }
        WXSDKManager wXSDKManager = WXSDKManager.getInstance();
        WXSDKInstance sDKInstance = WXSDKManager.getInstance().getSDKInstance(instanceId);
        if (sDKInstance == null) {
            return;
        }
        IWXHttpAdapter iWXHttpAdapter = WXSDKManager.getInstance().getIWXHttpAdapter();
        WXRequest wXRequest = new WXRequest();
        wXRequest.url = wXSDKManager.getURIAdapter().rewrite(sDKInstance, AbsURIAdapter.BUNDLE, Uri.parse(url)).toString();
        if (wXRequest.paramMap == null) {
            wXRequest.paramMap = new HashMap();
        }
        wXRequest.paramMap.put(WXHttpUtil.KEY_USER_AGENT, WXHttpUtil.assembleUserAgent(sDKInstance.getContext(), WXEnvironment.getConfig()));
        wXRequest.paramMap.put("isBundleRequest", AbsoluteConst.TRUE);
        WXLogUtils.i("Eagle", String.format(Locale.ENGLISH, "Weex eagle is going to download script from %s", url));
        iWXHttpAdapter.sendRequest(wXRequest, new OnHttpListenerInner(sDKInstance, nativeCallback, url));
    }

    public void getBundleType(String instanceId, final String content, final long nativeCallback) {
        WXBridgeManager.BundType bundleType = WXBridgeManager.getInstance().getBundleType("", content);
        final String bundType = bundleType == null ? "Others" : bundleType.toString();
        WXSDKInstance sDKInstance = WXSDKManager.getInstance().getSDKInstance(instanceId);
        if ("Others".equalsIgnoreCase(bundType) && sDKInstance != null) {
            WXErrorCode wXErrorCode = WXErrorCode.WX_KEY_EXCEPTION_NO_BUNDLE_TYPE;
            WXExceptionUtils.commitCriticalExceptionRT(instanceId, wXErrorCode, "RequestHandler.onSuccess", "eagle ->" + WXErrorCode.WX_KEY_EXCEPTION_NO_BUNDLE_TYPE.getErrorMsg(), null);
        }
        WXBridgeManager.getInstance().post(new Runnable() { // from class: com.taobao.weex.bridge.RequestHandler.1
            @Override // java.lang.Runnable
            public void run() {
                if (WXBridgeManager.getInstance().isJSFrameworkInit()) {
                    RequestHandler.this.nativeInvokeOnSuccess(nativeCallback, content, bundType);
                } else {
                    RequestHandler.this.nativeInvokeOnFailed(nativeCallback);
                }
            }
        });
    }

    /* loaded from: classes23.dex */
    class OnHttpListenerInner extends WXHttpListener {
        private long sNativeCallback;

        OnHttpListenerInner(WXSDKInstance instance, long nativeCallback, String bundlUrl) {
            super(instance, bundlUrl);
            this.sNativeCallback = nativeCallback;
        }

        @Override // com.taobao.weex.WXHttpListener
        public void onSuccess(WXResponse response) {
            final String str = new String(response.originalData);
            WXBridgeManager.BundType bundleType = WXBridgeManager.getInstance().getBundleType("", str);
            final String bundType = bundleType == null ? "Others" : bundleType.toString();
            if ("Others".equalsIgnoreCase(bundType) && getInstance() != null) {
                String instanceId = getInstance().getInstanceId();
                WXErrorCode wXErrorCode = WXErrorCode.WX_KEY_EXCEPTION_NO_BUNDLE_TYPE;
                WXExceptionUtils.commitCriticalExceptionRT(instanceId, wXErrorCode, "RequestHandler.onSuccess", "eagle ->" + WXErrorCode.WX_KEY_EXCEPTION_NO_BUNDLE_TYPE.getErrorMsg(), null);
            }
            WXBridgeManager.getInstance().post(new Runnable() { // from class: com.taobao.weex.bridge.RequestHandler.OnHttpListenerInner.1
                @Override // java.lang.Runnable
                public void run() {
                    if (WXBridgeManager.getInstance().isJSFrameworkInit()) {
                        RequestHandler.this.nativeInvokeOnSuccess(OnHttpListenerInner.this.sNativeCallback, str, bundType);
                    } else {
                        RequestHandler.this.nativeInvokeOnFailed(OnHttpListenerInner.this.sNativeCallback);
                    }
                }
            });
        }

        @Override // com.taobao.weex.WXHttpListener
        public void onFail(WXResponse response) {
            RequestHandler.this.nativeInvokeOnFailed(this.sNativeCallback);
        }
    }
}
