package com.taobao.weex.bridge;

import android.text.TextUtils;
import com.taobao.weex.common.WXJSService;
import io.dcloud.common.util.JSUtil;
import io.dcloud.common.util.StringUtil;
import java.util.Map;
import java.util.concurrent.ConcurrentHashMap;
/* loaded from: classes8.dex */
public class WXServiceManager {
    private static volatile ConcurrentHashMap<String, WXJSService> sInstanceJSServiceMap = new ConcurrentHashMap<>();

    public static boolean registerService(String name, String serviceScript, Map<String, Object> options) {
        if (TextUtils.isEmpty(name) || TextUtils.isEmpty(serviceScript)) {
            return false;
        }
        String str = "serviceName: \"" + name + JSUtil.QUOTE;
        for (String str2 : options.keySet()) {
            Object obj = options.get(str2);
            str = obj instanceof String ? str + ", '" + str2 + "': '" + obj + "'" : str + ", '" + str2 + "': " + obj;
        }
        String format = StringUtil.format(";(function(service, options){ ;%s; })({ %s }, { %s });", serviceScript, "register: global.registerService, unregister: global.unregisterService", str);
        WXJSService wXJSService = new WXJSService();
        wXJSService.setName(name);
        wXJSService.setScript(serviceScript);
        wXJSService.setOptions(options);
        sInstanceJSServiceMap.put(name, wXJSService);
        WXBridgeManager.getInstance().execJSService(format);
        return true;
    }

    public static boolean unRegisterService(String name) {
        if (TextUtils.isEmpty(name)) {
            return false;
        }
        sInstanceJSServiceMap.remove(name);
        WXBridgeManager.getInstance().execJSService(StringUtil.format("global.unregisterService( \"%s\" );", name));
        return true;
    }

    public static void execAllCacheJsService() {
        for (String str : sInstanceJSServiceMap.keySet()) {
            WXJSService wXJSService = sInstanceJSServiceMap.get(str);
            registerService(wXJSService.getName(), wXJSService.getScript(), wXJSService.getOptions());
        }
    }

    public static WXJSService getService(String serviceName) {
        if (sInstanceJSServiceMap != null) {
            return sInstanceJSServiceMap.get(serviceName);
        }
        return null;
    }

    public static void reload() {
        if (sInstanceJSServiceMap == null || sInstanceJSServiceMap.size() <= 0) {
            return;
        }
        WXBridgeManager.getInstance().post(new Runnable() { // from class: com.taobao.weex.bridge.WXServiceManager.1
            @Override // java.lang.Runnable
            public void run() {
                for (Map.Entry entry : WXServiceManager.sInstanceJSServiceMap.entrySet()) {
                    WXJSService wXJSService = (WXJSService) entry.getValue();
                    WXServiceManager.registerService(wXJSService.getName(), wXJSService.getScript(), wXJSService.getOptions());
                }
            }
        });
    }
}
