package com.taobao.weex.el.parse;

import com.taobao.weex.common.Constants;
import io.dcloud.common.constant.AbsoluteConst;
import java.lang.reflect.Array;
import java.util.HashMap;
import java.util.List;
import java.util.Map;
import java.util.Stack;
/* loaded from: classes8.dex */
public class Operators {
    public static final String AND = "&&";
    public static final String AND_NOT = "!";
    public static final char ARRAY_END = ']';
    public static final String ARRAY_END_STR = "]";
    public static final char ARRAY_SEPRATOR = ',';
    public static final String ARRAY_SEPRATOR_STR = ",";
    public static final char ARRAY_START = '[';
    public static final String ARRAY_START_STR = "[";
    public static final char BLOCK_END = '}';
    public static final String BLOCK_END_STR = "}";
    public static final char BLOCK_START = '{';
    public static final String BLOCK_START_STR = "{";
    public static final char BRACKET_END = ')';
    public static final String BRACKET_END_STR = ")";
    public static final char BRACKET_START = '(';
    public static final String BRACKET_START_STR = "(";
    public static final char CONDITION_IF = '?';
    public static final char CONDITION_IF_MIDDLE = ':';
    public static final String CONDITION_IF_STRING = "?";
    public static final String DIV = "/";
    public static final char DOLLAR = '$';
    public static final String DOLLAR_STR = "$";
    public static final char DOT = '.';
    public static final String DOT_STR = ".";
    public static final String EQUAL = "===";
    public static final String EQUAL2 = "==";
    public static final String G = ">";
    public static final String GE = ">=";
    public static final Map<String, Object> KEYWORDS;
    public static final String L = "<";
    public static final String LE = "<=";
    public static final String MOD = "%";
    public static final String MUL = "*";
    public static final String NOT_EQUAL = "!==";
    public static final String NOT_EQUAL2 = "!=";
    public static Map<String, Integer> OPERATORS_PRIORITY = null;
    public static final String OR = "||";
    public static final String PLUS = "+";
    public static final char QUOTE = '\"';
    public static final char SINGLE_QUOTE = '\'';
    public static final char SPACE = ' ';
    public static final String SPACE_STR = " ";
    public static final String SUB = "-";

    public static boolean isOpEnd(char op) {
        return op == ')' || op == ']' || op == ' ' || op == ',';
    }

    public static Object dot(Token left, Token right, Object context) {
        Object execute;
        Object execute2;
        if (left == null || right == null || (execute = left.execute(context)) == null) {
            return null;
        }
        if (right.getType() != 0) {
            Object execute3 = right.execute(context);
            if (execute3 instanceof Double) {
                execute3 = Integer.valueOf(((Double) execute3).intValue());
            }
            execute2 = el(execute, execute3 == null ? "" : execute3.toString().trim());
        } else {
            execute2 = right.execute(execute);
        }
        return execute2 != null ? execute2 : specialKey(execute, right.getToken());
    }

    public static Object el(Object context, String key) {
        if (context == null) {
            return null;
        }
        if (context instanceof ArrayStack) {
            ArrayStack arrayStack = (ArrayStack) context;
            for (int size = arrayStack.size() - 1; size >= 0; size--) {
                Object obj = arrayStack.get(size);
                if (obj instanceof Map) {
                    Map map = (Map) obj;
                    if (map.containsKey(key)) {
                        return map.get(key);
                    }
                }
            }
        }
        if (context instanceof Stack) {
            Stack stack = (Stack) context;
            for (int size2 = stack.size() - 1; size2 >= 0; size2--) {
                Object obj2 = stack.get(size2);
                if (obj2 instanceof Map) {
                    Map map2 = (Map) obj2;
                    if (map2.containsKey(key)) {
                        return map2.get(key);
                    }
                }
            }
        }
        if (context instanceof Map) {
            return ((Map) context).get(key);
        }
        if (context instanceof List) {
            try {
                return ((List) context).get(Integer.parseInt(key));
            } catch (Exception unused) {
            }
        }
        if (context.getClass().isArray()) {
            try {
                return Array.get(context, Integer.parseInt(key));
            } catch (Exception unused2) {
            }
        }
        return null;
    }

    public static Object specialKey(Object leftValue, String key) {
        if ("length".equals(key)) {
            if (leftValue instanceof CharSequence) {
                return Integer.valueOf(((CharSequence) leftValue).length());
            }
            boolean z = leftValue instanceof Map;
            if (z) {
                return Integer.valueOf(((Map) leftValue).size());
            }
            if (z) {
                return Integer.valueOf(((Map) leftValue).size());
            }
            if (leftValue instanceof List) {
                return Integer.valueOf(((List) leftValue).size());
            }
            if (leftValue.getClass().isArray()) {
                return Integer.valueOf(Array.getLength(leftValue));
            }
            return null;
        }
        return null;
    }

    public static Object plus(Token left, Token right, Object context) {
        Object execute = left != null ? left.execute(context) : null;
        Object execute2 = right != null ? right.execute(context) : null;
        if ((execute instanceof CharSequence) || (execute2 instanceof CharSequence)) {
            if (execute == null) {
                return execute2;
            }
            StringBuilder sb = new StringBuilder();
            sb.append(execute.toString());
            sb.append(execute2 != null ? execute2.toString() : "");
            return sb.toString();
        } else if ((execute instanceof Number) || (execute2 instanceof Number)) {
            return Double.valueOf(getNumber(execute) + getNumber(execute2));
        } else {
            if (execute == null && execute2 == null) {
                return null;
            }
            if (execute == null) {
                return execute2.toString();
            }
            StringBuilder sb2 = new StringBuilder();
            sb2.append(execute.toString());
            sb2.append(execute2 != null ? execute2.toString() : "");
            return sb2.toString();
        }
    }

    public static Object sub(Token left, Token right, Object context) {
        return Double.valueOf(getNumber(left != null ? left.execute(context) : null) - getNumber(right != null ? right.execute(context) : null));
    }

    public static Object div(Token left, Token right, Object context) {
        return Double.valueOf(getNumber(left != null ? left.execute(context) : null) / getNumber(right != null ? right.execute(context) : null));
    }

    public static Object mul(Token left, Token right, Object context) {
        return Double.valueOf(getNumber(left != null ? left.execute(context) : null) * getNumber(right != null ? right.execute(context) : null));
    }

    public static Object mod(Token left, Token right, Object context) {
        return Double.valueOf(getNumber(left != null ? left.execute(context) : null) % getNumber(right != null ? right.execute(context) : null));
    }

    public static Object condition(Token selfs, Token first, Token second, Object context) {
        if (selfs != null ? isTrue(selfs.execute(context)) : false) {
            if (first != null) {
                return first.execute(context);
            }
            return null;
        } else if (second != null) {
            return second.execute(context);
        } else {
            return null;
        }
    }

    public static boolean tokenTrue(Token selfs, Object context) {
        if (selfs == null) {
            return false;
        }
        return isTrue(selfs.execute(context));
    }

    public static double tokenNumber(Token self, Object context) {
        if (self == null) {
            return 0.0d;
        }
        return getNumber(self.execute(context));
    }

    public static boolean isEquals(Token left, Token right, Object context) {
        if (left == null && right == null) {
            return true;
        }
        Object execute = left != null ? left.execute(context) : null;
        Object execute2 = right != null ? right.execute(context) : null;
        if (execute == null) {
            if (execute2 == null) {
                return true;
            }
            return (execute2 instanceof CharSequence) && isEmpty(execute2.toString());
        } else if (execute2 == null) {
            return isEmpty(execute.toString());
        } else if (execute instanceof Number) {
            return execute2 instanceof Number ? ((Number) execute).doubleValue() == ((Number) execute2).doubleValue() : ((Number) execute).doubleValue() == getNumber(execute2);
        } else if (execute2 instanceof Number) {
            return getNumber(execute) == ((Number) execute2).doubleValue();
        } else if ((execute instanceof CharSequence) || (execute2 instanceof CharSequence)) {
            return execute.toString().trim().equals(execute2.toString().trim());
        } else {
            return execute.equals(execute2);
        }
    }

    public static boolean isTrue(Object value) {
        if (value == null) {
            return false;
        }
        if (value instanceof Number) {
            return ((Number) value).doubleValue() != 0.0d;
        }
        String trim = value.toString().trim();
        return (AbsoluteConst.FALSE.equals(trim) || Constants.Name.UNDEFINED.equals(trim) || "null".equals(trim) || isEmpty(trim)) ? false : true;
    }

    public static boolean isEmpty(String value) {
        if (value == null) {
            return true;
        }
        for (int i = 0; i < value.length(); i++) {
            if (value.charAt(i) != ' ') {
                return false;
            }
        }
        return true;
    }

    public static double getNumber(Object value) {
        if (value == null) {
            return 0.0d;
        }
        if (value instanceof Number) {
            return ((Number) value).doubleValue();
        }
        try {
            return Double.parseDouble(value.toString());
        } catch (Exception unused) {
            return 0.0d;
        }
    }

    public static boolean isOpEnd(String op) {
        return isOpEnd(op.charAt(0));
    }

    public static boolean isDot(String opStr) {
        char charAt = opStr.charAt(0);
        return charAt == '.' || charAt == '[';
    }

    static {
        HashMap hashMap = new HashMap();
        OPERATORS_PRIORITY = hashMap;
        hashMap.put(BLOCK_END_STR, 0);
        OPERATORS_PRIORITY.put(BRACKET_END_STR, 0);
        OPERATORS_PRIORITY.put(SPACE_STR, 0);
        OPERATORS_PRIORITY.put(",", 0);
        OPERATORS_PRIORITY.put(ARRAY_END_STR, 0);
        OPERATORS_PRIORITY.put(OR, 1);
        OPERATORS_PRIORITY.put(AND, 1);
        OPERATORS_PRIORITY.put(EQUAL, 2);
        OPERATORS_PRIORITY.put(EQUAL2, 2);
        OPERATORS_PRIORITY.put(NOT_EQUAL, 2);
        OPERATORS_PRIORITY.put(NOT_EQUAL2, 2);
        OPERATORS_PRIORITY.put(G, 7);
        OPERATORS_PRIORITY.put(GE, 7);
        OPERATORS_PRIORITY.put(L, 7);
        OPERATORS_PRIORITY.put(LE, 8);
        OPERATORS_PRIORITY.put(PLUS, 9);
        OPERATORS_PRIORITY.put(SUB, 9);
        OPERATORS_PRIORITY.put("*", 10);
        OPERATORS_PRIORITY.put("/", 10);
        OPERATORS_PRIORITY.put("%", 10);
        OPERATORS_PRIORITY.put(AND_NOT, 11);
        OPERATORS_PRIORITY.put(DOT_STR, 15);
        OPERATORS_PRIORITY.put(ARRAY_START_STR, 16);
        OPERATORS_PRIORITY.put(BRACKET_START_STR, 17);
        OPERATORS_PRIORITY.put(BLOCK_START_STR, 17);
        HashMap hashMap2 = new HashMap();
        KEYWORDS = hashMap2;
        hashMap2.put("null", null);
        hashMap2.put(AbsoluteConst.TRUE, Boolean.TRUE);
        hashMap2.put(AbsoluteConst.FALSE, Boolean.FALSE);
        hashMap2.put(Constants.Name.UNDEFINED, null);
    }
}
