package com.taobao.weex.http;

import android.net.Uri;
import android.text.TextUtils;
import android.util.Base64;
import com.alibaba.fastjson.JSONArray;
import com.alibaba.fastjson.JSONException;
import com.alibaba.fastjson.JSONObject;
import com.taobao.weex.WXEnvironment;
import com.taobao.weex.WXSDKInstance;
import com.taobao.weex.WXSDKManager;
import com.taobao.weex.adapter.IWXHttpAdapter;
import com.taobao.weex.annotation.JSMethod;
import com.taobao.weex.bridge.JSCallback;
import com.taobao.weex.bridge.WXBridgeManager;
import com.taobao.weex.common.WXModule;
import com.taobao.weex.common.WXRequest;
import com.taobao.weex.common.WXResponse;
import com.taobao.weex.el.parse.Operators;
import com.taobao.weex.http.Options;
import com.taobao.weex.ui.component.WXBasicComponentType;
import com.taobao.weex.utils.WXLogUtils;
import io.dcloud.common.constant.DOMException;
import io.dcloud.common.util.net.NetWork;
import io.dcloud.feature.uniapp.adapter.AbsURIAdapter;
import java.util.HashMap;
import java.util.List;
import java.util.Locale;
import java.util.Map;
import java.util.regex.Matcher;
import java.util.regex.Pattern;
/* loaded from: classes23.dex */
public class WXStreamModule extends WXModule {
    public static final String STATUS = "status";
    public static final String STATUS_TEXT = "statusText";
    final IWXHttpAdapter mAdapter;
    static final Pattern CHARSET_PATTERN = Pattern.compile("charset=([a-z0-9-]+)");
    public static HashMap<String, CertDTO> certMap = new HashMap<>();

    /* JADX INFO: Access modifiers changed from: private */
    /* loaded from: classes8.dex */
    public interface ResponseCallback {
        void onResponse(WXResponse response, Map<String, String> headers);
    }

    public WXStreamModule() {
        this(null);
    }

    public WXStreamModule(IWXHttpAdapter adapter) {
        this.mAdapter = adapter;
    }

    @JSMethod(uiThread = false)
    @Deprecated
    public void sendHttp(JSONObject paramsObj, final String callback) {
        String string = paramsObj.getString("method");
        String string2 = paramsObj.getString("url");
        JSONObject jSONObject = paramsObj.getJSONObject(WXBasicComponentType.HEADER);
        String string3 = paramsObj.getString("body");
        int intValue = paramsObj.getIntValue("timeout");
        boolean booleanValue = paramsObj.getBooleanValue("sslVerify");
        boolean booleanValue2 = paramsObj.getBooleanValue("firstIpv4");
        JSONObject jSONObject2 = paramsObj.getJSONObject("tls");
        if (string != null) {
            string = string.toUpperCase();
        }
        Options.Builder builder = new Options.Builder();
        if (!"GET".equals(string) && !"POST".equals(string) && !"PUT".equals(string) && !"DELETE".equals(string) && !"HEAD".equals(string) && !"PATCH".equals(string)) {
            string = "GET";
        }
        Options.Builder firstIpv4 = builder.setMethod(string).setUrl(string2).setBody(string3).setTimeout(intValue).setSslVerify(booleanValue).setAndroidTlsConfig(jSONObject2).setFirstIpv4(booleanValue2);
        extractHeaders(jSONObject, firstIpv4);
        final Options createOptions = firstIpv4.createOptions();
        sendRequest(firstIpv4.createOptions(), new ResponseCallback() { // from class: com.taobao.weex.http.WXStreamModule.1
            @Override // com.taobao.weex.http.WXStreamModule.ResponseCallback
            public void onResponse(WXResponse response, Map<String, String> headers) {
                String str;
                if (callback == null || WXStreamModule.this.mWXSDKInstance == null) {
                    return;
                }
                WXBridgeManager wXBridgeManager = WXBridgeManager.getInstance();
                String instanceId = WXStreamModule.this.mWXSDKInstance.getInstanceId();
                String str2 = callback;
                if (response == null || response.originalData == null) {
                    str = "{}";
                } else {
                    str = WXStreamModule.readAsString(response.originalData, headers != null ? WXStreamModule.getHeader(headers, NetWork.CONTENT_TYPE) : "", createOptions.getType());
                }
                wXBridgeManager.callback(instanceId, str2, str);
            }
        }, null, this.mWXSDKInstance.getInstanceId(), this.mWXSDKInstance.getBundleUrl());
    }

    @JSMethod(uiThread = false)
    public void fetch(JSONObject optionsObj, final JSCallback callback, JSCallback progressCallback) {
        fetch(optionsObj, callback, progressCallback, this.mWXSDKInstance.getInstanceId(), this.mWXSDKInstance.getBundleUrl());
    }

    @JSMethod(uiThread = false)
    public void fetchWithArrayBuffer(JSONObject arrayBufferObj, JSONObject optionsObj, final JSCallback callback, JSCallback progressCallback) {
        if (arrayBufferObj == null) {
            if (callback != null) {
                HashMap hashMap = new HashMap();
                hashMap.put("ok", false);
                hashMap.put(STATUS_TEXT, Status.ERR_INVALID_REQUEST);
                callback.invoke(hashMap);
                return;
            }
            return;
        }
        String string = arrayBufferObj.getString("@type");
        if (TextUtils.isEmpty(string) || !"binary".equalsIgnoreCase(string)) {
            if (callback != null) {
                HashMap hashMap2 = new HashMap();
                hashMap2.put("ok", false);
                hashMap2.put(STATUS_TEXT, Status.ERR_INVALID_REQUEST);
                callback.invoke(hashMap2);
                return;
            }
            return;
        }
        String string2 = arrayBufferObj.getString("base64");
        if (!TextUtils.isEmpty(string2)) {
            optionsObj.put("inputType", "base64");
            optionsObj.put("body", (Object) string2);
            fetch(optionsObj, callback, progressCallback, this.mWXSDKInstance.getInstanceId(), this.mWXSDKInstance.getBundleUrl());
        } else if (callback != null) {
            HashMap hashMap3 = new HashMap();
            hashMap3.put("ok", false);
            hashMap3.put(STATUS_TEXT, Status.ERR_INVALID_REQUEST);
            callback.invoke(hashMap3);
        }
    }

    @JSMethod(uiThread = false)
    public void configMTLS(JSONArray certArray, final JSCallback callback) {
        if (callback == null) {
            return;
        }
        if (certArray == null || certArray.isEmpty()) {
            callback.invoke(CertJSResponse.obtainFail(-1, DOMException.MSG_PARAMETER_ERROR));
            return;
        }
        certMap.clear();
        for (int i = 0; i < certArray.size(); i++) {
            JSONObject jSONObject = certArray.getJSONObject(i);
            if (jSONObject.containsKey("host")) {
                CertDTO certDTO = new CertDTO();
                String string = jSONObject.getString("host");
                certDTO.host = string;
                certDTO.client = jSONObject.getString("client");
                certDTO.clientPassword = jSONObject.getString("clientPassword");
                certDTO.server = (String[]) jSONObject.getJSONArray("server").toArray(new String[0]);
                certMap.put(string, certDTO);
            }
        }
        callback.invoke(CertJSResponse.obtainSuccess());
    }

    public void fetch(JSONObject optionsObj, final JSCallback callback, JSCallback progressCallback, String instanceId, String bundleURL) {
        if (optionsObj == null || optionsObj.getString("url") == null) {
            if (callback != null) {
                HashMap hashMap = new HashMap();
                hashMap.put("ok", false);
                hashMap.put(STATUS_TEXT, Status.ERR_INVALID_REQUEST);
                callback.invoke(hashMap);
                return;
            }
            return;
        }
        String string = optionsObj.getString("method");
        String string2 = optionsObj.getString("url");
        JSONObject jSONObject = optionsObj.getJSONObject("headers");
        String string3 = optionsObj.getString("body");
        String string4 = optionsObj.getString("type");
        String string5 = optionsObj.getString("inputType");
        int intValue = optionsObj.getIntValue("timeout");
        JSONObject jSONObject2 = optionsObj.getJSONObject("tls");
        boolean booleanValue = optionsObj.getBooleanValue("sslVerify");
        boolean booleanValue2 = optionsObj.getBooleanValue("firstIpv4");
        WXSDKInstance sDKInstance = WXSDKManager.getInstance().getSDKInstance(instanceId);
        if (sDKInstance != null && sDKInstance.getStreamNetworkHandler() != null) {
            String fetchLocal = sDKInstance.getStreamNetworkHandler().fetchLocal(string2);
            if (!TextUtils.isEmpty(fetchLocal)) {
                string2 = fetchLocal;
            }
        }
        if (string != null) {
            string = string.toUpperCase();
        }
        Options.Builder builder = new Options.Builder();
        if (!"GET".equals(string) && !"POST".equals(string) && !"PUT".equals(string) && !"DELETE".equals(string) && !"HEAD".equals(string) && !"PATCH".equals(string)) {
            string = "GET";
        }
        Options.Builder firstIpv4 = builder.setMethod(string).setUrl(string2).setBody(string3).setType(string4).setInputTypes(string5).setTimeout(intValue).setSslVerify(booleanValue).setAndroidTlsConfig(jSONObject2).setFirstIpv4(booleanValue2);
        extractHeaders(jSONObject, firstIpv4);
        final Options createOptions = firstIpv4.createOptions();
        sendRequest(createOptions, new ResponseCallback() { // from class: com.taobao.weex.http.WXStreamModule.2
            @Override // com.taobao.weex.http.WXStreamModule.ResponseCallback
            public void onResponse(WXResponse response, Map<String, String> headers) {
                if (callback != null) {
                    HashMap hashMap2 = new HashMap();
                    if (response == null || "-1".equals(response.statusCode)) {
                        hashMap2.put("status", -1);
                        hashMap2.put(WXStreamModule.STATUS_TEXT, Status.ERR_CONNECT_FAILED);
                        if (response != null) {
                            hashMap2.put("errorMsg", response.errorMsg);
                        } else {
                            hashMap2.put("errorMsg", "response 为空");
                        }
                    } else {
                        int parseInt = Integer.parseInt(response.statusCode);
                        hashMap2.put("status", Integer.valueOf(parseInt));
                        hashMap2.put("ok", Boolean.valueOf(parseInt >= 200 && parseInt <= 299));
                        if (response.originalData == null) {
                            hashMap2.put("data", response.errorMsg);
                        } else {
                            try {
                                hashMap2.put("data", WXStreamModule.this.parseData(WXStreamModule.readAsString(response.originalData, headers != null ? WXStreamModule.getHeader(headers, NetWork.CONTENT_TYPE) : "", createOptions.getType()), createOptions.getType()));
                            } catch (JSONException e) {
                                WXLogUtils.e("", e);
                                hashMap2.put("ok", false);
                                hashMap2.put("data", "{'err':'Data parse failed!'}");
                            }
                        }
                        hashMap2.put(WXStreamModule.STATUS_TEXT, Status.getStatusText(response.statusCode));
                    }
                    hashMap2.put("headers", headers);
                    callback.invoke(hashMap2);
                }
            }
        }, progressCallback, instanceId, bundleURL);
    }

    Object parseData(String data, Options.Type type) throws JSONException {
        if (type == Options.Type.json) {
            return JSONObject.parse(data);
        }
        if (type == Options.Type.jsonp) {
            if (data == null || data.isEmpty()) {
                return new JSONObject();
            }
            int indexOf = data.indexOf(Operators.BRACKET_START_STR) + 1;
            int lastIndexOf = data.lastIndexOf(Operators.BRACKET_END_STR);
            if (indexOf == 0 || indexOf >= lastIndexOf || lastIndexOf <= 0) {
                return new JSONObject();
            }
            return JSONObject.parse(data.substring(indexOf, lastIndexOf));
        }
        return data;
    }

    static String getHeader(Map<String, String> headers, String key) {
        if (headers == null || key == null) {
            return null;
        }
        if (headers.containsKey(key)) {
            return headers.get(key);
        }
        return headers.get(key.toLowerCase(Locale.ENGLISH));
    }

    /* JADX WARN: Removed duplicated region for block: B:11:0x0027 A[Catch: Exception -> 0x002d, TRY_LEAVE, TryCatch #0 {Exception -> 0x002d, blocks: (B:7:0x001d, B:9:0x0021, B:11:0x0027), top: B:16:0x001d }] */
    /* JADX WARN: Removed duplicated region for block: B:9:0x0021 A[Catch: Exception -> 0x002d, TryCatch #0 {Exception -> 0x002d, blocks: (B:7:0x001d, B:9:0x0021, B:11:0x0027), top: B:16:0x001d }] */
    /*
        Code decompiled incorrectly, please refer to instructions dump.
    */
    static String readAsString(byte[] data, String cType, Options.Type type) {
        String str;
        try {
            if (cType != null) {
                Matcher matcher = CHARSET_PATTERN.matcher(cType.toLowerCase(Locale.ENGLISH));
                if (matcher.find()) {
                    str = matcher.group(1);
                    if (type != Options.Type.base64) {
                        return Base64.encodeToString(data, 2);
                    }
                    return new String(data, str);
                }
            }
            if (type != Options.Type.base64) {
            }
        } catch (Exception e) {
            WXLogUtils.e("", e);
            return new String(data);
        }
        str = "utf-8";
    }

    private void extractHeaders(JSONObject headers, Options.Builder builder) {
        String assembleUserAgent = WXHttpUtil.assembleUserAgent(WXEnvironment.getApplication(), WXEnvironment.getConfig());
        if (headers != null) {
            for (String str : headers.keySet()) {
                if (str.equals(WXHttpUtil.KEY_USER_AGENT)) {
                    assembleUserAgent = headers.getString(str);
                } else {
                    builder.putHeader(str, headers.getString(str));
                }
            }
        }
        builder.putHeader(WXHttpUtil.KEY_USER_AGENT, assembleUserAgent);
    }

    private void sendRequest(Options options, ResponseCallback callback, JSCallback progressCallback, String instanceId, String bundleURL) {
        WXRequest wXRequest = new WXRequest();
        wXRequest.method = options.getMethod();
        wXRequest.url = WXSDKManager.getInstance().getURIAdapter().rewrite(bundleURL, AbsURIAdapter.REQUEST, Uri.parse(options.getUrl())).toString();
        wXRequest.body = options.getBody();
        wXRequest.timeoutMs = options.getTimeout();
        wXRequest.instanceId = instanceId;
        wXRequest.sslVerify = options.getSslVerify();
        wXRequest.isFirstIpv4 = options.isFirstIpv4();
        wXRequest.tls = options.getTlsConfig();
        if ("BASE64".equalsIgnoreCase(options.getInputType())) {
            wXRequest.inputType = "BASE64";
        } else {
            wXRequest.inputType = "";
        }
        if (options.getHeaders() != null) {
            if (wXRequest.paramMap == null) {
                wXRequest.paramMap = options.getHeaders();
            } else {
                wXRequest.paramMap.putAll(options.getHeaders());
            }
        }
        IWXHttpAdapter iWXHttpAdapter = this.mAdapter;
        if (iWXHttpAdapter == null) {
            iWXHttpAdapter = WXSDKManager.getInstance().getIWXHttpAdapter();
        }
        if (iWXHttpAdapter != null) {
            iWXHttpAdapter.sendRequest(wXRequest, new StreamHttpListener(callback, progressCallback));
        } else {
            WXLogUtils.e("WXStreamModule", "No HttpAdapter found,request failed.");
        }
    }

    /* JADX INFO: Access modifiers changed from: private */
    /* loaded from: classes18.dex */
    public static class StreamHttpListener implements IWXHttpAdapter.OnHttpListener {
        private ResponseCallback mCallback;
        private JSCallback mProgressCallback;
        private Map<String, String> mRespHeaders;
        private Map<String, Object> mResponse;

        @Override // com.taobao.weex.adapter.IWXHttpAdapter.OnHttpListener
        public void onHttpUploadProgress(int uploadProgress) {
        }

        private StreamHttpListener(ResponseCallback callback, JSCallback progressCallback) {
            this.mResponse = new HashMap();
            this.mCallback = callback;
            this.mProgressCallback = progressCallback;
        }

        @Override // com.taobao.weex.adapter.IWXHttpAdapter.OnHttpListener
        public void onHttpStart() {
            if (this.mProgressCallback != null) {
                this.mResponse.put("readyState", 1);
                this.mResponse.put("length", 0);
                this.mProgressCallback.invokeAndKeepAlive(new HashMap(this.mResponse));
            }
        }

        @Override // com.taobao.weex.adapter.IWXHttpAdapter.OnHttpListener
        public void onHeadersReceived(int statusCode, Map<String, List<String>> headers) {
            this.mResponse.put("readyState", 2);
            this.mResponse.put("status", Integer.valueOf(statusCode));
            HashMap hashMap = new HashMap();
            if (headers != null) {
                for (Map.Entry<String, List<String>> entry : headers.entrySet()) {
                    if (entry.getValue().size() != 0) {
                        if (entry.getValue().size() == 1) {
                            hashMap.put(entry.getKey() != null ? entry.getKey() : "_", entry.getValue().get(0));
                        } else {
                            hashMap.put(entry.getKey() != null ? entry.getKey() : "_", entry.getValue().toString());
                        }
                    }
                }
            }
            this.mResponse.put("headers", hashMap);
            this.mRespHeaders = hashMap;
            JSCallback jSCallback = this.mProgressCallback;
            if (jSCallback != null) {
                jSCallback.invokeAndKeepAlive(new HashMap(this.mResponse));
            }
        }

        @Override // com.taobao.weex.adapter.IWXHttpAdapter.OnHttpListener
        public void onHttpResponseProgress(int loadedLength) {
            this.mResponse.put("length", Integer.valueOf(loadedLength));
            JSCallback jSCallback = this.mProgressCallback;
            if (jSCallback != null) {
                jSCallback.invokeAndKeepAlive(new HashMap(this.mResponse));
            }
        }

        @Override // com.taobao.weex.adapter.IWXHttpAdapter.OnHttpListener
        public void onHttpFinish(final WXResponse response) {
            ResponseCallback responseCallback = this.mCallback;
            if (responseCallback != null) {
                responseCallback.onResponse(response, this.mRespHeaders);
            }
            if (WXEnvironment.isApkDebugable()) {
                WXLogUtils.d("WXStreamModule", (response == null || response.originalData == null) ? "response data is NUll!" : new String(response.originalData));
            }
        }
    }
}
