package com.taobao.weex.performance;

import android.util.Log;
import com.taobao.weex.WXEnvironment;
import com.taobao.weex.WXSDKInstance;
import com.taobao.weex.WXSDKManager;
import com.taobao.weex.bridge.WXBridgeManager;
import com.taobao.weex.common.WXErrorCode;
import com.taobao.weex.common.WXJSExceptionInfo;
import com.taobao.weex.ui.component.WXComponent;
import com.taobao.weex.ui.component.list.template.TemplateDom;
import com.taobao.weex.utils.WXUtils;
import java.util.List;
import org.json.JSONObject;
/* loaded from: classes8.dex */
public class WXAnalyzerDataTransfer {
    private static final String GROUP = "WXAnalyzer";
    public static final String INTERACTION_TAG = "wxInteractionAnalyzer";
    private static final String MODULE_ERROR = "WXError";
    private static final String MODULE_WX_APM = "wxapm";
    public static boolean isOpenPerformance;
    private static boolean sOpenInteractionLog;

    public static void transferPerformance(String instanceId, String type, String key, Object value) {
        WXSDKInstance wXSDKInstance;
        if (isOpenPerformance) {
            if (sOpenInteractionLog && "stage".equals(type)) {
                Log.d(INTERACTION_TAG, "[client][stage]" + instanceId + "," + key + "," + value);
            }
            List<IWXAnalyzer> wXAnalyzerList = WXSDKManager.getInstance().getWXAnalyzerList();
            if (wXAnalyzerList == null || wXAnalyzerList.size() == 0 || (wXSDKInstance = WXSDKManager.getInstance().getAllInstanceMap().get(instanceId)) == null) {
                return;
            }
            try {
                String jSONObject = new JSONObject().put(key, value).toString();
                for (IWXAnalyzer iWXAnalyzer : wXAnalyzerList) {
                    iWXAnalyzer.transfer(MODULE_WX_APM, wXSDKInstance.getInstanceId(), type, jSONObject);
                }
            } catch (Exception e) {
                e.printStackTrace();
            }
        }
    }

    public static void transferInteractionInfo(WXComponent targetComponent) {
        List<IWXAnalyzer> wXAnalyzerList;
        if (!isOpenPerformance || (wXAnalyzerList = WXSDKManager.getInstance().getWXAnalyzerList()) == null || wXAnalyzerList.size() == 0) {
            return;
        }
        try {
            String jSONObject = new JSONObject().put("renderOriginDiffTime", WXUtils.getFixUnixTime() - targetComponent.getInstance().getWXPerformance().renderUnixTimeOrigin).put("type", targetComponent.getComponentType()).put("ref", targetComponent.getRef()).put("style", targetComponent.getStyles()).put(TemplateDom.KEY_ATTRS, targetComponent.getAttrs()).toString();
            for (IWXAnalyzer iWXAnalyzer : wXAnalyzerList) {
                iWXAnalyzer.transfer(MODULE_WX_APM, targetComponent.getInstanceId(), "wxinteraction", jSONObject);
            }
        } catch (Exception e) {
            e.printStackTrace();
        }
    }

    public static void transferError(WXJSExceptionInfo exceptionInfo, String instanceId) {
        List<IWXAnalyzer> wXAnalyzerList;
        WXSDKInstance sDKInstance;
        String str;
        if (!WXEnvironment.isApkDebugable() || (wXAnalyzerList = WXSDKManager.getInstance().getWXAnalyzerList()) == null || wXAnalyzerList.size() == 0 || (sDKInstance = WXSDKManager.getInstance().getSDKInstance(instanceId)) == null) {
            return;
        }
        WXErrorCode errCode = exceptionInfo.getErrCode();
        try {
            str = new JSONObject().put("instanceId", instanceId).put("url", sDKInstance.getBundleUrl()).put("errorCode", errCode.getErrorCode()).put("errorMsg", errCode.getErrorMsg()).put("errorGroup", errCode.getErrorGroup()).toString();
        } catch (Exception e) {
            e.printStackTrace();
            str = "";
        }
        for (IWXAnalyzer iWXAnalyzer : wXAnalyzerList) {
            iWXAnalyzer.transfer(GROUP, MODULE_ERROR, errCode.getErrorType().toString(), str);
        }
    }

    public static void switchInteractionLog(final boolean isOpen) {
        if (sOpenInteractionLog == isOpen || !WXEnvironment.JsFrameworkInit) {
            return;
        }
        sOpenInteractionLog = isOpen;
        WXBridgeManager.getInstance().registerCoreEnv("switchInteractionLog", String.valueOf(isOpen));
    }

    public static boolean isInteractionLogOpen() {
        return sOpenInteractionLog;
    }
}
