package com.taobao.weex.ui;

import android.text.TextUtils;
import android.view.ViewGroup;
import com.taobao.weex.WXSDKInstance;
import com.taobao.weex.dom.RenderContext;
import com.taobao.weex.ui.component.DCWXScroller;
import com.taobao.weex.ui.component.Scrollable;
import com.taobao.weex.ui.component.WXComponent;
import io.dcloud.feature.weex_scroller.view.DCWXScrollView;
import java.util.List;
import java.util.Map;
import java.util.concurrent.ConcurrentHashMap;
import java.util.concurrent.CopyOnWriteArrayList;
/* JADX INFO: Access modifiers changed from: package-private */
/* loaded from: classes18.dex */
public class RenderContextImpl implements RenderContext {
    private WXSDKInstance mWXSDKInstance;
    private Map<String, WXComponent> mRegistry = new ConcurrentHashMap();
    private List<DCWXScroller> mScrollers = new CopyOnWriteArrayList();
    private Map<String, WXComponent> mIdComponent = new ConcurrentHashMap();

    public RenderContextImpl(WXSDKInstance instance) {
        this.mWXSDKInstance = instance;
    }

    public void destroy() {
        this.mWXSDKInstance = null;
        try {
            this.mRegistry.clear();
        } catch (Throwable th) {
            th.printStackTrace();
        }
    }

    public WXSDKInstance getWXSDKInstance() {
        return this.mWXSDKInstance;
    }

    @Override // com.taobao.weex.dom.RenderContext
    public WXSDKInstance getInstance() {
        return this.mWXSDKInstance;
    }

    @Override // com.taobao.weex.dom.RenderContext
    public WXComponent getComponent(String ref) {
        return this.mRegistry.get(ref);
    }

    public WXComponent getComponentById(String id) {
        return this.mIdComponent.get(id);
    }

    public void registerComponent(String ref, WXComponent comp) {
        if (comp instanceof DCWXScroller) {
            this.mScrollers.add((DCWXScroller) comp);
        }
        if (comp.getAttrs().containsKey("id")) {
            String str = (String) comp.getAttrs().get("id");
            if (!TextUtils.isEmpty(str)) {
                this.mIdComponent.put(str, comp);
            }
        }
        this.mRegistry.put(ref, comp);
    }

    @Override // com.taobao.weex.dom.RenderContext
    public WXComponent unregisterComponent(String ref) {
        return this.mRegistry.remove(ref);
    }

    public void setAllScrollerScrollable(boolean scrollable, String ref) {
        if (this.mScrollers.size() > 0) {
            Scrollable parentScroller = getComponent(ref).getParentScroller();
            while (parentScroller != null) {
                if (parentScroller instanceof DCWXScroller) {
                    DCWXScroller dCWXScroller = (DCWXScroller) parentScroller;
                    ViewGroup innerView = dCWXScroller.getInnerView();
                    if (innerView instanceof DCWXScrollView) {
                        ((DCWXScrollView) innerView).setScrollable(scrollable);
                    }
                    parentScroller = dCWXScroller.getParentScroller();
                } else {
                    parentScroller = ((WXComponent) parentScroller).getParentScroller();
                }
            }
        }
    }

    public int getComponentCount() {
        return this.mRegistry.size();
    }
}
