package com.taobao.weex.ui;

import android.opengl.GLES10;
import android.text.TextUtils;
import com.taobao.weex.WXSDKInstance;
import com.taobao.weex.common.WXErrorCode;
import com.taobao.weex.common.WXRuntimeException;
import com.taobao.weex.common.WXThread;
import com.taobao.weex.dom.RenderContext;
import com.taobao.weex.performance.WXInstanceApm;
import com.taobao.weex.ui.action.BasicGraphicAction;
import com.taobao.weex.ui.action.GraphicActionBatchAction;
import com.taobao.weex.ui.component.WXComponent;
import com.taobao.weex.utils.WXExceptionUtils;
import com.taobao.weex.utils.WXLogUtils;
import com.taobao.weex.utils.WXUtils;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;
import java.util.concurrent.ConcurrentHashMap;
import javax.microedition.khronos.egl.EGL10;
import javax.microedition.khronos.egl.EGLConfig;
import javax.microedition.khronos.egl.EGLContext;
import javax.microedition.khronos.egl.EGLDisplay;
import javax.microedition.khronos.egl.EGLSurface;
/* loaded from: classes8.dex */
public class WXRenderManager {
    private static int mOpenGLRenderLimitValue = 0;
    private static int nativeBatchTimes = 0;
    private static final String sKeyAction = "Action";
    private String mCurrentBatchInstanceId = null;
    private ArrayList<Map<String, Object>> mBatchActions = new ArrayList<>();
    private final int MAX_DROP_FRAME_NATIVE_BATCH = 2000;
    private volatile ConcurrentHashMap<String, RenderContextImpl> mRenderContext = new ConcurrentHashMap<>();
    private WXRenderHandler mWXRenderHandler = new WXRenderHandler();

    public RenderContext getRenderContext(String instanceId) {
        return this.mRenderContext.get(instanceId);
    }

    public WXComponent getWXComponent(String instanceId, String ref) {
        RenderContext renderContext;
        if (instanceId == null || TextUtils.isEmpty(ref) || (renderContext = getRenderContext(instanceId)) == null) {
            return null;
        }
        return renderContext.getComponent(ref);
    }

    public WXComponent getWXComponentById(String instanceId, String ref) {
        RenderContextImpl renderContextImpl;
        if (instanceId == null || TextUtils.isEmpty(ref) || (renderContextImpl = this.mRenderContext.get(instanceId)) == null) {
            return null;
        }
        return renderContextImpl.getComponentById(ref);
    }

    public void setScrollable(String instanceId, boolean scrollable, String ref) {
        if (instanceId == null) {
            return;
        }
        this.mRenderContext.get(instanceId).setAllScrollerScrollable(scrollable, ref);
    }

    public WXSDKInstance getWXSDKInstance(String instanceId) {
        RenderContextImpl renderContextImpl = this.mRenderContext.get(instanceId);
        if (renderContextImpl == null) {
            return null;
        }
        return renderContextImpl.getWXSDKInstance();
    }

    public static int getOpenGLRenderLimitValue() {
        if (mOpenGLRenderLimitValue == 0) {
            int i = 0;
            try {
                EGL10 egl10 = (EGL10) EGLContext.getEGL();
                EGLDisplay eglGetDisplay = egl10.eglGetDisplay(EGL10.EGL_DEFAULT_DISPLAY);
                egl10.eglInitialize(eglGetDisplay, new int[2]);
                EGLConfig[] eGLConfigArr = new EGLConfig[1];
                int[] iArr = new int[1];
                egl10.eglChooseConfig(eglGetDisplay, new int[]{12351, 12430, 12329, 0, 12339, 1, 12344}, eGLConfigArr, 1, iArr);
                if (iArr[0] == 0) {
                    i = -1;
                    egl10.eglTerminate(eglGetDisplay);
                } else {
                    EGLConfig eGLConfig = eGLConfigArr[0];
                    EGLSurface eglCreatePbufferSurface = egl10.eglCreatePbufferSurface(eglGetDisplay, eGLConfig, new int[]{12375, 64, 12374, 64, 12344});
                    EGLContext eglCreateContext = egl10.eglCreateContext(eglGetDisplay, eGLConfig, EGL10.EGL_NO_CONTEXT, new int[]{12440, 1, 12344});
                    egl10.eglMakeCurrent(eglGetDisplay, eglCreatePbufferSurface, eglCreatePbufferSurface, eglCreateContext);
                    int[] iArr2 = new int[1];
                    GLES10.glGetIntegerv(3379, iArr2, 0);
                    egl10.eglMakeCurrent(eglGetDisplay, EGL10.EGL_NO_SURFACE, EGL10.EGL_NO_SURFACE, EGL10.EGL_NO_CONTEXT);
                    egl10.eglDestroySurface(eglGetDisplay, eglCreatePbufferSurface);
                    egl10.eglDestroyContext(eglGetDisplay, eglCreateContext);
                    egl10.eglTerminate(eglGetDisplay);
                    i = iArr2[0];
                }
            } catch (Exception e) {
                WXLogUtils.e(WXLogUtils.getStackTrace(e));
            }
            mOpenGLRenderLimitValue = i;
        }
        return mOpenGLRenderLimitValue;
    }

    public void postOnUiThread(Runnable runnable, long delayMillis) {
        this.mWXRenderHandler.postDelayed(WXThread.secure(runnable), delayMillis);
    }

    public void postOnUiThread(Runnable runnable, final String instanceId) {
        this.mWXRenderHandler.post(instanceId, WXThread.secure(runnable));
    }

    public void postOnUiThread(Runnable runnable) {
        this.mWXRenderHandler.post(WXThread.secure(runnable));
    }

    public void removeTask(Runnable runnable) {
        this.mWXRenderHandler.removeCallbacks(runnable);
    }

    public void removeRenderStatement(String instanceId) {
        if (!WXUtils.isUiThread()) {
            throw new WXRuntimeException("[WXRenderManager] removeRenderStatement can only be called in main thread");
        }
        RenderContextImpl remove = this.mRenderContext.remove(instanceId);
        if (remove != null) {
            remove.destroy();
        }
        if (instanceId == null) {
            this.mWXRenderHandler.removeCallbacksAndMessages(null);
        } else {
            this.mWXRenderHandler.removeMessages(instanceId.hashCode());
        }
    }

    private void postAllStashedGraphicAction(final String instanceId, final BasicGraphicAction action) {
        RenderContextImpl renderContextImpl = this.mRenderContext.get(instanceId);
        ArrayList arrayList = renderContextImpl != null ? new ArrayList(this.mBatchActions) : null;
        this.mBatchActions.clear();
        this.mCurrentBatchInstanceId = null;
        nativeBatchTimes = 0;
        if (renderContextImpl == null) {
            return;
        }
        ArrayList arrayList2 = new ArrayList(arrayList.size());
        for (int i = 0; i < arrayList.size(); i++) {
            Object obj = ((Map) arrayList.get(i)).get(sKeyAction);
            if (obj instanceof BasicGraphicAction) {
                BasicGraphicAction basicGraphicAction = (BasicGraphicAction) obj;
                if (basicGraphicAction.mActionType != 1 && basicGraphicAction.mActionType != 2) {
                    arrayList2.add(basicGraphicAction);
                }
            }
        }
        postGraphicAction(instanceId, new GraphicActionBatchAction(action.getWXSDKIntance(), action.getRef(), arrayList2));
    }

    public void postGraphicAction(final String instanceId, final BasicGraphicAction action) {
        if (this.mRenderContext.get(instanceId) == null) {
            return;
        }
        String str = this.mCurrentBatchInstanceId;
        if (str != null && instanceId != null && !str.equals(instanceId) && this.mBatchActions.size() > 0) {
            ArrayList<Map<String, Object>> arrayList = this.mBatchActions;
            Object obj = arrayList.get(arrayList.size() - 1).get(sKeyAction);
            if (obj instanceof BasicGraphicAction) {
                postAllStashedGraphicAction(this.mCurrentBatchInstanceId, (BasicGraphicAction) obj);
            }
        }
        if (action.mActionType == 2) {
            postAllStashedGraphicAction(instanceId, action);
            return;
        }
        if (action.mActionType == 1 || this.mBatchActions.size() > 0) {
            int i = nativeBatchTimes + 1;
            nativeBatchTimes = i;
            if (i > 2000) {
                postAllStashedGraphicAction(instanceId, action);
            } else {
                HashMap hashMap = new HashMap(1);
                action.mIsRunByBatch = true;
                hashMap.put(sKeyAction, action);
                this.mBatchActions.add(hashMap);
                this.mCurrentBatchInstanceId = instanceId;
                return;
            }
        }
        this.mWXRenderHandler.post(instanceId, action);
    }

    public void registerInstance(WXSDKInstance instance) {
        if (instance.getInstanceId() == null) {
            WXErrorCode wXErrorCode = WXErrorCode.WX_RENDER_ERR_INSTANCE_ID_NULL;
            WXExceptionUtils.commitCriticalExceptionRT(null, wXErrorCode, "registerInstance", WXErrorCode.WX_RENDER_ERR_INSTANCE_ID_NULL.getErrorMsg() + "instanceId is null", null);
            return;
        }
        this.mRenderContext.put(instance.getInstanceId(), new RenderContextImpl(instance));
    }

    public List<WXSDKInstance> getAllInstances() {
        if (this.mRenderContext == null || this.mRenderContext.isEmpty()) {
            return null;
        }
        ArrayList arrayList = new ArrayList();
        for (Map.Entry<String, RenderContextImpl> entry : this.mRenderContext.entrySet()) {
            RenderContextImpl value = entry.getValue();
            if (value != null) {
                arrayList.add(value.getWXSDKInstance());
            }
        }
        return arrayList;
    }

    public void registerComponent(String instanceId, String ref, WXComponent comp) {
        RenderContextImpl renderContextImpl = this.mRenderContext.get(instanceId);
        if (renderContextImpl != null) {
            renderContextImpl.registerComponent(ref, comp);
            if (renderContextImpl.getInstance() != null) {
                renderContextImpl.getInstance().getApmForInstance().updateMaxStats(WXInstanceApm.KEY_PAGE_STATS_MAX_COMPONENT_NUM, renderContextImpl.getComponentCount());
            }
        }
    }

    public WXComponent unregisterComponent(String instanceId, String ref) {
        RenderContextImpl renderContextImpl = this.mRenderContext.get(instanceId);
        if (renderContextImpl != null) {
            if (renderContextImpl.getInstance() != null) {
                renderContextImpl.getInstance().getApmForInstance().updateMaxStats(WXInstanceApm.KEY_PAGE_STATS_MAX_COMPONENT_NUM, renderContextImpl.getComponentCount());
            }
            return renderContextImpl.unregisterComponent(ref);
        }
        return null;
    }
}
