package com.taobao.weex.ui.action;

import androidx.collection.ArrayMap;
import com.taobao.weex.WXSDKInstance;
import com.taobao.weex.WXSDKManager;
import com.taobao.weex.bridge.WXBridgeManager;
import com.taobao.weex.common.Constants;
import com.taobao.weex.dom.CSSShorthand;
import com.taobao.weex.dom.transition.WXTransition;
import com.taobao.weex.ui.component.WXComponent;
import java.util.Map;
/* loaded from: classes23.dex */
public class GraphicActionUpdateStyle extends BasicGraphicAction {
    private WXComponent component;
    private boolean mIsBorderSet;
    private boolean mIsCausedByPesudo;
    private Map<String, Object> mStyle;

    public GraphicActionUpdateStyle(WXSDKInstance instance, String ref, Map<String, Object> style, Map<String, String> paddings, Map<String, String> margins, Map<String, String> borders) {
        this(instance, ref, style, paddings, margins, borders, false);
    }

    public GraphicActionUpdateStyle(WXSDKInstance instance, String ref, Map<String, Object> style, CSSShorthand paddings, CSSShorthand margins, CSSShorthand borders, boolean byPesudo) {
        super(instance, ref);
        this.mStyle = style;
        this.mIsCausedByPesudo = byPesudo;
        WXComponent wXComponent = WXSDKManager.getInstance().getWXRenderManager().getWXComponent(getPageId(), getRef());
        this.component = wXComponent;
        if (wXComponent == null) {
            return;
        }
        Map<String, Object> map = this.mStyle;
        if (map != null) {
            wXComponent.updateStyle(map, this.mIsCausedByPesudo);
            if (style.containsKey("transform") && this.component.getTransition() == null) {
                ArrayMap arrayMap = new ArrayMap(2);
                arrayMap.put("transform", style.get("transform"));
                arrayMap.put(Constants.Name.TRANSFORM_ORIGIN, style.get(Constants.Name.TRANSFORM_ORIGIN));
                this.component.addAnimationForElement(arrayMap);
            }
        }
        if (paddings != null) {
            this.component.setPaddings(paddings);
        }
        if (margins != null) {
            this.component.setMargins(margins);
        }
        if (borders != null) {
            this.mIsBorderSet = true;
            this.component.setBorders(borders);
        }
    }

    public GraphicActionUpdateStyle(WXSDKInstance instance, String ref, Map<String, Object> style, Map<String, String> paddings, Map<String, String> margins, Map<String, String> borders, boolean byPesudo) {
        super(instance, ref);
        this.mStyle = style;
        this.mIsCausedByPesudo = byPesudo;
        WXComponent wXComponent = WXSDKManager.getInstance().getWXRenderManager().getWXComponent(getPageId(), getRef());
        this.component = wXComponent;
        if (wXComponent == null) {
            return;
        }
        Map<String, Object> map = this.mStyle;
        if (map != null) {
            wXComponent.addStyle(map, this.mIsCausedByPesudo);
            if (style.containsKey("transform") && this.component.getTransition() == null) {
                ArrayMap arrayMap = new ArrayMap(2);
                arrayMap.put("transform", style.get("transform"));
                arrayMap.put(Constants.Name.TRANSFORM_ORIGIN, style.get(Constants.Name.TRANSFORM_ORIGIN));
                this.component.addAnimationForElement(arrayMap);
                WXBridgeManager.getInstance().markDirty(this.component.getInstanceId(), this.component.getRef(), true);
            }
        }
        if (paddings != null) {
            this.component.addShorthand(paddings);
        }
        if (margins != null) {
            this.component.addShorthand(margins);
        }
        if (borders != null) {
            this.mIsBorderSet = true;
            this.component.addShorthand(borders);
        }
    }

    @Override // com.taobao.weex.ui.action.IExecutable
    public void executeAction() {
        WXComponent wXComponent = this.component;
        if (wXComponent == null || wXComponent.getInstance() == null) {
            return;
        }
        Map<String, Object> map = this.mStyle;
        if (map != null && map.size() > 0) {
            if (this.component.getTransition() != null) {
                this.component.getTransition().updateTranstionParams(this.mStyle);
                if (this.component.getTransition().hasTransitionProperty(this.mStyle)) {
                    this.component.getTransition().startTransition(this.mStyle);
                    return;
                }
                return;
            }
            WXComponent wXComponent2 = this.component;
            wXComponent2.setTransition(WXTransition.fromMap(this.mStyle, wXComponent2));
            this.component.updateStyles(this.mStyle);
        } else if (this.mIsBorderSet) {
            WXComponent wXComponent3 = this.component;
            wXComponent3.updateStyles(wXComponent3);
        }
    }
}
