package com.taobao.weex.ui.component;

import android.app.Activity;
import android.content.Context;
import android.graphics.Rect;
import android.text.Editable;
import android.text.InputFilter;
import android.text.TextPaint;
import android.text.TextUtils;
import android.text.TextWatcher;
import android.text.method.PasswordTransformationMethod;
import android.util.Log;
import android.view.KeyEvent;
import android.view.View;
import android.view.inputmethod.InputMethodManager;
import android.widget.EditText;
import android.widget.TextView;
import androidx.core.view.GravityCompat;
import com.alibaba.fastjson.JSONObject;
import com.facebook.common.callercontext.ContextChain;
import com.taobao.weex.WXSDKInstance;
import com.taobao.weex.WXSDKManager;
import com.taobao.weex.annotation.JSMethod;
import com.taobao.weex.bridge.WXBridgeManager;
import com.taobao.weex.common.Constants;
import com.taobao.weex.common.WXThread;
import com.taobao.weex.dom.CSSConstants;
import com.taobao.weex.dom.WXEvent;
import com.taobao.weex.dom.WXStyle;
import com.taobao.weex.layout.ContentBoxMeasurement;
import com.taobao.weex.layout.MeasureMode;
import com.taobao.weex.ui.action.BasicComponentData;
import com.taobao.weex.ui.component.WXComponent;
import com.taobao.weex.ui.component.helper.SoftKeyboardDetector;
import com.taobao.weex.ui.component.helper.WXTimeInputHelper;
import com.taobao.weex.ui.component.list.template.TemplateDom;
import com.taobao.weex.ui.view.WXEditText;
import com.taobao.weex.utils.TypefaceUtil;
import com.taobao.weex.utils.WXLogUtils;
import com.taobao.weex.utils.WXResourceUtils;
import com.taobao.weex.utils.WXUtils;
import com.taobao.weex.utils.WXViewUtils;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.regex.Pattern;
import java.util.regex.PatternSyntaxException;
/* loaded from: classes25.dex */
public abstract class AbstractEditComponent extends WXComponent<WXEditText> {
    private static final int MAX_TEXT_FORMAT_REPEAT = 3;
    private boolean mAutoFocus;
    private String mBeforeText;
    private int mEditorAction;
    private List<TextView.OnEditorActionListener> mEditorActionListeners;
    private int mFormatRepeatCount;
    private TextFormatter mFormatter;
    private boolean mIgnoreNextOnInputEvent;
    private final InputMethodManager mInputMethodManager;
    private boolean mKeepSelectionIndex;
    private String mLastValue;
    private int mLineHeight;
    private boolean mListeningKeyboard;
    private String mMax;
    private String mMin;
    private WXComponent.OnClickListener mOnClickListener;
    private TextPaint mPaint;
    private String mReturnKeyType;
    private TextWatcher mTextChangedEventDispatcher;
    private List<TextWatcher> mTextChangedListeners;
    private String mType;
    private SoftKeyboardDetector.Unregister mUnregister;

    /* loaded from: classes8.dex */
    private interface ReturnTypes {
        public static final String DEFAULT = "default";
        public static final String DONE = "done";
        public static final String GO = "go";
        public static final String NEXT = "next";
        public static final String SEARCH = "search";
        public static final String SEND = "send";
    }

    protected int getVerticalGravity() {
        return 16;
    }

    public AbstractEditComponent(WXSDKInstance instance, WXVContainer parent, boolean isLazy, BasicComponentData basicComponentData) {
        super(instance, parent, isLazy, basicComponentData);
        this.mBeforeText = "";
        this.mType = "text";
        this.mMax = null;
        this.mMin = null;
        this.mLastValue = "";
        this.mEditorAction = 6;
        this.mReturnKeyType = null;
        this.mListeningKeyboard = false;
        this.mIgnoreNextOnInputEvent = false;
        this.mKeepSelectionIndex = false;
        this.mFormatter = null;
        this.mFormatRepeatCount = 0;
        this.mPaint = new TextPaint();
        this.mLineHeight = -1;
        this.mOnClickListener = new WXComponent.OnClickListener() { // from class: com.taobao.weex.ui.component.AbstractEditComponent.3
            @Override // com.taobao.weex.ui.component.WXComponent.OnClickListener
            public void onHostViewClick() {
                String str = AbstractEditComponent.this.mType;
                str.hashCode();
                if (str.equals("date")) {
                    AbstractEditComponent.this.hideSoftKeyboard();
                    if (AbstractEditComponent.this.getParent() != null) {
                        AbstractEditComponent.this.getParent().interceptFocus();
                    }
                    WXTimeInputHelper.pickDate(AbstractEditComponent.this.mMax, AbstractEditComponent.this.mMin, AbstractEditComponent.this);
                } else if (str.equals(Constants.Value.TIME)) {
                    AbstractEditComponent.this.hideSoftKeyboard();
                    if (AbstractEditComponent.this.getParent() != null) {
                        AbstractEditComponent.this.getParent().interceptFocus();
                    }
                    WXTimeInputHelper.pickTime(AbstractEditComponent.this);
                }
            }
        };
        this.mInputMethodManager = (InputMethodManager) getContext().getSystemService("input_method");
        setContentBoxMeasurement(new ContentBoxMeasurement() { // from class: com.taobao.weex.ui.component.AbstractEditComponent.1
            @Override // com.taobao.weex.layout.ContentBoxMeasurement
            public void layoutAfter(float computedWidth, float computedHeight) {
            }

            @Override // com.taobao.weex.layout.ContentBoxMeasurement
            public void measureInternal(float width, float height, int widthMeasureMode, int heightMeasureMode) {
                width = (CSSConstants.isUndefined(width) || widthMeasureMode == MeasureMode.UNSPECIFIED) ? 0.0f : 0.0f;
                this.mMeasureWidth = width;
                this.mMeasureHeight = AbstractEditComponent.this.getMeasureHeight();
            }

            @Override // com.taobao.weex.layout.ContentBoxMeasurement
            public void layoutBefore() {
                AbstractEditComponent.this.updateStyleAndAttrs();
            }
        });
    }

    @Override // com.taobao.weex.ui.component.WXComponent
    protected void layoutDirectionDidChanged(boolean isRTL) {
        int textAlign = getTextAlign((String) getStyles().get(Constants.Name.TEXT_ALIGN));
        if (textAlign <= 0) {
            textAlign = GravityCompat.START;
        }
        if (getHostView() instanceof WXEditText) {
            getHostView().setGravity(textAlign | getVerticalGravity());
        }
    }

    /* JADX INFO: Access modifiers changed from: protected */
    public final float getMeasuredLineHeight() {
        int i = this.mLineHeight;
        return (i == -1 || i <= 0) ? this.mPaint.getFontMetrics(null) : i;
    }

    protected float getMeasureHeight() {
        return getMeasuredLineHeight();
    }

    /* JADX INFO: Access modifiers changed from: protected */
    public void updateStyleAndAttrs() {
        if (getStyles().size() > 0) {
            int fontSize = getStyles().containsKey(Constants.Name.FONT_SIZE) ? WXStyle.getFontSize(getStyles(), getInstance().getDefaultFontSize(), getViewPortWidthForFloat()) : -1;
            String fontFamily = getStyles().containsKey(Constants.Name.FONT_FAMILY) ? WXStyle.getFontFamily(getStyles()) : null;
            int fontStyle = getStyles().containsKey(Constants.Name.FONT_STYLE) ? WXStyle.getFontStyle(getStyles()) : -1;
            int fontWeight = getStyles().containsKey(Constants.Name.FONT_WEIGHT) ? WXStyle.getFontWeight(getStyles()) : -1;
            int lineHeight = WXStyle.getLineHeight(getStyles(), getViewPortWidthForFloat());
            if (lineHeight != -1) {
                this.mLineHeight = lineHeight;
            }
            if (fontSize != -1) {
                this.mPaint.setTextSize(fontSize);
            }
            if (fontFamily != null) {
                TypefaceUtil.applyFontStyle(this.mPaint, fontStyle, fontWeight, fontFamily);
            }
        }
    }

    /* JADX INFO: Access modifiers changed from: protected */
    @Override // com.taobao.weex.ui.component.WXComponent
    public WXEditText initComponentHostView(Context context) {
        WXEditText wXEditText = new WXEditText(context, getInstanceId());
        appleStyleAfterCreated(wXEditText);
        return wXEditText;
    }

    /* JADX INFO: Access modifiers changed from: protected */
    @Override // com.taobao.weex.ui.component.WXComponent
    public void onHostViewInitialized(WXEditText host) {
        super.onHostViewInitialized((AbstractEditComponent) host);
        addFocusChangeListener(new WXComponent.OnFocusChangeListener() { // from class: com.taobao.weex.ui.component.AbstractEditComponent.2
            @Override // com.taobao.weex.ui.component.WXComponent.OnFocusChangeListener
            public void onFocusChange(boolean hasFocus) {
                if (!hasFocus) {
                    AbstractEditComponent.this.decideSoftKeyboard();
                }
                AbstractEditComponent.this.setPseudoClassStatus(Constants.PSEUDO.FOCUS, hasFocus);
            }
        });
        addKeyboardListener(host);
    }

    @Override // com.taobao.weex.ui.component.WXComponent
    protected boolean isConsumeTouch() {
        return !isDisabled();
    }

    private void applyOnClickListener() {
        addClickListener(this.mOnClickListener);
    }

    /* JADX INFO: Access modifiers changed from: protected */
    public void appleStyleAfterCreated(final WXEditText editText) {
        int textAlign = getTextAlign((String) getStyles().get(Constants.Name.TEXT_ALIGN));
        if (textAlign <= 0) {
            textAlign = GravityCompat.START;
        }
        editText.setGravity(textAlign | getVerticalGravity());
        int color = WXResourceUtils.getColor("#999999");
        if (color != Integer.MIN_VALUE) {
            editText.setHintTextColor(color);
        }
        TextWatcher textWatcher = new TextWatcher() { // from class: com.taobao.weex.ui.component.AbstractEditComponent.4
            @Override // android.text.TextWatcher
            public void beforeTextChanged(CharSequence s, int start, int count, int after) {
                if (AbstractEditComponent.this.mTextChangedListeners != null) {
                    for (TextWatcher textWatcher2 : AbstractEditComponent.this.mTextChangedListeners) {
                        textWatcher2.beforeTextChanged(s, start, count, after);
                    }
                }
            }

            @Override // android.text.TextWatcher
            public void onTextChanged(CharSequence s, int start, int before, int count) {
                if (AbstractEditComponent.this.mFormatter != null) {
                    String format = AbstractEditComponent.this.mFormatter.format(AbstractEditComponent.this.mFormatter.recover(s.toString()));
                    if (format.equals(s.toString()) || AbstractEditComponent.this.mFormatRepeatCount >= 3) {
                        AbstractEditComponent.this.mFormatRepeatCount = 0;
                    } else {
                        AbstractEditComponent.this.mFormatRepeatCount++;
                        int length = AbstractEditComponent.this.mFormatter.format(AbstractEditComponent.this.mFormatter.recover(s.subSequence(0, editText.getSelectionStart()).toString())).length();
                        editText.setText(format);
                        editText.setSelection(length);
                        return;
                    }
                }
                if (AbstractEditComponent.this.mTextChangedListeners != null) {
                    for (TextWatcher textWatcher2 : AbstractEditComponent.this.mTextChangedListeners) {
                        textWatcher2.onTextChanged(s, start, before, count);
                    }
                }
            }

            @Override // android.text.TextWatcher
            public void afterTextChanged(Editable s) {
                if (AbstractEditComponent.this.mTextChangedListeners != null) {
                    for (TextWatcher textWatcher2 : AbstractEditComponent.this.mTextChangedListeners) {
                        textWatcher2.afterTextChanged(s);
                    }
                }
            }
        };
        this.mTextChangedEventDispatcher = textWatcher;
        editText.addTextChangedListener(textWatcher);
        editText.setTextSize(0, WXStyle.getFontSize(getStyles(), getInstance().getDefaultFontSize(), getInstance().getInstanceViewPortWidthWithFloat()));
    }

    @Override // com.taobao.weex.ui.component.WXComponent
    public void addEvent(final String type) {
        super.addEvent(type);
        if (getHostView() == null || TextUtils.isEmpty(type)) {
            return;
        }
        final WXEditText hostView = getHostView();
        if (type.equals(Constants.Event.CHANGE)) {
            addFocusChangeListener(new WXComponent.OnFocusChangeListener() { // from class: com.taobao.weex.ui.component.AbstractEditComponent.5
                @Override // com.taobao.weex.ui.component.WXComponent.OnFocusChangeListener
                public void onFocusChange(boolean hasFocus) {
                    if (hasFocus) {
                        AbstractEditComponent.this.mLastValue = hostView.getText().toString();
                        return;
                    }
                    CharSequence text = hostView.getText();
                    if (text == null) {
                        text = "";
                    }
                    if (text.toString().equals(AbstractEditComponent.this.mLastValue)) {
                        return;
                    }
                    AbstractEditComponent.this.fireEvent(Constants.Event.CHANGE, text.toString());
                    AbstractEditComponent.this.mLastValue = hostView.getText().toString();
                }
            });
            addEditorActionListener(new TextView.OnEditorActionListener() { // from class: com.taobao.weex.ui.component.AbstractEditComponent.6
                @Override // android.widget.TextView.OnEditorActionListener
                public boolean onEditorAction(TextView v, int actionId, KeyEvent event) {
                    if (actionId == AbstractEditComponent.this.mEditorAction) {
                        CharSequence text = hostView.getText();
                        if (text == null) {
                            text = "";
                        }
                        if (!text.toString().equals(AbstractEditComponent.this.mLastValue)) {
                            AbstractEditComponent.this.fireEvent(Constants.Event.CHANGE, text.toString());
                            AbstractEditComponent.this.mLastValue = hostView.getText().toString();
                        }
                        if (AbstractEditComponent.this.getParent() != null) {
                            AbstractEditComponent.this.getParent().interceptFocus();
                        }
                        AbstractEditComponent.this.hideSoftKeyboard();
                        return true;
                    }
                    return false;
                }
            });
        } else if (type.equals("input")) {
            addTextChangedListener(new TextWatcher() { // from class: com.taobao.weex.ui.component.AbstractEditComponent.7
                @Override // android.text.TextWatcher
                public void afterTextChanged(Editable s) {
                }

                @Override // android.text.TextWatcher
                public void beforeTextChanged(CharSequence s, int start, int count, int after) {
                }

                @Override // android.text.TextWatcher
                public void onTextChanged(CharSequence s, int start, int before, int count) {
                    if (AbstractEditComponent.this.mIgnoreNextOnInputEvent) {
                        AbstractEditComponent.this.mIgnoreNextOnInputEvent = false;
                        AbstractEditComponent.this.mBeforeText = s.toString();
                    } else if (AbstractEditComponent.this.mBeforeText.equals(s.toString())) {
                    } else {
                        AbstractEditComponent.this.mBeforeText = s.toString();
                        AbstractEditComponent.this.fireEvent("input", s.toString());
                    }
                }
            });
        }
        if (Constants.Event.RETURN.equals(type)) {
            addEditorActionListener(new TextView.OnEditorActionListener() { // from class: com.taobao.weex.ui.component.AbstractEditComponent.8
                @Override // android.widget.TextView.OnEditorActionListener
                public boolean onEditorAction(TextView v, int actionId, KeyEvent event) {
                    if (actionId == AbstractEditComponent.this.mEditorAction) {
                        HashMap hashMap = new HashMap(2);
                        hashMap.put(Constants.Name.RETURN_KEY_TYPE, AbstractEditComponent.this.mReturnKeyType);
                        hashMap.put("value", v.getText().toString());
                        AbstractEditComponent.this.fireEvent(Constants.Event.RETURN, hashMap);
                        return true;
                    }
                    return false;
                }
            });
        }
        if (Constants.Event.KEYBOARD.equals(type)) {
            this.mListeningKeyboard = true;
        }
    }

    /* JADX INFO: Access modifiers changed from: private */
    public void fireEvent(String event, String value) {
        if (event != null) {
            HashMap hashMap = new HashMap(2);
            hashMap.put("value", value);
            hashMap.put("timeStamp", Long.valueOf(System.currentTimeMillis()));
            HashMap hashMap2 = new HashMap();
            HashMap hashMap3 = new HashMap();
            hashMap3.put("value", value);
            hashMap2.put(TemplateDom.KEY_ATTRS, hashMap3);
            WXSDKManager.getInstance().fireEvent(getInstanceId(), getRef(), event, hashMap, hashMap2);
        }
    }

    public void performOnChange(String value) {
        if (getEvents() != null) {
            WXEvent events = getEvents();
            String str = Constants.Event.CHANGE;
            if (!events.contains(Constants.Event.CHANGE)) {
                str = null;
            }
            fireEvent(str, value);
        }
    }

    /* JADX INFO: Access modifiers changed from: protected */
    @Override // com.taobao.weex.ui.component.WXComponent
    public boolean setProperty(String key, Object param) {
        key.hashCode();
        char c = 65535;
        switch (key.hashCode()) {
            case -1898657397:
                if (key.equals(Constants.Name.KEEP_SELECTION_INDEX)) {
                    c = 0;
                    break;
                }
                break;
            case -1576785488:
                if (key.equals(Constants.Name.PLACEHOLDER_COLOR)) {
                    c = 1;
                    break;
                }
                break;
            case -1065511464:
                if (key.equals(Constants.Name.TEXT_ALIGN)) {
                    c = 2;
                    break;
                }
                break;
            case -791400086:
                if (key.equals(Constants.Name.MAX_LENGTH)) {
                    c = 3;
                    break;
                }
                break;
            case 107876:
                if (key.equals("max")) {
                    c = 4;
                    break;
                }
                break;
            case 108114:
                if (key.equals(Constants.Name.MIN)) {
                    c = 5;
                    break;
                }
                break;
            case 3575610:
                if (key.equals("type")) {
                    c = 6;
                    break;
                }
                break;
            case 94842723:
                if (key.equals("color")) {
                    c = 7;
                    break;
                }
                break;
            case 102977279:
                if (key.equals(Constants.Name.LINES)) {
                    c = '\b';
                    break;
                }
                break;
            case 124732746:
                if (key.equals(Constants.Name.MAXLENGTH)) {
                    c = '\t';
                    break;
                }
                break;
            case 270940796:
                if (key.equals(Constants.Name.DISABLED)) {
                    c = '\n';
                    break;
                }
                break;
            case 365601008:
                if (key.equals(Constants.Name.FONT_SIZE)) {
                    c = 11;
                    break;
                }
                break;
            case 598246771:
                if (key.equals(Constants.Name.PLACEHOLDER)) {
                    c = '\f';
                    break;
                }
                break;
            case 914346044:
                if (key.equals(Constants.Name.SINGLELINE)) {
                    c = '\r';
                    break;
                }
                break;
            case 947486441:
                if (key.equals(Constants.Name.RETURN_KEY_TYPE)) {
                    c = 14;
                    break;
                }
                break;
            case 1625554645:
                if (key.equals(Constants.Name.ALLOW_COPY_PASTE)) {
                    c = 15;
                    break;
                }
                break;
            case 1667607689:
                if (key.equals(Constants.Name.AUTOFOCUS)) {
                    c = 16;
                    break;
                }
                break;
        }
        switch (c) {
            case 0:
                this.mKeepSelectionIndex = WXUtils.getBoolean(param, false).booleanValue();
                return true;
            case 1:
                String string = WXUtils.getString(param, null);
                if (string != null) {
                    setPlaceholderColor(string);
                }
                return true;
            case 2:
                String string2 = WXUtils.getString(param, null);
                if (string2 != null) {
                    setTextAlign(string2);
                }
                return true;
            case 3:
                Integer integer = WXUtils.getInteger(param, null);
                if (integer != null) {
                    setMaxLength(integer.intValue());
                }
                return true;
            case 4:
                setMax(String.valueOf(param));
                return true;
            case 5:
                setMin(String.valueOf(param));
                return true;
            case 6:
                String string3 = WXUtils.getString(param, null);
                if (string3 != null) {
                    setType(string3);
                }
                return true;
            case 7:
                String string4 = WXUtils.getString(param, null);
                if (string4 != null) {
                    setColor(string4);
                }
                return true;
            case '\b':
                Integer integer2 = WXUtils.getInteger(param, null);
                if (integer2 != null) {
                    setLines(integer2.intValue());
                }
                return true;
            case '\t':
                Integer integer3 = WXUtils.getInteger(param, null);
                if (integer3 != null) {
                    setMaxLength(integer3.intValue());
                }
                return true;
            case '\n':
                Boolean bool = WXUtils.getBoolean(param, null);
                if (bool != null && this.mHost != 0) {
                    if (bool.booleanValue()) {
                        ((WXEditText) this.mHost).setFocusable(false);
                        ((WXEditText) this.mHost).setFocusableInTouchMode(false);
                    } else {
                        ((WXEditText) this.mHost).setFocusableInTouchMode(true);
                        ((WXEditText) this.mHost).setFocusable(true);
                    }
                }
                return true;
            case 11:
                String string5 = WXUtils.getString(param, null);
                if (string5 != null) {
                    setFontSize(string5);
                }
                return true;
            case '\f':
                String string6 = WXUtils.getString(param, null);
                if (string6 != null) {
                    setPlaceholder(string6);
                }
                return true;
            case '\r':
                Boolean bool2 = WXUtils.getBoolean(param, null);
                if (bool2 != null) {
                    setSingleLine(bool2.booleanValue());
                }
                return true;
            case 14:
                setReturnKeyType(String.valueOf(param));
                return true;
            case 15:
                boolean booleanValue = WXUtils.getBoolean(param, true).booleanValue();
                if (getHostView() != null) {
                    getHostView().setAllowCopyPaste(booleanValue);
                }
                return true;
            case 16:
                Boolean bool3 = WXUtils.getBoolean(param, null);
                if (bool3 != null) {
                    setAutofocus(bool3.booleanValue());
                }
                return true;
            default:
                return super.setProperty(key, param);
        }
    }

    @WXComponentProp(name = Constants.Name.RETURN_KEY_TYPE)
    public void setReturnKeyType(String type) {
        if (getHostView() == null || type.equals(this.mReturnKeyType)) {
            return;
        }
        this.mReturnKeyType = type;
        type.hashCode();
        char c = 65535;
        switch (type.hashCode()) {
            case -906336856:
                if (type.equals("search")) {
                    c = 0;
                    break;
                }
                break;
            case 3304:
                if (type.equals("go")) {
                    c = 1;
                    break;
                }
                break;
            case 3089282:
                if (type.equals("done")) {
                    c = 2;
                    break;
                }
                break;
            case 3377907:
                if (type.equals("next")) {
                    c = 3;
                    break;
                }
                break;
            case 3526536:
                if (type.equals("send")) {
                    c = 4;
                    break;
                }
                break;
            case 1544803905:
                if (type.equals("default")) {
                    c = 5;
                    break;
                }
                break;
        }
        switch (c) {
            case 0:
                this.mEditorAction = 3;
                break;
            case 1:
                this.mEditorAction = 2;
                break;
            case 2:
                this.mEditorAction = 6;
                break;
            case 3:
                this.mEditorAction = 5;
                break;
            case 4:
                this.mEditorAction = 4;
                break;
            case 5:
                this.mEditorAction = 0;
                break;
        }
        blur();
        getHostView().setImeOptions(this.mEditorAction);
    }

    @WXComponentProp(name = Constants.Name.PLACEHOLDER)
    public void setPlaceholder(String placeholder) {
        if (placeholder == null || getHostView() == null) {
            return;
        }
        getHostView().setHint(placeholder);
    }

    @WXComponentProp(name = Constants.Name.PLACEHOLDER_COLOR)
    public void setPlaceholderColor(String color) {
        int color2;
        if (getHostView() == null || TextUtils.isEmpty(color) || (color2 = WXResourceUtils.getColor(color)) == Integer.MIN_VALUE) {
            return;
        }
        getHostView().setHintTextColor(color2);
    }

    @WXComponentProp(name = "type")
    public void setType(String type) {
        Log.e("weex", "setType=" + type);
        if (type == null || getHostView() == null || this.mType.equals(type)) {
            return;
        }
        this.mType = type;
        getHostView().setInputType(getInputType(this.mType));
        String str = this.mType;
        str.hashCode();
        if (str.equals("date") || str.equals(Constants.Value.TIME)) {
            applyOnClickListener();
        }
    }

    @WXComponentProp(name = Constants.Name.AUTOFOCUS)
    public void setAutofocus(boolean autofocus) {
        if (getHostView() == null) {
            return;
        }
        this.mAutoFocus = autofocus;
        WXEditText hostView = getHostView();
        if (this.mAutoFocus) {
            hostView.setFocusable(true);
            hostView.requestFocus();
            hostView.setFocusableInTouchMode(true);
            showSoftKeyboard();
            return;
        }
        hideSoftKeyboard();
    }

    @WXComponentProp(name = "value")
    public void setValue(String value) {
        WXEditText hostView = getHostView();
        if (hostView == null || TextUtils.equals(hostView.getText(), value)) {
            return;
        }
        this.mIgnoreNextOnInputEvent = true;
        int selectionStart = hostView.getSelectionStart();
        hostView.setText(value);
        if (!this.mKeepSelectionIndex) {
            selectionStart = value.length();
        }
        if (value == null) {
            selectionStart = 0;
        }
        hostView.setSelection(selectionStart);
    }

    @WXComponentProp(name = "color")
    public void setColor(String color) {
        int color2;
        if (getHostView() == null || TextUtils.isEmpty(color) || (color2 = WXResourceUtils.getColor(color)) == Integer.MIN_VALUE) {
            return;
        }
        getHostView().setTextColor(color2);
    }

    @WXComponentProp(name = Constants.Name.FONT_SIZE)
    public void setFontSize(String fontSize) {
        if (getHostView() == null || fontSize == null) {
            return;
        }
        HashMap hashMap = new HashMap(1);
        hashMap.put(Constants.Name.FONT_SIZE, fontSize);
        getHostView().setTextSize(0, WXStyle.getFontSize(hashMap, getInstance().getDefaultFontSize(), getInstance().getInstanceViewPortWidthWithFloat()));
    }

    @WXComponentProp(name = Constants.Name.TEXT_ALIGN)
    public void setTextAlign(String textAlign) {
        int textAlign2 = getTextAlign(textAlign);
        if (textAlign2 > 0) {
            getHostView().setGravity(textAlign2 | getVerticalGravity());
        }
    }

    @WXComponentProp(name = Constants.Name.SINGLELINE)
    public void setSingleLine(boolean singleLine) {
        if (getHostView() == null) {
            return;
        }
        getHostView().setSingleLine(singleLine);
    }

    @WXComponentProp(name = Constants.Name.LINES)
    public void setLines(int lines) {
        if (getHostView() == null) {
            return;
        }
        getHostView().setLines(lines);
    }

    @WXComponentProp(name = Constants.Name.MAX_LENGTH)
    public void setMaxLength(int maxLength) {
        if (getHostView() == null) {
            return;
        }
        getHostView().setFilters(new InputFilter[]{new InputFilter.LengthFilter(maxLength)});
    }

    @WXComponentProp(name = Constants.Name.MAXLENGTH)
    @Deprecated
    public void setMaxlength(int maxLength) {
        setMaxLength(maxLength);
    }

    private int getInputType(String type) {
        type.hashCode();
        char c = 65535;
        switch (type.hashCode()) {
            case -1034364087:
                if (type.equals("number")) {
                    c = 0;
                    break;
                }
                break;
            case 114715:
                if (type.equals(Constants.Value.TEL)) {
                    c = 1;
                    break;
                }
                break;
            case 116079:
                if (type.equals("url")) {
                    c = 2;
                    break;
                }
                break;
            case 3076014:
                if (type.equals("date")) {
                    c = 3;
                    break;
                }
                break;
            case 3556653:
                if (type.equals("text")) {
                    c = 4;
                    break;
                }
                break;
            case 3560141:
                if (type.equals(Constants.Value.TIME)) {
                    c = 5;
                    break;
                }
                break;
            case 96619420:
                if (type.equals("email")) {
                    c = 6;
                    break;
                }
                break;
            case 1216985755:
                if (type.equals(Constants.Value.PASSWORD)) {
                    c = 7;
                    break;
                }
                break;
            case 1793702779:
                if (type.equals(Constants.Value.DATETIME)) {
                    c = '\b';
                    break;
                }
                break;
        }
        switch (c) {
            case 0:
                return 8194;
            case 1:
                return 3;
            case 2:
                return 17;
            case 3:
                getHostView().setFocusable(false);
                break;
            case 4:
            default:
                return 1;
            case 5:
                if (getHostView() != null) {
                    getHostView().setFocusable(false);
                    break;
                }
                break;
            case 6:
                return 33;
            case 7:
                if (getHostView() != null) {
                    getHostView().setTransformationMethod(PasswordTransformationMethod.getInstance());
                    return 129;
                }
                return 129;
            case '\b':
                return 4;
        }
        return 0;
    }

    @WXComponentProp(name = "max")
    public void setMax(String max) {
        this.mMax = max;
    }

    @WXComponentProp(name = Constants.Name.MIN)
    public void setMin(String min) {
        this.mMin = min;
    }

    private boolean showSoftKeyboard() {
        if (getHostView() == null) {
            return false;
        }
        getHostView().postDelayed(WXThread.secure(new Runnable() { // from class: com.taobao.weex.ui.component.AbstractEditComponent.9
            @Override // java.lang.Runnable
            public void run() {
                AbstractEditComponent.this.mInputMethodManager.showSoftInput(AbstractEditComponent.this.getHostView(), 1);
            }
        }), 100L);
        return true;
    }

    /* JADX INFO: Access modifiers changed from: private */
    public void hideSoftKeyboard() {
        if (getHostView() != null) {
            getHostView().postDelayed(WXThread.secure(new Runnable() { // from class: com.taobao.weex.ui.component.AbstractEditComponent.10
                @Override // java.lang.Runnable
                public void run() {
                    AbstractEditComponent.this.mInputMethodManager.hideSoftInputFromWindow(AbstractEditComponent.this.getHostView().getWindowToken(), 0);
                }
            }), 16L);
        }
    }

    private int getTextAlign(String textAlign) {
        int i = isLayoutRTL() ? GravityCompat.END : GravityCompat.START;
        if (TextUtils.isEmpty(textAlign)) {
            return i;
        }
        if (textAlign.equals("left")) {
            return GravityCompat.START;
        }
        if (textAlign.equals("center")) {
            return 17;
        }
        return textAlign.equals("right") ? GravityCompat.END : i;
    }

    @JSMethod
    public void blur() {
        WXEditText hostView = getHostView();
        if (hostView == null || !hostView.hasFocus()) {
            return;
        }
        if (getParent() != null) {
            getParent().interceptFocus();
        }
        hostView.clearFocus();
        hideSoftKeyboard();
    }

    @JSMethod
    public void focus() {
        WXEditText hostView = getHostView();
        if (hostView == null || hostView.hasFocus()) {
            return;
        }
        if (getParent() != null) {
            getParent().ignoreFocus();
        }
        hostView.requestFocus();
        hostView.setFocusable(true);
        hostView.setFocusableInTouchMode(true);
        showSoftKeyboard();
    }

    /* JADX INFO: Access modifiers changed from: protected */
    @Override // com.taobao.weex.ui.component.WXComponent
    public Object convertEmptyProperty(String propName, Object originalValue) {
        propName.hashCode();
        if (propName.equals("color")) {
            return "black";
        }
        if (propName.equals(Constants.Name.FONT_SIZE)) {
            return Integer.valueOf(getInstance().getDefaultFontSize());
        }
        return super.convertEmptyProperty(propName, originalValue);
    }

    /* JADX INFO: Access modifiers changed from: private */
    public void decideSoftKeyboard() {
        final Context context;
        WXEditText hostView = getHostView();
        if (hostView == null || (context = getContext()) == null || !(context instanceof Activity)) {
            return;
        }
        hostView.postDelayed(WXThread.secure(new Runnable() { // from class: com.taobao.weex.ui.component.AbstractEditComponent.11
            @Override // java.lang.Runnable
            public void run() {
                View currentFocus = ((Activity) context).getCurrentFocus();
                if (currentFocus == null || (currentFocus instanceof EditText) || currentFocus.isFocused()) {
                    return;
                }
                AbstractEditComponent.this.mInputMethodManager.hideSoftInputFromWindow(AbstractEditComponent.this.getHostView().getWindowToken(), 0);
            }
        }), 16L);
    }

    @JSMethod
    public void setSelectionRange(int selectionStart, int selectionEnd) {
        int length;
        WXEditText hostView = getHostView();
        if (hostView == null || selectionStart > (length = getHostView().length()) || selectionEnd > length) {
            return;
        }
        focus();
        hostView.setSelection(selectionStart, selectionEnd);
    }

    @JSMethod
    public void getSelectionRange(String callbackId) {
        HashMap hashMap = new HashMap(2);
        WXEditText hostView = getHostView();
        if (hostView != null) {
            int selectionStart = hostView.getSelectionStart();
            int selectionEnd = hostView.getSelectionEnd();
            if (!hostView.hasFocus()) {
                selectionStart = 0;
                selectionEnd = 0;
            }
            hashMap.put(Constants.Name.SELECTION_START, Integer.valueOf(selectionStart));
            hashMap.put(Constants.Name.SELECTION_END, Integer.valueOf(selectionEnd));
        }
        WXBridgeManager.getInstance().callback(getInstanceId(), callbackId, hashMap, false);
    }

    @JSMethod
    public void setTextFormatter(JSONObject params) {
        try {
            String string = params.getString("formatRule");
            String string2 = params.getString("formatReplace");
            String string3 = params.getString("recoverRule");
            String string4 = params.getString("recoverReplace");
            PatternWrapper parseToPattern = parseToPattern(string, string2);
            PatternWrapper parseToPattern2 = parseToPattern(string3, string4);
            if (parseToPattern == null || parseToPattern2 == null) {
                return;
            }
            this.mFormatter = new TextFormatter(parseToPattern, parseToPattern2);
        } catch (Throwable th) {
            th.printStackTrace();
        }
    }

    protected final void addEditorActionListener(TextView.OnEditorActionListener listener) {
        WXEditText hostView;
        if (listener == null || (hostView = getHostView()) == null) {
            return;
        }
        if (this.mEditorActionListeners == null) {
            this.mEditorActionListeners = new ArrayList();
            hostView.setOnEditorActionListener(new TextView.OnEditorActionListener() { // from class: com.taobao.weex.ui.component.AbstractEditComponent.12
                private boolean handled = true;

                @Override // android.widget.TextView.OnEditorActionListener
                public boolean onEditorAction(TextView v, int actionId, KeyEvent event) {
                    for (TextView.OnEditorActionListener onEditorActionListener : AbstractEditComponent.this.mEditorActionListeners) {
                        if (onEditorActionListener != null) {
                            this.handled = onEditorActionListener.onEditorAction(v, actionId, event) & this.handled;
                        }
                    }
                    return this.handled;
                }
            });
        }
        this.mEditorActionListeners.add(listener);
    }

    public final void addTextChangedListener(TextWatcher watcher) {
        if (this.mTextChangedListeners == null) {
            this.mTextChangedListeners = new ArrayList();
        }
        this.mTextChangedListeners.add(watcher);
    }

    private void addKeyboardListener(final WXEditText host) {
        final Context context;
        if (host == null || (context = host.getContext()) == null || !(context instanceof Activity)) {
            return;
        }
        this.mUnregister = SoftKeyboardDetector.registerKeyboardEventListener((Activity) context, new SoftKeyboardDetector.OnKeyboardEventListener() { // from class: com.taobao.weex.ui.component.AbstractEditComponent.13
            @Override // com.taobao.weex.ui.component.helper.SoftKeyboardDetector.OnKeyboardEventListener
            public void onKeyboardEvent(boolean isShown) {
                if (AbstractEditComponent.this.mListeningKeyboard) {
                    if (AbstractEditComponent.this.getInstance() == null || AbstractEditComponent.this.getInstance().isDestroy()) {
                        return;
                    }
                    HashMap hashMap = new HashMap(1);
                    hashMap.put("isShow", Boolean.valueOf(isShown));
                    if (isShown) {
                        Rect rect = new Rect();
                        ((Activity) context).getWindow().getDecorView().getWindowVisibleDisplayFrame(rect);
                        hashMap.put("keyboardSize", Float.valueOf(WXViewUtils.getWebPxByWidth(WXViewUtils.getScreenHeight(context) - (rect.bottom - rect.top), AbstractEditComponent.this.getInstance().getInstanceViewPortWidthWithFloat())));
                    }
                    AbstractEditComponent.this.fireEvent(Constants.Event.KEYBOARD, hashMap);
                }
                if (isShown) {
                    return;
                }
                AbstractEditComponent.this.blur();
            }
        });
    }

    @Override // com.taobao.weex.ui.component.WXComponent
    public void destroy() {
        super.destroy();
        if (getHostView() != null) {
            getHostView().destroy();
        }
        SoftKeyboardDetector.Unregister unregister = this.mUnregister;
        if (unregister != null) {
            try {
                unregister.execute();
                this.mUnregister = null;
            } catch (Throwable th) {
                WXLogUtils.w("Unregister throw ", th);
            }
        }
    }

    private PatternWrapper parseToPattern(String jsPattern, String replace) {
        Pattern pattern;
        if (jsPattern == null || replace == null) {
            return null;
        }
        if (!Pattern.compile("/[\\S]+/[i]?[m]?[g]?").matcher(jsPattern).matches()) {
            WXLogUtils.w("WXInput", "Illegal js pattern syntax: " + jsPattern);
            return null;
        }
        String substring = jsPattern.substring(jsPattern.lastIndexOf("/") + 1);
        String substring2 = jsPattern.substring(jsPattern.indexOf("/") + 1, jsPattern.lastIndexOf("/"));
        int i = substring.contains(ContextChain.TAG_INFRA) ? 2 : 0;
        if (substring.contains(WXComponent.PROP_FS_MATCH_PARENT)) {
            i |= 32;
        }
        boolean contains = substring.contains("g");
        try {
            pattern = Pattern.compile(substring2, i);
        } catch (PatternSyntaxException unused) {
            WXLogUtils.w("WXInput", "Pattern syntax error: " + substring2);
            pattern = null;
        }
        if (pattern == null) {
            return null;
        }
        PatternWrapper patternWrapper = new PatternWrapper();
        patternWrapper.global = contains;
        patternWrapper.matcher = pattern;
        patternWrapper.replace = replace;
        return patternWrapper;
    }

    /* JADX INFO: Access modifiers changed from: private */
    /* loaded from: classes8.dex */
    public static class PatternWrapper {
        private boolean global;
        private Pattern matcher;
        private String replace;

        private PatternWrapper() {
            this.global = false;
        }
    }

    /* loaded from: classes8.dex */
    private static class TextFormatter {
        private PatternWrapper format;
        private PatternWrapper recover;

        private TextFormatter(PatternWrapper format, PatternWrapper recover) {
            this.format = format;
            this.recover = recover;
        }

        /* JADX INFO: Access modifiers changed from: private */
        public String format(String src) {
            try {
                PatternWrapper patternWrapper = this.format;
                if (patternWrapper != null) {
                    return patternWrapper.global ? this.format.matcher.matcher(src).replaceAll(this.format.replace) : this.format.matcher.matcher(src).replaceFirst(this.format.replace);
                }
            } catch (Throwable th) {
                WXLogUtils.w("WXInput", "[format] " + th.getMessage());
            }
            return src;
        }

        /* JADX INFO: Access modifiers changed from: private */
        public String recover(String formatted) {
            try {
                PatternWrapper patternWrapper = this.recover;
                if (patternWrapper != null) {
                    return patternWrapper.global ? this.recover.matcher.matcher(formatted).replaceAll(this.recover.replace) : this.recover.matcher.matcher(formatted).replaceFirst(this.recover.replace);
                }
            } catch (Throwable th) {
                WXLogUtils.w("WXInput", "[formatted] " + th.getMessage());
            }
            return formatted;
        }
    }
}
