package com.taobao.weex.ui.component;

import android.animation.ObjectAnimator;
import android.content.Context;
import android.graphics.Point;
import android.graphics.Rect;
import android.os.Build;
import android.os.Handler;
import android.os.Looper;
import android.text.TextUtils;
import android.view.GestureDetector;
import android.view.MotionEvent;
import android.view.View;
import android.view.ViewGroup;
import android.view.ViewTreeObserver;
import android.widget.FrameLayout;
import androidx.core.view.ViewCompat;
import com.alibaba.fastjson.JSON;
import com.alibaba.fastjson.JSONObject;
import com.taobao.weex.WXEnvironment;
import com.taobao.weex.WXSDKInstance;
import com.taobao.weex.WXSDKManager;
import com.taobao.weex.annotation.Component;
import com.taobao.weex.annotation.JSMethod;
import com.taobao.weex.bridge.JSCallback;
import com.taobao.weex.common.Constants;
import com.taobao.weex.common.ICheckBindingScroller;
import com.taobao.weex.common.OnWXScrollListener;
import com.taobao.weex.common.WXThread;
import com.taobao.weex.performance.WXInstanceApm;
import com.taobao.weex.ui.ComponentCreator;
import com.taobao.weex.ui.action.BasicComponentData;
import com.taobao.weex.ui.component.WXComponent;
import com.taobao.weex.ui.component.helper.ScrollStartEndHelper;
import com.taobao.weex.ui.view.IWXScroller;
import com.taobao.weex.ui.view.WXBaseRefreshLayout;
import com.taobao.weex.ui.view.refresh.wrapper.BaseBounceView;
import com.taobao.weex.utils.WXLogUtils;
import com.taobao.weex.utils.WXUtils;
import com.taobao.weex.utils.WXViewUtils;
import io.dcloud.common.constant.AbsoluteConst;
import io.dcloud.common.util.DensityUtils;
import io.dcloud.common.util.StringUtil;
import io.dcloud.feature.weex_scroller.helper.DCScrollStartEndHelper;
import io.dcloud.feature.weex_scroller.view.DCBounceScrollerView;
import io.dcloud.feature.weex_scroller.view.DCWXHorizontalScrollView;
import io.dcloud.feature.weex_scroller.view.DCWXScrollView;
import io.dcloud.feature.weex_scroller.view.WXStickyHelper;
import java.lang.reflect.InvocationTargetException;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;
import java.util.concurrent.atomic.AtomicBoolean;
@Component(lazyload = false)
/* loaded from: classes27.dex */
public class DCWXScroller extends WXBaseScroller implements DCWXScrollView.WXScrollViewListener, Scrollable {
    public static final String DIRECTION = "direction";
    private static final int SWIPE_MIN_DISTANCE = 5;
    private static final int SWIPE_THRESHOLD_VELOCITY = 300;
    private boolean canScroll2Top;
    Map<String, WXComponent> childens;
    private Handler handler;
    private boolean isAnimation;
    private boolean isScrollable;
    private AtomicBoolean isViewLayoutFinished;
    private int mActiveFeature;
    private Map<String, AppearanceHelper> mAppearanceComponents;
    private int mChildrenLayoutOffset;
    private int mContentHeight;
    private int mContentWidth;
    private boolean mForceLoadmoreNextTime;
    private GestureDetector mGestureDetector;
    private boolean mHasAddScrollEvent;
    private boolean mIsHostAttachedToWindow;
    private Point mLastReport;
    private int mOffsetAccuracy;
    private View.OnAttachStateChangeListener mOnAttachStateChangeListener;
    protected int mOrientation;
    private FrameLayout mRealView;
    private List<WXComponent> mRefreshs;
    private ScrollStartEndHelper mScrollStartEndHelper;
    private FrameLayout mScrollerView;
    private Map<String, Map<String, WXComponent>> mStickyMap;
    private boolean pageEnable;
    private int pageSize;
    private WXStickyHelper stickyHelper;

    @Override // io.dcloud.feature.weex_scroller.view.DCWXScrollView.WXScrollViewListener
    public void onScrollStopped(DCWXScrollView scrollView, int x, int y) {
    }

    @Override // io.dcloud.feature.weex_scroller.view.DCWXScrollView.WXScrollViewListener
    public void onScrollToBottom(DCWXScrollView scrollView, int x, int y) {
    }

    @Override // io.dcloud.feature.weex_scroller.view.DCWXScrollView.WXScrollViewListener
    public void onScrollToTop(DCWXScrollView scrollView, int x, int y) {
    }

    /* loaded from: classes18.dex */
    public static class Creator implements ComponentCreator {
        @Override // com.taobao.weex.ui.ComponentCreator
        public WXComponent createInstance(WXSDKInstance instance, WXVContainer parent, BasicComponentData basicComponentData) throws IllegalAccessException, InvocationTargetException, InstantiationException {
            instance.setUseScroller(true);
            return new DCWXScroller(instance, parent, basicComponentData);
        }
    }

    @Deprecated
    public DCWXScroller(WXSDKInstance instance, WXVContainer parent, String instanceId, boolean isLazy, BasicComponentData basicComponentData) {
        this(instance, parent, basicComponentData);
    }

    public DCWXScroller(WXSDKInstance instance, WXVContainer parent, BasicComponentData basicComponentData) {
        super(instance, parent, basicComponentData);
        this.mOrientation = 1;
        this.mRefreshs = new ArrayList();
        this.mChildrenLayoutOffset = 0;
        this.mForceLoadmoreNextTime = false;
        this.mOffsetAccuracy = 10;
        this.mLastReport = new Point(-1, -1);
        this.mHasAddScrollEvent = false;
        this.mActiveFeature = 0;
        this.pageSize = 0;
        this.pageEnable = false;
        this.mIsHostAttachedToWindow = false;
        this.isAnimation = false;
        this.canScroll2Top = false;
        this.mAppearanceComponents = new HashMap();
        this.mStickyMap = new HashMap();
        this.mContentHeight = 0;
        this.mContentWidth = 0;
        this.handler = new Handler(Looper.getMainLooper());
        this.isScrollable = true;
        this.childens = new HashMap();
        this.isViewLayoutFinished = new AtomicBoolean(false);
        this.stickyHelper = new WXStickyHelper(this);
        instance.getApmForInstance().updateDiffStats(WXInstanceApm.KEY_PAGE_STATS_SCROLLER_NUM, 1.0d);
    }

    @Override // io.dcloud.feature.uniapp.ui.component.AbsVContainer, com.taobao.weex.ui.component.WXComponent
    public ViewGroup getRealView() {
        return this.mScrollerView;
    }

    @Override // io.dcloud.feature.uniapp.ui.component.AbsVContainer, com.taobao.weex.ui.component.WXComponent
    public void createViewImpl() {
        super.createViewImpl();
        for (int i = 0; i < this.mRefreshs.size(); i++) {
            WXComponent wXComponent = this.mRefreshs.get(i);
            wXComponent.createViewImpl();
            checkRefreshOrLoading(wXComponent);
        }
    }

    @Override // com.taobao.weex.ui.component.WXBaseScroller
    public ViewGroup getInnerView() {
        if (getHostView() == 0) {
            return null;
        }
        if (getHostView() instanceof DCBounceScrollerView) {
            return ((DCBounceScrollerView) getHostView()).getInnerView();
        }
        return (ViewGroup) getHostView();
    }

    @Override // com.taobao.weex.ui.component.WXComponent
    public void addEvent(String type) {
        super.addEvent(type);
        if (!DCScrollStartEndHelper.isScrollEvent(type) || getInnerView() == null || this.mHasAddScrollEvent) {
            return;
        }
        this.mHasAddScrollEvent = true;
        if (getInnerView() instanceof DCWXScrollView) {
            ((DCWXScrollView) getInnerView()).addScrollViewListener(new DCWXScrollView.WXScrollViewListener() { // from class: com.taobao.weex.ui.component.DCWXScroller.1
                @Override // io.dcloud.feature.weex_scroller.view.DCWXScrollView.WXScrollViewListener
                public void onScroll(DCWXScrollView scrollView, int x, int y) {
                }

                @Override // io.dcloud.feature.weex_scroller.view.DCWXScrollView.WXScrollViewListener
                public void onScrollChanged(DCWXScrollView scrollView, int x, int y, int oldx, int oldy) {
                    DCWXScroller.this.getScrollStartEndHelper().onScrolled(x, y);
                    if (DCWXScroller.this.getEvents().contains("scroll") && DCWXScroller.this.shouldReport(x, y)) {
                        DCWXScroller.this.fireScrollEvent(scrollView.getContentFrame(), x, y, oldx, oldy);
                    }
                }

                @Override // io.dcloud.feature.weex_scroller.view.DCWXScrollView.WXScrollViewListener
                public void onScrollToBottom(DCWXScrollView scrollView, int x, int y) {
                    HashMap hashMap = new HashMap(1);
                    hashMap.put("direction", "bottom");
                    HashMap hashMap2 = new HashMap(1);
                    hashMap2.put("detail", hashMap);
                    DCWXScroller.this.fireEvent("scrolltolower", hashMap2);
                }

                @Override // io.dcloud.feature.weex_scroller.view.DCWXScrollView.WXScrollViewListener
                public void onScrollToTop(DCWXScrollView scrollView, int x, int y) {
                    HashMap hashMap = new HashMap(1);
                    hashMap.put("direction", "top");
                    HashMap hashMap2 = new HashMap(1);
                    hashMap2.put("detail", hashMap);
                    DCWXScroller.this.fireEvent("scrolltoupper", hashMap2);
                }

                @Override // io.dcloud.feature.weex_scroller.view.DCWXScrollView.WXScrollViewListener
                public void onScrollStopped(DCWXScrollView scrollView, int x, int y) {
                    DCWXScroller.this.getScrollStartEndHelper().onScrolled(x, y);
                    if (DCWXScroller.this.getEvents().contains("scroll")) {
                        DCWXScroller.this.fireScrollEvent(scrollView.getContentFrame(), x, y, 0, 0);
                    }
                }
            });
        } else if (getInnerView() instanceof DCWXHorizontalScrollView) {
            ((DCWXHorizontalScrollView) getInnerView()).addScrollViewListener(new DCWXHorizontalScrollView.ScrollViewListener() { // from class: com.taobao.weex.ui.component.DCWXScroller.2
                @Override // io.dcloud.feature.weex_scroller.view.DCWXHorizontalScrollView.ScrollViewListener
                public void onScrollChanged(DCWXHorizontalScrollView scrollView, int x, int y, int oldx, int oldy) {
                    DCWXScroller.this.getScrollStartEndHelper().onScrolled(x, y);
                    if (DCWXScroller.this.getEvents().contains("scroll") && DCWXScroller.this.shouldReport(x, y)) {
                        DCWXScroller.this.fireScrollEvent(scrollView.getContentFrame(), x, y, oldx, oldy);
                    }
                }

                @Override // io.dcloud.feature.weex_scroller.view.DCWXHorizontalScrollView.ScrollViewListener
                public void onScrolltoTop() {
                    HashMap hashMap = new HashMap(1);
                    hashMap.put("direction", "top");
                    HashMap hashMap2 = new HashMap(1);
                    hashMap2.put("detail", hashMap);
                    DCWXScroller.this.fireEvent("scrolltoupper", hashMap2);
                }

                @Override // io.dcloud.feature.weex_scroller.view.DCWXHorizontalScrollView.ScrollViewListener
                public void onScrollToBottom() {
                    HashMap hashMap = new HashMap(1);
                    hashMap.put("direction", "bottom");
                    HashMap hashMap2 = new HashMap(1);
                    hashMap2.put("detail", hashMap);
                    DCWXScroller.this.fireEvent("scrolltolower", hashMap2);
                }
            });
        }
    }

    /* JADX INFO: Access modifiers changed from: private */
    public void fireScrollEvent(Rect contentFrame, int x, int y, int oldx, int oldy) {
        fireEvent("scroll", getScrollEvent(x, y, oldx, oldy));
    }

    public Map<String, Object> getScrollEvent(int x, int y, int oldx, int oldy) {
        int i;
        Rect rect = new Rect();
        int i2 = 0;
        if (getInnerView() instanceof DCWXScrollView) {
            rect = ((DCWXScrollView) getInnerView()).getContentFrame();
            i = getInnerView().getScrollY();
        } else {
            if (getInnerView() instanceof DCWXHorizontalScrollView) {
                rect = ((DCWXHorizontalScrollView) getInnerView()).getContentFrame();
                i2 = getInnerView().getScrollX();
            }
            i = 0;
        }
        HashMap hashMap = new HashMap(2);
        HashMap hashMap2 = new HashMap(6);
        new HashMap(2);
        float instanceViewPortWidthWithFloat = getInstance().getInstanceViewPortWidthWithFloat();
        hashMap2.put("scrollWidth", Float.valueOf(WXViewUtils.getWebPxByWidth(rect.width(), instanceViewPortWidthWithFloat)));
        hashMap2.put("scrollHeight", Float.valueOf(WXViewUtils.getWebPxByWidth(rect.height(), instanceViewPortWidthWithFloat)));
        hashMap2.put(Constants.Name.SCROLL_LEFT, Float.valueOf(WXViewUtils.getWebPxByWidth(i2, instanceViewPortWidthWithFloat)));
        hashMap2.put(Constants.Name.SCROLL_TOP, Float.valueOf(WXViewUtils.getWebPxByWidth(i, instanceViewPortWidthWithFloat)));
        hashMap2.put("deltaX", Float.valueOf(WXViewUtils.getWebPxByWidth(oldx, instanceViewPortWidthWithFloat)));
        hashMap2.put("deltaY", Float.valueOf(WXViewUtils.getWebPxByWidth(oldy, instanceViewPortWidthWithFloat)));
        hashMap.put("detail", hashMap2);
        return hashMap;
    }

    @Override // com.taobao.weex.ui.component.WXBaseScroller
    public Map<String, Object> getScrollEvent(int x, int y) {
        Rect rect = new Rect();
        if (getInnerView() instanceof DCWXScrollView) {
            rect = ((DCWXScrollView) getInnerView()).getContentFrame();
        } else if (getInnerView() instanceof DCWXHorizontalScrollView) {
            rect = ((DCWXHorizontalScrollView) getInnerView()).getContentFrame();
        }
        HashMap hashMap = new HashMap(2);
        HashMap hashMap2 = new HashMap(2);
        HashMap hashMap3 = new HashMap(2);
        float instanceViewPortWidthWithFloat = getInstance().getInstanceViewPortWidthWithFloat();
        hashMap2.put("width", Float.valueOf(WXViewUtils.getWebPxByWidth(rect.width(), instanceViewPortWidthWithFloat)));
        hashMap2.put("height", Float.valueOf(WXViewUtils.getWebPxByWidth(rect.height(), instanceViewPortWidthWithFloat)));
        hashMap3.put(Constants.Name.X, Float.valueOf(WXViewUtils.getWebPxByWidth(x, instanceViewPortWidthWithFloat)));
        hashMap3.put(Constants.Name.Y, Float.valueOf(WXViewUtils.getWebPxByWidth(y, instanceViewPortWidthWithFloat)));
        hashMap.put(Constants.Name.CONTENT_SIZE, hashMap2);
        hashMap.put(Constants.Name.CONTENT_OFFSET, hashMap3);
        return hashMap;
    }

    /* JADX INFO: Access modifiers changed from: private */
    public boolean shouldReport(int x, int y) {
        if (this.mLastReport.x == -1 && this.mLastReport.y == -1) {
            this.mLastReport.x = x;
            this.mLastReport.y = y;
            return true;
        } else if (this.mOrientation == 0 && Math.abs(x - this.mLastReport.x) >= this.mOffsetAccuracy) {
            this.mLastReport.x = x;
            this.mLastReport.y = y;
            return true;
        } else if (this.mOrientation != 1 || Math.abs(y - this.mLastReport.y) < this.mOffsetAccuracy) {
            return false;
        } else {
            this.mLastReport.x = x;
            this.mLastReport.y = y;
            return true;
        }
    }

    @Override // io.dcloud.feature.uniapp.ui.component.AbsVContainer
    public void addSubView(View child, int index) {
        FrameLayout frameLayout;
        if (child == null || (frameLayout = this.mRealView) == null || (child instanceof WXBaseRefreshLayout)) {
            return;
        }
        if (index >= frameLayout.getChildCount()) {
            index = -1;
        }
        if (child.getParent() != null) {
            ((ViewGroup) child.getParent()).removeView(child);
        }
        if (index == -1) {
            this.mRealView.addView(child);
        } else {
            this.mRealView.addView(child, index);
        }
    }

    /* JADX INFO: Access modifiers changed from: protected */
    @Override // com.taobao.weex.ui.component.WXVContainer, io.dcloud.feature.uniapp.ui.component.AbsVContainer
    public int getChildrenLayoutTopOffset() {
        int size;
        if (this.mChildrenLayoutOffset == 0 && (size = this.mRefreshs.size()) > 0) {
            for (int i = 0; i < size; i++) {
                this.mChildrenLayoutOffset += this.mRefreshs.get(i).getLayoutTopOffsetForSibling();
            }
        }
        return this.mChildrenLayoutOffset;
    }

    @Override // io.dcloud.feature.uniapp.ui.component.AbsVContainer
    public void addChild(WXComponent child, int index) {
        if (child.getAttrs().containsKey("id")) {
            this.childens.put(child.getAttrs().get("id").toString(), child);
        }
        if ((child instanceof WXBaseRefresh) && checkRefreshOrLoading(child)) {
            this.mRefreshs.add(child);
        }
        super.addChild(child, index);
    }

    private boolean checkRefreshOrLoading(final WXComponent child) {
        boolean z;
        if (!(child instanceof WXRefresh) || getHostView() == 0) {
            z = false;
        } else {
            ((BaseBounceView) getHostView()).setOnRefreshListener((WXRefresh) child);
            this.handler.postDelayed(WXThread.secure(new Runnable() { // from class: com.taobao.weex.ui.component.DCWXScroller.3
                @Override // java.lang.Runnable
                public void run() {
                    ((BaseBounceView) DCWXScroller.this.getHostView()).setHeaderView(child);
                }
            }), 100L);
            z = true;
        }
        if (!(child instanceof WXLoading) || getHostView() == 0) {
            return z;
        }
        ((BaseBounceView) getHostView()).setOnLoadingListener((WXLoading) child);
        this.handler.postDelayed(WXThread.secure(new Runnable() { // from class: com.taobao.weex.ui.component.DCWXScroller.4
            @Override // java.lang.Runnable
            public void run() {
                ((BaseBounceView) DCWXScroller.this.getHostView()).setFooterView(child);
            }
        }), 100L);
        return true;
    }

    @Override // io.dcloud.feature.uniapp.ui.component.AbsVContainer
    public void remove(WXComponent child, boolean destory) {
        super.remove(child, destory);
        if (child instanceof WXLoading) {
            ((BaseBounceView) getHostView()).removeFooterView(child);
        } else if (child instanceof WXRefresh) {
            ((BaseBounceView) getHostView()).removeHeaderView(child);
        }
    }

    @Override // io.dcloud.feature.uniapp.ui.component.AbsVContainer, com.taobao.weex.ui.component.WXComponent
    public void destroy() {
        if (getInnerView() != null && (getInnerView() instanceof IWXScroller)) {
            ((IWXScroller) getInnerView()).destroy();
        }
        Map<String, AppearanceHelper> map = this.mAppearanceComponents;
        if (map != null) {
            map.clear();
        }
        Map<String, Map<String, WXComponent>> map2 = this.mStickyMap;
        if (map2 != null) {
            map2.clear();
        }
        if (this.mOnAttachStateChangeListener != null && getInnerView() != null) {
            getInnerView().removeOnAttachStateChangeListener(this.mOnAttachStateChangeListener);
        }
        super.destroy();
    }

    @Override // com.taobao.weex.ui.component.WXComponent
    public void setMarginsSupportRTL(ViewGroup.MarginLayoutParams lp, int left, int top, int right, int bottom) {
        if (Build.VERSION.SDK_INT >= 17) {
            lp.setMargins(left, top, right, bottom);
            lp.setMarginStart(left);
            lp.setMarginEnd(right);
        } else if (lp instanceof FrameLayout.LayoutParams) {
            FrameLayout.LayoutParams layoutParams = (FrameLayout.LayoutParams) lp;
            if (isLayoutRTL()) {
                layoutParams.gravity = 53;
                lp.setMargins(right, top, left, bottom);
                return;
            }
            layoutParams.gravity = 51;
            lp.setMargins(left, top, right, bottom);
        } else {
            lp.setMargins(left, top, right, bottom);
        }
    }

    @Override // com.taobao.weex.ui.component.WXComponent
    public void setLayout(WXComponent component) {
        if (TextUtils.isEmpty(component.getComponentType()) || TextUtils.isEmpty(component.getRef()) || component.getLayoutPosition() == null || component.getLayoutSize() == null) {
            return;
        }
        if (component.getHostView() != null) {
            ViewCompat.setLayoutDirection(component.getHostView(), component.isLayoutRTL() ? 1 : 0);
        }
        super.setLayout(component);
    }

    /* JADX INFO: Access modifiers changed from: protected */
    @Override // com.taobao.weex.ui.component.WXComponent
    public WXComponent.MeasureOutput measure(int width, int height) {
        WXComponent.MeasureOutput measureOutput = new WXComponent.MeasureOutput();
        if (this.mOrientation == 0) {
            int screenWidth = WXViewUtils.getScreenWidth(WXEnvironment.sApplication);
            int weexWidth = WXViewUtils.getWeexWidth(getInstanceId());
            if (weexWidth < screenWidth) {
                screenWidth = weexWidth;
            }
            if (width > screenWidth) {
                width = -1;
            }
            measureOutput.width = width;
            measureOutput.height = height;
        } else {
            int screenHeight = WXViewUtils.getScreenHeight(WXEnvironment.sApplication);
            int weexHeight = WXViewUtils.getWeexHeight(getInstanceId());
            if (weexHeight < screenHeight) {
                screenHeight = weexHeight;
            }
            if (height > screenHeight) {
                height = -1;
            }
            measureOutput.height = height;
            measureOutput.width = width;
        }
        return measureOutput;
    }

    /* JADX INFO: Access modifiers changed from: protected */
    /* JADX WARN: Multi-variable type inference failed */
    @Override // com.taobao.weex.ui.component.WXComponent
    public ViewGroup initComponentHostView(Context context) {
        String str;
        boolean parseBoolean;
        boolean parseBoolean2;
        boolean z;
        DCBounceScrollerView dCBounceScrollerView;
        str = "vertical";
        if (getAttrs().isEmpty()) {
            parseBoolean = false;
            z = true;
            parseBoolean2 = false;
        } else {
            parseBoolean = getAttrs().containsKey("scrollX") ? Boolean.parseBoolean(getAttrs().get("scrollX").toString()) : false;
            parseBoolean2 = getAttrs().containsKey("scrollY") ? Boolean.parseBoolean(getAttrs().get("scrollY").toString()) : false;
            if (parseBoolean2) {
                z = !getAttrs().get("scrollY").equals(AbsoluteConst.FALSE);
            } else if (parseBoolean) {
                z = !getAttrs().get("scrollX").equals(AbsoluteConst.FALSE);
                str = Constants.Value.HORIZONTAL;
            } else {
                str = getAttrs().containsKey(Constants.Name.SCROLL_DIRECTION) ? getAttrs().getScrollDirection() : "vertical";
                z = true;
            }
            Object obj = getAttrs().get(Constants.Name.PAGE_ENABLED);
            this.pageEnable = obj != null && Boolean.parseBoolean(obj.toString());
            Object obj2 = getAttrs().get(Constants.Name.PAGE_SIZE);
            if (obj2 != null) {
                float realPxByWidth = WXViewUtils.getRealPxByWidth(WXUtils.getFloat(obj2), getInstance().getInstanceViewPortWidth());
                if (realPxByWidth != 0.0f) {
                    this.pageSize = (int) realPxByWidth;
                }
            }
        }
        if (Constants.Value.HORIZONTAL.equals(str)) {
            this.mOrientation = 0;
            final DCWXHorizontalScrollView dCWXHorizontalScrollView = new DCWXHorizontalScrollView(context);
            dCWXHorizontalScrollView.setWAScroller(this);
            dCWXHorizontalScrollView.setScrollable(z);
            this.mRealView = new FrameLayout(context);
            dCWXHorizontalScrollView.setScrollViewListener(new DCWXHorizontalScrollView.ScrollViewListener() { // from class: com.taobao.weex.ui.component.DCWXScroller.5
                @Override // io.dcloud.feature.weex_scroller.view.DCWXHorizontalScrollView.ScrollViewListener
                public void onScrollToBottom() {
                }

                @Override // io.dcloud.feature.weex_scroller.view.DCWXHorizontalScrollView.ScrollViewListener
                public void onScrolltoTop() {
                }

                @Override // io.dcloud.feature.weex_scroller.view.DCWXHorizontalScrollView.ScrollViewListener
                public void onScrollChanged(DCWXHorizontalScrollView scrollView, int x, int y, int oldx, int oldy) {
                    if (DCWXScroller.this.getInstance() == null) {
                        return;
                    }
                    DCWXScroller.this.procAppear(x, y, oldx, oldy);
                    DCWXScroller.this.onLoadMore(scrollView, x, y);
                }
            });
            dCWXHorizontalScrollView.addView(this.mRealView, new FrameLayout.LayoutParams(-1, -1));
            dCWXHorizontalScrollView.setHorizontalScrollBarEnabled(true);
            this.mScrollerView = dCWXHorizontalScrollView;
            dCWXHorizontalScrollView.setScrollBarSize(DensityUtils.dip2px(getInstance().getContext(), 4.0f));
            final View.OnLayoutChangeListener onLayoutChangeListener = new View.OnLayoutChangeListener() { // from class: com.taobao.weex.ui.component.DCWXScroller.6
                @Override // android.view.View.OnLayoutChangeListener
                public void onLayoutChange(final View view, int left, int top, int right, int bottom, int oldLeft, int oldTop, int oldRight, int oldBottom) {
                    dCWXHorizontalScrollView.post(new Runnable() { // from class: com.taobao.weex.ui.component.DCWXScroller.6.1
                        @Override // java.lang.Runnable
                        public void run() {
                            if (DCWXScroller.this.isLayoutRTL()) {
                                dCWXHorizontalScrollView.scrollTo(view.getMeasuredWidth(), this.getScrollY());
                                return;
                            }
                            dCWXHorizontalScrollView.scrollTo(0, this.getScrollY());
                        }
                    });
                    if (DCWXScroller.this.mRealView != null) {
                        DCWXScroller.this.mRealView.removeOnLayoutChangeListener(this);
                    }
                }
            };
            this.mRealView.addOnAttachStateChangeListener(new View.OnAttachStateChangeListener() { // from class: com.taobao.weex.ui.component.DCWXScroller.7
                @Override // android.view.View.OnAttachStateChangeListener
                public void onViewAttachedToWindow(View view) {
                    view.addOnLayoutChangeListener(onLayoutChangeListener);
                }

                @Override // android.view.View.OnAttachStateChangeListener
                public void onViewDetachedFromWindow(View view) {
                    view.removeOnLayoutChangeListener(onLayoutChangeListener);
                }
            });
            dCBounceScrollerView = dCWXHorizontalScrollView;
            if (this.pageEnable) {
                this.mGestureDetector = new GestureDetector(new MyGestureDetector(dCWXHorizontalScrollView));
                dCWXHorizontalScrollView.setOnTouchListener(new View.OnTouchListener() { // from class: com.taobao.weex.ui.component.DCWXScroller.8
                    @Override // android.view.View.OnTouchListener
                    public boolean onTouch(View v, MotionEvent event) {
                        if (DCWXScroller.this.pageSize == 0) {
                            DCWXScroller.this.pageSize = v.getMeasuredWidth();
                        }
                        if (DCWXScroller.this.mGestureDetector.onTouchEvent(event)) {
                            return true;
                        }
                        if (event.getAction() == 1 || event.getAction() == 3) {
                            int scrollX = DCWXScroller.this.getScrollX();
                            int i = DCWXScroller.this.pageSize;
                            DCWXScroller.this.mActiveFeature = (scrollX + (i / 2)) / i;
                            dCWXHorizontalScrollView.smoothScrollTo(DCWXScroller.this.mActiveFeature * i, 0);
                            return true;
                        }
                        return false;
                    }
                });
                dCBounceScrollerView = dCWXHorizontalScrollView;
            }
        } else {
            this.mOrientation = 1;
            DCBounceScrollerView dCBounceScrollerView2 = new DCBounceScrollerView(context, this.mOrientation, this);
            this.mRealView = new FrameLayout(context);
            DCWXScrollView innerView = dCBounceScrollerView2.getInnerView();
            innerView.addScrollViewListener(this);
            if (!parseBoolean && !parseBoolean2) {
                innerView.setScrollable(false);
            } else {
                innerView.setScrollable(z);
            }
            innerView.addView(this.mRealView, new FrameLayout.LayoutParams(-1, -1));
            innerView.setVerticalScrollBarEnabled(true);
            this.mScrollerView = innerView;
            innerView.setNestedScrollingEnabled(WXUtils.getBoolean(getAttrs().get(Constants.Name.NEST_SCROLLING_ENABLED), true).booleanValue());
            innerView.addScrollViewListener(new DCWXScrollView.WXScrollViewListener() { // from class: com.taobao.weex.ui.component.DCWXScroller.9
                @Override // io.dcloud.feature.weex_scroller.view.DCWXScrollView.WXScrollViewListener
                public void onScrollChanged(DCWXScrollView scrollView, int x, int y, int oldx, int oldy) {
                }

                @Override // io.dcloud.feature.weex_scroller.view.DCWXScrollView.WXScrollViewListener
                public void onScrollToBottom(DCWXScrollView scrollView, int x, int y) {
                }

                @Override // io.dcloud.feature.weex_scroller.view.DCWXScrollView.WXScrollViewListener
                public void onScrollToTop(DCWXScrollView scrollView, int x, int y) {
                }

                @Override // io.dcloud.feature.weex_scroller.view.DCWXScrollView.WXScrollViewListener
                public void onScrollStopped(DCWXScrollView scrollView, int x, int y) {
                    if (DCWXScroller.this.getInstance() == null) {
                        return;
                    }
                    List<OnWXScrollListener> wXScrollListeners = DCWXScroller.this.getInstance().getWXScrollListeners();
                    if (wXScrollListeners != null && wXScrollListeners.size() > 0) {
                        for (OnWXScrollListener onWXScrollListener : wXScrollListeners) {
                            if (onWXScrollListener != null) {
                                onWXScrollListener.onScrollStateChanged(scrollView, x, y, 0);
                            }
                        }
                    }
                    DCWXScroller.this.getScrollStartEndHelper().onScrollStateChanged(0);
                }

                @Override // io.dcloud.feature.weex_scroller.view.DCWXScrollView.WXScrollViewListener
                public void onScroll(DCWXScrollView scrollView, int x, int y) {
                    List<OnWXScrollListener> wXScrollListeners;
                    if (DCWXScroller.this.getInstance() == null || (wXScrollListeners = DCWXScroller.this.getInstance().getWXScrollListeners()) == null || wXScrollListeners.size() <= 0) {
                        return;
                    }
                    for (OnWXScrollListener onWXScrollListener : wXScrollListeners) {
                        if (onWXScrollListener != null) {
                            if (onWXScrollListener instanceof ICheckBindingScroller) {
                                if (((ICheckBindingScroller) onWXScrollListener).isNeedScroller(DCWXScroller.this.getRef(), null)) {
                                    onWXScrollListener.onScrolled(scrollView, x, y);
                                }
                            } else {
                                onWXScrollListener.onScrolled(scrollView, x, y);
                            }
                        }
                    }
                }
            });
            dCBounceScrollerView = dCBounceScrollerView2;
        }
        dCBounceScrollerView.getViewTreeObserver().addOnGlobalLayoutListener(new ViewTreeObserver.OnGlobalLayoutListener() { // from class: com.taobao.weex.ui.component.DCWXScroller.10
            /* JADX WARN: Type inference failed for: r0v2, types: [android.view.View] */
            @Override // android.view.ViewTreeObserver.OnGlobalLayoutListener
            public void onGlobalLayout() {
                DCWXScroller.this.procAppear(0, 0, 0, 0);
                ?? hostView = DCWXScroller.this.getHostView();
                if (hostView == 0 || DCWXScroller.this.getInstance() == null) {
                    return;
                }
                if (Build.VERSION.SDK_INT >= 16) {
                    hostView.getViewTreeObserver().removeOnGlobalLayoutListener(this);
                } else {
                    hostView.getViewTreeObserver().removeGlobalOnLayoutListener(this);
                }
            }
        });
        View.OnAttachStateChangeListener onAttachStateChangeListener = new View.OnAttachStateChangeListener() { // from class: com.taobao.weex.ui.component.DCWXScroller.11
            @Override // android.view.View.OnAttachStateChangeListener
            public void onViewAttachedToWindow(View v) {
                DCWXScroller.this.mIsHostAttachedToWindow = true;
                DCWXScroller dCWXScroller = DCWXScroller.this;
                dCWXScroller.procAppear(dCWXScroller.getScrollX(), DCWXScroller.this.getScrollY(), DCWXScroller.this.getScrollX(), DCWXScroller.this.getScrollY());
            }

            @Override // android.view.View.OnAttachStateChangeListener
            public void onViewDetachedFromWindow(View v) {
                DCWXScroller.this.mIsHostAttachedToWindow = false;
                DCWXScroller.this.dispatchDisappearEvent();
            }
        };
        this.mOnAttachStateChangeListener = onAttachStateChangeListener;
        dCBounceScrollerView.addOnAttachStateChangeListener(onAttachStateChangeListener);
        return dCBounceScrollerView;
    }

    @Override // com.taobao.weex.ui.component.WXBaseScroller, com.taobao.weex.ui.component.Scrollable
    public int getScrollY() {
        if (getInnerView() == null) {
            return 0;
        }
        return getInnerView().getScrollY();
    }

    @Override // com.taobao.weex.ui.component.WXBaseScroller, com.taobao.weex.ui.component.Scrollable
    public int getScrollX() {
        if (getInnerView() == null) {
            return 0;
        }
        return getInnerView().getScrollX();
    }

    @Override // com.taobao.weex.ui.component.WXBaseScroller, com.taobao.weex.ui.component.Scrollable
    public int getOrientation() {
        return this.mOrientation;
    }

    @Override // com.taobao.weex.ui.component.WXBaseScroller
    public Map<String, Map<String, WXComponent>> getStickMap() {
        return this.mStickyMap;
    }

    /* JADX INFO: Access modifiers changed from: protected */
    /* JADX WARN: Can't fix incorrect switch cases order, some code will duplicate */
    @Override // com.taobao.weex.ui.component.WXComponent
    public boolean setProperty(String key, Object param) {
        key.hashCode();
        char c = 65535;
        switch (key.hashCode()) {
            case -223520855:
                if (key.equals(Constants.Name.SHOW_SCROLLBAR)) {
                    c = 0;
                    break;
                }
                break;
            case -101546095:
                if (key.equals("scrollWithAnimation")) {
                    c = 1;
                    break;
                }
                break;
            case -5620052:
                if (key.equals(Constants.Name.OFFSET_ACCURACY)) {
                    c = 2;
                    break;
                }
                break;
            case 66669991:
                if (key.equals(Constants.Name.SCROLLABLE)) {
                    c = 3;
                    break;
                }
                break;
            case 1926689579:
                if (key.equals("scrollX")) {
                    c = 4;
                    break;
                }
                break;
            case 1926689580:
                if (key.equals("scrollY")) {
                    c = 5;
                    break;
                }
                break;
        }
        switch (c) {
            case 0:
                Boolean bool = WXUtils.getBoolean(param, null);
                if (bool != null) {
                    setShowScrollbar(bool.booleanValue());
                }
                return true;
            case 1:
                setScrollWithAnimation(WXUtils.getBoolean(param, false).booleanValue());
                break;
            case 2:
                setOffsetAccuracy(WXUtils.getInteger(param, 10).intValue());
                return true;
            case 3:
                setScrollable(WXUtils.getBoolean(param, true).booleanValue());
                return true;
            case 4:
            case 5:
                setScrollable(!String.valueOf(param).equals(AbsoluteConst.FALSE));
                return true;
        }
        return super.setProperty(key, param);
    }

    @WXComponentProp(name = "scrollIntoView")
    public void setScrollIntoView(final String ref) {
        if (!this.isViewLayoutFinished.get()) {
            getInnerView().getViewTreeObserver().addOnGlobalLayoutListener(new ViewTreeObserver.OnGlobalLayoutListener() { // from class: com.taobao.weex.ui.component.DCWXScroller.12
                @Override // android.view.ViewTreeObserver.OnGlobalLayoutListener
                public void onGlobalLayout() {
                    if (DCWXScroller.this.getInstance() == null) {
                        return;
                    }
                    WXComponent wXComponentById = WXSDKManager.getInstance().getWXRenderManager().getWXComponentById(DCWXScroller.this.getInstanceId(), ref);
                    if (wXComponentById != null) {
                        DCWXScroller.this.scrollTo(wXComponentById, JSONObject.parseObject("{'animated':false}"));
                    }
                    DCWXScroller.this.isViewLayoutFinished.set(true);
                    DCWXScroller.this.handler.postDelayed(new Runnable() { // from class: com.taobao.weex.ui.component.DCWXScroller.12.1
                        @Override // java.lang.Runnable
                        public void run() {
                            DCWXScroller.this.getInnerView().getViewTreeObserver().removeOnGlobalLayoutListener(this);
                        }
                    }, 100L);
                }
            });
            return;
        }
        WXComponent wXComponentById = WXSDKManager.getInstance().getWXRenderManager().getWXComponentById(getInstanceId(), ref);
        if (wXComponentById != null) {
            scrollTo(wXComponentById, JSONObject.parseObject(StringUtil.format("{'animated':%b}", Boolean.valueOf(this.isAnimation))));
        }
    }

    @JSMethod
    public void scrollTo(int top) {
        float realPxByWidth = WXViewUtils.getRealPxByWidth(top, getInstance().getInstanceViewPortWidth());
        if (getInnerView() instanceof DCWXScrollView) {
            ((DCWXScrollView) getInnerView()).smoothScrollTo(0, (int) realPxByWidth);
        } else if (getInnerView() instanceof DCWXHorizontalScrollView) {
            ((DCWXHorizontalScrollView) getInnerView()).smoothScrollTo((int) realPxByWidth, 0);
        }
    }

    @JSMethod
    public void scrollTo(String op, JSCallback callback) {
        float realPxByWidth = WXViewUtils.getRealPxByWidth(WXUtils.getFloat(JSON.parseObject(op).getString(Constants.Name.SCROLL_TOP)), getInstance().getInstanceViewPortWidth());
        if (getInnerView() instanceof DCWXScrollView) {
            ((DCWXScrollView) getInnerView()).smoothScrollTo(0, (int) realPxByWidth);
        } else if (getInnerView() instanceof DCWXHorizontalScrollView) {
            ((DCWXHorizontalScrollView) getInnerView()).smoothScrollTo((int) realPxByWidth, 0);
        }
        if (callback != null) {
            HashMap hashMap = new HashMap();
            hashMap.put("type", WXImage.SUCCEED);
            callback.invoke(hashMap);
        }
    }

    private WXComponent getViewById(String id) {
        if (this.childens.containsKey(id)) {
            return this.childens.get(id);
        }
        for (WXComponent wXComponent : this.childens.values()) {
            if (wXComponent.getAttrs().containsKey("id") && wXComponent.getAttrs().get("id").equals(id)) {
                return wXComponent;
            }
        }
        return null;
    }

    @WXComponentProp(name = Constants.Name.SHOW_SCROLLBAR)
    public void setShowScrollbar(boolean show) {
        if (getInnerView() == null) {
            return;
        }
        if (this.mOrientation == 1) {
            getInnerView().setVerticalScrollBarEnabled(show);
        } else {
            getInnerView().setHorizontalScrollBarEnabled(show);
        }
    }

    @WXComponentProp(name = "scrollWithAnimation")
    public void setScrollWithAnimation(boolean isAnimation) {
        this.isAnimation = isAnimation;
    }

    @WXComponentProp(name = "upperThreshold")
    public void setUpperHeight(int height) {
        ViewGroup innerView = getInnerView();
        float realPxByWidth = WXViewUtils.getRealPxByWidth(height, getInstance().getInstanceViewPortWidth());
        if (innerView instanceof DCWXHorizontalScrollView) {
            ((DCWXHorizontalScrollView) innerView).setUpperLength(realPxByWidth);
        } else if (innerView instanceof DCWXScrollView) {
            ((DCWXScrollView) innerView).setUpperLength(realPxByWidth);
        }
    }

    @WXComponentProp(name = "enable-back-to-top")
    public void isEnableBackToTop(boolean toTop) {
        this.canScroll2Top = toTop;
    }

    @JSMethod
    public void scrollToTop() {
        if ((getInnerView() instanceof DCWXScrollView) && this.canScroll2Top) {
            ((DCWXScrollView) getInnerView()).smoothScrollTo(0, 0);
        }
    }

    @WXComponentProp(name = Constants.Name.SCROLL_TOP)
    public void setScrollTop(String topStr) {
        if (getInnerView() instanceof DCWXScrollView) {
            final float realPxByWidth = WXViewUtils.getRealPxByWidth(WXUtils.getFloat(topStr), getInstance().getInstanceViewPortWidth());
            if (!this.isViewLayoutFinished.get()) {
                getInnerView().getViewTreeObserver().addOnGlobalLayoutListener(new ViewTreeObserver.OnGlobalLayoutListener() { // from class: com.taobao.weex.ui.component.DCWXScroller.13
                    @Override // android.view.ViewTreeObserver.OnGlobalLayoutListener
                    public void onGlobalLayout() {
                        DCWXScroller.this.getInnerView().scrollTo(0, (int) realPxByWidth);
                        DCWXScroller.this.isViewLayoutFinished.set(true);
                        DCWXScroller.this.handler.postDelayed(new Runnable() { // from class: com.taobao.weex.ui.component.DCWXScroller.13.1
                            @Override // java.lang.Runnable
                            public void run() {
                                DCWXScroller.this.getInnerView().getViewTreeObserver().removeOnGlobalLayoutListener(this);
                            }
                        }, 100L);
                    }
                });
                return;
            }
            if (this.isAnimation) {
                if (getInnerView() instanceof DCWXScrollView) {
                    ((DCWXScrollView) getInnerView()).stopScroll();
                }
                ObjectAnimator.ofInt(getInnerView(), "scrollY", getInnerView().getScrollY(), (int) realPxByWidth).setDuration(200L).start();
            } else {
                getInnerView().post(new Runnable() { // from class: com.taobao.weex.ui.component.DCWXScroller.14
                    @Override // java.lang.Runnable
                    public void run() {
                        DCWXScroller.this.getInnerView().scrollTo(0, (int) realPxByWidth);
                    }
                });
            }
            this.isViewLayoutFinished.set(true);
        }
    }

    @WXComponentProp(name = Constants.Name.SCROLL_LEFT)
    public void setScrollLeft(String leftStr) {
        if (getInnerView() instanceof DCWXHorizontalScrollView) {
            final float realPxByWidth = WXViewUtils.getRealPxByWidth(WXUtils.getFloat(leftStr), getInstance().getInstanceViewPortWidth());
            if (!this.isViewLayoutFinished.get()) {
                getInnerView().getViewTreeObserver().addOnGlobalLayoutListener(new ViewTreeObserver.OnGlobalLayoutListener() { // from class: com.taobao.weex.ui.component.DCWXScroller.15
                    @Override // android.view.ViewTreeObserver.OnGlobalLayoutListener
                    public void onGlobalLayout() {
                        ObjectAnimator.ofInt(DCWXScroller.this.getInnerView(), "scrollX", DCWXScroller.this.getInnerView().getScrollX(), (int) realPxByWidth).setDuration(1L).start();
                        DCWXScroller.this.isViewLayoutFinished.set(true);
                        DCWXScroller.this.handler.postDelayed(new Runnable() { // from class: com.taobao.weex.ui.component.DCWXScroller.15.1
                            @Override // java.lang.Runnable
                            public void run() {
                                DCWXScroller.this.getInnerView().getViewTreeObserver().removeOnGlobalLayoutListener(this);
                            }
                        }, 100L);
                    }
                });
                return;
            }
            if (this.isAnimation) {
                if (getInnerView() instanceof DCWXHorizontalScrollView) {
                    ((DCWXHorizontalScrollView) getInnerView()).stopScroll();
                }
                ObjectAnimator.ofInt(getInnerView(), "scrollX", getInnerView().getScrollX(), (int) realPxByWidth).setDuration(200L).start();
            } else {
                ((DCWXHorizontalScrollView) getInnerView()).smoothScrollTo((int) realPxByWidth, 0);
            }
            this.isViewLayoutFinished.set(true);
        }
    }

    @WXComponentProp(name = "lowerThreshold")
    public void setLowwerHeight(int height) {
        ViewGroup innerView = getInnerView();
        float realPxByWidth = WXViewUtils.getRealPxByWidth(height, getInstance().getInstanceViewPortWidth());
        if (innerView instanceof DCWXHorizontalScrollView) {
            ((DCWXHorizontalScrollView) innerView).setLowwerLength(realPxByWidth);
        } else if (innerView instanceof DCWXScrollView) {
            ((DCWXScrollView) innerView).setLowwerLength(realPxByWidth);
        }
    }

    /* JADX INFO: Access modifiers changed from: protected */
    @Override // com.taobao.weex.ui.component.WXComponent
    public void onFinishLayout() {
        super.onFinishLayout();
    }

    public void setScrollable(boolean scrollable) {
        this.isScrollable = scrollable;
        ViewGroup innerView = getInnerView();
        if (innerView instanceof DCWXHorizontalScrollView) {
            ((DCWXHorizontalScrollView) innerView).setScrollable(scrollable);
        } else if (innerView instanceof DCWXScrollView) {
            ((DCWXScrollView) innerView).setScrollable(scrollable);
        }
    }

    @WXComponentProp(name = Constants.Name.OFFSET_ACCURACY)
    public void setOffsetAccuracy(int accuracy) {
        this.mOffsetAccuracy = (int) WXViewUtils.getRealPxByWidth(accuracy, getInstance().getInstanceViewPortWidth());
    }

    @WXComponentProp(name = "decelerationRate")
    public void setDecelerationRate(float rate) {
        if (getInnerView() instanceof DCWXScrollView) {
            ((DCWXScrollView) getInnerView()).setRate(rate);
        }
    }

    @Override // com.taobao.weex.ui.component.WXBaseScroller, com.taobao.weex.ui.component.Scrollable
    public boolean isScrollable() {
        return this.isScrollable;
    }

    @Override // com.taobao.weex.ui.component.WXBaseScroller, com.taobao.weex.ui.component.Scrollable
    public void bindStickStyle(WXComponent component) {
        this.stickyHelper.bindStickStyle(component, this.mStickyMap);
    }

    @Override // com.taobao.weex.ui.component.WXBaseScroller, com.taobao.weex.ui.component.Scrollable
    public void unbindStickStyle(WXComponent component) {
        this.stickyHelper.unbindStickStyle(component, this.mStickyMap);
    }

    @Override // com.taobao.weex.ui.component.WXBaseScroller, com.taobao.weex.ui.component.Scrollable
    public void bindAppearEvent(WXComponent component) {
        setWatch(0, component, true);
    }

    private void setWatch(int event, WXComponent component, boolean isWatch) {
        AppearanceHelper appearanceHelper = this.mAppearanceComponents.get(component.getRef());
        if (appearanceHelper == null) {
            appearanceHelper = new AppearanceHelper(component);
            this.mAppearanceComponents.put(component.getRef(), appearanceHelper);
        }
        appearanceHelper.setWatchEvent(event, isWatch);
        procAppear(0, 0, 0, 0);
    }

    @Override // com.taobao.weex.ui.component.WXBaseScroller, com.taobao.weex.ui.component.Scrollable
    public void bindDisappearEvent(WXComponent component) {
        setWatch(1, component, true);
    }

    @Override // com.taobao.weex.ui.component.WXBaseScroller, com.taobao.weex.ui.component.Scrollable
    public void unbindAppearEvent(WXComponent component) {
        setWatch(0, component, false);
    }

    @Override // com.taobao.weex.ui.component.WXBaseScroller, com.taobao.weex.ui.component.Scrollable
    public void unbindDisappearEvent(WXComponent component) {
        setWatch(1, component, false);
    }

    @Override // com.taobao.weex.ui.component.WXBaseScroller, com.taobao.weex.ui.component.Scrollable
    public void scrollTo(WXComponent component, Map<String, Object> options) {
        int absoluteX;
        boolean z = true;
        float f = 0.0f;
        if (options != null) {
            String obj = options.get("offset") == null ? WXInstanceApm.VALUE_ERROR_CODE_DEFAULT : options.get("offset").toString();
            z = WXUtils.getBoolean(options.get(Constants.Name.ANIMATED), true).booleanValue();
            if (obj != null) {
                try {
                    f = WXViewUtils.getRealPxByWidth(Float.parseFloat(obj), getInstance().getInstanceViewPortWidth());
                } catch (Exception e) {
                    WXLogUtils.e("Float parseFloat error :" + e.getMessage());
                }
            }
        }
        if (this.pageEnable) {
            this.mActiveFeature = this.mChildren.indexOf(component);
        }
        int absoluteY = component.getAbsoluteY() - getAbsoluteY();
        if (isLayoutRTL()) {
            if (getInnerView().getChildCount() > 0) {
                absoluteX = (getInnerView().getChildAt(0).getWidth() - (component.getAbsoluteX() - getAbsoluteX())) - getInnerView().getMeasuredWidth();
            } else {
                absoluteX = component.getAbsoluteX() - getAbsoluteX();
            }
            f = -f;
        } else {
            absoluteX = component.getAbsoluteX() - getAbsoluteX();
        }
        int i = (int) f;
        scrollBy((absoluteX - getScrollX()) + i, (absoluteY - getScrollY()) + i, z);
    }

    public void scrollBy(final int x, final int y) {
        scrollBy(x, y, false);
    }

    public void scrollBy(final int x, final int y, final boolean smooth) {
        if (getInnerView() == null) {
            return;
        }
        getInnerView().postDelayed(new Runnable() { // from class: com.taobao.weex.ui.component.DCWXScroller.16
            @Override // java.lang.Runnable
            public void run() {
                if (DCWXScroller.this.mOrientation == 1) {
                    if (smooth) {
                        ((DCWXScrollView) DCWXScroller.this.getInnerView()).smoothScrollBy(0, y);
                    } else {
                        ((DCWXScrollView) DCWXScroller.this.getInnerView()).scrollBy(0, y);
                    }
                } else if (smooth) {
                    ((DCWXHorizontalScrollView) DCWXScroller.this.getInnerView()).smoothScrollBy(x, 0);
                } else {
                    ((DCWXHorizontalScrollView) DCWXScroller.this.getInnerView()).scrollBy(x, 0);
                }
                DCWXScroller.this.getInnerView().invalidate();
            }
        }, 16L);
    }

    @Override // io.dcloud.feature.weex_scroller.view.DCWXScrollView.WXScrollViewListener
    public void onScrollChanged(DCWXScrollView scrollView, int x, int y, int oldx, int oldy) {
        procAppear(x, y, oldx, oldy);
    }

    @Override // io.dcloud.feature.uniapp.ui.component.AbsVContainer, com.taobao.weex.ui.component.WXComponent
    public void notifyAppearStateChange(String wxEventType, String direction) {
        if (containsEvent(Constants.Event.APPEAR) || containsEvent(Constants.Event.DISAPPEAR)) {
            HashMap hashMap = new HashMap();
            hashMap.put("direction", direction);
            fireEvent(wxEventType, hashMap);
        }
    }

    /* JADX INFO: Access modifiers changed from: private */
    public void procAppear(int x, int y, int oldx, int oldy) {
        int appearStatus;
        if (this.mIsHostAttachedToWindow) {
            int i = y - oldy;
            int i2 = x - oldx;
            String str = i > 0 ? "up" : i < 0 ? "down" : null;
            if (this.mOrientation == 0 && i2 != 0) {
                str = i2 > 0 ? "right" : "left";
            }
            for (Map.Entry<String, AppearanceHelper> entry : this.mAppearanceComponents.entrySet()) {
                AppearanceHelper value = entry.getValue();
                if (value.isWatch() && (appearStatus = value.setAppearStatus(checkItemVisibleInScroller(value.getAwareChild()))) != 0) {
                    value.getAwareChild().notifyAppearStateChange(appearStatus == 1 ? Constants.Event.APPEAR : Constants.Event.DISAPPEAR, str);
                }
            }
        }
    }

    /* JADX WARN: Code restructure failed: missing block: B:13:0x0034, code lost:
        if (r1 < getLayoutWidth()) goto L13;
     */
    /* JADX WARN: Code restructure failed: missing block: B:14:0x0036, code lost:
        r1 = true;
     */
    /* JADX WARN: Code restructure failed: missing block: B:19:0x0058, code lost:
        if (r1 < getLayoutHeight()) goto L13;
     */
    /*
        Code decompiled incorrectly, please refer to instructions dump.
    */
    private boolean checkItemVisibleInScroller(WXComponent component) {
        boolean z = false;
        while (component != null && !(component instanceof DCWXScroller)) {
            if (component.getParent() instanceof DCWXScroller) {
                if (this.mOrientation == 0) {
                    float left = ((int) component.getLayoutPosition().getLeft()) - getScrollX();
                    if (left > 0.0f - component.getLayoutWidth()) {
                    }
                    z = false;
                } else {
                    float top = ((int) component.getLayoutPosition().getTop()) - getScrollY();
                    if (top > 0.0f - component.getLayoutHeight()) {
                    }
                    z = false;
                }
            }
            component = component.getParent();
        }
        return z;
    }

    /* JADX INFO: Access modifiers changed from: private */
    public void dispatchDisappearEvent() {
        int appearStatus;
        for (Map.Entry<String, AppearanceHelper> entry : this.mAppearanceComponents.entrySet()) {
            AppearanceHelper value = entry.getValue();
            if (value.isWatch() && (appearStatus = value.setAppearStatus(false)) != 0) {
                value.getAwareChild().notifyAppearStateChange(appearStatus == 1 ? Constants.Event.APPEAR : Constants.Event.DISAPPEAR, "");
            }
        }
    }

    @Override // io.dcloud.feature.weex_scroller.view.DCWXScrollView.WXScrollViewListener
    public void onScroll(DCWXScrollView scrollView, int x, int y) {
        onLoadMore(scrollView, x, y);
    }

    protected void onLoadMore(FrameLayout scrollView, int x, int y) {
        try {
            String loadMoreOffset = getAttrs().getLoadMoreOffset();
            if (TextUtils.isEmpty(loadMoreOffset)) {
                return;
            }
            int realPxByWidth = (int) WXViewUtils.getRealPxByWidth(Float.parseFloat(loadMoreOffset), getInstance().getInstanceViewPortWidth());
            if (scrollView instanceof DCWXHorizontalScrollView) {
                int width = scrollView.getChildAt(0).getWidth();
                if ((width - x) - scrollView.getWidth() < realPxByWidth) {
                    if (this.mContentWidth != width || this.mForceLoadmoreNextTime) {
                        fireEvent(Constants.Event.LOADMORE);
                        this.mContentWidth = width;
                        this.mForceLoadmoreNextTime = false;
                        return;
                    }
                    return;
                }
                return;
            }
            int height = scrollView.getChildAt(0).getHeight();
            int height2 = (height - y) - scrollView.getHeight();
            if (height2 < realPxByWidth) {
                if (WXEnvironment.isApkDebugable()) {
                    WXLogUtils.d("[WXScroller-onScroll] offScreenY :" + height2);
                }
                if (this.mContentHeight != height || this.mForceLoadmoreNextTime) {
                    fireEvent(Constants.Event.LOADMORE);
                    this.mContentHeight = height;
                    this.mForceLoadmoreNextTime = false;
                }
            }
        } catch (Exception e) {
            WXLogUtils.d("[DCWXScroller-onScroll] ", e);
        }
    }

    @JSMethod
    public void resetLoadmore() {
        this.mForceLoadmoreNextTime = true;
    }

    public ScrollStartEndHelper getScrollStartEndHelper() {
        if (this.mScrollStartEndHelper == null) {
            this.mScrollStartEndHelper = new ScrollStartEndHelper(this);
        }
        return this.mScrollStartEndHelper;
    }

    /* JADX INFO: Access modifiers changed from: package-private */
    /* loaded from: classes8.dex */
    public class MyGestureDetector extends GestureDetector.SimpleOnGestureListener {
        private final DCWXHorizontalScrollView scrollView;

        public DCWXHorizontalScrollView getScrollView() {
            return this.scrollView;
        }

        MyGestureDetector(DCWXHorizontalScrollView horizontalScrollView) {
            this.scrollView = horizontalScrollView;
        }

        @Override // android.view.GestureDetector.SimpleOnGestureListener, android.view.GestureDetector.OnGestureListener
        public boolean onFling(MotionEvent e1, MotionEvent e2, float velocityX, float velocityY) {
            int size = DCWXScroller.this.mChildren.size();
            try {
            } catch (Exception e) {
                WXLogUtils.e("There was an error processing the Fling event:" + e.getMessage());
            }
            if (e1.getX() - e2.getX() > 5.0f && Math.abs(velocityX) > 300.0f) {
                int i = DCWXScroller.this.pageSize;
                DCWXScroller dCWXScroller = DCWXScroller.this;
                int i2 = size - 1;
                if (dCWXScroller.mActiveFeature < i2) {
                    i2 = DCWXScroller.this.mActiveFeature + 1;
                }
                dCWXScroller.mActiveFeature = i2;
                this.scrollView.smoothScrollTo(DCWXScroller.this.mActiveFeature * i, 0);
                return true;
            }
            if (e2.getX() - e1.getX() > 5.0f && Math.abs(velocityX) > 300.0f) {
                int i3 = DCWXScroller.this.pageSize;
                DCWXScroller dCWXScroller2 = DCWXScroller.this;
                dCWXScroller2.mActiveFeature = dCWXScroller2.mActiveFeature > 0 ? DCWXScroller.this.mActiveFeature - 1 : 0;
                this.scrollView.smoothScrollTo(DCWXScroller.this.mActiveFeature * i3, 0);
                return true;
            }
            return false;
        }
    }
}
