package com.taobao.weex.ui.component.list.template;

import android.text.TextUtils;
import androidx.collection.ArrayMap;
import com.alibaba.fastjson.JSONArray;
import com.taobao.weex.WXEnvironment;
import com.taobao.weex.bridge.WXBridgeManager;
import com.taobao.weex.utils.WXUtils;
import java.util.HashMap;
import java.util.Map;
/* loaded from: classes8.dex */
public class CellDataManager {
    public static final String SUB_COMPONENT_TEMPLATE_ID = "@templateId";
    public static final String VIRTUAL_COMPONENT_ID = "@virtualComponentId";
    private static final String VIRTUAL_COMPONENT_SEPRATOR = "@";
    JSONArray listData;
    private Map<Integer, CellRenderState> renderStates = new ArrayMap();
    public final WXRecyclerTemplateList templateList;
    private Map<String, CellRenderState> virtualComponentRenderStates;

    public CellDataManager(WXRecyclerTemplateList templateList) {
        this.templateList = templateList;
    }

    public CellRenderState getRenderState(int position) {
        CellRenderState cellRenderState = this.renderStates.get(Integer.valueOf(position));
        if (cellRenderState == null) {
            cellRenderState = new CellRenderState();
            cellRenderState.position = position;
            this.renderStates.put(Integer.valueOf(position), cellRenderState);
        }
        if (position != cellRenderState.position) {
            cellRenderState.position = position;
            cellRenderState.hasPositionChange = true;
        }
        return cellRenderState;
    }

    public void updateVirtualComponentData(String virutalComponentId, Object data) {
        Map<String, CellRenderState> map = this.virtualComponentRenderStates;
        if (map != null) {
            CellRenderState cellRenderState = map.get(virutalComponentId);
            if (cellRenderState != null) {
                cellRenderState.getVirtualComponentDatas().put(virutalComponentId, data);
                cellRenderState.hasVirtualCompoentUpdate = true;
            } else if (WXEnvironment.isApkDebugable()) {
                throw new IllegalArgumentException("virtualComponentDatas illegal state empty render state" + virutalComponentId);
            }
        } else if (WXEnvironment.isApkDebugable()) {
            throw new IllegalArgumentException("virtualComponentDatas illegal state " + virutalComponentId);
        }
    }

    public void createVirtualComponentData(int position, String virutalComponentId, Object data) {
        if (this.virtualComponentRenderStates == null) {
            this.virtualComponentRenderStates = new HashMap(8);
        }
        CellRenderState cellRenderState = this.renderStates.get(Integer.valueOf(position));
        cellRenderState.getVirtualComponentDatas().put(virutalComponentId, data);
        this.virtualComponentRenderStates.put(virutalComponentId, cellRenderState);
    }

    public void setListData(JSONArray listData) {
        JSONArray jSONArray = this.listData;
        if (jSONArray != listData) {
            if (jSONArray != null && WXUtils.getBoolean(this.templateList.getAttrs().get("exitDetach"), true).booleanValue()) {
                for (int i = 0; i < this.listData.size(); i++) {
                    cleanRenderState(this.renderStates.remove(Integer.valueOf(i)));
                }
            }
            this.listData = listData;
            this.renderStates.clear();
            Map<String, CellRenderState> map = this.virtualComponentRenderStates;
            if (map != null) {
                map.clear();
            }
        }
    }

    public boolean insertData(int index, Object data) {
        this.listData.add(index, data);
        boolean z = false;
        for (int size = this.listData.size(); size >= index; size--) {
            CellRenderState remove = this.renderStates.remove(Integer.valueOf(size));
            if (remove != null) {
                this.renderStates.put(Integer.valueOf(size + 1), remove);
                z = true;
            }
        }
        return z;
    }

    public boolean insertRange(int index, JSONArray data) {
        this.listData.addAll(index, data);
        boolean z = false;
        for (int size = this.listData.size() - 1; size >= index; size--) {
            CellRenderState remove = this.renderStates.remove(Integer.valueOf(size));
            if (remove != null) {
                this.renderStates.put(Integer.valueOf(size + 1), remove);
                z = true;
            }
        }
        return z;
    }

    public boolean updateData(Object data, int index) {
        boolean equals = TextUtils.equals(this.templateList.getTemplateKey(index), this.templateList.getTemplateKey(data));
        this.listData.set(index, data);
        if (!equals) {
            cleanRenderState(this.renderStates.remove(Integer.valueOf(index)));
        } else {
            CellRenderState cellRenderState = this.renderStates.get(Integer.valueOf(index));
            if (cellRenderState != null) {
                cellRenderState.hasDataUpdate = true;
            }
        }
        return equals;
    }

    public void removeData(Integer index) {
        this.listData.remove(index.intValue());
        cleanRenderState(this.renderStates.remove(index));
        int size = this.listData.size() + 1;
        int intValue = index.intValue();
        while (true) {
            intValue++;
            if (intValue >= size) {
                return;
            }
            CellRenderState remove = this.renderStates.remove(Integer.valueOf(intValue));
            if (remove != null) {
                this.renderStates.put(Integer.valueOf(intValue - 1), remove);
            }
        }
    }

    private void cleanRenderState(CellRenderState renderState) {
        if (renderState != null && renderState.hasVirtualComponents()) {
            for (String str : renderState.getVirtualComponentIds().values()) {
                Map<String, CellRenderState> map = this.virtualComponentRenderStates;
                if (map != null) {
                    map.remove(str);
                }
                WXBridgeManager.getInstance().asyncCallJSEventVoidResult(WXBridgeManager.METHD_COMPONENT_HOOK_SYNC, this.templateList.getInstanceId(), null, str, VirtualComponentLifecycle.LIFECYCLE, "detach", null);
            }
        }
    }

    public static String createVirtualComponentId(String listRef, String viewTreeKey, long itemId) {
        return listRef + VIRTUAL_COMPONENT_SEPRATOR + viewTreeKey + VIRTUAL_COMPONENT_SEPRATOR + itemId;
    }

    public static String getListRef(String virtualComponentId) {
        if (virtualComponentId == null) {
            return null;
        }
        return virtualComponentId.split(VIRTUAL_COMPONENT_SEPRATOR)[0];
    }
}
