package com.taobao.weex.ui.component.list.template;

import android.view.View;
import androidx.core.view.ViewCompat;
import com.taobao.weex.WXSDKManager;
import com.taobao.weex.dom.WXAttr;
import com.taobao.weex.ui.component.WXComponent;
import com.taobao.weex.ui.component.WXVContainer;
import com.taobao.weex.ui.view.listview.WXRecyclerView;
import com.taobao.weex.ui.view.refresh.wrapper.BounceRecyclerView;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;
/* loaded from: classes8.dex */
public class TemplateDom {
    public static final String ATTACH_CELL_SLOT = "_attach_slot";
    public static final String ATTRS_KEY_REF = "ref";
    public static final String DETACH_CELL_SLOT = "_detach_slot";
    public static final String KEY_ATTRS = "attrs";
    public static final String KEY_RESET_ANIMATION = "resetAnimation";
    public static final String KEY_TYPE = "type";
    public static final String KEY_VIRTUAL_DOM_REF = "ref";
    public static final char SEPARATOR = '@';
    public static final String VIRTUAL_DOM_IDENTIFY = "[[VirtualElement]]";

    public static String genKeyVirtualDomRef(String listRef, int position, String key) {
        return listRef + SEPARATOR + position + SEPARATOR + key;
    }

    public static WXComponent findVirtualComponentByVRef(String pageId, String virtualRef) {
        String[] split;
        WXComponent wXComponent;
        try {
            split = virtualRef.split("@");
            wXComponent = WXSDKManager.getInstance().getWXRenderManager().getWXComponent(pageId, split[0]);
        } catch (Exception unused) {
        }
        if (wXComponent instanceof WXRecyclerTemplateList) {
            WXRecyclerTemplateList wXRecyclerTemplateList = (WXRecyclerTemplateList) wXComponent;
            if (wXRecyclerTemplateList.getHostView() != 0 && ((BounceRecyclerView) wXRecyclerTemplateList.getHostView()).getInnerView() != null) {
                TemplateViewHolder templateViewHolder = (TemplateViewHolder) ((WXRecyclerView) ((BounceRecyclerView) wXRecyclerTemplateList.getHostView()).getInnerView()).findViewHolderForAdapterPosition(Integer.parseInt(split[1]));
                if (templateViewHolder == null) {
                    return null;
                }
                return findComponentByViewTreeKey(templateViewHolder.getTemplate(), split[2]);
            }
            return null;
        }
        return null;
    }

    public static Map<String, Object> findAllComponentRefs(String listRef, int position, WXComponent component) {
        HashMap hashMap = new HashMap();
        findAllComponentRefs(listRef, position, component, hashMap);
        HashMap hashMap2 = new HashMap();
        hashMap2.put("refs", hashMap);
        hashMap2.put("position", Integer.valueOf(position));
        hashMap2.put("listRef", listRef);
        return hashMap2;
    }

    private static void findAllComponentRefs(String listRef, int position, WXComponent component, Map<String, Object> refs) {
        if (component.isWaste()) {
            return;
        }
        if (component instanceof WXVContainer) {
            WXVContainer wXVContainer = (WXVContainer) component;
            for (int i = 0; i < wXVContainer.getChildCount(); i++) {
                findAllComponentRefs(listRef, position, wXVContainer.getChild(i), refs);
            }
        }
        WXAttr attrs = component.getAttrs();
        if (attrs == null || attrs.get("ref") != null) {
            String obj = attrs.get("ref").toString();
            List list = (List) refs.get(obj);
            if (list == null) {
                list = new ArrayList();
                refs.put(obj, list);
            }
            list.add(toMap(listRef, position, component));
        }
    }

    public static Map toMap(String listRef, int position, WXComponent component) {
        HashMap hashMap = new HashMap();
        hashMap.put(KEY_ATTRS, component.getAttrs());
        hashMap.put("type", component.getComponentType());
        hashMap.put("ref", genKeyVirtualDomRef(listRef, position, component.getViewTreeKey()));
        hashMap.put(VIRTUAL_DOM_IDENTIFY, true);
        return hashMap;
    }

    public static boolean isVirtualDomRef(String ref) {
        return ref != null && ref.indexOf(64) > 0;
    }

    public static void resetAnimaiton(View view) {
        if (view == null) {
            return;
        }
        if (ViewCompat.getTranslationX(view) != 0.0f) {
            ViewCompat.setTranslationX(view, 0.0f);
        }
        if (ViewCompat.getTranslationY(view) != 0.0f) {
            ViewCompat.setTranslationY(view, 0.0f);
        }
        if (ViewCompat.getTranslationZ(view) != 0.0f) {
            ViewCompat.setTranslationZ(view, 0.0f);
        }
        if (ViewCompat.getScaleX(view) != 1.0f) {
            ViewCompat.setScaleX(view, 1.0f);
        }
        if (ViewCompat.getScaleY(view) != 1.0f) {
            ViewCompat.setScaleY(view, 1.0f);
        }
        if (ViewCompat.getRotationX(view) != 0.0f) {
            ViewCompat.setRotationX(view, 0.0f);
        }
        if (ViewCompat.getRotationY(view) != 0.0f) {
            ViewCompat.setRotationY(view, 0.0f);
        }
        if (ViewCompat.getElevation(view) != 0.0f) {
            ViewCompat.setElevation(view, 0.0f);
        }
    }

    public static final WXComponent findComponentByViewTreeKey(WXComponent component, String viewKey) {
        if (component.getViewTreeKey().equals(viewKey)) {
            return component;
        }
        if (component instanceof WXVContainer) {
            WXVContainer wXVContainer = (WXVContainer) component;
            for (int i = 0; i < wXVContainer.getChildCount(); i++) {
                WXComponent child = wXVContainer.getChild(i);
                if (findComponentByViewTreeKey(child, viewKey) != null) {
                    return child;
                }
            }
            return null;
        }
        return null;
    }

    private static WXComponent findChildByAttrsRef(WXComponent component, String ref) {
        if (component.getAttrs() == null || !ref.equals(component.getAttrs().get("ref"))) {
            if (component instanceof WXVContainer) {
                WXVContainer wXVContainer = (WXVContainer) component;
                for (int i = 0; i < wXVContainer.getChildCount(); i++) {
                    WXComponent findChildByAttrsRef = findChildByAttrsRef(wXVContainer.getChild(i), ref);
                    if (findChildByAttrsRef != null) {
                        return findChildByAttrsRef;
                    }
                }
                return null;
            }
            return null;
        }
        return component;
    }
}
