package com.taobao.weex.ui.component.list.template;

import android.content.Context;
import android.graphics.Point;
import android.graphics.PointF;
import android.os.Build;
import android.os.Looper;
import android.text.TextUtils;
import android.view.View;
import android.view.ViewGroup;
import android.view.ViewTreeObserver;
import android.widget.FrameLayout;
import android.widget.LinearLayout;
import androidx.collection.ArrayMap;
import androidx.recyclerview.widget.GridLayoutManager;
import androidx.recyclerview.widget.LinearLayoutManager;
import androidx.recyclerview.widget.RecyclerView;
import androidx.recyclerview.widget.StaggeredGridLayoutManager;
import com.alibaba.fastjson.JSONArray;
import com.alibaba.fastjson.JSONObject;
import com.taobao.weex.WXEnvironment;
import com.taobao.weex.WXSDKInstance;
import com.taobao.weex.annotation.Component;
import com.taobao.weex.annotation.JSMethod;
import com.taobao.weex.bridge.JSCallback;
import com.taobao.weex.common.Constants;
import com.taobao.weex.common.ICheckBindingScroller;
import com.taobao.weex.common.OnWXScrollListener;
import com.taobao.weex.common.WXErrorCode;
import com.taobao.weex.common.WXThread;
import com.taobao.weex.dom.CSSShorthand;
import com.taobao.weex.dom.WXAttr;
import com.taobao.weex.dom.WXEvent;
import com.taobao.weex.el.parse.ArrayStack;
import com.taobao.weex.performance.WXInstanceApm;
import com.taobao.weex.ui.action.BasicComponentData;
import com.taobao.weex.ui.component.AppearanceHelper;
import com.taobao.weex.ui.component.Scrollable;
import com.taobao.weex.ui.component.WXBaseRefresh;
import com.taobao.weex.ui.component.WXComponent;
import com.taobao.weex.ui.component.WXComponentProp;
import com.taobao.weex.ui.component.WXLoading;
import com.taobao.weex.ui.component.WXRefresh;
import com.taobao.weex.ui.component.WXVContainer;
import com.taobao.weex.ui.component.binding.Layouts;
import com.taobao.weex.ui.component.binding.Statements;
import com.taobao.weex.ui.component.helper.ScrollStartEndHelper;
import com.taobao.weex.ui.component.list.RecyclerTransform;
import com.taobao.weex.ui.component.list.WXCell;
import com.taobao.weex.ui.view.listview.WXRecyclerView;
import com.taobao.weex.ui.view.listview.adapter.IOnLoadMoreListener;
import com.taobao.weex.ui.view.listview.adapter.IRecyclerAdapterListener;
import com.taobao.weex.ui.view.listview.adapter.RecyclerViewBaseAdapter;
import com.taobao.weex.ui.view.listview.adapter.WXRecyclerViewOnScrollListener;
import com.taobao.weex.ui.view.refresh.wrapper.BounceRecyclerView;
import com.taobao.weex.utils.WXExceptionUtils;
import com.taobao.weex.utils.WXLogUtils;
import com.taobao.weex.utils.WXUtils;
import com.taobao.weex.utils.WXViewUtils;
import java.util.ArrayList;
import java.util.Arrays;
import java.util.HashMap;
import java.util.Iterator;
import java.util.List;
import java.util.Locale;
import java.util.Map;
import java.util.concurrent.ConcurrentHashMap;
@Component(lazyload = false)
/* loaded from: classes26.dex */
public class WXRecyclerTemplateList extends WXVContainer<BounceRecyclerView> implements IRecyclerAdapterListener<TemplateViewHolder>, IOnLoadMoreListener, Scrollable {
    private static final long APPEAR_CHANGE_RUNNABLE_DELAY = 50;
    private static final String EMPTY_HOLDER_TEMPLATE_KEY = "";
    public static final boolean ENABLE_TRACE_LOG = false;
    private static final String NAME_HAS_FIXED_SIZE = "hasFixedSize";
    private static final String NAME_ITEM_VIEW_CACHE_SIZE = "itemViewCacheSize";
    private static final String NAME_TEMPLATE_CACHE_SIZE = "templateCacheSize";
    public static final String TAG = "WXRecyclerTemplateList";
    private CellDataManager cellDataManager;
    private CellRenderContext cellRenderContext;
    private WXCell defaultTemplateCell;
    private String defaultTemplateKey;
    private boolean hasAppendTreeDone;
    private boolean hasLayoutDone;
    private boolean isScrollable;
    private String listDataIndexKey;
    private String listDataItemKey;
    private String listDataKey;
    private String listDataTemplateKey;
    private Runnable listUpdateRunnable;
    private Runnable mAppearChangeRunnable;
    private ArrayMap<Integer, List<AppearanceHelper>> mAppearHelpers;
    protected int mColumnCount;
    protected float mColumnGap;
    protected float mColumnWidth;
    private ArrayMap<Integer, Map<String, Map<Integer, List<Object>>>> mDisAppearWatchList;
    private boolean mForceLoadmoreNextTime;
    private boolean mHasAddScrollEvent;
    private RecyclerView.ItemAnimator mItemAnimator;
    private Point mLastReport;
    protected int mLayoutType;
    private int mListCellCount;
    private int mOffsetAccuracy;
    private float mPaddingLeft;
    private float mPaddingRight;
    private ScrollStartEndHelper mScrollStartEndHelper;
    private TemplateStickyHelper mStickyHelper;
    private Map<String, WXCell> mTemplateSources;
    private ArrayMap<String, Integer> mTemplateViewTypes;
    private ConcurrentHashMap<String, TemplateCache> mTemplatesCache;
    private WXRecyclerViewOnScrollListener mViewOnScrollListener;
    private int orientation;
    private int templateCacheSize;

    @Override // io.dcloud.feature.uniapp.ui.component.AbsVContainer
    public void addSubView(View child, int index) {
    }

    /* JADX INFO: Access modifiers changed from: protected */
    @Override // com.taobao.weex.ui.component.WXVContainer, io.dcloud.feature.uniapp.ui.component.AbsVContainer
    public int getChildrenLayoutTopOffset() {
        return 0;
    }

    @Override // com.taobao.weex.ui.view.listview.adapter.IRecyclerAdapterListener
    public boolean onFailedToRecycleView(TemplateViewHolder holder) {
        return false;
    }

    @Override // com.taobao.weex.ui.view.listview.adapter.IRecyclerAdapterListener
    public void onViewRecycled(TemplateViewHolder holder) {
    }

    public WXRecyclerTemplateList(WXSDKInstance instance, WXVContainer parent, BasicComponentData basicComponentData) {
        super(instance, parent, basicComponentData);
        this.mLayoutType = 1;
        this.mColumnCount = 1;
        this.mColumnGap = 0.0f;
        this.mColumnWidth = 0.0f;
        this.mViewOnScrollListener = new WXRecyclerViewOnScrollListener(this);
        this.mListCellCount = 0;
        this.mForceLoadmoreNextTime = false;
        this.orientation = 1;
        this.isScrollable = true;
        this.mOffsetAccuracy = 10;
        this.mLastReport = new Point(-1, -1);
        this.mHasAddScrollEvent = false;
        this.listDataKey = Constants.Name.Recycler.LIST_DATA;
        this.listDataItemKey = null;
        this.listDataIndexKey = null;
        this.listDataTemplateKey = Constants.Name.Recycler.SLOT_TEMPLATE_CASE;
        this.templateCacheSize = 2;
        this.defaultTemplateKey = "@default_template_cell";
        this.mAppearHelpers = new ArrayMap<>();
        this.mDisAppearWatchList = new ArrayMap<>();
        this.cellRenderContext = new CellRenderContext();
        this.mAppearChangeRunnable = null;
        this.hasAppendTreeDone = false;
        this.hasLayoutDone = false;
        initRecyclerTemplateList(instance, basicComponentData, parent);
    }

    private void initRecyclerTemplateList(WXSDKInstance instance, BasicComponentData basicComponentData, WXVContainer parent) {
        updateRecyclerAttr();
        ArrayMap<String, Integer> arrayMap = new ArrayMap<>();
        this.mTemplateViewTypes = arrayMap;
        arrayMap.put("", 0);
        this.mTemplateSources = new HashMap();
        this.mTemplatesCache = new ConcurrentHashMap<>();
        this.mStickyHelper = new TemplateStickyHelper(this);
        this.orientation = basicComponentData.getAttrs().getOrientation();
        this.listDataTemplateKey = WXUtils.getString(getAttrs().get(Constants.Name.Recycler.LIST_DATA_TEMPLATE_SWITCH_KEY), Constants.Name.Recycler.SLOT_TEMPLATE_CASE);
        this.listDataItemKey = WXUtils.getString(getAttrs().get(Constants.Name.Recycler.LIST_DATA_ITEM), this.listDataItemKey);
        this.listDataIndexKey = WXUtils.getString(getAttrs().get("index"), this.listDataIndexKey);
        CellDataManager cellDataManager = new CellDataManager(this);
        this.cellDataManager = cellDataManager;
        cellDataManager.listData = parseListDataToJSONArray(getAttrs().get(Constants.Name.Recycler.LIST_DATA));
    }

    /* JADX INFO: Access modifiers changed from: protected */
    @Override // com.taobao.weex.ui.component.WXComponent
    public BounceRecyclerView initComponentHostView(Context context) {
        BounceRecyclerView bounceRecyclerView = new BounceRecyclerView(context, this.mLayoutType, this.mColumnCount, this.mColumnGap, getOrientation());
        WXAttr attrs = getAttrs();
        String str = (String) attrs.get("transform");
        if (str != null) {
            ((WXRecyclerView) bounceRecyclerView.getInnerView()).addItemDecoration(RecyclerTransform.parseTransforms(getOrientation(), str));
        }
        this.mItemAnimator = ((WXRecyclerView) bounceRecyclerView.getInnerView()).getItemAnimator();
        if (attrs.get(NAME_TEMPLATE_CACHE_SIZE) != null) {
            this.templateCacheSize = WXUtils.getInteger(attrs.get(NAME_TEMPLATE_CACHE_SIZE), Integer.valueOf(this.templateCacheSize)).intValue();
        }
        int numberInt = attrs.get(NAME_ITEM_VIEW_CACHE_SIZE) != null ? WXUtils.getNumberInt(getAttrs().get(NAME_ITEM_VIEW_CACHE_SIZE), 2) : 2;
        boolean booleanValue = attrs.get("hasFixedSize") != null ? WXUtils.getBoolean(attrs.get("hasFixedSize"), false).booleanValue() : false;
        RecyclerViewBaseAdapter recyclerViewBaseAdapter = new RecyclerViewBaseAdapter(this);
        recyclerViewBaseAdapter.setHasStableIds(true);
        ((WXRecyclerView) bounceRecyclerView.getInnerView()).setItemAnimator(null);
        if (numberInt != 2) {
            ((WXRecyclerView) bounceRecyclerView.getInnerView()).setItemViewCacheSize(numberInt);
        }
        if (bounceRecyclerView.getSwipeLayout() != null && WXUtils.getBoolean(getAttrs().get(Constants.Name.NEST_SCROLLING_ENABLED), false).booleanValue()) {
            bounceRecyclerView.getSwipeLayout().setNestedScrollingEnabled(true);
        }
        ((WXRecyclerView) bounceRecyclerView.getInnerView()).setHasFixedSize(booleanValue);
        bounceRecyclerView.setRecyclerViewBaseAdapter(recyclerViewBaseAdapter);
        bounceRecyclerView.setOverScrollMode(2);
        ((WXRecyclerView) bounceRecyclerView.getInnerView()).clearOnScrollListeners();
        ((WXRecyclerView) bounceRecyclerView.getInnerView()).addOnScrollListener(this.mViewOnScrollListener);
        ((WXRecyclerView) bounceRecyclerView.getInnerView()).addOnScrollListener(new RecyclerView.OnScrollListener() { // from class: com.taobao.weex.ui.component.list.template.WXRecyclerTemplateList.1
            @Override // androidx.recyclerview.widget.RecyclerView.OnScrollListener
            public void onScrollStateChanged(RecyclerView recyclerView, int newState) {
                View childAt;
                super.onScrollStateChanged(recyclerView, newState);
                WXRecyclerTemplateList.this.getScrollStartEndHelper().onScrollStateChanged(newState);
                List<OnWXScrollListener> wXScrollListeners = WXRecyclerTemplateList.this.getInstance().getWXScrollListeners();
                if (wXScrollListeners == null || wXScrollListeners.size() <= 0) {
                    return;
                }
                for (OnWXScrollListener onWXScrollListener : wXScrollListeners) {
                    if (onWXScrollListener != null && (childAt = recyclerView.getChildAt(0)) != null) {
                        onWXScrollListener.onScrollStateChanged(recyclerView, 0, childAt.getTop(), newState);
                    }
                }
            }

            @Override // androidx.recyclerview.widget.RecyclerView.OnScrollListener
            public void onScrolled(RecyclerView recyclerView, int dx, int dy) {
                super.onScrolled(recyclerView, dx, dy);
                List<OnWXScrollListener> wXScrollListeners = WXRecyclerTemplateList.this.getInstance().getWXScrollListeners();
                if (wXScrollListeners == null || wXScrollListeners.size() <= 0) {
                    return;
                }
                try {
                    for (OnWXScrollListener onWXScrollListener : wXScrollListeners) {
                        if (onWXScrollListener != null) {
                            if (onWXScrollListener instanceof ICheckBindingScroller) {
                                if (((ICheckBindingScroller) onWXScrollListener).isNeedScroller(WXRecyclerTemplateList.this.getRef(), null)) {
                                    onWXScrollListener.onScrolled(recyclerView, dx, dy);
                                }
                            } else {
                                onWXScrollListener.onScrolled(recyclerView, dx, dy);
                            }
                        }
                    }
                } catch (Exception e) {
                    e.printStackTrace();
                }
            }
        });
        bounceRecyclerView.getViewTreeObserver().addOnGlobalLayoutListener(new ViewTreeObserver.OnGlobalLayoutListener() { // from class: com.taobao.weex.ui.component.list.template.WXRecyclerTemplateList.2
            @Override // android.view.ViewTreeObserver.OnGlobalLayoutListener
            public void onGlobalLayout() {
                BounceRecyclerView bounceRecyclerView2 = (BounceRecyclerView) WXRecyclerTemplateList.this.getHostView();
                if (bounceRecyclerView2 == null) {
                    return;
                }
                WXRecyclerTemplateList.this.mViewOnScrollListener.onScrolled((RecyclerView) bounceRecyclerView2.getInnerView(), 0, 0);
                if (Build.VERSION.SDK_INT >= 16) {
                    bounceRecyclerView2.getViewTreeObserver().removeOnGlobalLayoutListener(this);
                } else {
                    bounceRecyclerView2.getViewTreeObserver().removeGlobalOnLayoutListener(this);
                }
            }
        });
        this.listUpdateRunnable = new Runnable() { // from class: com.taobao.weex.ui.component.list.template.WXRecyclerTemplateList.3
            @Override // java.lang.Runnable
            public void run() {
                if (WXRecyclerTemplateList.this.mStickyHelper != null && WXRecyclerTemplateList.this.mStickyHelper.getStickyTypes().size() > 0) {
                    WXRecyclerTemplateList.this.mStickyHelper.getStickyPositions().clear();
                    if (WXRecyclerTemplateList.this.cellDataManager.listData != null) {
                        for (int i = 0; i < WXRecyclerTemplateList.this.cellDataManager.listData.size(); i++) {
                            WXCell sourceTemplate = WXRecyclerTemplateList.this.getSourceTemplate(i);
                            if (sourceTemplate != null && sourceTemplate.isSticky()) {
                                WXRecyclerTemplateList.this.mStickyHelper.getStickyPositions().add(Integer.valueOf(i));
                            }
                        }
                    }
                }
                if (WXRecyclerTemplateList.this.getHostView() != 0 && ((BounceRecyclerView) WXRecyclerTemplateList.this.getHostView()).getRecyclerViewBaseAdapter() != null) {
                    ((BounceRecyclerView) WXRecyclerTemplateList.this.getHostView()).getRecyclerViewBaseAdapter().notifyDataSetChanged();
                }
                WXEnvironment.isOpenDebugLog();
            }
        };
        return bounceRecyclerView;
    }

    /* JADX INFO: Access modifiers changed from: protected */
    @Override // com.taobao.weex.ui.component.WXComponent
    public void onHostViewInitialized(BounceRecyclerView host) {
        super.onHostViewInitialized((WXRecyclerTemplateList) host);
        WXRecyclerView wXRecyclerView = (WXRecyclerView) host.getInnerView();
        if (wXRecyclerView == null || wXRecyclerView.getAdapter() == null) {
            WXLogUtils.e(TAG, "RecyclerView is not found or Adapter is not bound");
        }
    }

    /* JADX INFO: Access modifiers changed from: protected */
    @Override // com.taobao.weex.ui.component.WXComponent
    public WXComponent.MeasureOutput measure(int width, int height) {
        int screenHeight = WXViewUtils.getScreenHeight(WXEnvironment.sApplication);
        int weexHeight = WXViewUtils.getWeexHeight(getInstanceId());
        if (weexHeight < screenHeight) {
            screenHeight = weexHeight;
        }
        if (height > screenHeight) {
            height = weexHeight - getAbsoluteY();
        }
        return super.measure(width, height);
    }

    @Override // com.taobao.weex.ui.component.Scrollable
    public void bindStickStyle(WXComponent component) {
        TemplateStickyHelper templateStickyHelper;
        WXComponent findParentType = findParentType(component, WXCell.class);
        if (findParentType == null || (templateStickyHelper = this.mStickyHelper) == null || templateStickyHelper.getStickyTypes().contains(findParentType.getRef())) {
            return;
        }
        this.mStickyHelper.getStickyTypes().add(findParentType.getRef());
        notifyUpdateList();
    }

    @Override // com.taobao.weex.ui.component.Scrollable
    public void unbindStickStyle(WXComponent component) {
        TemplateStickyHelper templateStickyHelper;
        WXComponent findParentType = findParentType(component, WXCell.class);
        if (findParentType == null || (templateStickyHelper = this.mStickyHelper) == null || !templateStickyHelper.getStickyTypes().contains(findParentType.getRef())) {
            return;
        }
        this.mStickyHelper.getStickyTypes().remove(findParentType.getRef());
        notifyUpdateList();
    }

    private WXCell findCell(WXComponent component) {
        WXVContainer parent;
        if (component instanceof WXCell) {
            return (WXCell) component;
        }
        if (component == null || (parent = component.getParent()) == null) {
            return null;
        }
        return findCell(parent);
    }

    private void setAppearanceWatch(WXComponent component, int event, boolean enable) {
        int cellTemplateItemType;
        if (this.cellDataManager.listData == null || this.mAppearHelpers == null || TextUtils.isEmpty(component.getRef()) || (cellTemplateItemType = getCellTemplateItemType(findCell(component))) < 0) {
            return;
        }
        List<AppearanceHelper> list = this.mAppearHelpers.get(Integer.valueOf(cellTemplateItemType));
        if (list == null) {
            list = new ArrayList<>();
            this.mAppearHelpers.put(Integer.valueOf(cellTemplateItemType), list);
        }
        AppearanceHelper appearanceHelper = null;
        Iterator<AppearanceHelper> it = list.iterator();
        while (true) {
            if (!it.hasNext()) {
                break;
            }
            AppearanceHelper next = it.next();
            if (component.getRef().equals(next.getAwareChild().getRef())) {
                appearanceHelper = next;
                break;
            }
        }
        if (appearanceHelper != null) {
            appearanceHelper.setWatchEvent(event, enable);
            return;
        }
        AppearanceHelper appearanceHelper2 = new AppearanceHelper(component, cellTemplateItemType);
        appearanceHelper2.setWatchEvent(event, enable);
        list.add(appearanceHelper2);
    }

    @Override // com.taobao.weex.ui.component.Scrollable
    public void bindAppearEvent(WXComponent component) {
        setAppearanceWatch(component, 0, true);
        if (this.mAppearChangeRunnable == null) {
            this.mAppearChangeRunnable = new Runnable() { // from class: com.taobao.weex.ui.component.list.template.WXRecyclerTemplateList.4
                @Override // java.lang.Runnable
                public void run() {
                    if (WXRecyclerTemplateList.this.mAppearChangeRunnable != null) {
                        WXRecyclerTemplateList.this.notifyAppearStateChange(0, 0, 0, 0);
                    }
                }
            };
        }
        if (getHostView() != 0) {
            ((BounceRecyclerView) getHostView()).removeCallbacks(this.mAppearChangeRunnable);
            ((BounceRecyclerView) getHostView()).postDelayed(this.mAppearChangeRunnable, APPEAR_CHANGE_RUNNABLE_DELAY);
        }
    }

    @Override // com.taobao.weex.ui.component.Scrollable
    public void bindDisappearEvent(WXComponent component) {
        setAppearanceWatch(component, 1, true);
        if (this.mAppearChangeRunnable == null) {
            this.mAppearChangeRunnable = new Runnable() { // from class: com.taobao.weex.ui.component.list.template.WXRecyclerTemplateList.5
                @Override // java.lang.Runnable
                public void run() {
                    if (WXRecyclerTemplateList.this.mAppearChangeRunnable != null) {
                        WXRecyclerTemplateList.this.notifyAppearStateChange(0, 0, 0, 0);
                    }
                }
            };
        }
        if (getHostView() != 0) {
            ((BounceRecyclerView) getHostView()).removeCallbacks(this.mAppearChangeRunnable);
            ((BounceRecyclerView) getHostView()).postDelayed(this.mAppearChangeRunnable, APPEAR_CHANGE_RUNNABLE_DELAY);
        }
    }

    @Override // com.taobao.weex.ui.component.Scrollable
    public void unbindAppearEvent(WXComponent component) {
        setAppearanceWatch(component, 0, false);
    }

    @Override // com.taobao.weex.ui.component.Scrollable
    public void unbindDisappearEvent(WXComponent component) {
        setAppearanceWatch(component, 1, false);
    }

    @JSMethod(uiThread = true)
    public void queryElement(String virtualRef, String selector, JSCallback callback) {
        try {
            String[] split = virtualRef.split("@");
            String str = split[0];
            int parseInt = Integer.parseInt(split[1]);
            WXComponent findVirtualComponentByVRef = TemplateDom.findVirtualComponentByVRef(getInstanceId(), virtualRef);
            if (findVirtualComponentByVRef != null && getHostView() != 0 && ((BounceRecyclerView) getHostView()).getInnerView() != null) {
                ArrayList arrayList = new ArrayList(4);
                Selector.queryElementAll(findVirtualComponentByVRef, selector, arrayList);
                if (arrayList.size() > 0) {
                    callback.invoke(TemplateDom.toMap(str, parseInt, (WXComponent) arrayList.get(0)));
                } else {
                    callback.invoke(new HashMap(4));
                }
            }
        } catch (Exception e) {
            callback.invoke(new HashMap(4));
            WXLogUtils.e(TAG, e);
        }
    }

    @JSMethod(uiThread = true)
    public void queryElementAll(String virtualRef, String selector, JSCallback callback) {
        ArrayList arrayList = new ArrayList();
        try {
            String[] split = virtualRef.split("@");
            String str = split[0];
            int parseInt = Integer.parseInt(split[1]);
            WXComponent findVirtualComponentByVRef = TemplateDom.findVirtualComponentByVRef(getInstanceId(), virtualRef);
            if (findVirtualComponentByVRef != null && getHostView() != 0 && ((BounceRecyclerView) getHostView()).getInnerView() != null) {
                ArrayList<WXComponent> arrayList2 = new ArrayList(4);
                Selector.queryElementAll(findVirtualComponentByVRef, selector, arrayList2);
                for (WXComponent wXComponent : arrayList2) {
                    arrayList.add(TemplateDom.toMap(str, parseInt, wXComponent));
                }
                callback.invoke(arrayList);
            }
        } catch (Exception e) {
            callback.invoke(arrayList);
            WXLogUtils.e(TAG, e);
        }
    }

    @JSMethod(uiThread = true)
    public void closest(String virtualRef, String selector, JSCallback callback) {
        try {
            String[] split = virtualRef.split("@");
            String str = split[0];
            int parseInt = Integer.parseInt(split[1]);
            WXComponent findVirtualComponentByVRef = TemplateDom.findVirtualComponentByVRef(getInstanceId(), virtualRef);
            if (findVirtualComponentByVRef != null && getHostView() != 0 && ((BounceRecyclerView) getHostView()).getInnerView() != null) {
                ArrayList arrayList = new ArrayList(4);
                Selector.closest(findVirtualComponentByVRef, selector, arrayList);
                if (arrayList.size() > 0) {
                    callback.invoke(TemplateDom.toMap(str, parseInt, (WXComponent) arrayList.get(0)));
                } else {
                    callback.invoke(new HashMap(4));
                }
            }
        } catch (Exception e) {
            callback.invoke(new HashMap(4));
            WXLogUtils.e(TAG, e);
        }
    }

    @JSMethod(uiThread = true)
    public void scrollToElement(String virtualRef, Map<String, Object> options) {
        scrollTo(virtualRef, options);
    }

    @JSMethod(uiThread = true)
    public void scrollTo(String virtualRef, Map<String, Object> options) {
        int parseFloat;
        try {
            if (virtualRef.indexOf(64) > 0) {
                parseFloat = Integer.parseInt(virtualRef.split("@")[0]);
            } else {
                parseFloat = (int) Float.parseFloat(virtualRef);
            }
            if (parseFloat >= 0) {
                float f = 0.0f;
                boolean z = true;
                if (options != null) {
                    WXUtils.getBoolean(options.get(Constants.Name.ANIMATED), true).booleanValue();
                    String obj = options.get("offset") == null ? WXInstanceApm.VALUE_ERROR_CODE_DEFAULT : options.get("offset").toString();
                    z = WXUtils.getBoolean(options.get(Constants.Name.ANIMATED), true).booleanValue();
                    if (obj != null) {
                        try {
                            f = WXViewUtils.getRealPxByWidth(Float.parseFloat(obj), getInstance().getInstanceViewPortWidthWithFloat());
                        } catch (Exception e) {
                            WXLogUtils.e("Float parseFloat error :" + e.getMessage());
                        }
                    }
                }
                int i = (int) f;
                BounceRecyclerView bounceRecyclerView = (BounceRecyclerView) getHostView();
                if (bounceRecyclerView == null) {
                    return;
                }
                ((WXRecyclerView) bounceRecyclerView.getInnerView()).scrollTo(z, parseFloat, i, getOrientation());
            }
        } catch (Exception e2) {
            WXLogUtils.e(TAG, e2);
        }
    }

    @Override // com.taobao.weex.ui.component.Scrollable
    public void scrollTo(WXComponent component, Map<String, Object> options) {
        int i;
        boolean z;
        int i2 = -1;
        float f = 0.0f;
        if (options != null) {
            String obj = options.get("offset") == null ? WXInstanceApm.VALUE_ERROR_CODE_DEFAULT : options.get("offset").toString();
            z = WXUtils.getBoolean(options.get(Constants.Name.ANIMATED), true).booleanValue();
            if (obj != null) {
                try {
                    f = WXViewUtils.getRealPxByWidth(Float.parseFloat(obj), getInstance().getInstanceViewPortWidthWithFloat());
                } catch (Exception e) {
                    WXLogUtils.e("Float parseFloat error :" + e.getMessage());
                }
            }
            i = WXUtils.getNumberInt(options.get(Constants.Name.Recycler.CELL_INDEX), -1);
            i2 = WXUtils.getNumberInt(options.get(Constants.Name.Recycler.TYPE_INDEX), -1);
        } else {
            i = -1;
            z = true;
        }
        WXCell findCell = findCell(component);
        if (i2 >= 0 && this.cellDataManager.listData != null && component.getRef() != null) {
            int i3 = 0;
            int i4 = 0;
            while (true) {
                if (i3 >= this.cellDataManager.listData.size()) {
                    break;
                }
                WXCell sourceTemplate = getSourceTemplate(i3);
                if (sourceTemplate != null) {
                    if (findCell.getRef().equals(sourceTemplate.getRef())) {
                        i4++;
                    }
                    if (i4 > i2) {
                        i = i3;
                        break;
                    }
                }
                i3++;
            }
            if (i < 0) {
                i = this.cellDataManager.listData.size() - 1;
            }
        }
        int i5 = (int) f;
        BounceRecyclerView bounceRecyclerView = (BounceRecyclerView) getHostView();
        if (bounceRecyclerView != null && i >= 0) {
            ((WXRecyclerView) bounceRecyclerView.getInnerView()).scrollTo(z, i, i5, getOrientation());
        }
    }

    @Override // com.taobao.weex.ui.component.Scrollable
    public int getScrollY() {
        BounceRecyclerView bounceRecyclerView = (BounceRecyclerView) getHostView();
        if (bounceRecyclerView == null) {
            return 0;
        }
        return ((WXRecyclerView) bounceRecyclerView.getInnerView()).getScrollY();
    }

    @Override // com.taobao.weex.ui.component.Scrollable
    public int getScrollX() {
        BounceRecyclerView bounceRecyclerView = (BounceRecyclerView) getHostView();
        if (bounceRecyclerView == null) {
            return 0;
        }
        return ((WXRecyclerView) bounceRecyclerView.getInnerView()).getScrollX();
    }

    @Override // com.taobao.weex.ui.component.Scrollable
    public int getOrientation() {
        return this.orientation;
    }

    @Override // com.taobao.weex.ui.component.Scrollable
    public boolean isScrollable() {
        return this.isScrollable;
    }

    @Override // io.dcloud.feature.uniapp.ui.component.AbsVContainer
    public void addChild(WXComponent child) {
        addChild(child, -1);
    }

    @Override // io.dcloud.feature.uniapp.ui.component.AbsVContainer
    public void addChild(WXComponent child, int index) {
        boolean z = child instanceof WXCell;
        if (!z) {
            super.addChild(child, index);
        }
        if (!(child instanceof WXBaseRefresh) && z) {
            if (child.getAttrs() != null) {
                String string = WXUtils.getString(child.getAttrs().get(Constants.Name.Recycler.SLOT_TEMPLATE_CASE), null);
                if (getAttrs().containsKey(Constants.Name.Recycler.LIST_DATA_TEMPLATE_SWITCH_KEY)) {
                    if (this.defaultTemplateCell == null) {
                        this.defaultTemplateCell = (WXCell) child;
                        if (!TextUtils.isEmpty(string)) {
                            this.defaultTemplateKey = string;
                        } else {
                            string = this.defaultTemplateKey;
                            child.getAttrs().put(Constants.Name.Recycler.SLOT_TEMPLATE_CASE, (Object) string);
                        }
                    }
                } else if (this.defaultTemplateCell == null || child.getAttrs().containsKey("default")) {
                    this.defaultTemplateCell = (WXCell) child;
                    if (!TextUtils.isEmpty(string)) {
                        this.defaultTemplateKey = string;
                    } else {
                        string = this.defaultTemplateKey;
                        child.getAttrs().put(Constants.Name.Recycler.SLOT_TEMPLATE_CASE, (Object) string);
                    }
                }
                if (string != null) {
                    this.mTemplateSources.put(string, (WXCell) child);
                    if (this.mTemplateViewTypes.get(string) == null) {
                        ArrayMap<String, Integer> arrayMap = this.mTemplateViewTypes;
                        arrayMap.put(string, Integer.valueOf(arrayMap.size()));
                    }
                }
            }
            ((WXCell) child).setCellAppendTreeListener(new WXCell.CellAppendTreeListener() { // from class: com.taobao.weex.ui.component.list.template.WXRecyclerTemplateList.6
                @Override // com.taobao.weex.ui.component.list.WXCell.CellAppendTreeListener
                public void onAppendTreeDone() {
                    WXRecyclerTemplateList.this.checkAppendDone(false);
                }
            });
        }
    }

    /* JADX INFO: Access modifiers changed from: private */
    public void checkAppendDone(boolean listDone) {
        if (this.mTemplateSources.size() == 0) {
            return;
        }
        for (Map.Entry<String, WXCell> entry : this.mTemplateSources.entrySet()) {
            if (!entry.getValue().isAppendTreeDone()) {
                return;
            }
        }
        this.hasAppendTreeDone = true;
        if (this.hasLayoutDone) {
            notifyUpdateList();
        }
    }

    /* JADX INFO: Access modifiers changed from: protected */
    @Override // com.taobao.weex.ui.component.WXComponent
    public void setHostLayoutParams(BounceRecyclerView host, int width, int height, int left, int right, int top, int bottom) {
        super.setHostLayoutParams((WXRecyclerTemplateList) host, width, height, left, right, top, bottom);
        if (this.hasLayoutDone) {
            return;
        }
        this.hasLayoutDone = true;
        this.hasAppendTreeDone = true;
        notifyUpdateList();
    }

    @Override // io.dcloud.feature.uniapp.ui.component.AbsVContainer
    public void createChildViewAt(int index) {
        if (index >= 0 || childCount() - 1 >= 0) {
            WXComponent child = getChild(index);
            if (child instanceof WXBaseRefresh) {
                child.createView();
                setRefreshOrLoading(child);
            }
        }
    }

    @Override // io.dcloud.feature.uniapp.ui.component.AbsVContainer
    public void remove(WXComponent child, boolean destroy) {
        removeFooterOrHeader(child);
        super.remove(child, destroy);
    }

    @Override // com.taobao.weex.ui.component.WXComponent
    public void computeVisiblePointInViewCoordinate(PointF pointF) {
        RecyclerView recyclerView = (RecyclerView) ((BounceRecyclerView) getHostView()).getInnerView();
        pointF.set(recyclerView.computeHorizontalScrollOffset(), recyclerView.computeVerticalScrollOffset());
    }

    /* JADX INFO: Access modifiers changed from: protected */
    @Override // com.taobao.weex.ui.component.WXComponent
    public boolean setProperty(String key, Object param) {
        key.hashCode();
        char c = 65535;
        switch (key.hashCode()) {
            case -889473228:
                if (key.equals(Constants.Name.Recycler.LIST_DATA_TEMPLATE_SWITCH_KEY)) {
                    c = 0;
                    break;
                }
                break;
            case -713683669:
                if (key.equals(NAME_ITEM_VIEW_CACHE_SIZE)) {
                    c = 1;
                    break;
                }
                break;
            case -338674661:
                if (key.equals("hasFixedSize")) {
                    c = 2;
                    break;
                }
                break;
            case -223520855:
                if (key.equals(Constants.Name.SHOW_SCROLLBAR)) {
                    c = 3;
                    break;
                }
                break;
            case -112563826:
                if (key.equals("loadmoreoffset")) {
                    c = 4;
                    break;
                }
                break;
            case -5620052:
                if (key.equals(Constants.Name.OFFSET_ACCURACY)) {
                    c = 5;
                    break;
                }
                break;
            case 3046192:
                if (key.equals(Constants.Name.Recycler.SLOT_TEMPLATE_CASE)) {
                    c = 6;
                    break;
                }
                break;
            case 66669991:
                if (key.equals(Constants.Name.SCROLLABLE)) {
                    c = 7;
                    break;
                }
                break;
            case 92902992:
                if (key.equals(Constants.Name.Recycler.LIST_DATA_ITEM)) {
                    c = '\b';
                    break;
                }
                break;
            case 100346066:
                if (key.equals("index")) {
                    c = '\t';
                    break;
                }
                break;
            case 1345164648:
                if (key.equals(Constants.Name.Recycler.LIST_DATA)) {
                    c = '\n';
                    break;
                }
                break;
            case 1614714674:
                if (key.equals(Constants.Name.SCROLL_DIRECTION)) {
                    c = 11;
                    break;
                }
                break;
        }
        switch (c) {
            case 0:
            case 6:
                this.listDataTemplateKey = WXUtils.getString(param, Constants.Name.Recycler.SLOT_TEMPLATE_CASE);
                return true;
            case 1:
            case 2:
                return true;
            case 3:
                Boolean bool = WXUtils.getBoolean(param, null);
                if (bool != null) {
                    setShowScrollbar(bool.booleanValue());
                }
                return true;
            case 4:
                return true;
            case 5:
                setOffsetAccuracy(WXUtils.getInteger(param, 10).intValue());
                return true;
            case 7:
                setScrollable(WXUtils.getBoolean(param, true).booleanValue());
                return true;
            case '\b':
                this.listDataItemKey = WXUtils.getString(param, this.listDataItemKey);
                return true;
            case '\t':
                this.listDataIndexKey = WXUtils.getString(param, this.listDataIndexKey);
                return true;
            case '\n':
                setListData(param);
                return true;
            case 11:
                if (param != null) {
                    setScrollDirection(param.toString());
                }
                return true;
            default:
                return super.setProperty(key, param);
        }
    }

    @WXComponentProp(name = Constants.Name.OFFSET_ACCURACY)
    public void setOffsetAccuracy(int accuracy) {
        this.mOffsetAccuracy = (int) WXViewUtils.getRealPxByWidth(accuracy, getInstance().getInstanceViewPortWidthWithFloat());
    }

    private void updateRecyclerAttr() {
        this.mLayoutType = getAttrs().getLayoutType();
        int columnCount = getAttrs().getColumnCount();
        this.mColumnCount = columnCount;
        if (columnCount <= 0 && this.mLayoutType != 1) {
            ArrayMap arrayMap = new ArrayMap();
            arrayMap.put("componentType", getComponentType());
            arrayMap.put("attribute", getAttrs().toString());
            arrayMap.put("stackTrace", Arrays.toString(Thread.currentThread().getStackTrace()));
            WXExceptionUtils.commitCriticalExceptionRT(getInstanceId(), WXErrorCode.WX_RENDER_ERR_LIST_INVALID_COLUMN_COUNT, Constants.Name.COLUMN_COUNT, String.format(Locale.ENGLISH, "You are trying to set the list/recycler/vlist/waterfall's column to %d, which is illegal. The column count should be a positive integer", Integer.valueOf(this.mColumnCount)), arrayMap);
            this.mColumnCount = 1;
        }
        this.mColumnGap = getAttrs().getColumnGap();
        this.mColumnWidth = getAttrs().getColumnWidth();
        this.mPaddingLeft = getPadding().get(CSSShorthand.EDGE.LEFT);
        this.mPaddingRight = getPadding().get(CSSShorthand.EDGE.RIGHT);
    }

    @WXComponentProp(name = Constants.Name.SCROLL_DIRECTION)
    public void setScrollDirection(String direction) {
        if (this.orientation != getAttrs().getOrientation()) {
            this.orientation = getAttrs().getOrientation();
            updateRecyclerAttr();
            WXRecyclerView wXRecyclerView = (WXRecyclerView) ((BounceRecyclerView) getHostView()).getInnerView();
            if (this.orientation == 0) {
                wXRecyclerView.setHorizontalScrollBarEnabled(true);
            } else {
                wXRecyclerView.setHorizontalScrollBarEnabled(false);
            }
            wXRecyclerView.initView(getContext(), this.mLayoutType, this.mColumnCount, this.mColumnGap, getOrientation());
        }
    }

    @WXComponentProp(name = Constants.Name.COLUMN_WIDTH)
    public void setColumnWidth(int columnCount) {
        if (getAttrs().getColumnWidth() != this.mColumnWidth) {
            updateRecyclerAttr();
            ((WXRecyclerView) ((BounceRecyclerView) getHostView()).getInnerView()).initView(getContext(), this.mLayoutType, this.mColumnCount, this.mColumnGap, getOrientation());
        }
    }

    @WXComponentProp(name = Constants.Name.SHOW_SCROLLBAR)
    public void setShowScrollbar(boolean show) {
        if (getHostView() == 0 || ((BounceRecyclerView) getHostView()).getInnerView() == null) {
            return;
        }
        if (getOrientation() == 1) {
            ((WXRecyclerView) ((BounceRecyclerView) getHostView()).getInnerView()).setVerticalScrollBarEnabled(show);
        } else {
            ((WXRecyclerView) ((BounceRecyclerView) getHostView()).getInnerView()).setHorizontalScrollBarEnabled(show);
        }
    }

    @WXComponentProp(name = Constants.Name.COLUMN_COUNT)
    public void setColumnCount(int columnCount) {
        if (getAttrs().getColumnCount() != this.mColumnCount) {
            updateRecyclerAttr();
            ((WXRecyclerView) ((BounceRecyclerView) getHostView()).getInnerView()).initView(getContext(), this.mLayoutType, this.mColumnCount, this.mColumnGap, getOrientation());
        }
    }

    @WXComponentProp(name = Constants.Name.COLUMN_GAP)
    public void setColumnGap(float columnGap) throws InterruptedException {
        if (getAttrs().getColumnGap() != this.mColumnGap) {
            updateRecyclerAttr();
            ((WXRecyclerView) ((BounceRecyclerView) getHostView()).getInnerView()).initView(getContext(), this.mLayoutType, this.mColumnCount, this.mColumnGap, getOrientation());
        }
    }

    @WXComponentProp(name = Constants.Name.SCROLLABLE)
    public void setScrollable(boolean scrollable) {
        ((WXRecyclerView) ((BounceRecyclerView) getHostView()).getInnerView()).setScrollable(scrollable);
    }

    @JSMethod
    public void setListData(Object param) {
        JSONArray parseListDataToJSONArray = parseListDataToJSONArray(param);
        boolean z = this.cellDataManager.listData != parseListDataToJSONArray;
        if ((parseListDataToJSONArray instanceof JSONArray) && z) {
            this.cellDataManager.setListData(parseListDataToJSONArray);
            notifyUpdateList();
        }
    }

    @JSMethod
    public void appendData(JSONArray data) {
        if (data == null || data.size() == 0) {
            return;
        }
        if (this.cellDataManager.listData == null) {
            this.cellDataManager.listData = new JSONArray();
        }
        int size = this.cellDataManager.listData.size();
        if (size < 0) {
            size = 0;
        }
        if (data instanceof JSONArray) {
            this.cellDataManager.listData.addAll(data);
        }
        ((BounceRecyclerView) getHostView()).getRecyclerViewBaseAdapter().notifyItemRangeInserted(size, data.size());
    }

    @JSMethod
    public void insertData(int index, Object data) {
        if (data == null || this.cellDataManager.listData == null || index > this.cellDataManager.listData.size()) {
            return;
        }
        if (this.cellDataManager.insertData(index, data)) {
            notifyUpdateList();
        } else {
            ((BounceRecyclerView) getHostView()).getRecyclerViewBaseAdapter().notifyItemInserted(index);
        }
    }

    @JSMethod
    public void appendRange(int index, JSONArray data) {
        insertRange(index, data);
    }

    @JSMethod
    public void insertRange(int index, JSONArray data) {
        if (data == null || data.size() == 0 || this.cellDataManager.listData == null || index > this.cellDataManager.listData.size()) {
            return;
        }
        if (this.cellDataManager.insertRange(index, data)) {
            notifyUpdateList();
        } else {
            ((BounceRecyclerView) getHostView()).getRecyclerViewBaseAdapter().notifyItemRangeInserted(index, data.size());
        }
    }

    @JSMethod
    public void updateData(int index, Object data) {
        if (data == null || this.cellDataManager.listData == null || index >= this.cellDataManager.listData.size()) {
            return;
        }
        if (this.cellDataManager.updateData(data, index)) {
            ((BounceRecyclerView) getHostView()).getRecyclerViewBaseAdapter().notifyItemChanged(index, data);
        } else {
            notifyUpdateList();
        }
    }

    @JSMethod
    public void removeData(int index, int count) {
        if (this.cellDataManager.listData == null || index >= this.cellDataManager.listData.size()) {
            return;
        }
        if (count <= 0) {
            count = 1;
        }
        int i = 0;
        while (count > 0 && index < this.cellDataManager.listData.size()) {
            this.cellDataManager.removeData(Integer.valueOf(index));
            count--;
            i++;
        }
        if (i > 0) {
            notifyUpdateList();
        }
    }

    @JSMethod
    public void resetLoadmore() {
        this.mForceLoadmoreNextTime = true;
        this.mListCellCount = 0;
    }

    @Override // com.taobao.weex.ui.component.WXComponent
    public void updateProperties(Map<String, Object> props) {
        super.updateProperties(props);
        if (props.containsKey("padding") || props.containsKey(Constants.Name.PADDING_LEFT) || props.containsKey(Constants.Name.PADDING_RIGHT)) {
            if (this.mPaddingLeft == getPadding().get(CSSShorthand.EDGE.LEFT) && this.mPaddingRight == getPadding().get(CSSShorthand.EDGE.RIGHT)) {
                return;
            }
            updateRecyclerAttr();
            ((WXRecyclerView) ((BounceRecyclerView) getHostView()).getInnerView()).initView(getContext(), this.mLayoutType, this.mColumnCount, this.mColumnGap, getOrientation());
        }
    }

    @Override // com.taobao.weex.ui.component.WXComponent
    public void addEvent(String type) {
        super.addEvent(type);
        if (!ScrollStartEndHelper.isScrollEvent(type) || getHostView() == 0 || ((BounceRecyclerView) getHostView()).getInnerView() == null || this.mHasAddScrollEvent) {
            return;
        }
        this.mHasAddScrollEvent = true;
        ((WXRecyclerView) ((BounceRecyclerView) getHostView()).getInnerView()).addOnScrollListener(new RecyclerView.OnScrollListener() { // from class: com.taobao.weex.ui.component.list.template.WXRecyclerTemplateList.7
            private boolean mFirstEvent = true;
            private int offsetXCorrection;
            private int offsetYCorrection;

            @Override // androidx.recyclerview.widget.RecyclerView.OnScrollListener
            public void onScrolled(RecyclerView recyclerView, int dx, int dy) {
                int i;
                int i2;
                super.onScrolled(recyclerView, dx, dy);
                if (recyclerView.getLayoutManager().canScrollVertically()) {
                    int computeHorizontalScrollOffset = recyclerView.computeHorizontalScrollOffset();
                    int computeVerticalScrollOffset = recyclerView.computeVerticalScrollOffset();
                    if (dx == 0 && dy == 0) {
                        this.offsetXCorrection = computeHorizontalScrollOffset;
                        this.offsetYCorrection = computeVerticalScrollOffset;
                        i = 0;
                        i2 = 0;
                    } else {
                        i = computeHorizontalScrollOffset - this.offsetXCorrection;
                        i2 = computeVerticalScrollOffset - this.offsetYCorrection;
                    }
                    WXRecyclerTemplateList.this.getScrollStartEndHelper().onScrolled(i, i2);
                    if (WXRecyclerTemplateList.this.getEvents().contains("scroll")) {
                        if (!this.mFirstEvent) {
                            if (WXRecyclerTemplateList.this.shouldReport(i, i2)) {
                                WXRecyclerTemplateList.this.fireScrollEvent(recyclerView, i, i2);
                                return;
                            }
                            return;
                        }
                        this.mFirstEvent = false;
                    }
                }
            }
        });
    }

    /* JADX INFO: Access modifiers changed from: private */
    public void fireScrollEvent(RecyclerView recyclerView, int offsetX, int offsetY) {
        fireEvent("scroll", getScrollEvent(recyclerView, offsetX, offsetY));
    }

    public Map<String, Object> getScrollEvent(RecyclerView recyclerView, int offsetX, int offsetY) {
        int measuredWidth = recyclerView.getMeasuredWidth() + recyclerView.computeHorizontalScrollRange();
        int calcContentSize = calcContentSize();
        HashMap hashMap = new HashMap(3);
        HashMap hashMap2 = new HashMap(3);
        HashMap hashMap3 = new HashMap(3);
        hashMap2.put("width", Float.valueOf(WXViewUtils.getWebPxByWidth(measuredWidth, getInstance().getInstanceViewPortWidthWithFloat())));
        hashMap2.put("height", Float.valueOf(WXViewUtils.getWebPxByWidth(calcContentSize, getInstance().getInstanceViewPortWidthWithFloat())));
        hashMap3.put(Constants.Name.X, Float.valueOf(-WXViewUtils.getWebPxByWidth(offsetX, getInstance().getInstanceViewPortWidthWithFloat())));
        hashMap3.put(Constants.Name.Y, Float.valueOf(-WXViewUtils.getWebPxByWidth(-calcContentOffset(recyclerView), getInstance().getInstanceViewPortWidthWithFloat())));
        hashMap.put(Constants.Name.CONTENT_SIZE, hashMap2);
        hashMap.put(Constants.Name.CONTENT_OFFSET, hashMap3);
        hashMap.put(Constants.Name.ISDRAGGING, Boolean.valueOf(recyclerView.getScrollState() == 1));
        return hashMap;
    }

    /* JADX INFO: Access modifiers changed from: private */
    public boolean shouldReport(int offsetX, int offsetY) {
        if (this.mLastReport.x == -1 && this.mLastReport.y == -1) {
            this.mLastReport.x = offsetX;
            this.mLastReport.y = offsetY;
            return true;
        }
        int abs = Math.abs(this.mLastReport.x - offsetX);
        int abs2 = Math.abs(this.mLastReport.y - offsetY);
        int i = this.mOffsetAccuracy;
        if (abs >= i || abs2 >= i) {
            this.mLastReport.x = offsetX;
            this.mLastReport.y = offsetY;
            return true;
        }
        return false;
    }

    private boolean setRefreshOrLoading(final WXComponent child) {
        if ((child instanceof WXRefresh) && getHostView() != 0) {
            ((BounceRecyclerView) getHostView()).setOnRefreshListener((WXRefresh) child);
            ((BounceRecyclerView) getHostView()).postDelayed(WXThread.secure(new Runnable() { // from class: com.taobao.weex.ui.component.list.template.WXRecyclerTemplateList.8
                @Override // java.lang.Runnable
                public void run() {
                    ((BounceRecyclerView) WXRecyclerTemplateList.this.getHostView()).setHeaderView(child);
                }
            }), 100L);
            return true;
        } else if (!(child instanceof WXLoading) || getHostView() == 0) {
            return false;
        } else {
            ((BounceRecyclerView) getHostView()).setOnLoadingListener((WXLoading) child);
            ((BounceRecyclerView) getHostView()).postDelayed(WXThread.secure(new Runnable() { // from class: com.taobao.weex.ui.component.list.template.WXRecyclerTemplateList.9
                @Override // java.lang.Runnable
                public void run() {
                    ((BounceRecyclerView) WXRecyclerTemplateList.this.getHostView()).setFooterView(child);
                }
            }), 100L);
            return true;
        }
    }

    private void removeFooterOrHeader(WXComponent child) {
        if (child instanceof WXLoading) {
            ((BounceRecyclerView) getHostView()).removeFooterView(child);
        } else if (child instanceof WXRefresh) {
            ((BounceRecyclerView) getHostView()).removeHeaderView(child);
        }
    }

    @Override // io.dcloud.feature.uniapp.ui.component.AbsVContainer
    public ViewGroup.LayoutParams getChildLayoutParams(WXComponent child, View hostView, int width, int height, int left, int right, int top, int bottom) {
        ViewGroup.MarginLayoutParams marginLayoutParams = (ViewGroup.MarginLayoutParams) hostView.getLayoutParams();
        if ((child instanceof WXBaseRefresh) && marginLayoutParams == null) {
            return new LinearLayout.LayoutParams(width, height);
        }
        if (marginLayoutParams == null) {
            return new RecyclerView.LayoutParams(width, height);
        }
        marginLayoutParams.width = width;
        marginLayoutParams.height = height;
        setMarginsSupportRTL(marginLayoutParams, left, 0, right, 0);
        return marginLayoutParams;
    }

    @Override // io.dcloud.feature.uniapp.ui.component.AbsVContainer, com.taobao.weex.ui.component.WXComponent
    public void destroy() {
        synchronized (this) {
            if (getHostView() != 0) {
                if (this.mAppearChangeRunnable != null) {
                    ((BounceRecyclerView) getHostView()).removeCallbacks(this.mAppearChangeRunnable);
                    this.mAppearChangeRunnable = null;
                }
                ((BounceRecyclerView) getHostView()).removeCallbacks(this.listUpdateRunnable);
                if (((BounceRecyclerView) getHostView()).getInnerView() != null) {
                    ((WXRecyclerView) ((BounceRecyclerView) getHostView()).getInnerView()).setAdapter(null);
                }
            }
            if (this.cellDataManager.listData != null) {
                this.cellDataManager.setListData(null);
            }
            if (this.mStickyHelper != null) {
                this.mStickyHelper = null;
            }
            ArrayMap<String, Integer> arrayMap = this.mTemplateViewTypes;
            if (arrayMap != null) {
                arrayMap.clear();
            }
            Map<String, WXCell> map = this.mTemplateSources;
            if (map != null) {
                map.clear();
            }
            ArrayMap<Integer, List<AppearanceHelper>> arrayMap2 = this.mAppearHelpers;
            if (arrayMap2 != null) {
                arrayMap2.clear();
            }
            ArrayMap<Integer, Map<String, Map<Integer, List<Object>>>> arrayMap3 = this.mDisAppearWatchList;
            if (arrayMap3 != null) {
                arrayMap3.clear();
            }
            super.destroy();
        }
    }

    @Override // com.taobao.weex.ui.view.listview.adapter.IRecyclerAdapterListener
    public void onBindViewHolder(final TemplateViewHolder templateViewHolder, int position) {
        WXCell template;
        if (templateViewHolder == null || (template = templateViewHolder.getTemplate()) == null) {
            return;
        }
        if (templateViewHolder.getHolderPosition() >= 0) {
            fireEvent(TemplateDom.DETACH_CELL_SLOT, TemplateDom.findAllComponentRefs(getRef(), position, template));
        }
        System.currentTimeMillis();
        templateViewHolder.setHolderPosition(position);
        Object obj = this.cellDataManager.listData.get(position);
        CellRenderState renderState = this.cellDataManager.getRenderState(position);
        if (template.getRenderData() == obj && (renderState == null || !renderState.isDirty())) {
            WXEnvironment.isOpenDebugLog();
            fireEvent(TemplateDom.ATTACH_CELL_SLOT, TemplateDom.findAllComponentRefs(getRef(), position, template));
            return;
        }
        Statements.doInitCompontent(doRenderTemplate(template, position));
        template.setRenderData(obj);
        Layouts.doLayoutAsync(templateViewHolder, true);
        WXEnvironment.isOpenDebugLog();
    }

    @Override // com.taobao.weex.ui.view.listview.adapter.IRecyclerAdapterListener
    public TemplateViewHolder onCreateViewHolder(ViewGroup parent, int viewType) {
        String keyAt = this.mTemplateViewTypes.keyAt(viewType);
        WXCell wXCell = this.mTemplateSources.get(keyAt);
        if (wXCell == null) {
            FrameLayout frameLayout = new FrameLayout(getContext());
            frameLayout.setLayoutParams(new FrameLayout.LayoutParams(0, 0));
            return new TemplateViewHolder(this, frameLayout, viewType);
        }
        WXCell cellTemplateFromCache = getCellTemplateFromCache(keyAt);
        if (cellTemplateFromCache == null && !wXCell.isSourceUsed()) {
            wXCell.setSourceUsed(true);
            renderTemplateCellWithData(wXCell);
            WXEnvironment.isOpenDebugLog();
            cellTemplateFromCache = wXCell;
        }
        if (cellTemplateFromCache == null) {
            System.currentTimeMillis();
            cellTemplateFromCache = (WXCell) copyComponentFromSourceCell(wXCell);
            WXEnvironment.isOpenDebugLog();
        }
        if (cellTemplateFromCache.isLazy() || cellTemplateFromCache.getHostView() == 0) {
            doCreateCellViewBindData(cellTemplateFromCache, keyAt, false);
            WXEnvironment.isOpenDebugLog();
        } else {
            WXEnvironment.isOpenDebugLog();
        }
        return new TemplateViewHolder(this, cellTemplateFromCache, viewType);
    }

    @Override // com.taobao.weex.ui.view.listview.adapter.IRecyclerAdapterListener
    public int getItemViewType(int position) {
        int indexOfKey = this.mTemplateViewTypes.indexOfKey(getTemplateKey(position));
        return indexOfKey < 0 ? this.mTemplateViewTypes.indexOfKey("") : indexOfKey;
    }

    private List<WXComponent> doRenderTemplate(WXCell cell, int position) {
        this.cellRenderContext.clear();
        Object obj = this.cellDataManager.listData.get(position);
        CellRenderState renderState = this.cellDataManager.getRenderState(position);
        this.cellRenderContext.renderState = renderState;
        this.cellRenderContext.templateList = this;
        this.cellRenderContext.position = position;
        ArrayStack arrayStack = this.cellRenderContext.stack;
        Map map = this.cellRenderContext.map;
        if (this.cellDataManager.listData != null) {
            arrayStack.push(map);
            map.put(this.listDataKey, this.cellDataManager.listData);
            if (!TextUtils.isEmpty(this.listDataIndexKey)) {
                map.put(this.listDataIndexKey, new PositionRef(renderState));
            }
            if (!TextUtils.isEmpty(this.listDataItemKey)) {
                map.put(this.listDataItemKey, obj);
            } else {
                arrayStack.push(obj);
            }
        }
        if (renderState.itemId <= 0) {
            getItemId(position);
        }
        List<WXComponent> doRender = Statements.doRender(cell, this.cellRenderContext);
        if (renderState.isDirty()) {
            renderState.resetDirty();
        }
        return doRender;
    }

    public ArrayStack copyStack(CellRenderContext context, ArrayStack stack) {
        ArrayStack arrayStack = new ArrayStack();
        for (int i = 0; i < stack.size(); i++) {
            Object obj = stack.get(i);
            if (obj instanceof Map) {
                obj = new HashMap((Map) obj);
            }
            arrayStack.push(obj);
        }
        return arrayStack;
    }

    public String getTemplateKey(int position) {
        return getTemplateKey(safeGetListData(position));
    }

    public String getTemplateKey(Object data) {
        String string = data instanceof JSONObject ? ((JSONObject) data).getString(this.listDataTemplateKey) : null;
        return TextUtils.isEmpty(string) ? this.defaultTemplateCell != null ? this.defaultTemplateKey : "" : string;
    }

    public WXCell getSourceTemplate(int position) {
        return this.mTemplateSources.get(getTemplateKey(position));
    }

    private int getCellTemplateItemType(WXCell cell) {
        if (cell == null) {
            return -1;
        }
        if (cell.getAttrs() != null) {
            String string = WXUtils.getString(cell.getAttrs().get(Constants.Name.Recycler.SLOT_TEMPLATE_CASE), null);
            if (cell == this.defaultTemplateCell) {
                string = this.defaultTemplateKey;
            }
            int indexOfKey = this.mTemplateViewTypes.indexOfKey(string);
            if (indexOfKey < 0) {
                return -1;
            }
            return indexOfKey;
        }
        return 0;
    }

    @Override // com.taobao.weex.ui.view.listview.adapter.IRecyclerAdapterListener
    public int getItemCount() {
        ArrayMap<String, Integer> arrayMap;
        Map<String, WXCell> map;
        if (!this.hasLayoutDone || !this.hasAppendTreeDone || this.cellDataManager.listData == null || (arrayMap = this.mTemplateViewTypes) == null || arrayMap.size() <= 1 || (map = this.mTemplateSources) == null || map.size() == 0) {
            return 0;
        }
        return this.cellDataManager.listData.size();
    }

    @Override // com.taobao.weex.ui.view.listview.adapter.IRecyclerAdapterListener
    public long getItemId(int position) {
        CellRenderState renderState = this.cellDataManager.getRenderState(position);
        if (renderState.itemId <= 0) {
            if (TextUtils.isEmpty(getTemplateKey(position))) {
                return -1L;
            }
            Object safeGetListData = safeGetListData(position);
            if (safeGetListData instanceof JSONObject) {
                JSONObject jSONObject = (JSONObject) safeGetListData;
                if (jSONObject.containsKey("keyItemId")) {
                    renderState.itemId = jSONObject.getLongValue("keyItemId");
                }
            }
            renderState.itemId = (Math.abs(safeGetListData.hashCode()) << 24) + position;
        }
        return renderState.itemId;
    }

    @Override // com.taobao.weex.ui.view.listview.adapter.IOnLoadMoreListener
    public void onBeforeScroll(int dx, int dy) {
        TemplateStickyHelper templateStickyHelper = this.mStickyHelper;
        if (templateStickyHelper != null) {
            templateStickyHelper.onBeforeScroll(dx, dy);
        }
    }

    @Override // com.taobao.weex.ui.view.listview.adapter.IOnLoadMoreListener
    public void onLoadMore(int offScreenY) {
        try {
            String loadMoreOffset = getAttrs().getLoadMoreOffset();
            if (TextUtils.isEmpty(loadMoreOffset)) {
                loadMoreOffset = WXInstanceApm.VALUE_ERROR_CODE_DEFAULT;
            }
            if (offScreenY > WXViewUtils.getRealPxByWidth(Integer.parseInt(loadMoreOffset), getInstance().getInstanceViewPortWidthWithFloat()) || this.cellDataManager.listData == null) {
                return;
            }
            if (this.mListCellCount != this.cellDataManager.listData.size() || this.mForceLoadmoreNextTime) {
                fireEvent(Constants.Event.LOADMORE);
                this.mListCellCount = this.cellDataManager.listData.size();
                this.mForceLoadmoreNextTime = false;
            }
        } catch (Exception e) {
            if (WXEnvironment.isApkDebugable()) {
                WXLogUtils.d("WXRecyclerTemplateList onLoadMore : ", e);
            }
        }
    }

    @Override // com.taobao.weex.ui.view.listview.adapter.IOnLoadMoreListener
    public void notifyAppearStateChange(int firstVisible, int lastVisible, int directionX, int directionY) {
        int i;
        Map<Integer, List<Object>> value;
        List<WXComponent> findChildListByRef;
        ArrayMap<Integer, List<AppearanceHelper>> arrayMap = this.mAppearHelpers;
        if (arrayMap == null || arrayMap.size() <= 0) {
            return;
        }
        if (this.mAppearChangeRunnable != null) {
            ((BounceRecyclerView) getHostView()).removeCallbacks(this.mAppearChangeRunnable);
            this.mAppearChangeRunnable = null;
        }
        String str = directionY > 0 ? "up" : directionY < 0 ? "down" : null;
        if (getOrientation() == 0 && directionX != 0) {
            str = directionX > 0 ? "left" : "right";
        }
        RecyclerView recyclerView = (RecyclerView) ((BounceRecyclerView) getHostView()).getInnerView();
        int i2 = firstVisible;
        while (true) {
            i = 0;
            if (i2 > lastVisible) {
                break;
            }
            List<AppearanceHelper> list = this.mAppearHelpers.get(Integer.valueOf(getItemViewType(i2)));
            if (list != null) {
                for (AppearanceHelper appearanceHelper : list) {
                    if (appearanceHelper.isWatch()) {
                        TemplateViewHolder templateViewHolder = (TemplateViewHolder) recyclerView.findViewHolderForAdapterPosition(i2);
                        if (templateViewHolder != null && templateViewHolder.getComponent() != null && (findChildListByRef = findChildListByRef(templateViewHolder.getComponent(), appearanceHelper.getAwareChild().getRef())) != null && findChildListByRef.size() != 0) {
                            Map<String, Map<Integer, List<Object>>> map = this.mDisAppearWatchList.get(Integer.valueOf(i2));
                            if (map == null) {
                                map = new ArrayMap<>();
                                this.mDisAppearWatchList.put(Integer.valueOf(i2), map);
                            }
                            Map<Integer, List<Object>> map2 = map.get(appearanceHelper.getAwareChild().getRef());
                            if (map2 == null) {
                                map2 = new ArrayMap<>();
                                map.put(appearanceHelper.getAwareChild().getRef(), map2);
                            }
                            for (int i3 = 0; i3 < findChildListByRef.size(); i3++) {
                                WXComponent wXComponent = findChildListByRef.get(i3);
                                if (wXComponent.getHostView() != null) {
                                    boolean isViewVisible = appearanceHelper.isViewVisible(wXComponent.getHostView());
                                    int hashCode = wXComponent.getHostView().hashCode();
                                    if (isViewVisible) {
                                        if (!map2.containsKey(Integer.valueOf(hashCode))) {
                                            wXComponent.notifyAppearStateChange(Constants.Event.APPEAR, str);
                                            map2.put(Integer.valueOf(hashCode), (wXComponent.getEvents() == null || wXComponent.getEvents().getEventBindingArgsValues() == null || wXComponent.getEvents().getEventBindingArgsValues().get(Constants.Event.DISAPPEAR) == null) ? null : wXComponent.getEvents().getEventBindingArgsValues().get(Constants.Event.DISAPPEAR));
                                        }
                                    } else if (map2.containsKey(Integer.valueOf(hashCode))) {
                                        wXComponent.notifyAppearStateChange(Constants.Event.DISAPPEAR, str);
                                        map2.remove(Integer.valueOf(hashCode));
                                    }
                                }
                            }
                        }
                    }
                }
            }
            i2++;
        }
        int itemCount = getItemCount();
        while (i < itemCount) {
            if (i < firstVisible || i > lastVisible) {
                Map<String, Map<Integer, List<Object>>> map3 = this.mDisAppearWatchList.get(Integer.valueOf(i));
                if (map3 != null) {
                    WXCell wXCell = this.mTemplateSources.get(getTemplateKey(i));
                    if (wXCell == null) {
                        return;
                    }
                    for (Map.Entry<String, Map<Integer, List<Object>>> entry : map3.entrySet()) {
                        WXComponent findChildByRef = findChildByRef(wXCell, entry.getKey());
                        if (findChildByRef != null && (value = entry.getValue()) != null && value.size() != 0) {
                            WXEvent events = findChildByRef.getEvents();
                            for (Map.Entry<Integer, List<Object>> entry2 : value.entrySet()) {
                                events.putEventBindingArgsValue(Constants.Event.DISAPPEAR, entry2.getValue());
                                findChildByRef.notifyAppearStateChange(Constants.Event.DISAPPEAR, str);
                            }
                            value.clear();
                        }
                    }
                    this.mDisAppearWatchList.remove(Integer.valueOf(i));
                } else {
                    continue;
                }
            } else {
                i = lastVisible + 1;
            }
            i++;
        }
    }

    private Object safeGetListData(int position) {
        try {
            return this.cellDataManager.listData.get(position);
        } catch (Exception unused) {
            return JSONObject.parseObject("{}");
        }
    }

    public void notifyUpdateList() {
        if (getHostView() == 0 || ((BounceRecyclerView) getHostView()).getInnerView() == null || this.listUpdateRunnable == null) {
            return;
        }
        if (Looper.getMainLooper().getThread().getId() != Thread.currentThread().getId()) {
            ((BounceRecyclerView) getHostView()).removeCallbacks(this.listUpdateRunnable);
            ((BounceRecyclerView) getHostView()).post(this.listUpdateRunnable);
            return;
        }
        this.listUpdateRunnable.run();
    }

    private int calcContentSize() {
        if (this.cellDataManager.listData == null) {
            return 0;
        }
        int i = 0;
        for (int i2 = 0; i2 < this.cellDataManager.listData.size(); i2++) {
            WXCell sourceTemplate = getSourceTemplate(i2);
            if (sourceTemplate != null) {
                i = (int) (i + sourceTemplate.getLayoutHeight());
            }
        }
        return i;
    }

    public int calcContentOffset(RecyclerView recyclerView) {
        RecyclerView.LayoutManager layoutManager = recyclerView.getLayoutManager();
        int i = 0;
        if (layoutManager instanceof LinearLayoutManager) {
            int findFirstVisibleItemPosition = ((LinearLayoutManager) layoutManager).findFirstVisibleItemPosition();
            int i2 = 0;
            while (i < findFirstVisibleItemPosition) {
                WXCell sourceTemplate = getSourceTemplate(i);
                if (sourceTemplate != null) {
                    i2 = (int) (i2 - sourceTemplate.getLayoutHeight());
                }
                i++;
            }
            if (layoutManager instanceof GridLayoutManager) {
                i2 /= ((GridLayoutManager) layoutManager).getSpanCount();
            }
            View findViewByPosition = layoutManager.findViewByPosition(findFirstVisibleItemPosition);
            return findViewByPosition != null ? i2 + findViewByPosition.getTop() : i2;
        } else if (layoutManager instanceof StaggeredGridLayoutManager) {
            StaggeredGridLayoutManager staggeredGridLayoutManager = (StaggeredGridLayoutManager) layoutManager;
            int spanCount = staggeredGridLayoutManager.getSpanCount();
            int i3 = staggeredGridLayoutManager.findFirstVisibleItemPositions(null)[0];
            int i4 = 0;
            while (i < i3) {
                WXCell sourceTemplate2 = getSourceTemplate(i);
                if (sourceTemplate2 != null) {
                    i4 = (int) (i4 - sourceTemplate2.getLayoutHeight());
                }
                i++;
            }
            int i5 = i4 / spanCount;
            View findViewByPosition2 = layoutManager.findViewByPosition(i3);
            return findViewByPosition2 != null ? i5 + findViewByPosition2.getTop() : i5;
        } else {
            return -1;
        }
    }

    public WXComponent findParentType(WXComponent component, Class type) {
        if (type.isAssignableFrom(component.getClass())) {
            return component;
        }
        if (component.getParent() != null) {
            findTypeParent(component.getParent(), type);
            return null;
        }
        return null;
    }

    public WXComponent findChildByRef(WXComponent component, String ref) {
        if (ref.equals(component.getRef())) {
            return component;
        }
        if (component instanceof WXVContainer) {
            WXVContainer wXVContainer = (WXVContainer) component;
            for (int i = 0; i < wXVContainer.getChildCount(); i++) {
                WXComponent findChildByRef = findChildByRef(wXVContainer.getChild(i), ref);
                if (findChildByRef != null) {
                    return findChildByRef;
                }
            }
            return null;
        }
        return null;
    }

    public List<WXComponent> findChildListByRef(WXComponent component, String ref) {
        WXComponent findChildByRef = findChildByRef(component, ref);
        if (findChildByRef == null) {
            return null;
        }
        ArrayList arrayList = new ArrayList();
        WXVContainer parent = findChildByRef.getParent();
        if (parent != null && !(parent instanceof WXRecyclerTemplateList)) {
            for (int i = 0; i < parent.getChildCount(); i++) {
                WXComponent child = parent.getChild(i);
                if (ref.equals(child.getRef())) {
                    arrayList.add(child);
                }
            }
        } else {
            arrayList.add(findChildByRef);
        }
        return arrayList;
    }

    public WXComponent findChildByAttrsRef(WXComponent component, String ref) {
        if (component.getAttrs() == null || !ref.equals(component.getAttrs().get("ref"))) {
            if (component instanceof WXVContainer) {
                WXVContainer wXVContainer = (WXVContainer) component;
                for (int i = 0; i < wXVContainer.getChildCount(); i++) {
                    WXComponent findChildByAttrsRef = findChildByAttrsRef(wXVContainer.getChild(i), ref);
                    if (findChildByAttrsRef != null) {
                        return findChildByAttrsRef;
                    }
                }
                return null;
            }
            return null;
        }
        return component;
    }

    private WXCell getCellTemplateFromCache(final String template) {
        TemplateCache templateCache = this.mTemplatesCache.get(template);
        WXCell poll = (templateCache == null || templateCache.cells == null || templateCache.cells.size() <= 0) ? null : templateCache.cells.poll();
        if (templateCache == null || !templateCache.isLoadIng) {
            if (templateCache == null) {
                templateCache = new TemplateCache();
                this.mTemplatesCache.put(template, templateCache);
            }
            templateCache.isLoadIng = true;
            WXCell wXCell = this.mTemplateSources.get(template);
            if (wXCell != null && WXUtils.getBoolean(wXCell.getAttrs().get("preload"), true).booleanValue()) {
                new AsyncCellLoadTask(template, wXCell, this).startTask();
            }
        }
        return poll;
    }

    public WXComponent copyComponentFromSourceCell(WXCell cell) {
        renderTemplateCellWithData(cell);
        return (WXCell) Statements.copyComponentTree(cell);
    }

    private synchronized void renderTemplateCellWithData(WXCell cell) {
        if (cell.getRenderData() == null && this.cellDataManager.listData != null && this.cellDataManager.listData.size() > 0) {
            synchronized (this) {
                if (cell.getRenderData() == null) {
                    Statements.parseStatementsToken(cell);
                    int i = 0;
                    while (true) {
                        if (i >= this.cellDataManager.listData.size()) {
                            break;
                        } else if (cell == getSourceTemplate(i)) {
                            Object obj = this.cellDataManager.listData.get(i);
                            doRenderTemplate(cell, i);
                            Layouts.doLayoutSync(cell, getLayoutWidth(), getLayoutHeight());
                            cell.setRenderData(obj);
                            break;
                        } else {
                            i++;
                        }
                    }
                }
            }
        }
    }

    public static void doCreateCellViewBindData(WXCell component, String template, boolean inPreload) {
        if (component.isLazy() || component.getHostView() == 0) {
            System.currentTimeMillis();
            Statements.initLazyComponent(component, null);
            WXEnvironment.isOpenDebugLog();
        }
    }

    public ScrollStartEndHelper getScrollStartEndHelper() {
        if (this.mScrollStartEndHelper == null) {
            this.mScrollStartEndHelper = new ScrollStartEndHelper(this);
        }
        return this.mScrollStartEndHelper;
    }

    public int getTemplateCacheSize() {
        return this.templateCacheSize;
    }

    public ConcurrentHashMap<String, TemplateCache> getTemplatesCache() {
        if (this.mTemplatesCache == null) {
            this.mTemplatesCache = new ConcurrentHashMap<>();
        }
        return this.mTemplatesCache;
    }

    public CellDataManager getCellDataManager() {
        return this.cellDataManager;
    }

    private JSONArray parseListDataToJSONArray(Object value) {
        try {
        } catch (Exception e) {
            WXLogUtils.e(TAG, "parseListDataException" + e.getMessage());
        }
        if (value instanceof JSONArray) {
            return (JSONArray) value;
        }
        if (value instanceof String) {
            return JSONArray.parseArray(getAttrs().get(Constants.Name.Recycler.LIST_DATA).toString());
        }
        return new JSONArray();
    }

    @WXComponentProp(name = Constants.Name.SCROLL_TOP)
    public void setScrollTop(String topStr) {
        BounceRecyclerView bounceRecyclerView = (BounceRecyclerView) getHostView();
        if (bounceRecyclerView == null) {
            return;
        }
        ((WXRecyclerView) bounceRecyclerView.getInnerView()).scrollTo(0, (int) WXViewUtils.getRealPxByWidth(WXUtils.getFloat(topStr), getInstance().getInstanceViewPortWidthWithFloat()), getAttrs().getOrientation());
    }

    @WXComponentProp(name = Constants.Name.SCROLL_LEFT)
    public void setScrollLeft(String leftStr) {
        BounceRecyclerView bounceRecyclerView = (BounceRecyclerView) getHostView();
        if (bounceRecyclerView == null) {
            return;
        }
        ((WXRecyclerView) bounceRecyclerView.getInnerView()).scrollTo((int) WXViewUtils.getRealPxByWidth(WXUtils.getFloat(leftStr), getInstance().getInstanceViewPortWidthWithFloat()), 0, getAttrs().getOrientation());
    }

    @Override // io.dcloud.feature.uniapp.ui.component.AbsBasicComponent
    public void setIsLayoutRTL(boolean isRTL) {
        super.setIsLayoutRTL(isRTL);
        this.mViewOnScrollListener.setLayoutRTL(isLayoutRTL());
    }
}
