package com.taobao.weex.ui.component.richtext.span;

import android.graphics.Canvas;
import android.graphics.Paint;
import android.graphics.drawable.Drawable;
import android.text.style.ReplacementSpan;
import android.view.View;
import com.taobao.weex.WXSDKManager;
import com.taobao.weex.adapter.IDrawableLoader;
import com.taobao.weex.ui.component.WXComponent;
/* loaded from: classes23.dex */
public class ImgSpan extends ReplacementSpan implements IDrawableLoader.StaticTarget {
    private int height;
    private String instanceId;
    private Drawable mDrawable;
    private View mView;
    private String ref;
    private int width;

    public ImgSpan(int width, int height, String instanceId, String ref) {
        this.width = width;
        this.height = height;
        this.instanceId = instanceId;
        this.ref = ref;
    }

    @Override // android.text.style.ReplacementSpan
    public int getSize(Paint paint, CharSequence text, int start, int end, Paint.FontMetricsInt fm) {
        WXComponent wXComponent;
        if (this.mView == null && (wXComponent = WXSDKManager.getInstance().getWXRenderManager().getWXComponent(this.instanceId, this.ref)) != null && wXComponent.getHostView() != null && this.width > wXComponent.getHostView().getWidth() && wXComponent.getHostView().getWidth() > 0) {
            int width = wXComponent.getHostView().getWidth();
            int i = (this.height * width) / this.width;
            this.height = i;
            this.width = width;
            Drawable drawable = this.mDrawable;
            if (drawable != null) {
                drawable.setBounds(0, 0, width, i);
            }
        }
        if (fm != null) {
            fm.ascent = -this.height;
            fm.descent = 0;
            fm.top = fm.ascent;
            fm.bottom = 0;
        }
        return this.width;
    }

    @Override // android.text.style.ReplacementSpan
    public void draw(Canvas canvas, CharSequence text, int start, int end, float x, int top, int y, int bottom, Paint paint) {
        if (this.mDrawable != null) {
            canvas.save();
            canvas.translate(x, (bottom - this.mDrawable.getBounds().bottom) - paint.getFontMetricsInt().descent);
            this.mDrawable.draw(canvas);
            canvas.restore();
        }
    }

    @Override // com.taobao.weex.adapter.IDrawableLoader.StaticTarget, com.taobao.weex.adapter.IDrawableLoader.DrawableTarget
    public void setDrawable(Drawable drawable, boolean resetBounds) {
        this.mDrawable = drawable;
        if (resetBounds) {
            drawable.setBounds(0, 0, this.width, this.height);
        }
        setCallback();
        this.mDrawable.invalidateSelf();
    }

    public void setView(View view) {
        this.mView = view;
        setCallback();
    }

    private void setCallback() {
        View view;
        Drawable drawable = this.mDrawable;
        if (drawable == null || (view = this.mView) == null) {
            return;
        }
        drawable.setCallback(view);
    }
}
