package com.taobao.weex.ui.flat;

import android.text.TextUtils;
import android.view.View;
import androidx.collection.ArrayMap;
import com.taobao.weex.common.Constants;
import com.taobao.weex.common.Destroyable;
import com.taobao.weex.dom.WXAttr;
import com.taobao.weex.dom.WXStyle;
import com.taobao.weex.ui.component.WXComponent;
import com.taobao.weex.ui.flat.widget.AndroidViewWidget;
import com.taobao.weex.ui.flat.widget.Widget;
import java.util.Map;
/* loaded from: classes18.dex */
public class FlatGUIContext implements Destroyable {
    private Map<WXComponent, WidgetContainer> mWidgetRegistry = new ArrayMap();
    private Map<WXComponent, AndroidViewWidget> mViewWidgetRegistry = new ArrayMap();
    private Map<Widget, WXComponent> widgetToComponent = new ArrayMap();

    public boolean isFlatUIEnabled(WXComponent component) {
        return false;
    }

    public void register(WXComponent descendant, WidgetContainer ancestor) {
        if (!(ancestor instanceof FlatComponent) || ((FlatComponent) ancestor).promoteToView(true)) {
            this.mWidgetRegistry.put(descendant, ancestor);
        }
    }

    public void register(WXComponent component, AndroidViewWidget viewWidget) {
        this.mViewWidgetRegistry.put(component, viewWidget);
    }

    public void register(Widget widget, WXComponent component) {
        this.widgetToComponent.put(widget, component);
    }

    public WidgetContainer getFlatComponentAncestor(WXComponent flatWidget) {
        return this.mWidgetRegistry.get(flatWidget);
    }

    public AndroidViewWidget getAndroidViewWidget(WXComponent component) {
        return this.mViewWidgetRegistry.get(component);
    }

    public boolean promoteToView(WXComponent component, boolean checkAncestor, Class<? extends WXComponent<?>> expectedClass) {
        return !isFlatUIEnabled(component) || !expectedClass.equals(component.getClass()) || TextUtils.equals(component.getRef(), WXComponent.ROOT) || (checkAncestor && getFlatComponentAncestor(component) == null) || checkComponent(component);
    }

    /* JADX WARN: Type inference failed for: r1v4, types: [android.view.View] */
    public View getWidgetContainerView(Widget widget) {
        WidgetContainer flatComponentAncestor;
        WXComponent component = getComponent(widget);
        if (component == null || (flatComponentAncestor = getFlatComponentAncestor(component)) == null) {
            return null;
        }
        return flatComponentAncestor.getHostView();
    }

    @Override // com.taobao.weex.common.Destroyable
    public void destroy() {
        this.widgetToComponent.clear();
        for (Map.Entry<WXComponent, AndroidViewWidget> entry : this.mViewWidgetRegistry.entrySet()) {
            entry.getValue().destroy();
        }
        this.mViewWidgetRegistry.clear();
        for (Map.Entry<WXComponent, WidgetContainer> entry2 : this.mWidgetRegistry.entrySet()) {
            entry2.getValue().unmountFlatGUI();
        }
        this.mWidgetRegistry.clear();
    }

    private WXComponent getComponent(Widget widget) {
        return this.widgetToComponent.get(widget);
    }

    private boolean checkComponent(WXComponent component) {
        if (component != null) {
            WXStyle styles = component.getStyles();
            WXAttr attrs = component.getAttrs();
            if (styles.containsKey("opacity") || styles.containsKey("transform") || styles.containsKey(Constants.Name.VISIBILITY) || attrs.containsKey(Constants.Name.ELEVATION) || attrs.containsKey(Constants.Name.ARIA_HIDDEN) || attrs.containsKey(Constants.Name.ARIA_LABEL) || attrs.containsKey(WXComponent.PROP_FIXED_SIZE) || attrs.containsKey(Constants.Name.DISABLED) || styles.isFixed() || styles.isSticky() || !styles.getPesudoStyles().isEmpty() || component.getEvents().size() > 0) {
                return true;
            }
        }
        return false;
    }
}
