package com.taobao.weex.ui.view.border;

import android.graphics.Canvas;
import android.graphics.Paint;
import android.graphics.RectF;
import android.os.Build;
import com.taobao.weex.base.FloatUtil;
/* loaded from: classes8.dex */
abstract class BorderCorner {
    static final float SWEEP_ANGLE = 45.0f;
    protected float mAngleBisector;
    private RectF mBorderBox;
    private float mOvalBottom;
    private float mOvalLeft;
    private float mOvalRight;
    private float mOvalTop;
    private float mRoundCornerEndX;
    private float mRoundCornerEndY;
    private float mRoundCornerStartX;
    private float mRoundCornerStartY;
    private float mCornerRadius = 0.0f;
    private float mPreBorderWidth = 0.0f;
    private float mPostBorderWidth = 0.0f;
    private boolean hasInnerCorner = false;
    private boolean hasOuterCorner = false;

    protected abstract void prepareOval();

    protected abstract void prepareRoundCorner();

    /* JADX INFO: Access modifiers changed from: package-private */
    public final void set(float cornerRadius, float preBorderWidth, float postBorderWidth, RectF borderBox, float angleBisector) {
        RectF rectF;
        boolean z = false;
        if ((FloatUtil.floatsEqual(this.mCornerRadius, cornerRadius) && FloatUtil.floatsEqual(this.mPreBorderWidth, preBorderWidth) && FloatUtil.floatsEqual(this.mPostBorderWidth, postBorderWidth) && FloatUtil.floatsEqual(this.mAngleBisector, angleBisector) && ((rectF = this.mBorderBox) == null || !rectF.equals(borderBox))) ? false : true) {
            this.mCornerRadius = cornerRadius;
            this.mPreBorderWidth = preBorderWidth;
            this.mPostBorderWidth = postBorderWidth;
            this.mBorderBox = borderBox;
            this.mAngleBisector = angleBisector;
            boolean z2 = cornerRadius > 0.0f && !FloatUtil.floatsEqual(0.0f, cornerRadius);
            this.hasOuterCorner = z2;
            if (z2 && getPreBorderWidth() >= 0.0f && getPostBorderWidth() >= 0.0f && getOuterCornerRadius() > getPreBorderWidth() && getOuterCornerRadius() > getPostBorderWidth()) {
                z = true;
            }
            this.hasInnerCorner = z;
            if (this.hasOuterCorner) {
                prepareOval();
            }
            prepareRoundCorner();
        }
    }

    public final void drawRoundedCorner(Canvas canvas, Paint paint, float startAngle) {
        if (hasOuterCorner()) {
            Paint paint2 = new Paint(paint);
            float abs = Math.abs(this.mOvalLeft - this.mOvalRight);
            if (paint.getStrokeWidth() > abs) {
                paint2.setStrokeWidth(abs);
            }
            paint2.setStrokeCap(Paint.Cap.ROUND);
            if (Build.VERSION.SDK_INT >= 21) {
                canvas.drawArc(this.mOvalLeft, this.mOvalTop, this.mOvalRight, this.mOvalBottom, startAngle, SWEEP_ANGLE, false, paint2);
            } else {
                canvas.drawArc(new RectF(this.mOvalLeft, this.mOvalTop, this.mOvalRight, this.mOvalBottom), startAngle, SWEEP_ANGLE, false, paint2);
            }
        } else if (getRoundCornerStartX() == getRoundCornerEndX() && getRoundCornerStartY() == getRoundCornerEndY()) {
        } else {
            canvas.drawLine(getRoundCornerStartX(), getRoundCornerStartY(), getRoundCornerEndX(), getRoundCornerEndY(), paint);
        }
    }

    public final float getRoundCornerStartX() {
        return this.mRoundCornerStartX;
    }

    /* JADX INFO: Access modifiers changed from: package-private */
    public final void setRoundCornerStartX(float roundCornerStartX) {
        this.mRoundCornerStartX = roundCornerStartX;
    }

    public final float getRoundCornerStartY() {
        return this.mRoundCornerStartY;
    }

    /* JADX INFO: Access modifiers changed from: package-private */
    public final void setRoundCornerStartY(float roundCornerStartY) {
        this.mRoundCornerStartY = roundCornerStartY;
    }

    public final float getRoundCornerEndX() {
        return this.mRoundCornerEndX;
    }

    /* JADX INFO: Access modifiers changed from: package-private */
    public final void setRoundCornerEndX(float mRoundCornerEndX) {
        this.mRoundCornerEndX = mRoundCornerEndX;
    }

    public final float getRoundCornerEndY() {
        return this.mRoundCornerEndY;
    }

    /* JADX INFO: Access modifiers changed from: package-private */
    public final void setRoundCornerEndY(float mRoundCornerEndY) {
        this.mRoundCornerEndY = mRoundCornerEndY;
    }

    /* JADX INFO: Access modifiers changed from: package-private */
    public final void setOvalLeft(float mOvalLeft) {
        this.mOvalLeft = mOvalLeft;
    }

    /* JADX INFO: Access modifiers changed from: package-private */
    public final void setOvalTop(float mOvalTop) {
        this.mOvalTop = mOvalTop;
    }

    /* JADX INFO: Access modifiers changed from: package-private */
    public final void setOvalRight(float mOvalRight) {
        this.mOvalRight = mOvalRight;
    }

    /* JADX INFO: Access modifiers changed from: package-private */
    public final void setOvalBottom(float mOvalBottom) {
        this.mOvalBottom = mOvalBottom;
    }

    /* JADX INFO: Access modifiers changed from: package-private */
    public boolean hasInnerCorner() {
        return this.hasInnerCorner;
    }

    /* JADX INFO: Access modifiers changed from: package-private */
    public boolean hasOuterCorner() {
        return this.hasOuterCorner;
    }

    /* JADX INFO: Access modifiers changed from: protected */
    public final float getPreBorderWidth() {
        return this.mPreBorderWidth;
    }

    /* JADX INFO: Access modifiers changed from: protected */
    public final float getPostBorderWidth() {
        return this.mPostBorderWidth;
    }

    /* JADX INFO: Access modifiers changed from: protected */
    public final float getOuterCornerRadius() {
        return this.mCornerRadius;
    }

    /* JADX INFO: Access modifiers changed from: protected */
    public final float getAngleBisectorDegree() {
        return this.mAngleBisector;
    }

    /* JADX INFO: Access modifiers changed from: protected */
    public final RectF getBorderBox() {
        return this.mBorderBox;
    }
}
