package com.taobao.weex.ui.view.listview;

import android.content.Context;
import android.graphics.Rect;
import android.util.AttributeSet;
import android.view.MotionEvent;
import android.view.View;
import androidx.recyclerview.widget.GridLayoutManager;
import androidx.recyclerview.widget.LinearLayoutManager;
import androidx.recyclerview.widget.RecyclerView;
import androidx.recyclerview.widget.StaggeredGridLayoutManager;
import com.alibaba.fastjson.JSONObject;
import com.taobao.weex.WXSDKManager;
import com.taobao.weex.common.WXThread;
import com.taobao.weex.ui.component.WXComponent;
import com.taobao.weex.ui.component.WXVContainer;
import com.taobao.weex.ui.component.list.WXListComponent;
import com.taobao.weex.ui.view.gesture.WXGesture;
import com.taobao.weex.ui.view.gesture.WXGestureObservable;
import com.taobao.weex.ui.view.listview.ExtendedLinearLayoutManager;
import com.taobao.weex.ui.view.refresh.wrapper.BounceRecyclerView;
import io.dcloud.common.ui.blur.AppEventForBlurManager;
import io.dcloud.feature.weex.extend.DCWXSlider;
import io.dcloud.weex.FlingHelper;
/* loaded from: classes26.dex */
public class WXRecyclerView extends RecyclerView implements WXGestureObservable {
    public static final int TYPE_GRID_LAYOUT = 2;
    public static final int TYPE_LINEAR_LAYOUT = 1;
    public static final int TYPE_STAGGERED_GRID_LAYOUT = 3;
    private JSONObject NestInfo;
    private boolean hasTouch;
    private float headerHeight;
    public boolean isNestParent;
    boolean isStartFling;
    private Float lastY;
    RecyclerView.OnScrollListener mChildScrollListener;
    private int mCurrentDy;
    private FlingHelper mFlingHelper;
    private WXGesture mGesture;
    private String mInstanceId;
    RecyclerView.OnScrollListener mParentScrollListener;
    private boolean scrollable;
    private int totalDy;
    private int velocityY;

    static /* synthetic */ int access$212(WXRecyclerView wXRecyclerView, int i) {
        int i2 = wXRecyclerView.totalDy + i;
        wXRecyclerView.totalDy = i2;
        return i2;
    }

    public void setNestInfo(JSONObject nestInfo) {
        this.NestInfo = nestInfo;
        if (nestInfo != null) {
            this.isNestParent = nestInfo.getBooleanValue("isNestParent");
            this.mInstanceId = nestInfo.getString("instanceId");
            if (this.mFlingHelper == null) {
                this.mFlingHelper = new FlingHelper(getContext());
            }
            if (this.isNestParent) {
                setDescendantFocusability(131072);
                if (this.mParentScrollListener == null) {
                    this.headerHeight = nestInfo.getFloat("headerHeight").floatValue();
                    RecyclerView.OnScrollListener onScrollListener = new RecyclerView.OnScrollListener() { // from class: com.taobao.weex.ui.view.listview.WXRecyclerView.1
                        @Override // androidx.recyclerview.widget.RecyclerView.OnScrollListener
                        public void onScrollStateChanged(RecyclerView recyclerView, int newState) {
                            super.onScrollStateChanged(recyclerView, newState);
                            if (newState == 0) {
                                WXRecyclerView.this.mCurrentDy = 0;
                                WXRecyclerView.this.dispatchChildFling();
                            }
                        }

                        @Override // androidx.recyclerview.widget.RecyclerView.OnScrollListener
                        public void onScrolled(RecyclerView recyclerView, int dx, int dy) {
                            super.onScrolled(recyclerView, dx, dy);
                            WXRecyclerView.this.mCurrentDy = dy;
                            if (WXRecyclerView.this.isStartFling) {
                                WXRecyclerView.this.totalDy = 0;
                                WXRecyclerView.this.isStartFling = false;
                            }
                            WXRecyclerView.access$212(WXRecyclerView.this, dy);
                        }
                    };
                    this.mParentScrollListener = onScrollListener;
                    addOnScrollListener(onScrollListener);
                }
            } else if (this.mChildScrollListener == null) {
                RecyclerView.OnScrollListener onScrollListener2 = new RecyclerView.OnScrollListener() { // from class: com.taobao.weex.ui.view.listview.WXRecyclerView.2
                    @Override // androidx.recyclerview.widget.RecyclerView.OnScrollListener
                    public void onScrollStateChanged(RecyclerView recyclerView, int newState) {
                        if (newState == 0) {
                            WXRecyclerView.this.mCurrentDy = 0;
                            WXRecyclerView.this.dispatchParentFling();
                        }
                        super.onScrollStateChanged(recyclerView, newState);
                    }

                    @Override // androidx.recyclerview.widget.RecyclerView.OnScrollListener
                    public void onScrolled(RecyclerView recyclerView, int dx, int dy) {
                        super.onScrolled(recyclerView, dx, dy);
                        WXRecyclerView.this.mCurrentDy = dy;
                        if (WXRecyclerView.this.isStartFling) {
                            WXRecyclerView.this.totalDy = 0;
                            WXRecyclerView.this.isStartFling = false;
                        }
                        WXRecyclerView.access$212(WXRecyclerView.this, dy);
                    }
                };
                this.mChildScrollListener = onScrollListener2;
                addOnScrollListener(onScrollListener2);
            }
        }
    }

    public int getCurrentDy() {
        return this.mCurrentDy;
    }

    public void callBackNestParent(String ref, String instanceId, float headerHeight) {
        WXRecyclerView parentRecyclerView = getParentRecyclerView();
        if (parentRecyclerView != null) {
            JSONObject jSONObject = new JSONObject();
            jSONObject.put("isNestParent", (Object) true);
            jSONObject.put("instanceId", (Object) instanceId);
            jSONObject.put("nestChildRef", (Object) ref);
            jSONObject.put("headerHeight", (Object) Float.valueOf(headerHeight));
            parentRecyclerView.setNestInfo(jSONObject);
        }
    }

    public WXRecyclerView(Context context) {
        super(context);
        this.scrollable = true;
        this.hasTouch = false;
        this.NestInfo = null;
        this.isNestParent = false;
        this.mCurrentDy = 0;
        this.lastY = Float.valueOf(0.0f);
        this.totalDy = 0;
        this.velocityY = 0;
        this.headerHeight = 0.0f;
        this.isStartFling = false;
    }

    public WXRecyclerView(Context context, AttributeSet attrs) {
        super(context, attrs);
        this.scrollable = true;
        this.hasTouch = false;
        this.NestInfo = null;
        this.isNestParent = false;
        this.mCurrentDy = 0;
        this.lastY = Float.valueOf(0.0f);
        this.totalDy = 0;
        this.velocityY = 0;
        this.headerHeight = 0.0f;
        this.isStartFling = false;
    }

    public boolean isScrollable() {
        return this.scrollable;
    }

    public void setScrollable(boolean scrollable) {
        this.scrollable = scrollable;
    }

    public void initView(Context context, int type, int orientation) {
        initView(context, type, 1, 32.0f, orientation);
    }

    public void initView(Context context, int type, int columnCount, float columnGap, final int orientation) {
        if (type == 2) {
            setLayoutManager(new GridLayoutManager(context, columnCount, orientation, false) { // from class: com.taobao.weex.ui.view.listview.WXRecyclerView.3
                @Override // androidx.recyclerview.widget.LinearLayoutManager, androidx.recyclerview.widget.RecyclerView.LayoutManager
                public boolean canScrollVertically() {
                    try {
                        return WXRecyclerView.this.canParentScrollVertically(orientation, super.canScrollVertically());
                    } catch (Exception unused) {
                        return true;
                    }
                }

                @Override // androidx.recyclerview.widget.GridLayoutManager, androidx.recyclerview.widget.LinearLayoutManager, androidx.recyclerview.widget.RecyclerView.LayoutManager
                public void onLayoutChildren(RecyclerView.Recycler recycler, RecyclerView.State state) {
                    try {
                        super.onLayoutChildren(recycler, state);
                    } catch (Exception e) {
                        e.printStackTrace();
                    }
                }
            });
        } else if (type == 3) {
            setLayoutManager(new ExtendedStaggeredGridLayoutManager(columnCount, orientation) { // from class: com.taobao.weex.ui.view.listview.WXRecyclerView.4
                @Override // androidx.recyclerview.widget.StaggeredGridLayoutManager, androidx.recyclerview.widget.RecyclerView.LayoutManager
                public boolean canScrollVertically() {
                    try {
                        return WXRecyclerView.this.canParentScrollVertically(orientation, super.canScrollVertically());
                    } catch (Exception unused) {
                        return true;
                    }
                }

                @Override // androidx.recyclerview.widget.StaggeredGridLayoutManager, androidx.recyclerview.widget.RecyclerView.LayoutManager
                public void onLayoutChildren(RecyclerView.Recycler recycler, RecyclerView.State state) {
                    try {
                        super.onLayoutChildren(recycler, state);
                    } catch (Exception e) {
                        e.printStackTrace();
                    }
                }
            });
        } else if (type == 1) {
            setLayoutManager(new LinearLayoutManager(context, orientation, false) { // from class: com.taobao.weex.ui.view.listview.WXRecyclerView.5
                @Override // androidx.recyclerview.widget.LinearLayoutManager, androidx.recyclerview.widget.RecyclerView.LayoutManager
                public boolean canScrollVertically() {
                    try {
                        return WXRecyclerView.this.canParentScrollVertically(orientation, super.canScrollVertically());
                    } catch (Exception unused) {
                        return true;
                    }
                }

                @Override // androidx.recyclerview.widget.LinearLayoutManager, androidx.recyclerview.widget.RecyclerView.LayoutManager
                public void onLayoutChildren(RecyclerView.Recycler recycler, RecyclerView.State state) {
                    try {
                        super.onLayoutChildren(recycler, state);
                    } catch (Exception e) {
                        e.printStackTrace();
                    }
                }
            });
        }
    }

    /* JADX INFO: Access modifiers changed from: private */
    public boolean canParentScrollVertically(int orientation, boolean defV) {
        if (orientation == 1 && orientation == 1) {
            try {
                if (this.NestInfo != null && this.isNestParent) {
                    WXRecyclerView childRecylerView = getChildRecylerView();
                    if (childRecylerView == null) {
                        return true;
                    }
                    Rect rect = new Rect();
                    childRecylerView.getLocalVisibleRect(rect);
                    if (childRecylerView.getHeight() - rect.bottom == 0) {
                        if (!childRecylerView.isScrollTop()) {
                            return false;
                        }
                    }
                    return true;
                }
            } catch (Exception e) {
                e.printStackTrace();
            }
        }
        return defV;
    }

    @Override // com.taobao.weex.ui.view.gesture.WXGestureObservable
    public void registerGestureListener(WXGesture wxGesture) {
        this.mGesture = wxGesture;
    }

    @Override // com.taobao.weex.ui.view.gesture.WXGestureObservable
    public WXGesture getGestureListener() {
        return this.mGesture;
    }

    @Override // androidx.recyclerview.widget.RecyclerView, android.view.View
    public boolean onTouchEvent(MotionEvent event) {
        View view;
        WXRecyclerView childRecylerView;
        int floatValue;
        if (this.scrollable) {
            if (this.NestInfo != null && this.isNestParent) {
                if (this.lastY.floatValue() == 0.0f) {
                    this.lastY = Float.valueOf(event.getY());
                }
                if (isScrollEnd() && (childRecylerView = getChildRecylerView()) != null && (floatValue = (int) (this.lastY.floatValue() - event.getY())) != 0) {
                    childRecylerView.scrollBy(0, floatValue);
                }
                this.lastY = Float.valueOf(event.getY());
            }
            if (event.getAction() == 1 && (view = (View) getParent().getParent()) != null && view.hasOnClickListeners() && (view instanceof BounceRecyclerView) && pointInView(event.getX(), event.getY(), 0.0f) && getScrollState() == 0) {
                view.performClick();
            }
            return super.onTouchEvent(event);
        }
        return true;
    }

    @Override // android.view.ViewGroup, android.view.View
    public boolean dispatchTouchEvent(MotionEvent event) {
        this.hasTouch = true;
        if (this.NestInfo != null) {
            if (this.isNestParent) {
                if (event != null && event.getAction() == 0) {
                    this.velocityY = 0;
                    stopScroll();
                }
                if (event != null && event.getAction() != 2) {
                    this.lastY = Float.valueOf(0.0f);
                }
            } else if (event != null && event.getAction() == 0) {
                this.velocityY = 0;
            }
        }
        boolean dispatchTouchEvent = super.dispatchTouchEvent(event);
        WXGesture wXGesture = this.mGesture;
        return wXGesture != null ? dispatchTouchEvent | wXGesture.onTouch(this, event) : dispatchTouchEvent;
    }

    @Override // androidx.recyclerview.widget.RecyclerView, android.view.ViewGroup
    public boolean onInterceptTouchEvent(MotionEvent e) {
        return super.onInterceptTouchEvent(e);
    }

    public void scrollTo(boolean smooth, int position, final int offset, final int orientation) {
        try {
            RecyclerView.LayoutManager layoutManager = getLayoutManager();
            stopScroll();
            if (!smooth) {
                if (layoutManager instanceof LinearLayoutManager) {
                    ((LinearLayoutManager) layoutManager).scrollToPositionWithOffset(position, -offset);
                    return;
                } else if (layoutManager instanceof StaggeredGridLayoutManager) {
                    ((StaggeredGridLayoutManager) layoutManager).scrollToPositionWithOffset(position, -offset);
                    return;
                } else {
                    return;
                }
            }
            if (orientation == 1) {
                if (layoutManager instanceof LinearLayoutManager) {
                    int findFirstVisibleItemPosition = ((LinearLayoutManager) layoutManager).findFirstVisibleItemPosition();
                    int findLastVisibleItemPosition = ((LinearLayoutManager) layoutManager).findLastVisibleItemPosition();
                    if (position >= findFirstVisibleItemPosition && position <= findLastVisibleItemPosition) {
                        smoothScrollBy(0, getChildAt(position - findFirstVisibleItemPosition).getTop() + offset);
                        return;
                    }
                } else if (layoutManager instanceof StaggeredGridLayoutManager) {
                    int[] findFirstVisibleItemPositions = ((StaggeredGridLayoutManager) layoutManager).findFirstVisibleItemPositions(null);
                    int[] findLastCompletelyVisibleItemPositions = ((StaggeredGridLayoutManager) layoutManager).findLastCompletelyVisibleItemPositions(null);
                    if (position >= findFirstVisibleItemPositions[0] && position <= findLastCompletelyVisibleItemPositions[0]) {
                        smoothScrollBy(0, getChildAt(position - findFirstVisibleItemPositions[0]).getTop() + offset);
                        return;
                    }
                }
            }
            smoothScrollToPosition(position);
            if (offset != 0) {
                setOnSmoothScrollEndListener(new ExtendedLinearLayoutManager.OnSmoothScrollEndListener() { // from class: com.taobao.weex.ui.view.listview.WXRecyclerView.6
                    @Override // com.taobao.weex.ui.view.listview.ExtendedLinearLayoutManager.OnSmoothScrollEndListener
                    public void onStop() {
                        WXRecyclerView.this.post(WXThread.secure(new Runnable() { // from class: com.taobao.weex.ui.view.listview.WXRecyclerView.6.1
                            @Override // java.lang.Runnable
                            public void run() {
                                if (orientation == 1) {
                                    WXRecyclerView.this.smoothScrollBy(0, offset);
                                } else {
                                    WXRecyclerView.this.smoothScrollBy(offset, 0);
                                }
                            }
                        }));
                    }
                });
            }
        } catch (Exception unused) {
        }
    }

    public void scrollTo(final int x, final int y, final int orientation) {
        postDelayed(WXThread.secure(new Runnable() { // from class: com.taobao.weex.ui.view.listview.WXRecyclerView.7
            @Override // java.lang.Runnable
            public void run() {
                int i;
                RecyclerView.LayoutManager layoutManager = WXRecyclerView.this.getLayoutManager();
                if (orientation == 1) {
                    i = y;
                } else {
                    i = x;
                }
                if (layoutManager instanceof LinearLayoutManager) {
                    ((LinearLayoutManager) layoutManager).scrollToPositionWithOffset(0, -i);
                } else if (layoutManager instanceof StaggeredGridLayoutManager) {
                    ((StaggeredGridLayoutManager) layoutManager).scrollToPositionWithOffset(0, -i);
                }
            }
        }), 100L);
    }

    public void setOnSmoothScrollEndListener(final ExtendedLinearLayoutManager.OnSmoothScrollEndListener onSmoothScrollEndListener) {
        addOnScrollListener(new RecyclerView.OnScrollListener() { // from class: com.taobao.weex.ui.view.listview.WXRecyclerView.8
            @Override // androidx.recyclerview.widget.RecyclerView.OnScrollListener
            public void onScrollStateChanged(RecyclerView recyclerView, int newState) {
                if (newState == 0) {
                    recyclerView.removeOnScrollListener(this);
                    ExtendedLinearLayoutManager.OnSmoothScrollEndListener onSmoothScrollEndListener2 = onSmoothScrollEndListener;
                    if (onSmoothScrollEndListener2 != null) {
                        onSmoothScrollEndListener2.onStop();
                    }
                }
            }
        });
    }

    private WXRecyclerView getParentRecyclerView() {
        WXListComponent listComponent;
        JSONObject jSONObject = this.NestInfo;
        if (jSONObject == null || this.isNestParent) {
            return null;
        }
        WXComponent wXComponentById = WXSDKManager.getInstance().getWXRenderManager().getWXComponentById(this.mInstanceId, jSONObject.getString("listParentId"));
        if (wXComponentById == null || (listComponent = getListComponent(wXComponentById)) == null || listComponent.getHostView() == 0) {
            return null;
        }
        return (WXRecyclerView) ((BounceRecyclerView) listComponent.getHostView()).getInnerView();
    }

    private WXRecyclerView getChildRecylerView() {
        WXComponent wXComponent;
        WXListComponent listComponent;
        JSONObject jSONObject = this.NestInfo;
        if (jSONObject == null || !this.isNestParent) {
            return null;
        }
        if (jSONObject.getBooleanValue("isSwipelist")) {
            wXComponent = WXSDKManager.getInstance().getWXRenderManager().getWXComponentById(this.mInstanceId, this.NestInfo.getString("swipeId"));
            if (wXComponent != null && (wXComponent = getDCWXSliderComponent(wXComponent)) != null && (wXComponent instanceof DCWXSlider)) {
                DCWXSlider dCWXSlider = (DCWXSlider) wXComponent;
                wXComponent = dCWXSlider.getChild(dCWXSlider.getCurrentIndex());
            }
        } else {
            wXComponent = WXSDKManager.getInstance().getWXRenderManager().getWXComponent(this.mInstanceId, this.NestInfo.getString("nestChildRef"));
        }
        if (wXComponent == null || (listComponent = getListComponent(wXComponent)) == null || listComponent.getHostView() == 0) {
            return null;
        }
        return (WXRecyclerView) ((BounceRecyclerView) listComponent.getHostView()).getInnerView();
    }

    public WXListComponent getListComponent(WXComponent component) {
        if (component instanceof WXListComponent) {
            return (WXListComponent) component;
        }
        if (component instanceof WXVContainer) {
            WXVContainer wXVContainer = (WXVContainer) component;
            if (wXVContainer.getChildCount() > 0) {
                for (int i = 0; i < wXVContainer.getChildCount(); i++) {
                    WXListComponent listComponent = getListComponent(wXVContainer.getChild(i));
                    if (listComponent != null) {
                        return listComponent;
                    }
                }
                return null;
            }
            return null;
        }
        return null;
    }

    public DCWXSlider getDCWXSliderComponent(WXComponent component) {
        if (component instanceof DCWXSlider) {
            return (DCWXSlider) component;
        }
        if (component instanceof WXVContainer) {
            WXVContainer wXVContainer = (WXVContainer) component;
            if (wXVContainer.getChildCount() > 0) {
                for (int i = 0; i < wXVContainer.getChildCount(); i++) {
                    DCWXSlider dCWXSliderComponent = getDCWXSliderComponent(wXVContainer.getChild(i));
                    if (dCWXSliderComponent != null) {
                        return dCWXSliderComponent;
                    }
                }
                return null;
            }
            return null;
        }
        return null;
    }

    @Override // androidx.recyclerview.widget.RecyclerView
    public boolean fling(int velX, int velY) {
        if (isAttachedToWindow()) {
            boolean fling = super.fling(velX, velY);
            if (this.NestInfo != null) {
                if (this.isNestParent) {
                    if (!fling || velY <= 0) {
                        this.velocityY = 0;
                    } else {
                        this.isStartFling = true;
                        this.velocityY = velY;
                    }
                } else if (!fling || velY >= 0) {
                    this.velocityY = 0;
                } else {
                    this.isStartFling = true;
                    this.velocityY = velY;
                }
            }
            return fling;
        }
        return false;
    }

    public boolean isNestScroll() {
        return this.NestInfo != null;
    }

    public boolean isScrollTop() {
        return !canScrollVertically(-1);
    }

    private boolean isScrollEnd() {
        return true ^ canScrollVertically(1);
    }

    /* JADX INFO: Access modifiers changed from: private */
    public void dispatchChildFling() {
        int i;
        if (isScrollEnd() && (i = this.velocityY) != 0) {
            double splineFlingDistance = this.mFlingHelper.getSplineFlingDistance(i);
            int i2 = this.totalDy;
            if (splineFlingDistance > i2) {
                FlingHelper flingHelper = this.mFlingHelper;
                double d = i2;
                Double.isNaN(d);
                childFling(flingHelper.getVelocityByDistance(splineFlingDistance - d));
            }
        }
        this.totalDy = 0;
        this.velocityY = 0;
    }

    /* JADX INFO: Access modifiers changed from: private */
    public void dispatchParentFling() {
        int i;
        WXRecyclerView parentRecyclerView = getParentRecyclerView();
        if (parentRecyclerView == null || !isScrollTop() || (i = this.velocityY) == 0) {
            return;
        }
        double splineFlingDistance = this.mFlingHelper.getSplineFlingDistance(i);
        if (splineFlingDistance > Math.abs(this.totalDy)) {
            FlingHelper flingHelper = this.mFlingHelper;
            double d = this.totalDy;
            Double.isNaN(d);
            parentRecyclerView.fling(0, -flingHelper.getVelocityByDistance(splineFlingDistance + d));
        }
        this.totalDy = 0;
        this.velocityY = 0;
    }

    private void childFling(int velY) {
        WXRecyclerView childRecylerView = getChildRecylerView();
        if (childRecylerView != null) {
            childRecylerView.fling(0, velY);
        }
    }

    @Override // androidx.recyclerview.widget.RecyclerView
    public void scrollToPosition(final int position) {
        if (this.isNestParent && this.NestInfo != null) {
            WXRecyclerView childRecylerView = getChildRecylerView();
            if (childRecylerView != null) {
                childRecylerView.scrollToPosition(position);
            }
            postDelayed(new Runnable() { // from class: com.taobao.weex.ui.view.listview.WXRecyclerView.9
                @Override // java.lang.Runnable
                public void run() {
                    WXRecyclerView.super.scrollToPosition(position);
                }
            }, 50L);
            return;
        }
        super.scrollToPosition(position);
    }

    @Override // android.view.ViewGroup, android.view.ViewParent
    public boolean onStartNestedScroll(View child, View target, int nestedScrollAxes) {
        if (!this.isNestParent || this.NestInfo == null || target == null || !(target instanceof WXRecyclerView) || ((WXRecyclerView) target).isNestParent) {
            return super.onStartNestedScroll(child, target, nestedScrollAxes);
        }
        return true;
    }

    @Override // android.view.ViewGroup, android.view.ViewParent
    public void onNestedPreScroll(View target, int dx, int dy, int[] consumed) {
        if (!this.isNestParent || this.NestInfo == null) {
            return;
        }
        WXRecyclerView childRecylerView = getChildRecylerView();
        boolean z = dy > 0 && !isScrollEnd();
        boolean z2 = dy < 0 && childRecylerView != null && childRecylerView.isScrollTop();
        if (z || z2) {
            scrollBy(0, dy);
            consumed[1] = dy;
        }
    }

    @Override // android.view.ViewGroup, android.view.ViewParent
    public boolean onNestedFling(View target, float velocityX, float velocityY, boolean consumed) {
        if (!this.isNestParent || this.NestInfo == null) {
            return super.onNestedFling(target, velocityX, velocityY, consumed);
        }
        return true;
    }

    @Override // android.view.ViewGroup, android.view.ViewParent
    public boolean onNestedPreFling(View target, float velocityX, float velocityY) {
        if (this.isNestParent && this.NestInfo != null) {
            WXRecyclerView childRecylerView = getChildRecylerView();
            boolean z = velocityY > 0.0f && !isScrollEnd();
            boolean z2 = velocityY < 0.0f && childRecylerView != null && childRecylerView.isScrollTop();
            if (z || z2) {
                fling(0, (int) velocityY);
                return true;
            }
            return false;
        }
        return super.onNestedPreFling(target, velocityX, velocityY);
    }

    public boolean pointInView(float localX, float localY, float slop) {
        float f = -slop;
        return localX >= f && localY >= f && localX < ((float) (getRight() - getLeft())) + slop && localY < ((float) (getBottom() - getTop())) + slop;
    }

    @Override // android.view.View
    protected void onScrollChanged(int l, int t, int oldl, int oldt) {
        super.onScrollChanged(l, t, oldl, oldt);
        AppEventForBlurManager.onScrollChanged(l, t);
    }
}
