package com.taobao.weex.utils;

import android.content.res.Resources;
import android.graphics.Bitmap;
import android.graphics.BlurMaskFilter;
import android.graphics.Canvas;
import android.graphics.ColorFilter;
import android.graphics.LinearGradient;
import android.graphics.Paint;
import android.graphics.Path;
import android.graphics.Point;
import android.graphics.PointF;
import android.graphics.Rect;
import android.graphics.RectF;
import android.graphics.Region;
import android.graphics.Shader;
import android.graphics.drawable.BitmapDrawable;
import android.graphics.drawable.Drawable;
import android.graphics.drawable.LayerDrawable;
import android.os.Build;
import android.text.TextUtils;
import android.util.Log;
import android.view.View;
import android.view.ViewGroup;
import android.view.ViewParent;
import com.taobao.weex.WXEnvironment;
import com.taobao.weex.common.WXThread;
import com.taobao.weex.el.parse.Operators;
import com.taobao.weex.performance.WXInstanceApm;
import io.dcloud.common.util.StringUtil;
import java.util.ArrayList;
import java.util.Arrays;
import java.util.List;
import java.util.regex.Matcher;
import java.util.regex.Pattern;
/* loaded from: classes8.dex */
public class BoxShadowUtil {
    private static final String TAG = "BoxShadowUtil";
    private static boolean sBoxShadowEnabled = true;
    private static Pattern sColorPattern;

    public static void setBoxShadowEnabled(boolean enabled) {
        sBoxShadowEnabled = enabled;
        WXLogUtils.w(TAG, "Switch box-shadow status: " + enabled);
    }

    public static boolean isBoxShadowEnabled() {
        return sBoxShadowEnabled;
    }

    public static void setBoxShadow(final View target, String style, final float[] radii, float viewPort, final float quality) {
        if (!sBoxShadowEnabled) {
            WXLogUtils.w(TAG, "box-shadow was disabled by config");
        } else if (target == null) {
            WXLogUtils.w(TAG, "Target view is null!");
        } else if (TextUtils.isEmpty(style) && Build.VERSION.SDK_INT >= 18) {
            target.getOverlay().clear();
            WXLogUtils.d(TAG, "Remove all box-shadow");
        } else {
            BoxShadowOptions[] parseBoxShadows = parseBoxShadows(style, viewPort);
            if (parseBoxShadows == null || parseBoxShadows.length == 0) {
                WXLogUtils.w(TAG, "Failed to parse box-shadow: " + style);
                return;
            }
            final ArrayList arrayList = new ArrayList();
            final ArrayList arrayList2 = new ArrayList();
            for (BoxShadowOptions boxShadowOptions : parseBoxShadows) {
                if (boxShadowOptions != null) {
                    if (boxShadowOptions.isInset) {
                        arrayList2.add(0, boxShadowOptions);
                    } else {
                        arrayList.add(0, boxShadowOptions);
                    }
                }
            }
            if (radii != null) {
                if (radii.length != 8) {
                    WXLogUtils.w(TAG, "Length of radii must be 8");
                } else {
                    for (int i = 0; i < radii.length; i++) {
                        radii[i] = WXViewUtils.getRealSubPxByWidth(radii[i], viewPort);
                    }
                }
            }
            target.post(WXThread.secure(new Runnable() { // from class: com.taobao.weex.utils.BoxShadowUtil.1
                @Override // java.lang.Runnable
                public void run() {
                    if (Build.VERSION.SDK_INT >= 18) {
                        target.getOverlay().clear();
                        if (arrayList.size() > 0) {
                            BoxShadowUtil.setNormalBoxShadow(target, arrayList, quality, radii);
                        }
                        if (arrayList2.size() > 0) {
                            BoxShadowUtil.setInsetBoxShadow(target, arrayList2, quality, radii);
                        }
                    }
                }
            }));
        }
    }

    private static void drawShadow(Canvas canvas, BoxShadowOptions options) {
        RectF rectF = new RectF(0.0f, 0.0f, options.viewWidth + (options.spread * 2.0f), options.viewHeight + (options.spread * 2.0f));
        if (options.topLeft != null) {
            rectF.offset(options.topLeft.x, options.topLeft.y);
        }
        float f = options.blur;
        float f2 = options.blur;
        if (options.hShadow > 0.0f) {
            f += options.hShadow * 2.0f;
        }
        if (options.vShadow > 0.0f) {
            f2 += options.vShadow * 2.0f;
        }
        rectF.offset(f, f2);
        Paint paint = new Paint();
        paint.setAntiAlias(true);
        paint.setColor(options.color);
        paint.setStyle(Paint.Style.FILL);
        if (options.blur > 0.0f) {
            paint.setMaskFilter(new BlurMaskFilter(options.blur, BlurMaskFilter.Blur.NORMAL));
        }
        Path path = new Path();
        float[] fArr = new float[8];
        for (int i = 0; i < options.radii.length; i++) {
            if (options.radii[i] == 0.0f) {
                fArr[i] = 0.0f;
            } else {
                fArr[i] = options.radii[i] + options.spread;
            }
        }
        path.addRoundRect(rectF, fArr, Path.Direction.CCW);
        canvas.drawPath(path, paint);
    }

    /* JADX INFO: Access modifiers changed from: private */
    public static void setNormalBoxShadow(View target, List<BoxShadowOptions> options, float quality, float[] radii) {
        int height = target.getHeight();
        int width = target.getWidth();
        target.getLayoutParams();
        if (height == 0 || width == 0) {
            Log.w(TAG, "Target view is invisible, ignore set shadow.");
        } else if (Build.VERSION.SDK_INT >= 18) {
            int i = 0;
            int i2 = 0;
            for (BoxShadowOptions boxShadowOptions : options) {
                boxShadowOptions.viewWidth = width;
                boxShadowOptions.viewHeight = height;
                boxShadowOptions.radii = radii;
                Rect targetCanvasRect = boxShadowOptions.getTargetCanvasRect();
                if (i < targetCanvasRect.width()) {
                    i = targetCanvasRect.width();
                }
                if (i2 < targetCanvasRect.height()) {
                    i2 = targetCanvasRect.height();
                }
            }
            Bitmap createBitmap = Bitmap.createBitmap((int) (i * quality), (int) (i2 * quality), Bitmap.Config.ARGB_4444);
            if (Build.VERSION.SDK_INT >= 19) {
                WXLogUtils.d(TAG, "Allocation memory for box-shadow: " + (createBitmap.getAllocationByteCount() / 1024) + " KB");
            }
            Canvas canvas = new Canvas(createBitmap);
            for (BoxShadowOptions boxShadowOptions2 : options) {
                Rect targetCanvasRect2 = boxShadowOptions2.getTargetCanvasRect();
                boxShadowOptions2.topLeft = new PointF((i - targetCanvasRect2.width()) / 2.0f, (i2 - targetCanvasRect2.height()) / 2.0f);
                drawShadow(canvas, boxShadowOptions2.scale(quality));
            }
            OverflowBitmapDrawable overflowBitmapDrawable = new OverflowBitmapDrawable(target.getResources(), createBitmap, new Point((i - width) / 2, (i2 - height) / 2), new Rect(0, 0, width, height), radii);
            target.getOverlay().add(overflowBitmapDrawable);
            ViewParent parent = target.getParent();
            if (parent != null) {
                parent.requestLayout();
                if (parent instanceof ViewGroup) {
                    ((ViewGroup) parent).invalidate(overflowBitmapDrawable.getBounds());
                }
            }
        } else {
            Log.w(TAG, "Call setNormalBoxShadow() requires API level 18 or higher.");
        }
    }

    /* JADX INFO: Access modifiers changed from: private */
    public static void setInsetBoxShadow(View target, List<BoxShadowOptions> options, float quality, float[] radii) {
        if (target == null || options == null) {
            WXLogUtils.w(TAG, "Illegal arguments");
        } else if (target.getWidth() == 0 || target.getHeight() == 0) {
            WXLogUtils.w(TAG, "Target view is invisible, ignore set shadow.");
        } else if (Build.VERSION.SDK_INT >= 18) {
            Drawable[] drawableArr = new Drawable[options.size()];
            for (int i = 0; i < options.size(); i++) {
                BoxShadowOptions boxShadowOptions = options.get(i);
                drawableArr[i] = new InsetShadowDrawable(target.getWidth(), target.getHeight(), boxShadowOptions.hShadow, boxShadowOptions.vShadow, boxShadowOptions.blur, boxShadowOptions.spread, boxShadowOptions.color, radii);
            }
            target.getOverlay().add(new LayerDrawable(drawableArr));
            target.invalidate();
        } else {
            Log.w(TAG, "Call setInsetBoxShadow() requires API level 18 or higher.");
        }
    }

    public static BoxShadowOptions[] parseBoxShadows(String boxShadowStyle, float viewport) {
        int i;
        if (sColorPattern == null) {
            sColorPattern = Pattern.compile("([rR][gG][bB][aA]?)\\((\\d+\\s*),\\s*(\\d+\\s*),\\s*(\\d+\\s*)(?:,\\s*(\\d+(?:\\.\\d+)?))?\\)");
        }
        Matcher matcher = sColorPattern.matcher(boxShadowStyle);
        while (true) {
            if (!matcher.find()) {
                break;
            }
            String group = matcher.group();
            boxShadowStyle = boxShadowStyle.replace(group, "#" + StringUtil.format("%8s", Integer.toHexString(WXResourceUtils.getColor(group, -16777216))).replaceAll("\\s", WXInstanceApm.VALUE_ERROR_CODE_DEFAULT));
        }
        String[] split = boxShadowStyle.split(",");
        if (split == null || split.length <= 0) {
            return null;
        }
        BoxShadowOptions[] boxShadowOptionsArr = new BoxShadowOptions[split.length];
        for (i = 0; i < split.length; i++) {
            boxShadowOptionsArr[i] = parseBoxShadow(split[i], viewport);
        }
        return boxShadowOptionsArr;
    }

    private static BoxShadowOptions parseBoxShadow(String boxShadow, float viewport) {
        int i;
        BoxShadowOptions boxShadowOptions = new BoxShadowOptions(viewport);
        if (TextUtils.isEmpty(boxShadow)) {
            return null;
        }
        String replaceAll = boxShadow.replaceAll("\\s*,\\s+", ",");
        if (replaceAll.contains("inset")) {
            boxShadowOptions.isInset = true;
            replaceAll = replaceAll.replace("inset", "");
        }
        ArrayList arrayList = new ArrayList(Arrays.asList(replaceAll.trim().split("\\s+")));
        String str = (String) arrayList.get(arrayList.size() - 1);
        if (!TextUtils.isEmpty(str) && (str.startsWith("#") || str.startsWith("rgb") || WXResourceUtils.isNamedColor(str))) {
            boxShadowOptions.color = WXResourceUtils.getColor(str, -16777216);
            arrayList.remove(arrayList.size() - 1);
        }
        try {
        } catch (Throwable th) {
            th.printStackTrace();
        }
        if (arrayList.size() < 2) {
            return null;
        }
        if (!TextUtils.isEmpty((CharSequence) arrayList.get(0))) {
            boxShadowOptions.hShadow = WXViewUtils.getRealSubPxByWidth(WXUtils.getFloat(((String) arrayList.get(0)).trim(), Float.valueOf(0.0f)).floatValue(), viewport);
        }
        if (!TextUtils.isEmpty((CharSequence) arrayList.get(1))) {
            boxShadowOptions.vShadow = WXViewUtils.getRealPxByWidth(WXUtils.getFloat(((String) arrayList.get(1)).trim(), Float.valueOf(0.0f)).floatValue(), viewport);
        }
        for (i = 2; i < arrayList.size(); i++) {
            ((BoxShadowOptions.IParser) boxShadowOptions.optionParamParsers.get(i - 2)).parse((String) arrayList.get(i));
        }
        return boxShadowOptions;
    }

    /* JADX INFO: Access modifiers changed from: private */
    /* loaded from: classes8.dex */
    public static class OverflowBitmapDrawable extends BitmapDrawable {
        private int paddingX;
        private int paddingY;
        private float[] radii;
        private Rect viewRect;

        private OverflowBitmapDrawable(Resources resources, Bitmap bitmap, Point topLeft, Rect viewRect, float[] radii) {
            super(resources, bitmap);
            this.paddingX = topLeft.x;
            int i = topLeft.y;
            this.paddingY = i;
            this.viewRect = viewRect;
            this.radii = radii;
            setBounds(-this.paddingX, -i, viewRect.width() + this.paddingX, viewRect.height() + this.paddingY);
        }

        @Override // android.graphics.drawable.BitmapDrawable, android.graphics.drawable.Drawable
        public void draw(Canvas canvas) {
            Rect clipBounds = canvas.getClipBounds();
            Rect rect = new Rect(clipBounds);
            rect.inset((-this.paddingX) * 2, (-this.paddingY) * 2);
            try {
                if (WXEnvironment.sApplication.getApplicationInfo().targetSdkVersion > 26) {
                    canvas.clipRect(rect);
                } else {
                    canvas.clipRect(rect, Region.Op.REPLACE);
                }
            } catch (NullPointerException unused) {
                canvas.clipRect(rect);
            }
            Path path = new Path();
            path.addRoundRect(new RectF(clipBounds), this.radii, Path.Direction.CCW);
            canvas.clipPath(path, Region.Op.DIFFERENCE);
            canvas.translate(clipBounds.left, clipBounds.top);
            super.draw(canvas);
        }
    }

    /* JADX INFO: Access modifiers changed from: private */
    /* loaded from: classes8.dex */
    public static class InsetShadowDrawable extends Drawable {
        private static final int BOTTOM_TO_TOP = 3;
        private static final int LEFT_TO_RIGHT = 0;
        private static final int RIGHT_TO_LEFT = 2;
        private static final int TOP_TO_BOTTOM = 1;
        private float blurRadius;
        private float height;
        private Paint paint;
        private Path[] paths;
        private float[] radii;
        private Shader[] shades;
        private int shadowColor;
        private float shadowXSize;
        private float shadowYSize;
        private float width;

        @Override // android.graphics.drawable.Drawable
        public int getOpacity() {
            return -1;
        }

        @Override // android.graphics.drawable.Drawable
        public void setAlpha(int alpha) {
        }

        @Override // android.graphics.drawable.Drawable
        public void setColorFilter(ColorFilter colorFilter) {
        }

        private InsetShadowDrawable(int viewWidth, int viewHeight, float dx, float dy, float blurRadius, float spread, int shadowColor, float[] radii) {
            this.shades = new Shader[4];
            this.paths = new Path[4];
            this.blurRadius = blurRadius;
            this.shadowColor = shadowColor;
            this.width = viewWidth + (dx * 2.0f);
            this.height = viewHeight + (2.0f * dy);
            this.shadowXSize = dx + spread;
            this.shadowYSize = dy + spread;
            this.radii = radii;
            setBounds(0, 0, viewWidth, viewHeight);
            prepare();
        }

        private void prepare() {
            PointF pointF = new PointF(0.0f, 0.0f);
            PointF pointF2 = new PointF(this.width, 0.0f);
            PointF pointF3 = new PointF(pointF2.x, this.height);
            PointF pointF4 = new PointF(pointF.x, pointF3.y);
            PointF pointF5 = new PointF(this.shadowXSize, this.shadowYSize);
            PointF pointF6 = new PointF(pointF2.x - this.shadowXSize, pointF5.y);
            PointF pointF7 = new PointF(pointF6.x, pointF3.y - this.shadowYSize);
            PointF pointF8 = new PointF(pointF5.x, pointF7.y);
            LinearGradient linearGradient = new LinearGradient(pointF5.x - this.blurRadius, pointF5.y, pointF5.x, pointF5.y, this.shadowColor, 0, Shader.TileMode.CLAMP);
            LinearGradient linearGradient2 = new LinearGradient(pointF5.x, pointF5.y - this.blurRadius, pointF5.x, pointF5.y, this.shadowColor, 0, Shader.TileMode.CLAMP);
            LinearGradient linearGradient3 = new LinearGradient(pointF7.x + this.blurRadius, pointF7.y, pointF7.x, pointF7.y, this.shadowColor, 0, Shader.TileMode.CLAMP);
            LinearGradient linearGradient4 = new LinearGradient(pointF7.x, pointF7.y + this.blurRadius, pointF7.x, pointF7.y, this.shadowColor, 0, Shader.TileMode.CLAMP);
            Shader[] shaderArr = this.shades;
            shaderArr[0] = linearGradient;
            shaderArr[1] = linearGradient2;
            shaderArr[2] = linearGradient3;
            shaderArr[3] = linearGradient4;
            Path path = new Path();
            path.moveTo(pointF.x, pointF.y);
            path.lineTo(pointF5.x, pointF5.y);
            path.lineTo(pointF8.x, pointF8.y);
            path.lineTo(pointF4.x, pointF4.y);
            path.close();
            Path path2 = new Path();
            path2.moveTo(pointF.x, pointF.y);
            path2.lineTo(pointF2.x, pointF2.y);
            path2.lineTo(pointF6.x, pointF6.y);
            path2.lineTo(pointF5.x, pointF5.y);
            path2.close();
            Path path3 = new Path();
            path3.moveTo(pointF2.x, pointF2.y);
            path3.lineTo(pointF3.x, pointF3.y);
            path3.lineTo(pointF7.x, pointF7.y);
            path3.lineTo(pointF6.x, pointF6.y);
            path3.close();
            Path path4 = new Path();
            path4.moveTo(pointF4.x, pointF4.y);
            path4.lineTo(pointF3.x, pointF3.y);
            path4.lineTo(pointF7.x, pointF7.y);
            path4.lineTo(pointF8.x, pointF8.y);
            path4.close();
            Path[] pathArr = this.paths;
            pathArr[0] = path;
            pathArr[1] = path2;
            pathArr[2] = path3;
            pathArr[3] = path4;
            Paint paint = new Paint();
            this.paint = paint;
            paint.setAntiAlias(true);
            this.paint.setStyle(Paint.Style.FILL);
            this.paint.setColor(this.shadowColor);
        }

        @Override // android.graphics.drawable.Drawable
        public void draw(Canvas canvas) {
            Rect clipBounds = canvas.getClipBounds();
            Path path = new Path();
            path.addRoundRect(new RectF(clipBounds), this.radii, Path.Direction.CCW);
            canvas.clipPath(path);
            canvas.translate(clipBounds.left, clipBounds.top);
            for (int i = 0; i < 4; i++) {
                Shader shader = this.shades[i];
                Path path2 = this.paths[i];
                this.paint.setShader(shader);
                canvas.drawPath(path2, this.paint);
            }
        }
    }

    /* loaded from: classes8.dex */
    public static class BoxShadowOptions {
        public float blur;
        public int color;
        public float hShadow;
        public boolean isInset;
        private List<IParser> optionParamParsers;
        public float[] radii;
        public float spread;
        public PointF topLeft;
        public float vShadow;
        public int viewHeight;
        public int viewWidth;
        private float viewport;

        /* JADX INFO: Access modifiers changed from: private */
        /* loaded from: classes8.dex */
        public interface IParser {
            void parse(String param);
        }

        private BoxShadowOptions(float vp) {
            this.viewport = 750.0f;
            this.blur = 0.0f;
            this.spread = 0.0f;
            this.radii = new float[]{0.0f, 0.0f, 0.0f, 0.0f, 0.0f, 0.0f, 0.0f, 0.0f};
            this.color = -16777216;
            this.isInset = false;
            this.viewWidth = 0;
            this.viewHeight = 0;
            this.topLeft = null;
            if (750.0f != 0.0f) {
                this.viewport = vp;
            }
            this.optionParamParsers = new ArrayList();
            IParser iParser = new IParser() { // from class: com.taobao.weex.utils.BoxShadowUtil.BoxShadowOptions.1
                @Override // com.taobao.weex.utils.BoxShadowUtil.BoxShadowOptions.IParser
                public void parse(String param) {
                    if (TextUtils.isEmpty(param)) {
                        return;
                    }
                    float floatValue = WXUtils.getFloat(param, Float.valueOf(0.0f)).floatValue();
                    BoxShadowOptions boxShadowOptions = BoxShadowOptions.this;
                    boxShadowOptions.spread = WXViewUtils.getRealSubPxByWidth(floatValue, boxShadowOptions.viewport);
                    WXLogUtils.w(BoxShadowUtil.TAG, "Experimental box-shadow attribute: spread");
                }
            };
            this.optionParamParsers.add(new IParser() { // from class: com.taobao.weex.utils.BoxShadowUtil.BoxShadowOptions.2
                @Override // com.taobao.weex.utils.BoxShadowUtil.BoxShadowOptions.IParser
                public void parse(String param) {
                    if (TextUtils.isEmpty(param)) {
                        return;
                    }
                    float floatValue = WXUtils.getFloat(param, Float.valueOf(0.0f)).floatValue();
                    BoxShadowOptions boxShadowOptions = BoxShadowOptions.this;
                    boxShadowOptions.blur = WXViewUtils.getRealSubPxByWidth(floatValue, boxShadowOptions.viewport);
                }
            });
            this.optionParamParsers.add(iParser);
        }

        public BoxShadowOptions scale(float scale) {
            if (scale <= 0.0f || scale > 1.0f) {
                return null;
            }
            BoxShadowOptions boxShadowOptions = new BoxShadowOptions(this.viewport);
            boxShadowOptions.hShadow = this.hShadow * scale;
            boxShadowOptions.vShadow = this.vShadow * scale;
            boxShadowOptions.blur = this.blur * scale;
            boxShadowOptions.spread = this.spread * scale;
            int i = 0;
            while (true) {
                float[] fArr = this.radii;
                if (i >= fArr.length) {
                    break;
                }
                boxShadowOptions.radii[i] = fArr[i] * scale;
                i++;
            }
            boxShadowOptions.viewHeight = (int) (this.viewHeight * scale);
            boxShadowOptions.viewWidth = (int) (this.viewWidth * scale);
            if (this.topLeft != null) {
                PointF pointF = new PointF();
                boxShadowOptions.topLeft = pointF;
                pointF.x = this.topLeft.x * scale;
                boxShadowOptions.topLeft.y = this.topLeft.y * scale;
            }
            boxShadowOptions.color = this.color;
            boxShadowOptions.isInset = this.isInset;
            WXLogUtils.d(BoxShadowUtil.TAG, "Scaled BoxShadowOptions: [" + scale + "] " + boxShadowOptions);
            return boxShadowOptions;
        }

        public Rect getTargetCanvasRect() {
            return new Rect(0, 0, this.viewWidth + (((int) (this.blur + this.spread + Math.abs(this.hShadow))) * 2), this.viewHeight + (((int) (this.blur + this.spread + Math.abs(this.vShadow))) * 2));
        }

        public String toString() {
            StringBuffer stringBuffer = new StringBuffer("BoxShadowOptions{");
            stringBuffer.append("h-shadow=");
            stringBuffer.append(this.hShadow);
            stringBuffer.append(", v-shadow=");
            stringBuffer.append(this.vShadow);
            stringBuffer.append(", blur=");
            stringBuffer.append(this.blur);
            stringBuffer.append(", spread=");
            stringBuffer.append(this.spread);
            stringBuffer.append(", corner-radius=");
            stringBuffer.append(Operators.ARRAY_START_STR + this.radii[0] + "," + this.radii[2] + "," + this.radii[4] + "," + this.radii[6] + Operators.ARRAY_END_STR);
            stringBuffer.append(", color=#");
            stringBuffer.append(Integer.toHexString(this.color));
            stringBuffer.append(", inset=");
            stringBuffer.append(this.isInset);
            stringBuffer.append(Operators.BLOCK_END);
            return stringBuffer.toString();
        }
    }
}
