package com.taobao.weex.utils;

import android.text.TextUtils;
import com.taobao.weex.WXEnvironment;
import com.taobao.weex.WXSDKInstance;
import com.taobao.weex.WXSDKManager;
import com.taobao.weex.adapter.IWXConfigAdapter;
import com.taobao.weex.adapter.IWXJSExceptionAdapter;
import com.taobao.weex.common.WXErrorCode;
import com.taobao.weex.common.WXJSExceptionInfo;
import com.taobao.weex.el.parse.Operators;
import com.taobao.weex.performance.WXAnalyzerDataTransfer;
import com.taobao.weex.performance.WXInstanceApm;
import com.taobao.weex.performance.WXStateRecord;
import io.dcloud.common.constant.AbsoluteConst;
import java.util.ArrayList;
import java.util.Collections;
import java.util.Comparator;
import java.util.HashMap;
import java.util.Map;
import java.util.Set;
import java.util.concurrent.CopyOnWriteArraySet;
/* loaded from: classes8.dex */
public class WXExceptionUtils {
    private static Set<String> sGlobalExceptionRecord = new CopyOnWriteArraySet();
    public static String degradeUrl = "BundleUrlDefaultDegradeUrl";

    private static boolean checkNeedReportCauseRepeat(String instanceId, WXErrorCode errCode, String exception) {
        Set<String> set;
        if (TextUtils.isEmpty(exception)) {
            return true;
        }
        if (errCode == null || errCode.getErrorGroup() == WXErrorCode.ErrorGroup.JS) {
            if (TextUtils.isEmpty(instanceId)) {
                instanceId = "instanceIdNull";
            }
            if (exception.length() > 200) {
                exception = exception.substring(0, 200);
            }
            WXSDKInstance wXSDKInstance = WXSDKManager.getInstance().getAllInstanceMap().get(instanceId);
            if (wXSDKInstance == null) {
                set = sGlobalExceptionRecord;
            } else {
                set = wXSDKInstance.getApmForInstance().exceptionRecord;
            }
            if (set == null) {
                return true;
            }
            if (set.contains(exception)) {
                return false;
            }
            set.add(exception);
            return true;
        }
        return true;
    }

    public static void commitCriticalExceptionRT(final String instanceId, final WXErrorCode errCode, final String function, final String exception, final Map<String, String> extParams) {
        try {
            WXLogUtils.e("weex", "commitCriticalExceptionRT :" + errCode + "exception" + exception);
            WXStateRecord.getInstance().recordException(instanceId, exception);
            IWXConfigAdapter wxConfigAdapter = WXSDKManager.getInstance().getWxConfigAdapter();
            if (!(wxConfigAdapter != null ? AbsoluteConst.TRUE.equalsIgnoreCase(wxConfigAdapter.getConfig("wxapm", "check_repeat_report", AbsoluteConst.TRUE)) : true ? checkNeedReportCauseRepeat(instanceId, errCode, exception) : true)) {
                return;
            }
        } catch (Throwable th) {
            th.printStackTrace();
        }
        commitCriticalExceptionWithDefaultUrl("BundleUrlDefault", instanceId, errCode, function, exception, extParams);
    }

    public static void commitCriticalExceptionWithDefaultUrl(final String defaultUrl, final String instanceId, final WXErrorCode errCode, final String function, final String exception, final Map<String, String> extParams) {
        String str;
        String str2;
        IWXJSExceptionAdapter iWXJSExceptionAdapter = WXSDKManager.getInstance().getIWXJSExceptionAdapter();
        if (TextUtils.isEmpty(defaultUrl)) {
            defaultUrl = "BundleUrlDefault";
        }
        if (extParams == null) {
            extParams = new HashMap<>();
        }
        Map<String, String> map = extParams;
        map.put("wxSdkInitStartTime", String.valueOf(WXEnvironment.sSDKInitStart));
        map.put("wxSDKInitCostTime", String.valueOf(WXEnvironment.sSDKInitTime));
        map.put("wxSDKCurExceptionTime", String.valueOf(System.currentTimeMillis()));
        map.put("wxUseRuntimeApi", String.valueOf(WXEnvironment.sUseRunTimeApi));
        if (!TextUtils.isEmpty(instanceId)) {
            WXSDKInstance wXSDKInstance = WXSDKManager.getInstance().getAllInstanceMap().get(instanceId);
            if (wXSDKInstance != null) {
                defaultUrl = wXSDKInstance.getApmForInstance().reportPageName;
                Object obj = wXSDKInstance.getApmForInstance().extInfo.get(WXInstanceApm.VALUE_BUNDLE_LOAD_LENGTH);
                map.put(WXInstanceApm.VALUE_BUNDLE_LOAD_LENGTH, obj instanceof Integer ? String.valueOf(obj) : "unknownLength");
                map.put("templateInfo", wXSDKInstance.getTemplateInfo());
                if (TextUtils.isEmpty(defaultUrl) || defaultUrl.equals("default")) {
                    if (!TextUtils.equals(degradeUrl, "BundleUrlDefaultDegradeUrl")) {
                        defaultUrl = degradeUrl;
                    } else {
                        defaultUrl = WXSDKInstance.requestUrl;
                    }
                }
                for (Map.Entry<String, String> entry : wXSDKInstance.getContainerInfo().entrySet()) {
                    map.put(entry.getKey(), entry.getValue());
                }
                map.put("wxStageList", convertStageToStr(wXSDKInstance));
                String template = wXSDKInstance.getTemplate();
                map.put("wxTemplateOfBundle", template == null ? "has recycle by gc" : template.substring(0, Math.min(template.length(), 300)));
                Long l = wXSDKInstance.getApmForInstance().stageMap.get(WXInstanceApm.KEY_PAGE_STAGES_DOWN_BUNDLE_START);
                if (l == null) {
                    l = wXSDKInstance.getApmForInstance().stageMap.get(WXInstanceApm.KEY_PAGE_STAGES_RENDER_ORGIGIN);
                }
                if (l != null) {
                    map.put("wxUseTime", String.valueOf(WXUtils.getFixUnixTime() - l.longValue()));
                }
            }
            str = defaultUrl;
            str2 = instanceId;
        } else {
            if (map.size() > 0) {
                defaultUrl = TextUtils.isEmpty(map.get("weexUrl")) ? map.get("weexUrl") : map.get("bundleUrl");
            }
            str = defaultUrl;
            str2 = "InstanceIdDefalut";
        }
        String str3 = map.get("errorCode");
        if (str3 != null && str3.length() > 200) {
            map.remove("errorCode");
        }
        WXJSExceptionInfo wXJSExceptionInfo = new WXJSExceptionInfo(str2, str, errCode, function, exception, map);
        if (iWXJSExceptionAdapter != null) {
            iWXJSExceptionAdapter.onJSException(wXJSExceptionInfo);
        }
        WXAnalyzerDataTransfer.transferError(wXJSExceptionInfo, instanceId);
    }

    private static String convertStageToStr(WXSDKInstance instance) {
        if (instance == null || instance.getApmForInstance() == null || instance.getApmForInstance().stageMap.isEmpty()) {
            return "noStageRecord";
        }
        ArrayList<Map.Entry> arrayList = new ArrayList(instance.getApmForInstance().stageMap.entrySet());
        Collections.sort(arrayList, new Comparator<Map.Entry<String, Long>>() { // from class: com.taobao.weex.utils.WXExceptionUtils.1
            @Override // java.util.Comparator
            public int compare(Map.Entry<String, Long> o1, Map.Entry<String, Long> o2) {
                return (int) (o1.getValue().longValue() - o2.getValue().longValue());
            }
        });
        StringBuilder sb = new StringBuilder();
        for (Map.Entry entry : arrayList) {
            sb.append((String) entry.getKey());
            sb.append(Operators.CONDITION_IF_MIDDLE);
            sb.append(entry.getValue());
            sb.append("->");
        }
        return sb.toString();
    }
}
