package com.taobao.weex.utils;

import android.text.TextUtils;
import android.util.Log;
import com.taobao.weex.WXEnvironment;
import com.taobao.weex.performance.WXStateRecord;
import io.dcloud.feature.uniapp.utils.AbsLogLevel;
import io.dcloud.weex.ConsoleLogUtils;
import java.io.IOException;
import java.io.PrintWriter;
import java.io.StringWriter;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
/* loaded from: classes8.dex */
public class WXLogUtils {
    private static final String CLAZZ_NAME_LOG_UTIL = "com.taobao.weex.devtools.common.LogUtil";
    public static final String WEEX_PERF_TAG = "weex_perf";
    public static final String WEEX_TAG = "weex";
    private static StringBuilder builder = new StringBuilder(50);
    private static HashMap<String, Class> clazzMaps;
    private static boolean isDebug;
    private static List<JsLogWatcher> jsLogWatcherList;
    private static LogWatcher sLogWatcher;

    /* loaded from: classes8.dex */
    public interface JsLogWatcher {
        void onJsLog(int level, String log);
    }

    /* loaded from: classes8.dex */
    public interface LogWatcher {
        void onLog(String level, String tag, String msg);
    }

    public static void performance(String instanceId, byte[] msg) {
    }

    static {
        HashMap<String, Class> hashMap = new HashMap<>(2);
        clazzMaps = hashMap;
        isDebug = true;
        hashMap.put(CLAZZ_NAME_LOG_UTIL, loadClass(CLAZZ_NAME_LOG_UTIL));
        jsLogWatcherList = new ArrayList();
    }

    public static void setIsDebug(boolean isDebug2) {
        isDebug = isDebug2;
    }

    private static Class loadClass(String clazzName) {
        try {
            Class<?> cls = Class.forName(clazzName);
            if (cls != null) {
                try {
                    clazzMaps.put(clazzName, cls);
                    return cls;
                } catch (ClassNotFoundException unused) {
                    return cls;
                }
            }
            return cls;
        } catch (ClassNotFoundException unused2) {
            return null;
        }
    }

    public static void renderPerformanceLog(String type, long time) {
        if (WXEnvironment.isApkDebugable()) {
            return;
        }
        WXEnvironment.isPerf();
    }

    private static void log(String tag, String msg, AbsLogLevel level) {
        if (TextUtils.isEmpty(msg) || TextUtils.isEmpty(tag) || level == null || TextUtils.isEmpty(level.getName()) || !isDebug) {
            return;
        }
        if (level == LogLevel.ERROR && !TextUtils.isEmpty(msg) && msg.contains("IPCException")) {
            WXStateRecord.getInstance().recordIPCException("ipc", msg);
        }
        ConsoleLogUtils.consoleLog(tag, msg, level);
        LogWatcher logWatcher = sLogWatcher;
        if (logWatcher != null) {
            logWatcher.onLog(level.getName(), tag, msg);
        }
        if (WXEnvironment.isApkDebugable()) {
            if (level.getValue() - WXEnvironment.sLogLevel.getValue() >= 0) {
                Log.println(level.getPriority(), tag, msg);
                writeConsoleLog(level.getName(), msg);
            }
        } else if (level.getValue() - LogLevel.WARN.getValue() < 0 || level.getValue() - WXEnvironment.sLogLevel.getValue() < 0) {
        } else {
            Log.println(level.getPriority(), tag, msg);
        }
    }

    public static void v(String msg) {
        v("weex", msg);
    }

    public static void d(String msg) {
        d("weex", msg);
    }

    public static void d(String tag, byte[] msg) {
        d(tag, new String(msg));
    }

    public static void i(String msg) {
        i("weex", msg);
    }

    public static void i(String tag, byte[] msg) {
        i(tag, new String(msg));
    }

    public static void info(String msg) {
        i("weex", msg);
    }

    public static void w(String msg) {
        w("weex", msg);
    }

    public static void w(String tag, byte[] msg) {
        w(tag, new String(msg));
    }

    public static void e(String msg) {
        e("weex", msg);
    }

    public static void e(String tag, byte[] msg) {
        e(tag, new String(msg));
    }

    public static void wtf(String msg) {
        wtf("weex", msg);
    }

    public static void d(String tag, String msg) {
        List<JsLogWatcher> list;
        if (TextUtils.isEmpty(tag) || TextUtils.isEmpty(msg)) {
            return;
        }
        log(tag, msg, LogLevel.DEBUG);
        if (!WXEnvironment.isApkDebugable() || !"jsLog".equals(tag) || (list = jsLogWatcherList) == null || list.size() <= 0) {
            return;
        }
        for (JsLogWatcher jsLogWatcher : jsLogWatcherList) {
            if (msg.endsWith("__DEBUG")) {
                jsLogWatcher.onJsLog(3, msg.replace("__DEBUG", ""));
            } else if (msg.endsWith("__INFO")) {
                jsLogWatcher.onJsLog(3, msg.replace("__INFO", ""));
            } else if (msg.endsWith("__WARN")) {
                jsLogWatcher.onJsLog(3, msg.replace("__WARN", ""));
            } else if (msg.endsWith("__ERROR")) {
                jsLogWatcher.onJsLog(3, msg.replace("__ERROR", ""));
            } else {
                jsLogWatcher.onJsLog(3, msg);
            }
        }
    }

    private static LogLevel getLogLevel(String level) {
        String trim = level.trim();
        trim.hashCode();
        char c = 65535;
        switch (trim.hashCode()) {
            case -1485211506:
                if (trim.equals("__INFO")) {
                    c = 0;
                    break;
                }
                break;
            case -1484806554:
                if (trim.equals("__WARN")) {
                    c = 1;
                    break;
                }
                break;
            case 90640196:
                if (trim.equals("__LOG")) {
                    c = 2;
                    break;
                }
                break;
            case 1198194259:
                if (trim.equals("__DEBUG")) {
                    c = 3;
                    break;
                }
                break;
            case 1199520264:
                if (trim.equals("__ERROR")) {
                    c = 4;
                    break;
                }
                break;
        }
        switch (c) {
            case 0:
                return LogLevel.INFO;
            case 1:
                return LogLevel.WARN;
            case 2:
                return LogLevel.INFO;
            case 3:
                return LogLevel.DEBUG;
            case 4:
                return LogLevel.ERROR;
            default:
                return LogLevel.DEBUG;
        }
    }

    public static void i(String tag, String msg) {
        log(tag, msg, LogLevel.INFO);
    }

    public static void v(String tag, String msg) {
        log(tag, msg, LogLevel.VERBOSE);
    }

    public static void w(String tag, String msg) {
        log(tag, msg, LogLevel.WARN);
    }

    public static void e(String tag, String msg) {
        log(tag, msg, LogLevel.ERROR);
    }

    public static void wtf(String tag, String msg) {
        log(tag, msg, LogLevel.WTF);
    }

    public static void p(String msg) {
        d(WEEX_PERF_TAG, msg);
    }

    public static void d(String prefix, Throwable e) {
        if (WXEnvironment.isApkDebugable()) {
            d(prefix + getStackTrace(e));
        }
    }

    public static void i(String prefix, Throwable e) {
        if (WXEnvironment.isApkDebugable()) {
            info(prefix + getStackTrace(e));
        }
    }

    public static void v(String prefix, Throwable e) {
        if (WXEnvironment.isApkDebugable()) {
            v(prefix + getStackTrace(e));
        }
    }

    public static void w(String prefix, Throwable e) {
        w(prefix + getStackTrace(e));
    }

    public static void e(String prefix, Throwable e) {
        e(prefix + getStackTrace(e));
    }

    public static void wtf(String prefix, Throwable e) {
        if (WXEnvironment.isApkDebugable()) {
            wtf(prefix + getStackTrace(e));
        }
    }

    public static void p(String prefix, Throwable e) {
        if (WXEnvironment.isApkDebugable()) {
            p(prefix + getStackTrace(e));
        }
    }

    public static void eTag(String tag, Throwable e) {
        if (WXEnvironment.isApkDebugable()) {
            e(tag, getStackTrace(e));
        }
    }

    public static String getStackTrace(Throwable e) {
        PrintWriter printWriter;
        if (e == null) {
            return "";
        }
        StringWriter stringWriter = null;
        try {
            StringWriter stringWriter2 = new StringWriter();
            try {
                printWriter = new PrintWriter(stringWriter2);
                try {
                    e.printStackTrace(printWriter);
                    printWriter.flush();
                    stringWriter2.flush();
                    try {
                        stringWriter2.close();
                    } catch (IOException e2) {
                        e2.printStackTrace();
                    }
                    printWriter.close();
                    return stringWriter2.toString();
                } catch (Throwable th) {
                    th = th;
                    stringWriter = stringWriter2;
                    if (stringWriter != null) {
                        try {
                            stringWriter.close();
                        } catch (IOException e3) {
                            e3.printStackTrace();
                        }
                    }
                    if (printWriter != null) {
                        printWriter.close();
                    }
                    throw th;
                }
            } catch (Throwable th2) {
                th = th2;
                printWriter = null;
            }
        } catch (Throwable th3) {
            th = th3;
            printWriter = null;
        }
    }

    private static void writeConsoleLog(String level, String message) {
        if (WXEnvironment.isApkDebugable()) {
            try {
                Class cls = clazzMaps.get(CLAZZ_NAME_LOG_UTIL);
                if (cls != null) {
                    cls.getMethod("log", String.class, String.class).invoke(cls, level, message);
                }
            } catch (Exception unused) {
                Log.d("weex", "LogUtil not found!");
            }
        }
    }

    public static void setJsLogWatcher(JsLogWatcher watcher) {
        if (jsLogWatcherList.contains(watcher)) {
            return;
        }
        jsLogWatcherList.add(watcher);
    }

    public static void setLogWatcher(LogWatcher watcher) {
        sLogWatcher = watcher;
    }
}
