package com.taobao.weex.utils;

import android.app.ActivityManager;
import android.content.Context;
import android.os.Looper;
import android.os.SystemClock;
import android.text.TextUtils;
import androidx.collection.LruCache;
import com.taobao.weex.WXEnvironment;
import com.taobao.weex.WXSDKManager;
import com.taobao.weex.adapter.IWXConfigAdapter;
import com.taobao.weex.common.Constants;
import com.taobao.weex.el.parse.Operators;
import io.dcloud.common.constant.AbsoluteConst;
/* loaded from: classes9.dex */
public class WXUtils {
    private static final int HUNDRED = 100;
    public static final char PERCENT = '%';
    static final LruCache<String, Integer> sCache = new LruCache<>(64);
    private static final long sInterval = System.currentTimeMillis() - SystemClock.uptimeMillis();

    public static LruCache getCache() {
        return sCache;
    }

    public static boolean isUiThread() {
        return Thread.currentThread().getId() == Looper.getMainLooper().getThread().getId();
    }

    public static boolean isUndefined(float value) {
        return Float.isNaN(value);
    }

    public static float getFloatByViewport(Object value, float viewport) {
        return floatByViewport(value, viewport);
    }

    public static float getFloatByViewport(Object value, int viewport) {
        return floatByViewport(value, viewport);
    }

    private static float floatByViewport(Object value, float viewport) {
        if (value == null) {
            return Float.NaN;
        }
        String trim = value.toString().trim();
        if ("auto".equals(trim) || Constants.Name.UNDEFINED.equals(trim) || TextUtils.isEmpty(trim)) {
            WXLogUtils.e("Argument Warning ! value is " + trim + "And default Value:NaN");
            return Float.NaN;
        }
        if (trim.endsWith("wx")) {
            try {
                return transferWx(trim, viewport);
            } catch (NumberFormatException e) {
                WXLogUtils.e("Argument format error! value is " + value, e);
            } catch (Exception e2) {
                WXLogUtils.e("Argument error! value is " + value, e2);
            }
        } else if (trim.endsWith("px")) {
            if (trim.length() > 3 && (trim.endsWith("rpx") || trim.endsWith("upx"))) {
                try {
                    return transferRpxAndUpx(trim.substring(0, trim.length() - 3), 750.0f);
                } catch (NumberFormatException e3) {
                    WXLogUtils.e("Argument format error! value is " + value, e3);
                } catch (Exception e4) {
                    WXLogUtils.e("Argument error! value is " + value, e4);
                }
            } else {
                try {
                    return Float.parseFloat(trim.substring(0, trim.indexOf("px")));
                } catch (NumberFormatException e5) {
                    WXLogUtils.e("Argument format error! value is " + value, e5);
                } catch (Exception e6) {
                    WXLogUtils.e("Argument error! value is " + value, e6);
                }
            }
        } else {
            try {
                return Float.parseFloat(trim);
            } catch (NumberFormatException e7) {
                WXLogUtils.e("Argument format error! value is " + value, e7);
            } catch (Exception e8) {
                WXLogUtils.e("Argument error! value is " + value, e8);
            }
        }
        return Float.NaN;
    }

    public static float getFloat(Object value) {
        return getFloat(value, Float.valueOf(Float.NaN)).floatValue();
    }

    public static Float getFloat(Object value, Float df) {
        if (value == null) {
            return df;
        }
        String trim = value.toString().trim();
        if ("auto".equals(trim) || Constants.Name.UNDEFINED.equals(trim) || TextUtils.isEmpty(trim)) {
            WXLogUtils.e("Argument Warning ! value is " + trim + "And default Value:NaN");
            return df;
        }
        if (trim.endsWith("wx")) {
            try {
                return Float.valueOf(transferWx(trim, 750.0f));
            } catch (NumberFormatException e) {
                WXLogUtils.e("Argument format error! value is " + value, e);
            } catch (Exception e2) {
                WXLogUtils.e("Argument error! value is " + value, e2);
            }
        } else if (trim.endsWith("px")) {
            if (trim.length() > 3 && (trim.endsWith("rpx") || trim.endsWith("upx"))) {
                try {
                    return Float.valueOf(transferRpxAndUpx(trim.substring(0, trim.length() - 3), 750.0f));
                } catch (NumberFormatException e3) {
                    WXLogUtils.e("Argument format error! value is " + value, e3);
                } catch (Exception e4) {
                    WXLogUtils.e("Argument error! value is " + value, e4);
                }
            } else {
                try {
                    return Float.valueOf(Float.parseFloat(trim.substring(0, trim.indexOf("px"))));
                } catch (NumberFormatException e5) {
                    WXLogUtils.e("Argument format error! value is " + value, e5);
                } catch (Exception e6) {
                    WXLogUtils.e("Argument error! value is " + value, e6);
                }
            }
        } else {
            try {
                return Float.valueOf(Float.parseFloat(trim));
            } catch (NumberFormatException e7) {
                WXLogUtils.e("Argument format error! value is " + value, e7);
            } catch (Exception e8) {
                WXLogUtils.e("Argument error! value is " + value, e8);
            }
        }
        return df;
    }

    private static float transferWx(String stringWithWXPostfix, float viewport) {
        if (stringWithWXPostfix == null) {
            return 0.0f;
        }
        if (stringWithWXPostfix.endsWith("wx")) {
            stringWithWXPostfix = stringWithWXPostfix.substring(0, stringWithWXPostfix.indexOf("wx"));
        }
        return ((WXEnvironment.sApplication.getResources().getDisplayMetrics().density * Float.valueOf(Float.parseFloat(stringWithWXPostfix)).floatValue()) * viewport) / WXViewUtils.getScreenWidth();
    }

    private static float transferRpxAndUpx(String stringWithWXPostfix, float viewport) {
        if (stringWithWXPostfix == null) {
            return 0.0f;
        }
        if (stringWithWXPostfix.endsWith("rpx")) {
            stringWithWXPostfix = stringWithWXPostfix.substring(0, stringWithWXPostfix.indexOf("rpx"));
        } else if (stringWithWXPostfix.endsWith("upx")) {
            stringWithWXPostfix = stringWithWXPostfix.substring(0, stringWithWXPostfix.indexOf("upx"));
        }
        return (WXEnvironment.getViewProt() / viewport) * Float.valueOf(Float.parseFloat(stringWithWXPostfix)).floatValue();
    }

    /* JADX WARN: Code restructure failed: missing block: B:33:0x0077, code lost:
        return r1 * (-1.0f);
     */
    /*
        Code decompiled incorrectly, please refer to instructions dump.
    */
    public static float fastGetFloat(String raw, float precision) {
        int i;
        boolean z;
        char charAt;
        char charAt2;
        float f = 0.0f;
        if (TextUtils.isEmpty(raw)) {
            return 0.0f;
        }
        if (raw.charAt(0) == '-') {
            i = 1;
            z = false;
        } else {
            i = raw.charAt(0) == '+' ? 1 : 0;
            z = true;
        }
        while (i < raw.length() && (charAt2 = raw.charAt(i)) >= '0' && charAt2 <= '9') {
            f = ((f * 10.0f) + charAt2) - 48.0f;
            i++;
        }
        if (i < raw.length() && raw.charAt(i) == '.') {
            int i2 = i + 1;
            int i3 = 10;
            for (int i4 = 0; i2 < raw.length() && i4 < precision && (charAt = raw.charAt(i2)) >= '0' && charAt <= '9'; i4++) {
                f += (charAt - '0') / i3;
                i3 *= 10;
                i2++;
            }
        }
        return f;
    }

    public static float fastGetFloat(String raw) {
        return fastGetFloat(raw, 2.14748365E9f);
    }

    public static int parseInt(String value) {
        try {
            if (TextUtils.isEmpty(value) || value.contains(Operators.DOT_STR)) {
                return 0;
            }
            return Integer.parseInt(value);
        } catch (NumberFormatException e) {
            if (WXEnvironment.isApkDebugable()) {
                WXLogUtils.e(WXLogUtils.getStackTrace(e));
                return 0;
            }
            return 0;
        }
    }

    public static int parseInt(Object value) {
        return parseInt(String.valueOf(value));
    }

    public static float parseFloat(Object value) {
        return parseFloat(String.valueOf(value));
    }

    public static float parseFloat(String value) {
        try {
            if (!TextUtils.isEmpty(value) && !TextUtils.equals(value, "null")) {
                return Float.parseFloat(value);
            }
            if (WXEnvironment.isApkDebugable()) {
                WXLogUtils.e("WXUtils parseFloat illegal value is " + value);
                return 0.0f;
            }
            return 0.0f;
        } catch (NumberFormatException e) {
            if (WXEnvironment.isApkDebugable()) {
                WXLogUtils.e(WXLogUtils.getStackTrace(e));
                return 0.0f;
            }
            return 0.0f;
        }
    }

    public static int getInt(Object value) {
        return getInteger(value, 0).intValue();
    }

    /* JADX WARN: Multi-variable type inference failed */
    /* JADX WARN: Type inference failed for: r9v10 */
    /* JADX WARN: Type inference failed for: r9v16, types: [java.lang.Integer] */
    /* JADX WARN: Type inference failed for: r9v17 */
    /* JADX WARN: Type inference failed for: r9v23, types: [java.lang.Integer] */
    /* JADX WARN: Type inference failed for: r9v24 */
    /* JADX WARN: Type inference failed for: r9v25 */
    public static Integer getInteger(Object value, Integer df) {
        if (value == null) {
            return df;
        }
        String trim = value.toString().trim();
        Integer num = sCache.get(trim);
        if (num != null) {
            return num;
        }
        String substring = trim.length() >= 2 ? trim.substring(trim.length() - 2, trim.length()) : "";
        if (TextUtils.equals("wx", substring)) {
            if (WXEnvironment.isApkDebugable()) {
                WXLogUtils.w("the value of " + value + " use wx unit, which will be not supported soon after.");
            }
            try {
                value = Integer.valueOf((int) transferWx(trim, 750.0f));
            } catch (NumberFormatException e) {
                WXLogUtils.e("Argument format error! value is " + value, e);
            } catch (Exception e2) {
                WXLogUtils.e("Argument error! value is " + value, e2);
            }
        } else if (TextUtils.equals("px", substring)) {
            if (trim.length() > 3 && (trim.endsWith("rpx") || trim.endsWith("upx"))) {
                try {
                    value = Integer.valueOf((int) transferRpxAndUpx(trim.substring(0, trim.length() - 3), 750.0f));
                } catch (NumberFormatException e3) {
                    WXLogUtils.e("Argument format error! value is " + value, e3);
                } catch (Exception e4) {
                    WXLogUtils.e("Argument error! value is " + value, e4);
                }
            } else {
                try {
                    String substring2 = trim.substring(0, trim.length() - 2);
                    if (!TextUtils.isEmpty(substring2) && substring2.contains(Operators.DOT_STR)) {
                        value = Integer.valueOf((int) parseFloat(substring2));
                    } else {
                        value = Integer.valueOf(Integer.parseInt(substring2));
                    }
                } catch (NumberFormatException e5) {
                    WXLogUtils.e("Argument format error! value is " + value, e5);
                } catch (Exception e6) {
                    WXLogUtils.e("Argument error! value is " + value, e6);
                }
            }
        } else {
            try {
            } catch (NumberFormatException e7) {
                WXLogUtils.e("Argument format error! value is " + value, e7);
            } catch (Exception e8) {
                WXLogUtils.e("Argument error! value is " + value, e8);
            }
            if (!TextUtils.isEmpty(trim)) {
                if (trim.contains(Operators.DOT_STR)) {
                    value = Integer.valueOf((int) parseFloat(trim));
                } else {
                    value = Integer.valueOf(Integer.parseInt(trim));
                }
            } else {
                if (WXEnvironment.isApkDebugable()) {
                    WXLogUtils.e("Argument value is null, df is" + df);
                }
                value = df;
            }
        }
        if (value != null && !value.equals(df)) {
            sCache.put(trim, value);
        }
        return value;
    }

    @Deprecated
    public static long getLong(Object value) {
        if (value == null) {
            return 0L;
        }
        String trim = value.toString().trim();
        if (trim.endsWith("wx")) {
            if (WXEnvironment.isApkDebugable()) {
                WXLogUtils.w("the value of " + value + " use wx unit, which will be not supported soon after.");
            }
            try {
                return transferWx(trim, 750.0f);
            } catch (NumberFormatException e) {
                WXLogUtils.e("Argument format error! value is " + value, e);
            } catch (Exception e2) {
                WXLogUtils.e("Argument error! value is " + value, e2);
            }
        } else if (trim.endsWith("px")) {
            if (trim.length() > 3 && (trim.endsWith("rpx") || trim.endsWith("upx"))) {
                try {
                    return transferRpxAndUpx(trim.substring(0, trim.length() - 3), 750.0f);
                } catch (NumberFormatException e3) {
                    WXLogUtils.e("Argument format error! value is " + value, e3);
                } catch (Exception e4) {
                    WXLogUtils.e("Argument error! value is " + value, e4);
                }
            } else {
                try {
                    return Long.parseLong(trim.substring(0, trim.indexOf("px")));
                } catch (NumberFormatException e5) {
                    WXLogUtils.e("Argument format error! value is " + value, e5);
                } catch (Exception e6) {
                    WXLogUtils.e("Argument error! value is " + value, e6);
                }
            }
        } else {
            try {
                return Long.parseLong(trim);
            } catch (NumberFormatException e7) {
                WXLogUtils.e("Argument format error! value is " + value, e7);
            } catch (Exception e8) {
                WXLogUtils.e("Argument error! value is " + value, e8);
            }
        }
        return 0L;
    }

    @Deprecated
    public static double getDouble(Object value) {
        if (value == null) {
            return 0.0d;
        }
        String trim = value.toString().trim();
        if (trim.endsWith("wx")) {
            if (WXEnvironment.isApkDebugable()) {
                WXLogUtils.w("the value of " + value + " use wx unit, which will be not supported soon after.");
            }
            try {
                return transferWx(trim, 750.0f);
            } catch (NumberFormatException e) {
                WXLogUtils.e("Argument format error! value is " + value, e);
            } catch (Exception e2) {
                WXLogUtils.e("Argument error! value is " + value, e2);
            }
        } else if (trim.endsWith("px")) {
            if (trim.length() > 3 && (trim.endsWith("rpx") || trim.endsWith("upx"))) {
                try {
                    return transferRpxAndUpx(trim.substring(0, trim.length() - 3), 750.0f);
                } catch (NumberFormatException e3) {
                    WXLogUtils.e("Argument format error! value is " + value, e3);
                } catch (Exception e4) {
                    WXLogUtils.e("Argument error! value is " + value, e4);
                }
            } else {
                try {
                    return Double.parseDouble(trim.substring(0, trim.indexOf("px")));
                } catch (NumberFormatException e5) {
                    WXLogUtils.e("Argument format error! value is " + value, e5);
                } catch (Exception e6) {
                    WXLogUtils.e("Argument error! value is " + value, e6);
                }
            }
        } else {
            try {
                return Double.parseDouble(trim);
            } catch (NumberFormatException e7) {
                WXLogUtils.e("Argument format error! value is " + value, e7);
            } catch (Exception e8) {
                WXLogUtils.e("Argument error! value is " + value, e8);
            }
        }
        return 0.0d;
    }

    @Deprecated
    public static boolean isTabletDevice() {
        try {
            return (WXEnvironment.getApplication().getResources().getConfiguration().screenLayout & 15) >= 3;
        } catch (Exception unused) {
            return false;
        }
    }

    public static Boolean getBoolean(Object value, Boolean df) {
        if (value == null) {
            return df;
        }
        if (TextUtils.equals(AbsoluteConst.FALSE, value.toString())) {
            return false;
        }
        if (TextUtils.equals(AbsoluteConst.TRUE, value.toString())) {
            return true;
        }
        return df;
    }

    public static long getAvailMemory(Context context) {
        ActivityManager.MemoryInfo memoryInfo = new ActivityManager.MemoryInfo();
        ((ActivityManager) context.getSystemService("activity")).getMemoryInfo(memoryInfo);
        WXLogUtils.w("app AvailMemory ---->>>" + (memoryInfo.availMem / 1048576));
        return memoryInfo.availMem / 1048576;
    }

    public static String getString(Object value, String df) {
        if (value == null) {
            return df;
        }
        if (value instanceof String) {
            return (String) value;
        }
        return value.toString();
    }

    public static int parseUnitOrPercent(String raw, int unit) {
        int lastIndexOf = raw.lastIndexOf(37);
        if (lastIndexOf != -1) {
            return parsePercent(raw.substring(0, lastIndexOf), unit);
        }
        return parseInt(raw);
    }

    private static int parsePercent(String raw, int unit) {
        return (int) ((Float.parseFloat(raw) / 100.0f) * unit);
    }

    public static String getBundleBanner(String content) {
        int i;
        int indexLineBreak;
        int indexOf = content.indexOf("/*!");
        if (indexOf == -1 || (indexLineBreak = indexLineBreak(content, (i = indexOf + 3))) == -1) {
            return null;
        }
        int i2 = indexLineBreak + 1;
        String substring = content.substring(i2, Integer.parseInt(content.substring(i, indexLineBreak)) + i2);
        int lastIndexOf = substring.lastIndexOf("!*/");
        if (lastIndexOf == -1) {
            return null;
        }
        String substring2 = substring.substring(0, lastIndexOf);
        StringBuilder sb = new StringBuilder();
        for (String str : splitLineBreak(substring2)) {
            sb.append(str.replaceFirst("\\*", ""));
        }
        return sb.toString();
    }

    private static int indexLineBreak(String str, int fromIndex) {
        int indexOf = str.indexOf("\r", fromIndex);
        if (indexOf == -1) {
            indexOf = str.indexOf("\n", fromIndex);
        }
        return indexOf == -1 ? str.indexOf("\r\n", fromIndex) : indexOf;
    }

    private static String[] splitLineBreak(String str) {
        String[] split = str.split("\r");
        if (split.length == 1) {
            split = str.split("\n");
        }
        return split.length == 1 ? str.split("\r\n") : split;
    }

    public static int getNumberInt(Object value, int defaultValue) {
        if (value == null) {
            return defaultValue;
        }
        if (value instanceof Number) {
            return ((Number) value).intValue();
        }
        try {
            String obj = value.toString();
            if (obj.indexOf(46) >= 0) {
                return (int) Float.parseFloat(value.toString());
            }
            return Integer.parseInt(obj);
        } catch (Exception unused) {
            return defaultValue;
        }
    }

    public static boolean checkGreyConfig(String group, String key, String defaultValue) {
        IWXConfigAdapter wxConfigAdapter = WXSDKManager.getInstance().getWxConfigAdapter();
        if (wxConfigAdapter == null) {
            return false;
        }
        double d = 100.0d;
        double random = Math.random() * 100.0d;
        try {
            d = Double.valueOf(wxConfigAdapter.getConfig(group, key, defaultValue)).doubleValue();
        } catch (Exception e) {
            e.printStackTrace();
        }
        return random < d;
    }

    public static long getFixUnixTime() {
        return sInterval + SystemClock.uptimeMillis();
    }
}
