package com.taobao.weex.utils;

import android.content.Context;
import android.content.res.Resources;
import android.graphics.Canvas;
import android.graphics.Path;
import android.graphics.Point;
import android.graphics.RectF;
import android.graphics.drawable.Drawable;
import android.graphics.drawable.LayerDrawable;
import android.os.Build;
import android.util.DisplayMetrics;
import android.view.View;
import android.view.ViewGroup;
import android.view.WindowManager;
import com.taobao.weex.WXEnvironment;
import com.taobao.weex.WXSDKInstance;
import com.taobao.weex.WXSDKManager;
import com.taobao.weex.common.Constants;
import com.taobao.weex.common.WXErrorCode;
import com.taobao.weex.common.WXRuntimeException;
import com.taobao.weex.ui.component.WXComponent;
import com.taobao.weex.ui.component.WXDiv;
import com.taobao.weex.ui.flat.widget.Widget;
import com.taobao.weex.ui.flat.widget.WidgetGroup;
import com.taobao.weex.ui.view.WXFrameLayout;
import com.taobao.weex.ui.view.border.BorderDrawable;
import io.dcloud.common.constant.AbsoluteConst;
import java.lang.annotation.Retention;
import java.lang.annotation.RetentionPolicy;
import java.util.concurrent.atomic.AtomicInteger;
/* loaded from: classes9.dex */
public class WXViewUtils {
    public static final int DIMENSION_UNSET = -1;
    @Deprecated
    public static final int OPAQUE = -1;
    @Deprecated
    public static final int TRANSLUCENT = -3;
    @Deprecated
    public static final int TRANSPARENT = -2;
    private static int mScreenHeight;
    private static int mScreenWidth;
    private static final boolean mUseWebPx = false;
    private static final AtomicInteger sNextGeneratedId = new AtomicInteger(1);

    @Retention(RetentionPolicy.SOURCE)
    /* loaded from: classes9.dex */
    public @interface Opacity {
    }

    public static int getOpacityFromColor(int color) {
        int i = color >>> 24;
        if (i == 255) {
            return -1;
        }
        return i == 0 ? -2 : -3;
    }

    public static int multiplyColorAlpha(int color, int alpha) {
        if (alpha == 255) {
            return color;
        }
        if (alpha == 0) {
            return color & 16777215;
        }
        return (color & 16777215) | ((((color >>> 24) * (alpha + (alpha >> 7))) >> 8) << 24);
    }

    public static int generateViewId() {
        AtomicInteger atomicInteger;
        int i;
        int i2;
        if (Build.VERSION.SDK_INT < 17) {
            do {
                atomicInteger = sNextGeneratedId;
                i = atomicInteger.get();
                i2 = i + 1;
                if (i2 > 16777215) {
                    i2 = 1;
                }
            } while (!atomicInteger.compareAndSet(i, i2));
            return i;
        }
        return View.generateViewId();
    }

    public static int getWeexHeight(String instanceId) {
        WXSDKInstance sDKInstance = WXSDKManager.getInstance().getSDKInstance(instanceId);
        if (sDKInstance != null) {
            int weexHeight = sDKInstance.getWeexHeight();
            return (weexHeight >= 0 || weexHeight == -2) ? weexHeight : getScreenHeight(WXEnvironment.sApplication);
        }
        return -3;
    }

    public static int getWeexWidth(String instanceId) {
        WXSDKInstance sDKInstance = WXSDKManager.getInstance().getSDKInstance(instanceId);
        if (sDKInstance != null) {
            int weexWidth = sDKInstance.getWeexWidth();
            return (weexWidth >= 0 || weexWidth == -2) ? weexWidth : getScreenWidth(WXEnvironment.sApplication);
        }
        return -3;
    }

    @Deprecated
    public static int getScreenWidth() {
        return getScreenWidth(WXEnvironment.sApplication);
    }

    @Deprecated
    public static int setScreenWidth(int screenWidth) {
        mScreenWidth = screenWidth;
        return screenWidth;
    }

    public static float getScreenDensity(Context ctx) {
        if (ctx != null) {
            try {
                return ctx.getResources().getDisplayMetrics().density;
            } catch (Exception e) {
                WXLogUtils.e("getScreenDensityDpi exception:" + e.getMessage());
                return 3.0f;
            }
        }
        return 3.0f;
    }

    public static void updateApplicationScreen(Context context) {
        if (context == null || WXEnvironment.sApplication == null) {
            return;
        }
        DisplayMetrics displayMetrics = context.getResources().getDisplayMetrics();
        DisplayMetrics displayMetrics2 = WXEnvironment.sApplication.getResources().getDisplayMetrics();
        displayMetrics2.heightPixels = displayMetrics.heightPixels;
        displayMetrics2.widthPixels = displayMetrics.widthPixels;
        displayMetrics2.density = displayMetrics.density;
        displayMetrics2.densityDpi = displayMetrics.densityDpi;
        displayMetrics2.scaledDensity = displayMetrics.scaledDensity;
        displayMetrics2.xdpi = displayMetrics.xdpi;
    }

    public static int getScreenWidth(Context ctx) {
        if (ctx != null) {
            Resources resources = ctx.getResources();
            mScreenWidth = resources.getDisplayMetrics().widthPixels;
            if (WXEnvironment.SETTING_FORCE_VERTICAL_SCREEN) {
                int i = resources.getDisplayMetrics().heightPixels;
                mScreenHeight = i;
                int i2 = mScreenWidth;
                if (i > i2) {
                    i = i2;
                }
                mScreenWidth = i;
            }
        } else if (WXEnvironment.isApkDebugable()) {
            throw new WXRuntimeException("Error Context is null When getScreenHeight");
        }
        return mScreenWidth;
    }

    public static int getStatusBarHeight(Context context) {
        Resources resources = context.getResources();
        int identifier = resources.getIdentifier("status_bar_height", "dimen", WXEnvironment.OS);
        if (identifier > 0) {
            return resources.getDimensionPixelSize(identifier);
        }
        return -1;
    }

    @Deprecated
    public static int getScreenHeight() {
        return getScreenHeight(WXEnvironment.sApplication);
    }

    public static int getScreenHeight(String instanceId) {
        return WXSDKManager.getInstance().getSDKInstance(instanceId).isFullScreenHeightEnabled() ? getFullScreenHeight(WXEnvironment.sApplication) : getScreenHeight(WXEnvironment.sApplication);
    }

    public static int getFullScreenHeight(Context cxt) {
        WindowManager windowManager;
        if (cxt != null) {
            Resources resources = cxt.getResources();
            if (Build.VERSION.SDK_INT >= 17 && (windowManager = (WindowManager) cxt.getSystemService("window")) != null && windowManager.getDefaultDisplay() != null) {
                Point point = new Point();
                windowManager.getDefaultDisplay().getRealSize(point);
                mScreenHeight = point.y;
            } else {
                mScreenHeight = cxt.getResources().getDisplayMetrics().heightPixels;
            }
            if (WXEnvironment.SETTING_FORCE_VERTICAL_SCREEN) {
                int i = resources.getDisplayMetrics().widthPixels;
                mScreenWidth = i;
                int i2 = mScreenHeight;
                if (i2 > i) {
                    i = i2;
                }
                mScreenHeight = i;
            }
        } else if (WXEnvironment.isApkDebugable()) {
            throw new WXRuntimeException("Error Context is null When getScreenHeight");
        }
        return mScreenHeight;
    }

    public static int getScreenHeight(Context cxt) {
        if (cxt != null) {
            Resources resources = cxt.getResources();
            mScreenHeight = resources.getDisplayMetrics().heightPixels;
            if (WXEnvironment.SETTING_FORCE_VERTICAL_SCREEN) {
                int i = resources.getDisplayMetrics().widthPixels;
                mScreenWidth = i;
                int i2 = mScreenHeight;
                if (i2 > i) {
                    i = i2;
                }
                mScreenHeight = i;
            }
        } else if (WXEnvironment.isApkDebugable()) {
            throw new WXRuntimeException("Error Context is null When getScreenHeight");
        }
        return mScreenHeight;
    }

    @Deprecated
    public static float getRealPxByWidth(float pxValue) {
        return realPxByWidth(pxValue, 750.0f);
    }

    public static float getRealPxByWidth(float pxValue, float customViewport) {
        return realPxByWidth(pxValue, customViewport);
    }

    public static float getRealPxByWidth(float pxValue, int customViewport) {
        return realPxByWidth(pxValue, customViewport);
    }

    private static float realPxByWidth(float pxValue, float customViewport) {
        if (Float.isNaN(pxValue)) {
            return pxValue;
        }
        float screenWidth = (pxValue * getScreenWidth()) / customViewport;
        double d = screenWidth;
        if (d <= 0.005d || screenWidth >= 1.0f) {
            return (float) Math.rint(d);
        }
        return 1.0f;
    }

    @Deprecated
    public static float getRealSubPxByWidth(float pxValue) {
        return realSubPxByWidth(pxValue, 750.0f);
    }

    public static float getRealSubPxByWidth(float pxValue, float customViewport) {
        return realSubPxByWidth(pxValue, customViewport);
    }

    public static float getRealSubPxByWidth(float pxValue, int customViewport) {
        return realSubPxByWidth(pxValue, customViewport);
    }

    private static float realSubPxByWidth(float pxValue, float customViewport) {
        if (Float.isNaN(pxValue)) {
            return pxValue;
        }
        float screenWidth = (pxValue * getScreenWidth()) / customViewport;
        if (screenWidth <= 0.005d || screenWidth >= 1.0f) {
            return screenWidth;
        }
        return 1.0f;
    }

    @Deprecated
    public static float getWeexPxByReal(float pxValue) {
        return weexPxByReal(pxValue, 750.0f);
    }

    public static float getWeexPxByReal(float pxValue, float customViewport) {
        return weexPxByReal(pxValue, customViewport);
    }

    public static float getWeexPxByReal(float pxValue, int customViewport) {
        return weexPxByReal(pxValue, customViewport);
    }

    private static float weexPxByReal(float pxValue, float customViewport) {
        return Float.isNaN(pxValue) ? pxValue : (pxValue * customViewport) / getScreenWidth();
    }

    @Deprecated
    public static float getRealPxByWidth2(float pxValue) {
        return realPxByWidth2(pxValue, 750.0f);
    }

    public static int getRealPxByWidth2(float pxValue, float customViewport) {
        return realPxByWidth2(pxValue, customViewport);
    }

    public static int getRealPxByWidth2(float pxValue, int customViewport) {
        return realPxByWidth2(pxValue, customViewport);
    }

    private static int realPxByWidth2(float pxValue, float customViewport) {
        float screenWidth = (pxValue * getScreenWidth()) / customViewport;
        if (screenWidth <= 0.005d || screenWidth >= 1.0f) {
            return ((int) screenWidth) - 1;
        }
        return 1;
    }

    @Deprecated
    public static float getWebPxByWidth(float pxValue) {
        return webPxByWidth(pxValue, 750.0f);
    }

    public static float getWebPxByWidth(float pxValue, float customViewport) {
        return webPxByWidth(pxValue, customViewport);
    }

    public static float getWebPxByWidth(float pxValue, int customViewport) {
        return webPxByWidth(pxValue, customViewport);
    }

    private static float webPxByWidth(float pxValue, float customViewport) {
        double d = pxValue;
        if (d >= -1.9999d || d <= -2.005d) {
            float screenWidth = (pxValue * customViewport) / getScreenWidth();
            if (screenWidth <= 0.005d || screenWidth >= 1.0f) {
                return screenWidth;
            }
            return 1.0f;
        }
        return Float.NaN;
    }

    public static int dip2px(float dpValue) {
        float f;
        try {
            f = WXEnvironment.getApplication().getResources().getDisplayMetrics().density;
        } catch (Exception e) {
            WXLogUtils.e("[WXViewUtils] dip2px:", e);
            f = 2.0f;
        }
        float f2 = (dpValue * f) + 0.5f;
        if (f2 <= 0.0f || f2 >= 1.0f) {
            return (int) f2;
        }
        return 1;
    }

    public static boolean onScreenArea(View view) {
        int height;
        if (view == null || view.getVisibility() != 0) {
            return false;
        }
        int[] iArr = new int[2];
        view.getLocationOnScreen(iArr);
        ViewGroup.LayoutParams layoutParams = view.getLayoutParams();
        if (layoutParams != null) {
            height = layoutParams.height;
        } else {
            height = view.getHeight();
        }
        return (iArr[1] > 0 && iArr[1] - getScreenHeight(WXEnvironment.sApplication) < 0) || (height + iArr[1] > 0 && iArr[1] <= 0);
    }

    public static void setBackGround(View view, Drawable drawable, WXComponent component) {
        if (Build.VERSION.SDK_INT < 16) {
            view.setBackgroundDrawable(drawable);
            return;
        }
        try {
            view.setBackground(drawable);
        } catch (Exception unused) {
            if (component == null) {
                return;
            }
            WXExceptionUtils.commitCriticalExceptionRT(component.getInstanceId(), WXErrorCode.WX_RENDER_ERR_TEXTURE_SETBACKGROUND, component.getComponentType() + " setBackGround for android view", WXErrorCode.WX_RENDER_ERR_TEXTURE_SETBACKGROUND.getErrorMsg() + ": TextureView doesn't support displaying a background drawable!", null);
        }
    }

    public static BorderDrawable getBorderDrawable(View view) {
        Drawable background = view.getBackground();
        if (background instanceof BorderDrawable) {
            return (BorderDrawable) background;
        }
        if (background instanceof LayerDrawable) {
            LayerDrawable layerDrawable = (LayerDrawable) background;
            if (layerDrawable.getNumberOfLayers() > 1) {
                for (int i = 0; i < layerDrawable.getNumberOfLayers(); i++) {
                    Drawable drawable = layerDrawable.getDrawable(i);
                    if (drawable instanceof BorderDrawable) {
                        return (BorderDrawable) drawable;
                    }
                }
                return null;
            }
            return null;
        }
        return null;
    }

    public static void clipCanvasWithinBorderBox(View targetView, Canvas canvas) {
        if (clipCanvasDueToAndroidVersion(canvas) && clipCanvasIfAnimationExist(targetView)) {
            BorderDrawable borderDrawable = getBorderDrawable(targetView);
            if (borderDrawable instanceof BorderDrawable) {
                BorderDrawable borderDrawable2 = borderDrawable;
                if (borderDrawable2.isRounded() && clipCanvasIfBackgroundImageExist(targetView, borderDrawable2)) {
                    RectF rectF = new RectF(0.0f, 0.0f, targetView.getWidth(), targetView.getHeight());
                    Path contentPath = borderDrawable2.getContentPath(rectF);
                    if (targetView instanceof WXFrameLayout) {
                        WXDiv component = ((WXFrameLayout) targetView).getComponent();
                        if (component != null) {
                            Object obj = component.getAttrs().get(Constants.Name.ROTATE_FIX);
                            if (obj != null && obj.toString().equals(AbsoluteConst.TRUE)) {
                                canvas.clipRect(rectF);
                                return;
                            } else if ((component.getStyles() == null || !"hidden".equals(component.getStyles().getOverflow())) && Build.VERSION.SDK_INT >= 24) {
                                return;
                            } else {
                                canvas.clipPath(contentPath);
                                return;
                            }
                        }
                        return;
                    }
                    canvas.clipPath(contentPath);
                }
            }
        }
    }

    public static void clipCanvasWithinBorderBox(Widget widget, Canvas canvas) {
        BorderDrawable backgroundAndBorder;
        if (clipCanvasDueToAndroidVersion(canvas) && clipCanvasIfAnimationExist(null) && (backgroundAndBorder = widget.getBackgroundAndBorder()) != null) {
            if (backgroundAndBorder.isRounded() && clipCanvasIfBackgroundImageExist(widget, backgroundAndBorder)) {
                canvas.clipPath(backgroundAndBorder.getContentPath(new RectF(0.0f, 0.0f, widget.getBorderBox().width(), widget.getBorderBox().height())));
            } else {
                canvas.clipRect(widget.getBorderBox());
            }
        }
    }

    private static boolean clipCanvasDueToAndroidVersion(Canvas canvas) {
        return Build.VERSION.SDK_INT >= 18 || !canvas.isHardwareAccelerated();
    }

    private static boolean clipCanvasIfAnimationExist(View targetView) {
        return Build.VERSION.SDK_INT < 24;
    }

    private static boolean clipCanvasIfBackgroundImageExist(View targetView, BorderDrawable borderDrawable) {
        if (targetView instanceof ViewGroup) {
            ViewGroup viewGroup = (ViewGroup) targetView;
            int childCount = viewGroup.getChildCount();
            for (int i = 0; i < childCount; i++) {
                BorderDrawable borderDrawable2 = getBorderDrawable(viewGroup.getChildAt(i));
                if (borderDrawable2 != null && borderDrawable2.hasImage() && Build.VERSION.SDK_INT < 21) {
                    return false;
                }
            }
            return true;
        }
        return true;
    }

    private static boolean clipCanvasIfBackgroundImageExist(Widget widget, BorderDrawable borderDrawable) {
        if (widget instanceof WidgetGroup) {
            for (Widget widget2 : ((WidgetGroup) widget).getChildren()) {
                if (widget2.getBackgroundAndBorder().hasImage() && Build.VERSION.SDK_INT < 21) {
                    return false;
                }
            }
            return true;
        }
        return true;
    }
}
