package com.taobao.weex.utils.cache;

import com.taobao.weex.bridge.ModuleFactory;
import com.taobao.weex.bridge.WXModuleManager;
import com.taobao.weex.ui.IFComponentHolder;
import com.taobao.weex.ui.WXComponentRegistry;
import com.taobao.weex.ui.config.AutoScanConfigRegister;
import com.taobao.weex.utils.WXLogUtils;
import java.util.Map;
import java.util.concurrent.ConcurrentHashMap;
/* loaded from: classes9.dex */
public class RegisterCache {
    private static RegisterCache registerCache;
    private static Map<String, ModuleCache> moduleCacheMap = new ConcurrentHashMap();
    private static Map<String, ComponentCache> componentCacheMap = new ConcurrentHashMap();
    private boolean enable = false;
    private boolean enableAutoScan = true;
    private volatile boolean finished = false;
    private volatile int doNotCacheSize = Integer.MAX_VALUE;

    public static RegisterCache getInstance() {
        if (registerCache == null) {
            synchronized (RegisterCache.class) {
                if (registerCache == null) {
                    registerCache = new RegisterCache();
                }
            }
        }
        return registerCache;
    }

    private RegisterCache() {
    }

    public void setEnable(boolean enable) {
        this.enable = enable;
    }

    private boolean enableCache() {
        return this.enable;
    }

    private boolean canCache() {
        return enableCache() && !this.finished && getDoNotCacheSize() < 1;
    }

    public boolean enableAutoScan() {
        return this.enableAutoScan;
    }

    public void setEnableAutoScan(boolean enableAutoScan) {
        if (this.enableAutoScan != enableAutoScan) {
            if (enableAutoScan) {
                AutoScanConfigRegister.doScanConfig();
            }
            this.enableAutoScan = enableAutoScan;
        }
    }

    private int getDoNotCacheSize() {
        int i = this.doNotCacheSize;
        this.doNotCacheSize = i - 1;
        return i;
    }

    public void setDoNotCacheSize(int doNotCacheSize) {
        this.doNotCacheSize = doNotCacheSize;
    }

    public boolean idle(boolean atCreateInstance) {
        if (this.finished) {
            return true;
        }
        String str = atCreateInstance ? "idle from create instance" : "idle from external";
        WXLogUtils.e(str + " cache size is " + (moduleCacheMap.size() + componentCacheMap.size()));
        this.finished = true;
        CacheComponentRegister();
        CacheModuleRegister();
        return true;
    }

    public boolean cacheModule(final String moduleName, final ModuleFactory factory, final boolean global) {
        if (canCache()) {
            try {
                moduleCacheMap.put(moduleName, new ModuleCache(moduleName, factory, global));
                return true;
            } catch (Exception unused) {
                return false;
            }
        }
        return false;
    }

    public boolean cacheComponent(final String type, final IFComponentHolder holder, final Map<String, Object> componentInfo) {
        if (canCache()) {
            try {
                componentCacheMap.put(type, new ComponentCache(type, holder, componentInfo));
                return true;
            } catch (Exception unused) {
                return false;
            }
        }
        return false;
    }

    private void CacheComponentRegister() {
        if (componentCacheMap.isEmpty()) {
            return;
        }
        WXComponentRegistry.registerComponent(componentCacheMap);
    }

    private void CacheModuleRegister() {
        if (moduleCacheMap.isEmpty()) {
            return;
        }
        WXModuleManager.registerModule(moduleCacheMap);
    }

    /* loaded from: classes9.dex */
    public class ModuleCache {
        public final ModuleFactory factory;
        public final boolean global;
        public final String name;

        ModuleCache(String moduleName, ModuleFactory factory, boolean global) {
            this.name = moduleName;
            this.factory = factory;
            this.global = global;
        }
    }

    /* loaded from: classes9.dex */
    public class ComponentCache {
        public final Map<String, Object> componentInfo;
        public final IFComponentHolder holder;
        public final String type;

        ComponentCache(String type, IFComponentHolder holder, Map<String, Object> componentInfo) {
            this.type = type;
            this.componentInfo = componentInfo;
            this.holder = holder;
        }
    }
}
