package io.dcloud.feature.contacts;

import android.accounts.Account;
import android.accounts.AccountManager;
import android.content.ContentProviderOperation;
import android.content.ContentProviderResult;
import android.content.ContentUris;
import android.content.ContentValues;
import android.content.Context;
import android.content.OperationApplicationException;
import android.database.Cursor;
import android.net.Uri;
import android.os.RemoteException;
import android.provider.ContactsContract;
import android.util.Base64;
import android.util.Log;
import com.taobao.weex.bridge.WXBridgeManager;
import com.taobao.weex.common.Constants;
import com.taobao.weex.el.parse.Operators;
import com.taobao.weex.utils.WXUtils;
import io.dcloud.common.adapter.util.DeviceInfo;
import io.dcloud.common.adapter.util.Logger;
import io.dcloud.common.constant.AbsoluteConst;
import io.dcloud.common.util.ExifInterface;
import io.dcloud.common.util.JSONUtil;
import io.dcloud.feature.contacts.ContactAccessor;
import java.io.ByteArrayOutputStream;
import java.io.FileNotFoundException;
import java.io.IOException;
import java.io.InputStream;
import java.net.URL;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.Iterator;
import java.util.Locale;
import java.util.Map;
import org.json.JSONArray;
import org.json.JSONException;
import org.json.JSONObject;
/* loaded from: classes20.dex */
public class ContactAccessorImpl extends ContactAccessor {
    private static final String EMAIL_REGEXP = ".+@.+\\.+.+";
    private static final long MAX_PHOTO_SIZE = 1048576;
    private static final String Tag = "contacts";
    private static final Map<String, String> dbMap;

    private String getAddressType(int type) {
        return type != 1 ? type != 2 ? "other" : "work" : "home";
    }

    private String getContactType(int type) {
        return type != 0 ? type != 1 ? type != 2 ? type != 4 ? "other" : "mobile" : "work" : "home" : "custom";
    }

    private String getOrgType(int type) {
        return type != 0 ? type != 1 ? "other" : "work" : "custom";
    }

    private String getPhoneType(int type) {
        switch (type) {
            case 0:
                return "custom";
            case 1:
                return "home";
            case 2:
                return "mobile";
            case 3:
                return "work";
            case 4:
                return "work fax";
            case 5:
                return "home fax";
            case 6:
                return "pager";
            case 7:
            case 12:
            default:
                return "other";
            case 8:
                return WXBridgeManager.METHOD_CALLBACK;
            case 9:
                return "car";
            case 10:
                return "company main";
            case 11:
                return "isdn";
            case 13:
                return "other fax";
            case 14:
                return "radio";
            case 15:
                return "telex";
            case 16:
                return "tty tdd";
            case 17:
                return "work mobile";
            case 18:
                return "work pager";
            case 19:
                return "assistant";
            case 20:
                return "mms";
        }
    }

    static {
        HashMap hashMap = new HashMap();
        dbMap = hashMap;
        hashMap.put("id", "raw_contact_id");
        hashMap.put("displayName", "display_name");
        hashMap.put("name", "data1");
        hashMap.put("name.formatted", "data1");
        hashMap.put("name.familyName", "data3");
        hashMap.put("name.givenName", "data2");
        hashMap.put("name.middleName", "data5");
        hashMap.put("name.honorificPrefix", "data4");
        hashMap.put("name.honorificSuffix", "data6");
        hashMap.put("nickname", "data1");
        hashMap.put("phoneNumbers", "data1");
        hashMap.put("phoneNumbers.value", "data1");
        hashMap.put("emails", "data1");
        hashMap.put("emails.value", "data1");
        hashMap.put("addresses", "data1");
        hashMap.put("addresses.formatted", "data1");
        hashMap.put("addresses.streetAddress", "data4");
        hashMap.put("addresses.locality", "data7");
        hashMap.put("addresses.region", "data8");
        hashMap.put("addresses.postalCode", "data9");
        hashMap.put("addresses.country", "data10");
        hashMap.put("ims", "data1");
        hashMap.put("ims.value", "data1");
        hashMap.put("organizations", "data1");
        hashMap.put("organizations.name", "data1");
        hashMap.put("organizations.department", "data5");
        hashMap.put("organizations.title", "data4");
        hashMap.put("birthday", "vnd.android.cursor.item/contact_event");
        hashMap.put("note", "data1");
        hashMap.put("photos.value", "vnd.android.cursor.item/photo");
        hashMap.put("urls", "data1");
        hashMap.put("urls.value", "data1");
    }

    public ContactAccessorImpl(Context app) {
        this.mApp = app;
    }

    @Override // io.dcloud.feature.contacts.ContactAccessor
    public JSONArray search(JSONArray fields, JSONObject options) {
        JSONArray jSONArray;
        String[] selectionArgs;
        String str;
        int i = Integer.MAX_VALUE;
        boolean z = true;
        if (options != null) {
            jSONArray = JSONUtil.getJSONArray(options, Constants.Name.FILTER);
            if (!options.optBoolean("multiple", true)) {
                i = 1;
            }
        } else {
            jSONArray = null;
        }
        if (jSONArray != null && jSONArray.length() != 0 && (jSONArray.length() != 1 || !jSONArray.optJSONObject(0).isNull("field"))) {
            z = false;
        }
        if (z) {
            str = null;
            selectionArgs = null;
        } else {
            ContactAccessor.WhereOptions buildWhereClause = buildWhereClause(jSONArray);
            String selection = buildWhereClause.getSelection();
            selectionArgs = buildWhereClause.getSelectionArgs();
            str = selection;
        }
        Cursor query = this.mApp.getContentResolver().query(ContactsContract.Data.CONTENT_URI, new String[]{"raw_contact_id"}, str, selectionArgs, "raw_contact_id ASC");
        ArrayList<String> arrayList = new ArrayList<>();
        while (query.moveToNext()) {
            arrayList.add(query.getString(query.getColumnIndex("raw_contact_id")));
        }
        query.close();
        if (arrayList.size() == 0) {
            return new JSONArray();
        }
        ContactAccessor.WhereOptions buildIdClause = buildIdClause(arrayList);
        return populateContactArray(i, buildPopulationSet(fields), this.mApp.getContentResolver().query(ContactsContract.Data.CONTENT_URI, null, buildIdClause.getSelection(), buildIdClause.getSelectionArgs(), "raw_contact_id ASC"));
    }

    /*  JADX ERROR: JadxRuntimeException in pass: BlockProcessor
        jadx.core.utils.exceptions.JadxRuntimeException: Unreachable block: B:59:0x0198
        	at jadx.core.dex.visitors.blocks.BlockProcessor.checkForUnreachableBlocks(BlockProcessor.java:81)
        	at jadx.core.dex.visitors.blocks.BlockProcessor.processBlocksTree(BlockProcessor.java:47)
        	at jadx.core.dex.visitors.blocks.BlockProcessor.visit(BlockProcessor.java:39)
        */
    private org.json.JSONArray populateContactArray(int r34, java.util.HashMap<java.lang.String, java.lang.Boolean> r35, android.database.Cursor r36) {
        /*
            Method dump skipped, instructions count: 1114
            To view this dump add '--comments-level debug' option
        */
        throw new UnsupportedOperationException("Method not decompiled: io.dcloud.feature.contacts.ContactAccessorImpl.populateContactArray(int, java.util.HashMap, android.database.Cursor):org.json.JSONArray");
    }

    private ContactAccessor.WhereOptions buildIdClause(ArrayList<String> contactIds) {
        ContactAccessor.WhereOptions whereOptions = new ContactAccessor.WhereOptions();
        Iterator<String> it = contactIds.iterator();
        StringBuffer stringBuffer = new StringBuffer(Operators.BRACKET_START_STR);
        while (it.hasNext()) {
            stringBuffer.append("'" + it.next() + "'");
            if (it.hasNext()) {
                stringBuffer.append(",");
            }
        }
        stringBuffer.append(Operators.BRACKET_END_STR);
        whereOptions.setSelection("raw_contact_id IN " + stringBuffer.toString());
        whereOptions.setSelectionArgs(null);
        return whereOptions;
    }

    private JSONObject populateContact(HashMap<String, Boolean> populate, JSONObject contact, JSONArray organizations, JSONArray addresses, JSONArray phones, JSONArray emails, JSONArray ims, JSONArray websites, JSONArray photos) {
        try {
            if (phones.length() > 0 || isRequired("phoneNumbers", populate)) {
                contact.put("phoneNumbers", phones);
            }
            if (emails.length() > 0 || isRequired("emails", populate)) {
                contact.put("emails", emails);
            }
            if (addresses.length() > 0 || isRequired("addresses", populate)) {
                contact.put("addresses", addresses);
            }
            if (ims.length() > 0 || isRequired("ims", populate)) {
                contact.put("ims", ims);
            }
            if (organizations.length() > 0 || isRequired("organizations", populate)) {
                contact.put("organizations", organizations);
            }
            if (websites.length() > 0 || isRequired("urls", populate)) {
                contact.put("urls", websites);
            }
            if (photos.length() > 0 || isRequired("photos", populate)) {
                contact.put("photos", photos);
            }
        } catch (JSONException e) {
            Log.e("ContactsAccessor", "e.getMessage()==" + e.getMessage(), e);
        }
        return contact;
    }

    private ContactAccessor.WhereOptions buildWhereClause(JSONArray searchArr) {
        int length;
        ContactAccessor.WhereOptions whereOptions = new ContactAccessor.WhereOptions();
        if (searchArr != null && (length = searchArr.length()) > 0) {
            StringBuffer stringBuffer = new StringBuffer();
            ArrayList arrayList = new ArrayList();
            boolean z = false;
            for (int i = 0; i < length; i++) {
                JSONObject jSONObject = JSONUtil.getJSONObject(searchArr, i);
                String string = JSONUtil.getString(jSONObject, "field");
                String formatLogic = formatLogic(JSONUtil.getString(jSONObject, "logic"));
                String string2 = JSONUtil.getString(jSONObject, "value");
                if (string != null) {
                    Map<String, String> map = dbMap;
                    if (map.containsKey(string) && string2 != null && !string2.equals("")) {
                        String replace = string2.replace(Operators.CONDITION_IF, '_').replace('*', WXUtils.PERCENT);
                        stringBuffer.append(Operators.BRACKET_START_STR + map.get(string) + " LIKE ? )");
                        if (i != length - 1) {
                            stringBuffer.append(Operators.SPACE_STR + formatLogic + Operators.SPACE_STR);
                        }
                        arrayList.add(replace);
                        z = true;
                    }
                }
            }
            if (z) {
                whereOptions.setSelection(stringBuffer.toString());
                String[] strArr = new String[arrayList.size()];
                arrayList.toArray(strArr);
                whereOptions.setSelectionArgs(strArr);
            }
        }
        return whereOptions;
    }

    private String formatLogic(String unFormatLogic) {
        String lowerCase = unFormatLogic != null ? unFormatLogic.toLowerCase(Locale.ENGLISH) : "or";
        return (lowerCase.equals("not") || lowerCase.equals("and")) ? lowerCase : "or";
    }

    private boolean isSearchAll(JSONArray fields) {
        if (fields.length() == 1) {
            try {
                if ("*".equals(fields.getString(0))) {
                    return true;
                }
            } catch (JSONException unused) {
            }
        }
        return false;
    }

    private JSONObject organizationQuery(Cursor cursor) {
        JSONObject jSONObject = new JSONObject();
        try {
            jSONObject.put("id", cursor.getString(cursor.getColumnIndex("_id")));
            jSONObject.put("pref", false);
            jSONObject.put("type", getOrgType(cursor.getInt(cursor.getColumnIndex("data2"))));
            jSONObject.put("department", cursor.getString(cursor.getColumnIndex("data5")));
            jSONObject.put("name", cursor.getString(cursor.getColumnIndex("data1")));
            jSONObject.put(AbsoluteConst.JSON_KEY_TITLE, cursor.getString(cursor.getColumnIndex("data4")));
        } catch (JSONException e) {
            Log.e("ContactsAccessor", e.getMessage(), e);
        }
        return jSONObject;
    }

    private JSONObject addressQuery(Cursor cursor) {
        JSONObject jSONObject = new JSONObject();
        try {
            jSONObject.put("id", cursor.getString(cursor.getColumnIndex("_id")));
            jSONObject.put("pref", false);
            jSONObject.put("type", getAddressType(cursor.getInt(cursor.getColumnIndex("data2"))));
            jSONObject.put("formatted", cursor.getString(cursor.getColumnIndex("data1")));
            jSONObject.put("streetAddress", cursor.getString(cursor.getColumnIndex("data4")));
            jSONObject.put("locality", cursor.getString(cursor.getColumnIndex("data7")));
            jSONObject.put("region", cursor.getString(cursor.getColumnIndex("data8")));
            jSONObject.put("postalCode", cursor.getString(cursor.getColumnIndex("data9")));
            jSONObject.put("country", cursor.getString(cursor.getColumnIndex("data10")));
        } catch (JSONException e) {
            Log.e("ContactsAccessor", e.getMessage(), e);
        }
        return jSONObject;
    }

    private JSONObject nameQuery(Cursor cursor) {
        JSONObject jSONObject = new JSONObject();
        try {
            String string = cursor.getString(cursor.getColumnIndex("data3"));
            String string2 = cursor.getString(cursor.getColumnIndex("data2"));
            String string3 = cursor.getString(cursor.getColumnIndex("data5"));
            String string4 = cursor.getString(cursor.getColumnIndex("data4"));
            String string5 = cursor.getString(cursor.getColumnIndex("data6"));
            StringBuffer stringBuffer = new StringBuffer("");
            if (string4 != null) {
                stringBuffer.append(string4 + Operators.SPACE_STR);
            }
            if (string2 != null) {
                stringBuffer.append(string2 + Operators.SPACE_STR);
            }
            if (string3 != null) {
                stringBuffer.append(string3 + Operators.SPACE_STR);
            }
            if (string != null) {
                stringBuffer.append(string + Operators.SPACE_STR);
            }
            if (string5 != null) {
                stringBuffer.append(string5 + Operators.SPACE_STR);
            }
            jSONObject.put("familyName", string);
            jSONObject.put("givenName", string2);
            jSONObject.put("middleName", string3);
            jSONObject.put("honorificPrefix", string4);
            jSONObject.put("honorificSuffix", string5);
            jSONObject.put("formatted", stringBuffer);
        } catch (JSONException e) {
            Log.e("ContactsAccessor", e.getMessage(), e);
        }
        return jSONObject;
    }

    private JSONObject phoneQuery(Cursor cursor) {
        JSONObject jSONObject = new JSONObject();
        try {
            jSONObject.put("id", cursor.getString(cursor.getColumnIndex("_id")));
            jSONObject.put("pref", false);
            jSONObject.put("value", cursor.getString(cursor.getColumnIndex("data1")));
            jSONObject.put("type", getPhoneType(cursor.getInt(cursor.getColumnIndex("data2"))));
        } catch (JSONException e) {
            Log.e("ContactsAccessor", e.getMessage(), e);
        } catch (Exception e2) {
            Log.e("ContactsAccessor", e2.getMessage(), e2);
        }
        return jSONObject;
    }

    private JSONObject emailQuery(Cursor cursor) {
        JSONObject jSONObject = new JSONObject();
        try {
            jSONObject.put("id", cursor.getString(cursor.getColumnIndex("_id")));
            jSONObject.put("pref", false);
            jSONObject.put("value", cursor.getString(cursor.getColumnIndex("data1")));
            jSONObject.put("type", getContactType(cursor.getInt(cursor.getColumnIndex("data2"))));
        } catch (JSONException e) {
            Log.e("ContactsAccessor", e.getMessage(), e);
        }
        return jSONObject;
    }

    private JSONObject imQuery(Cursor cursor) {
        JSONObject jSONObject = new JSONObject();
        try {
            jSONObject.put("id", cursor.getString(cursor.getColumnIndex("_id")));
            jSONObject.put("pref", false);
            jSONObject.put("value", cursor.getString(cursor.getColumnIndex("data1")));
            jSONObject.put("type", getContactType(cursor.getInt(cursor.getColumnIndex("data2"))));
        } catch (JSONException e) {
            Log.e("ContactsAccessor", e.getMessage(), e);
        }
        return jSONObject;
    }

    private JSONObject urlQuery(Cursor cursor) {
        JSONObject jSONObject = new JSONObject();
        try {
            jSONObject.put("id", cursor.getString(cursor.getColumnIndex("_id")));
            jSONObject.put("pref", false);
            jSONObject.put("value", cursor.getString(cursor.getColumnIndex("data1")));
            jSONObject.put("type", getContactType(cursor.getInt(cursor.getColumnIndex("data2"))));
        } catch (JSONException e) {
            Log.e("ContactsAccessor", e.getMessage(), e);
        }
        return jSONObject;
    }

    private JSONObject photoQuery(Cursor cursor, long contactId) {
        byte[] bArr;
        String str;
        JSONObject jSONObject = new JSONObject();
        try {
            jSONObject.put("id", cursor.getString(cursor.getColumnIndex("_id")));
            jSONObject.put("pref", false);
            jSONObject.put("type", "url");
            InputStream openContactPhotoInputStream = ContactsContract.Contacts.openContactPhotoInputStream(this.mApp.getContentResolver(), ContentUris.withAppendedId(ContactsContract.Contacts.CONTENT_URI, contactId));
            try {
                openContactPhotoInputStream.read(new byte[openContactPhotoInputStream.available()]);
                str = "data:image/png;base64," + Base64.encodeToString(bArr, 2);
            } catch (Exception e) {
                e.printStackTrace();
            }
            jSONObject.put("value", str);
        } catch (JSONException e2) {
            Log.e("ContactsAccessor", e2.getMessage(), e2);
        }
        return jSONObject;
    }

    @Override // io.dcloud.feature.contacts.ContactAccessor
    public boolean save(JSONObject contact) {
        Account[] accounts = AccountManager.get(this.mApp).getAccounts();
        Account account = null;
        if (accounts.length == 1) {
            account = accounts[0];
        } else if (accounts.length > 1) {
            int length = accounts.length;
            int i = 0;
            while (true) {
                if (i >= length) {
                    break;
                }
                Account account2 = accounts[i];
                if (account2.type.contains("eas") && account2.name.matches(EMAIL_REGEXP)) {
                    account = account2;
                    break;
                }
                i++;
            }
            if (account == null) {
                int length2 = accounts.length;
                int i2 = 0;
                while (true) {
                    if (i2 >= length2) {
                        break;
                    }
                    Account account3 = accounts[i2];
                    if (account3.type.contains("com.google") && account3.name.matches(EMAIL_REGEXP)) {
                        account = account3;
                        break;
                    }
                    i2++;
                }
            }
            if (account == null) {
                int length3 = accounts.length;
                int i3 = 0;
                while (true) {
                    if (i3 >= length3) {
                        break;
                    }
                    Account account4 = accounts[i3];
                    if (account4.name.matches(EMAIL_REGEXP)) {
                        account = account4;
                        break;
                    }
                    i3++;
                }
            }
            if (account == null) {
                account = accounts[0];
            }
        }
        String jsonString = getJsonString(contact, "id");
        if (jsonString == null || "null".equals(jsonString)) {
            return createNewContact(contact, account);
        }
        return modifyContact(contact, account, jsonString);
    }

    private void modifyContactOption(ArrayList<ContentProviderOperation> ops, JSONArray data, String rawId, String mimeType, String dataKey, String typeKey) {
        ops.add(ContentProviderOperation.newDelete(ContactsContract.Data.CONTENT_URI).withSelection("raw_contact_id=? and mimetype=?", new String[]{String.valueOf(rawId), mimeType}).build());
        if (data != null) {
            for (int i = 0; i < data.length(); i++) {
                JSONObject optJSONObject = data.optJSONObject(i);
                if (optJSONObject != null) {
                    ContentValues contentValues = new ContentValues();
                    contentValues.put("raw_contact_id", rawId);
                    contentValues.put("mimetype", mimeType);
                    contentValues.put(dataKey, getJsonString(optJSONObject, "value"));
                    contentValues.put(typeKey, Integer.valueOf(getContactType(getJsonString(optJSONObject, "type"))));
                    ops.add(ContentProviderOperation.newInsert(ContactsContract.Data.CONTENT_URI).withValues(contentValues).build());
                }
            }
        }
    }

    /* JADX WARN: Can't wrap try/catch for region: R(19:1|(1:3)(1:95)|4|(3:5|6|7)|(2:8|9)|10|11|12|(3:14|(4:17|(11:19|20|21|22|23|24|25|26|27|28|30)(2:84|85)|31|15)|86)|88|34|35|(2:37|(4:40|(2:42|43)(2:45|46)|44|38))|48|49|(3:51|(4:54|(2:61|62)(2:58|59)|60|52)|63)|64|(3:66|67|69)|(1:(0))) */
    /* JADX WARN: Code restructure failed: missing block: B:32:0x01f4, code lost:
        r5 = r29;
        r6 = r18;
     */
    /* JADX WARN: Code restructure failed: missing block: B:47:0x0296, code lost:
        android.util.Log.d(r3, "Could not get organizations");
     */
    /* JADX WARN: Code restructure failed: missing block: B:62:0x038e, code lost:
        android.util.Log.d(r3, "Could not get photos");
     */
    /* JADX WARN: Removed duplicated region for block: B:16:0x014a  */
    /* JADX WARN: Removed duplicated region for block: B:38:0x0227  */
    /* JADX WARN: Removed duplicated region for block: B:50:0x02bf  */
    /*
        Code decompiled incorrectly, please refer to instructions dump.
    */
    private boolean modifyContact(JSONObject contact, Account account, String id) {
        String str;
        String str2;
        String str3;
        String str4;
        ContactAccessorImpl contactAccessorImpl;
        String str5;
        String str6;
        String str7;
        String str8;
        JSONArray optJSONArray;
        String str9;
        byte[] photoBytes;
        JSONArray optJSONArray2;
        JSONArray jSONArray;
        String str10;
        String str11;
        JSONArray optJSONArray3;
        JSONArray jSONArray2;
        String str12;
        String jsonString;
        JSONObject jSONObject;
        String str13 = "vnd.android.cursor.item/postal-address_v2";
        String str14 = "vnd.android.cursor.item/photo";
        String str15 = "vnd.android.cursor.item/organization";
        String str16 = "type";
        ArrayList<ContentProviderOperation> arrayList = new ArrayList<>();
        if (account != null) {
            str = "raw_contact_id=? and mimetype=?";
            str2 = "raw_contact_id";
            str3 = "mimetype";
            arrayList.add(ContentProviderOperation.newUpdate(ContactsContract.RawContacts.CONTENT_URI).withValue("account_type", account.type).withValue("account_name", account.name).build());
        } else {
            str = "raw_contact_id=? and mimetype=?";
            str2 = "raw_contact_id";
            str3 = "mimetype";
        }
        try {
            jsonString = getJsonString(contact, "displayName");
            jSONObject = contact.getJSONObject("name");
            str4 = "name";
        } catch (JSONException unused) {
            str4 = "name";
        }
        try {
            ContentProviderOperation.Builder withSelection = ContentProviderOperation.newUpdate(ContactsContract.Data.CONTENT_URI).withSelection("raw_contact_id=? AND mimetype=?", new String[]{id, "vnd.android.cursor.item/name"});
            withSelection.withValue("data1", jsonString);
            withSelection.withValue("data3", getJsonString(jSONObject, "familyName"));
            withSelection.withValue("data5", getJsonString(jSONObject, "middleName"));
            withSelection.withValue("data2", getJsonString(jSONObject, "givenName"));
            withSelection.withValue("data4", getJsonString(jSONObject, "honorificPrefix"));
            withSelection.withValue("data6", getJsonString(jSONObject, "honorificSuffix"));
            arrayList.add(withSelection.build());
        } catch (JSONException unused2) {
            Log.d("ContactsAccessor", "Could not get name");
            String str17 = "data5";
            String str18 = str;
            String str19 = "data1";
            String str20 = str2;
            String str21 = "data2";
            String str22 = str3;
            modifyContactOption(arrayList, contact.optJSONArray("phoneNumbers"), id, "vnd.android.cursor.item/phone_v2", "data1", "data2");
            modifyContactOption(arrayList, contact.optJSONArray("emails"), id, "vnd.android.cursor.item/email_v2", "data1", "data2");
            modifyContactOption(arrayList, contact.optJSONArray("ims"), id, "vnd.android.cursor.item/im", "data1", "data2");
            modifyContactOption(arrayList, contact.optJSONArray("websites"), id, "vnd.android.cursor.item/website", "data1", "data2");
            arrayList.add(ContentProviderOperation.newDelete(ContactsContract.Data.CONTENT_URI).withSelection(str18, new String[]{String.valueOf(id), "vnd.android.cursor.item/postal-address_v2"}).build());
            optJSONArray3 = contact.optJSONArray("addresses");
            if (optJSONArray3 != null) {
            }
            contactAccessorImpl = this;
            str5 = str16;
            str6 = str21;
            str7 = str19;
            str8 = "ContactsAccessor";
            arrayList.add(ContentProviderOperation.newDelete(ContactsContract.Data.CONTENT_URI).withSelection(str18, new String[]{String.valueOf(id), str15}).build());
            optJSONArray2 = contact.optJSONArray("organizations");
            if (optJSONArray2 != null) {
            }
            arrayList.add(ContentProviderOperation.newDelete(ContactsContract.Data.CONTENT_URI).withSelection(str18, new String[]{String.valueOf(id), str14}).build());
            optJSONArray = contact.optJSONArray("photos");
            if (optJSONArray != null) {
            }
            arrayList.add(ContentProviderOperation.newUpdate(ContactsContract.Data.CONTENT_URI).withSelection("raw_contact_id=? AND mimetype=?", new String[]{id, "vnd.android.cursor.item/note"}).withValue(str7, contactAccessorImpl.getJsonString(contact, "note")).build());
            arrayList.add(ContentProviderOperation.newUpdate(ContactsContract.Data.CONTENT_URI).withSelection("raw_contact_id=? AND mimetype=?", new String[]{id, "vnd.android.cursor.item/nickname"}).withValue(str7, contactAccessorImpl.getJsonString(contact, "nickname")).build());
            arrayList.add(ContentProviderOperation.newUpdate(ContactsContract.Data.CONTENT_URI).withSelection("raw_contact_id=? AND mimetype=? AND data2=?", new String[]{id, "vnd.android.cursor.item/contact_event", ExifInterface.GPS_MEASUREMENT_3D}).withValue(str6, 3).withValue(str7, contactAccessorImpl.getJsonString(contact, "birthday")).build());
            contactAccessorImpl.mApp.getContentResolver().applyBatch("com.android.contacts", arrayList);
            return true;
        }
        String str172 = "data5";
        String str182 = str;
        String str192 = "data1";
        String str202 = str2;
        String str212 = "data2";
        String str222 = str3;
        modifyContactOption(arrayList, contact.optJSONArray("phoneNumbers"), id, "vnd.android.cursor.item/phone_v2", "data1", "data2");
        modifyContactOption(arrayList, contact.optJSONArray("emails"), id, "vnd.android.cursor.item/email_v2", "data1", "data2");
        modifyContactOption(arrayList, contact.optJSONArray("ims"), id, "vnd.android.cursor.item/im", "data1", "data2");
        modifyContactOption(arrayList, contact.optJSONArray("websites"), id, "vnd.android.cursor.item/website", "data1", "data2");
        arrayList.add(ContentProviderOperation.newDelete(ContactsContract.Data.CONTENT_URI).withSelection(str182, new String[]{String.valueOf(id), "vnd.android.cursor.item/postal-address_v2"}).build());
        optJSONArray3 = contact.optJSONArray("addresses");
        if (optJSONArray3 != null) {
            int i = 0;
            while (i < optJSONArray3.length()) {
                JSONObject optJSONObject = optJSONArray3.optJSONObject(i);
                if (optJSONObject != null) {
                    ContentValues contentValues = new ContentValues();
                    contentValues.put(str202, id);
                    contentValues.put(str222, str13);
                    contactAccessorImpl = this;
                    str5 = str16;
                    try {
                        str6 = str212;
                        try {
                            contentValues.put(str6, Integer.valueOf(contactAccessorImpl.getAddressType(contactAccessorImpl.getJsonString(optJSONObject, str5))));
                            jSONArray2 = optJSONArray3;
                            str7 = str192;
                            try {
                                contentValues.put(str7, contactAccessorImpl.getJsonString(optJSONObject, "formatted"));
                                contentValues.put("data4", contactAccessorImpl.getJsonString(optJSONObject, "streetAddress"));
                                str12 = str13;
                                contentValues.put("data7", contactAccessorImpl.getJsonString(optJSONObject, "locality"));
                                contentValues.put("data8", contactAccessorImpl.getJsonString(optJSONObject, "region"));
                                contentValues.put("data9", contactAccessorImpl.getJsonString(optJSONObject, "postalCode"));
                                contentValues.put("data10", contactAccessorImpl.getJsonString(optJSONObject, "country"));
                                arrayList.add(ContentProviderOperation.newInsert(ContactsContract.Data.CONTENT_URI).withValues(contentValues).build());
                            } catch (Exception unused3) {
                                str8 = "ContactsAccessor";
                                Log.d(str8, "Could not get addresses");
                                arrayList.add(ContentProviderOperation.newDelete(ContactsContract.Data.CONTENT_URI).withSelection(str182, new String[]{String.valueOf(id), str15}).build());
                                optJSONArray2 = contact.optJSONArray("organizations");
                                if (optJSONArray2 != null) {
                                }
                                arrayList.add(ContentProviderOperation.newDelete(ContactsContract.Data.CONTENT_URI).withSelection(str182, new String[]{String.valueOf(id), str14}).build());
                                optJSONArray = contact.optJSONArray("photos");
                                if (optJSONArray != null) {
                                }
                                arrayList.add(ContentProviderOperation.newUpdate(ContactsContract.Data.CONTENT_URI).withSelection("raw_contact_id=? AND mimetype=?", new String[]{id, "vnd.android.cursor.item/note"}).withValue(str7, contactAccessorImpl.getJsonString(contact, "note")).build());
                                arrayList.add(ContentProviderOperation.newUpdate(ContactsContract.Data.CONTENT_URI).withSelection("raw_contact_id=? AND mimetype=?", new String[]{id, "vnd.android.cursor.item/nickname"}).withValue(str7, contactAccessorImpl.getJsonString(contact, "nickname")).build());
                                arrayList.add(ContentProviderOperation.newUpdate(ContactsContract.Data.CONTENT_URI).withSelection("raw_contact_id=? AND mimetype=? AND data2=?", new String[]{id, "vnd.android.cursor.item/contact_event", ExifInterface.GPS_MEASUREMENT_3D}).withValue(str6, 3).withValue(str7, contactAccessorImpl.getJsonString(contact, "birthday")).build());
                                contactAccessorImpl.mApp.getContentResolver().applyBatch("com.android.contacts", arrayList);
                                return true;
                            }
                        } catch (Exception unused4) {
                            str7 = str192;
                            str8 = "ContactsAccessor";
                            Log.d(str8, "Could not get addresses");
                            arrayList.add(ContentProviderOperation.newDelete(ContactsContract.Data.CONTENT_URI).withSelection(str182, new String[]{String.valueOf(id), str15}).build());
                            optJSONArray2 = contact.optJSONArray("organizations");
                            if (optJSONArray2 != null) {
                            }
                            arrayList.add(ContentProviderOperation.newDelete(ContactsContract.Data.CONTENT_URI).withSelection(str182, new String[]{String.valueOf(id), str14}).build());
                            optJSONArray = contact.optJSONArray("photos");
                            if (optJSONArray != null) {
                            }
                            arrayList.add(ContentProviderOperation.newUpdate(ContactsContract.Data.CONTENT_URI).withSelection("raw_contact_id=? AND mimetype=?", new String[]{id, "vnd.android.cursor.item/note"}).withValue(str7, contactAccessorImpl.getJsonString(contact, "note")).build());
                            arrayList.add(ContentProviderOperation.newUpdate(ContactsContract.Data.CONTENT_URI).withSelection("raw_contact_id=? AND mimetype=?", new String[]{id, "vnd.android.cursor.item/nickname"}).withValue(str7, contactAccessorImpl.getJsonString(contact, "nickname")).build());
                            arrayList.add(ContentProviderOperation.newUpdate(ContactsContract.Data.CONTENT_URI).withSelection("raw_contact_id=? AND mimetype=? AND data2=?", new String[]{id, "vnd.android.cursor.item/contact_event", ExifInterface.GPS_MEASUREMENT_3D}).withValue(str6, 3).withValue(str7, contactAccessorImpl.getJsonString(contact, "birthday")).build());
                            contactAccessorImpl.mApp.getContentResolver().applyBatch("com.android.contacts", arrayList);
                            return true;
                        }
                    } catch (Exception unused5) {
                        str6 = str212;
                        str7 = str192;
                        str8 = "ContactsAccessor";
                        Log.d(str8, "Could not get addresses");
                        arrayList.add(ContentProviderOperation.newDelete(ContactsContract.Data.CONTENT_URI).withSelection(str182, new String[]{String.valueOf(id), str15}).build());
                        optJSONArray2 = contact.optJSONArray("organizations");
                        if (optJSONArray2 != null) {
                        }
                        arrayList.add(ContentProviderOperation.newDelete(ContactsContract.Data.CONTENT_URI).withSelection(str182, new String[]{String.valueOf(id), str14}).build());
                        optJSONArray = contact.optJSONArray("photos");
                        if (optJSONArray != null) {
                        }
                        arrayList.add(ContentProviderOperation.newUpdate(ContactsContract.Data.CONTENT_URI).withSelection("raw_contact_id=? AND mimetype=?", new String[]{id, "vnd.android.cursor.item/note"}).withValue(str7, contactAccessorImpl.getJsonString(contact, "note")).build());
                        arrayList.add(ContentProviderOperation.newUpdate(ContactsContract.Data.CONTENT_URI).withSelection("raw_contact_id=? AND mimetype=?", new String[]{id, "vnd.android.cursor.item/nickname"}).withValue(str7, contactAccessorImpl.getJsonString(contact, "nickname")).build());
                        arrayList.add(ContentProviderOperation.newUpdate(ContactsContract.Data.CONTENT_URI).withSelection("raw_contact_id=? AND mimetype=? AND data2=?", new String[]{id, "vnd.android.cursor.item/contact_event", ExifInterface.GPS_MEASUREMENT_3D}).withValue(str6, 3).withValue(str7, contactAccessorImpl.getJsonString(contact, "birthday")).build());
                        contactAccessorImpl.mApp.getContentResolver().applyBatch("com.android.contacts", arrayList);
                        return true;
                    }
                } else {
                    jSONArray2 = optJSONArray3;
                    str5 = str16;
                    str6 = str212;
                    str7 = str192;
                    str12 = str13;
                }
                i++;
                str192 = str7;
                str16 = str5;
                str13 = str12;
                optJSONArray3 = jSONArray2;
                str212 = str6;
            }
        }
        contactAccessorImpl = this;
        str5 = str16;
        str6 = str212;
        str7 = str192;
        str8 = "ContactsAccessor";
        arrayList.add(ContentProviderOperation.newDelete(ContactsContract.Data.CONTENT_URI).withSelection(str182, new String[]{String.valueOf(id), str15}).build());
        optJSONArray2 = contact.optJSONArray("organizations");
        if (optJSONArray2 != null) {
            int i2 = 0;
            while (i2 < optJSONArray2.length()) {
                JSONObject optJSONObject2 = optJSONArray2.optJSONObject(i2);
                if (optJSONObject2 != null) {
                    ContentValues contentValues2 = new ContentValues();
                    contentValues2.put(str202, id);
                    jSONArray = optJSONArray2;
                    String str23 = str15;
                    contentValues2.put(str222, str23);
                    str15 = str23;
                    contentValues2.put(str6, Integer.valueOf(contactAccessorImpl.getOrgType(contactAccessorImpl.getJsonString(optJSONObject2, str5))));
                    str10 = str5;
                    String str24 = str172;
                    contentValues2.put(str24, contactAccessorImpl.getJsonString(optJSONObject2, "department"));
                    str172 = str24;
                    str11 = str4;
                    contentValues2.put(str7, contactAccessorImpl.getJsonString(optJSONObject2, str11));
                    contentValues2.put("data4", contactAccessorImpl.getJsonString(optJSONObject2, AbsoluteConst.JSON_KEY_TITLE));
                    arrayList.add(ContentProviderOperation.newInsert(ContactsContract.Data.CONTENT_URI).withValues(contentValues2).build());
                } else {
                    jSONArray = optJSONArray2;
                    str10 = str5;
                    str11 = str4;
                }
                i2++;
                str4 = str11;
                str5 = str10;
                optJSONArray2 = jSONArray;
            }
        }
        arrayList.add(ContentProviderOperation.newDelete(ContactsContract.Data.CONTENT_URI).withSelection(str182, new String[]{String.valueOf(id), str14}).build());
        optJSONArray = contact.optJSONArray("photos");
        if (optJSONArray != null) {
            int i3 = 0;
            while (i3 < optJSONArray.length()) {
                JSONObject optJSONObject3 = optJSONArray.optJSONObject(i3);
                if (optJSONObject3 == null || (photoBytes = contactAccessorImpl.getPhotoBytes(contactAccessorImpl.getJsonString(optJSONObject3, "value"))) == null) {
                    str9 = str14;
                } else {
                    ContentValues contentValues3 = new ContentValues();
                    contentValues3.put(str202, id);
                    str9 = str14;
                    contentValues3.put(str222, str9);
                    contentValues3.put("is_super_primary", (Integer) 1);
                    contentValues3.put("data15", photoBytes);
                    arrayList.add(ContentProviderOperation.newInsert(ContactsContract.Data.CONTENT_URI).withValues(contentValues3).build());
                }
                i3++;
                str14 = str9;
            }
        }
        arrayList.add(ContentProviderOperation.newUpdate(ContactsContract.Data.CONTENT_URI).withSelection("raw_contact_id=? AND mimetype=?", new String[]{id, "vnd.android.cursor.item/note"}).withValue(str7, contactAccessorImpl.getJsonString(contact, "note")).build());
        arrayList.add(ContentProviderOperation.newUpdate(ContactsContract.Data.CONTENT_URI).withSelection("raw_contact_id=? AND mimetype=?", new String[]{id, "vnd.android.cursor.item/nickname"}).withValue(str7, contactAccessorImpl.getJsonString(contact, "nickname")).build());
        arrayList.add(ContentProviderOperation.newUpdate(ContactsContract.Data.CONTENT_URI).withSelection("raw_contact_id=? AND mimetype=? AND data2=?", new String[]{id, "vnd.android.cursor.item/contact_event", ExifInterface.GPS_MEASUREMENT_3D}).withValue(str6, 3).withValue(str7, contactAccessorImpl.getJsonString(contact, "birthday")).build());
        try {
            contactAccessorImpl.mApp.getContentResolver().applyBatch("com.android.contacts", arrayList);
            return true;
        } catch (OperationApplicationException e) {
            Log.e(str8, e.getMessage(), e);
            Log.e(str8, Log.getStackTraceString(e), e);
            return false;
        } catch (RemoteException e2) {
            Log.e(str8, e2.getMessage(), e2);
            Log.e(str8, Log.getStackTraceString(e2), e2);
            return false;
        }
    }

    private void insertWebsite(ArrayList<ContentProviderOperation> ops, JSONObject website) {
        ops.add(ContentProviderOperation.newInsert(ContactsContract.Data.CONTENT_URI).withValueBackReference("raw_contact_id", 0).withValue("mimetype", "vnd.android.cursor.item/website").withValue("data1", getJsonString(website, "value")).withValue("data2", Integer.valueOf(getContactType(getJsonString(website, "type")))).build());
    }

    private void insertIm(ArrayList<ContentProviderOperation> ops, JSONObject im) {
        ops.add(ContentProviderOperation.newInsert(ContactsContract.Data.CONTENT_URI).withValueBackReference("raw_contact_id", 0).withValue("mimetype", "vnd.android.cursor.item/im").withValue("data1", getJsonString(im, "value")).withValue("data2", Integer.valueOf(getContactType(getJsonString(im, "type")))).build());
    }

    private void insertOrganization(ArrayList<ContentProviderOperation> ops, JSONObject org2) {
        ops.add(ContentProviderOperation.newInsert(ContactsContract.Data.CONTENT_URI).withValueBackReference("raw_contact_id", 0).withValue("mimetype", "vnd.android.cursor.item/organization").withValue("data2", Integer.valueOf(getOrgType(getJsonString(org2, "type")))).withValue("data5", getJsonString(org2, "department")).withValue("data1", getJsonString(org2, "name")).withValue("data4", getJsonString(org2, AbsoluteConst.JSON_KEY_TITLE)).build());
    }

    private void insertAddress(ArrayList<ContentProviderOperation> ops, JSONObject address) {
        ops.add(ContentProviderOperation.newInsert(ContactsContract.Data.CONTENT_URI).withValueBackReference("raw_contact_id", 0).withValue("mimetype", "vnd.android.cursor.item/postal-address_v2").withValue("data2", Integer.valueOf(getAddressType(getJsonString(address, "type")))).withValue("data1", getJsonString(address, "formatted")).withValue("data4", getJsonString(address, "streetAddress")).withValue("data7", getJsonString(address, "locality")).withValue("data8", getJsonString(address, "region")).withValue("data9", getJsonString(address, "postalCode")).withValue("data10", getJsonString(address, "country")).build());
    }

    private void insertEmail(ArrayList<ContentProviderOperation> ops, JSONObject email) {
        ops.add(ContentProviderOperation.newInsert(ContactsContract.Data.CONTENT_URI).withValueBackReference("raw_contact_id", 0).withValue("mimetype", "vnd.android.cursor.item/email_v2").withValue("data1", getJsonString(email, "value")).withValue("data2", Integer.valueOf(getPhoneType(getJsonString(email, "type")))).build());
    }

    private void insertPhone(ArrayList<ContentProviderOperation> ops, JSONObject phone) {
        ops.add(ContentProviderOperation.newInsert(ContactsContract.Data.CONTENT_URI).withValueBackReference("raw_contact_id", 0).withValue("mimetype", "vnd.android.cursor.item/phone_v2").withValue("data1", getJsonString(phone, "value")).withValue("data2", Integer.valueOf(getPhoneType(getJsonString(phone, "type")))).build());
    }

    private void insertPhoto(ArrayList<ContentProviderOperation> ops, JSONObject photo) {
        ops.add(ContentProviderOperation.newInsert(ContactsContract.Data.CONTENT_URI).withValueBackReference("raw_contact_id", 0).withValue("is_super_primary", 1).withValue("mimetype", "vnd.android.cursor.item/photo").withValue("data15", getPhotoBytes(getJsonString(photo, "value"))).build());
    }

    private byte[] getPhotoBytes(String filename) {
        int indexOf = filename.indexOf(";base64,");
        if (indexOf > 0) {
            String substring = filename.substring(indexOf + 8);
            if (DeviceInfo.sDeviceSdkVer >= 8) {
                return Base64.decode(substring, 2);
            }
            return io.dcloud.common.util.Base64.decode2bytes(substring);
        }
        ByteArrayOutputStream byteArrayOutputStream = new ByteArrayOutputStream();
        long j = 0;
        try {
            InputStream pathFromUri = getPathFromUri(filename);
            if (pathFromUri != null) {
                byte[] bArr = new byte[8192];
                while (true) {
                    int read = pathFromUri.read(bArr, 0, 8192);
                    if (read == -1 || j > MAX_PHOTO_SIZE) {
                        break;
                    }
                    byteArrayOutputStream.write(bArr, 0, read);
                    j += read;
                }
                pathFromUri.close();
                byteArrayOutputStream.flush();
            }
        } catch (FileNotFoundException e) {
            Log.e("ContactsAccessor", e.getMessage(), e);
        } catch (IOException e2) {
            Log.e("ContactsAccessor", e2.getMessage(), e2);
        }
        return byteArrayOutputStream.toByteArray();
    }

    private InputStream getPathFromUri(String path) throws IOException {
        if (path.startsWith("content:")) {
            return this.mApp.getContentResolver().openInputStream(Uri.parse(path));
        } else if (path.startsWith("http:") || path.startsWith("file:")) {
            return new URL(path).openStream();
        } else {
            return this.mView.obtainFrameView().obtainApp().obtainResInStream(this.mView.obtainFullUrl(), path);
        }
    }

    private boolean createNewContact(JSONObject contact, Account account) {
        ArrayList<ContentProviderOperation> arrayList = new ArrayList<>();
        ArrayList arrayList2 = new ArrayList();
        if (account != null) {
            arrayList.add(ContentProviderOperation.newInsert(ContactsContract.RawContacts.CONTENT_URI).withValue("account_type", account.type).withValue("account_name", account.name).build());
        } else {
            arrayList.add(ContentProviderOperation.newInsert(ContactsContract.RawContacts.CONTENT_URI).withValue("aggregation_mode", 3).build());
        }
        arrayList2.add(contact);
        JSONObject optJSONObject = contact.optJSONObject("name");
        String jsonString = getJsonString(contact, "displayName");
        if (jsonString != null || optJSONObject != null) {
            arrayList.add(ContentProviderOperation.newInsert(ContactsContract.Data.CONTENT_URI).withValueBackReference("raw_contact_id", 0).withValue("mimetype", "vnd.android.cursor.item/name").withValue("data1", jsonString).withValue("data3", getJsonString(optJSONObject, "familyName")).withValue("data5", getJsonString(optJSONObject, "middleName")).withValue("data2", getJsonString(optJSONObject, "givenName")).withValue("data4", getJsonString(optJSONObject, "honorificPrefix")).withValue("data6", getJsonString(optJSONObject, "honorificSuffix")).build());
            arrayList2.add(optJSONObject);
        }
        try {
            JSONArray jSONArray = contact.getJSONArray("phoneNumbers");
            if (jSONArray != null) {
                for (int i = 0; i < jSONArray.length(); i++) {
                    insertPhone(arrayList, (JSONObject) jSONArray.get(i));
                }
            }
        } catch (JSONException unused) {
            Log.d("ContactsAccessor", "Could not get phone numbers");
        }
        try {
            JSONArray jSONArray2 = contact.getJSONArray("emails");
            if (jSONArray2 != null) {
                for (int i2 = 0; i2 < jSONArray2.length(); i2++) {
                    JSONObject jSONObject = (JSONObject) jSONArray2.get(i2);
                    insertEmail(arrayList, jSONObject);
                    arrayList2.add(jSONObject);
                }
            }
        } catch (JSONException unused2) {
            Log.d("ContactsAccessor", "Could not get emails");
        }
        try {
            JSONArray jSONArray3 = contact.getJSONArray("addresses");
            if (jSONArray3 != null) {
                for (int i3 = 0; i3 < jSONArray3.length(); i3++) {
                    JSONObject jSONObject2 = (JSONObject) jSONArray3.get(i3);
                    insertAddress(arrayList, jSONObject2);
                    arrayList2.add(jSONObject2);
                }
            }
        } catch (JSONException unused3) {
            Log.d("ContactsAccessor", "Could not get addresses");
        }
        try {
            JSONArray jSONArray4 = contact.getJSONArray("organizations");
            if (jSONArray4 != null) {
                for (int i4 = 0; i4 < jSONArray4.length(); i4++) {
                    JSONObject jSONObject3 = (JSONObject) jSONArray4.get(i4);
                    insertOrganization(arrayList, jSONObject3);
                    arrayList2.add(jSONObject3);
                }
            }
        } catch (JSONException unused4) {
            Log.d("ContactsAccessor", "Could not get organizations");
        }
        try {
            JSONArray jSONArray5 = contact.getJSONArray("ims");
            if (jSONArray5 != null) {
                for (int i5 = 0; i5 < jSONArray5.length(); i5++) {
                    JSONObject jSONObject4 = (JSONObject) jSONArray5.get(i5);
                    insertIm(arrayList, jSONObject4);
                    arrayList2.add(jSONObject4);
                }
            }
        } catch (JSONException unused5) {
            Log.d("ContactsAccessor", "Could not get emails");
        }
        try {
            JSONArray jSONArray6 = contact.getJSONArray("websites");
            if (jSONArray6 != null) {
                for (int i6 = 0; i6 < jSONArray6.length(); i6++) {
                    JSONObject jSONObject5 = (JSONObject) jSONArray6.get(i6);
                    insertWebsite(arrayList, jSONObject5);
                    arrayList2.add(jSONObject5);
                }
            }
        } catch (JSONException unused6) {
            Log.d("ContactsAccessor", "Could not get websites");
        }
        try {
            JSONArray jSONArray7 = contact.getJSONArray("photos");
            if (jSONArray7 != null) {
                for (int i7 = 0; i7 < jSONArray7.length(); i7++) {
                    JSONObject jSONObject6 = (JSONObject) jSONArray7.get(i7);
                    insertPhoto(arrayList, jSONObject6);
                    arrayList2.add(jSONObject6);
                }
            }
        } catch (JSONException unused7) {
            Log.d("ContactsAccessor", "Could not get photos");
        }
        String jsonString2 = getJsonString(contact, "birthday");
        if (jsonString2 != null) {
            arrayList.add(ContentProviderOperation.newInsert(ContactsContract.Data.CONTENT_URI).withValueBackReference("raw_contact_id", 0).withValue("mimetype", "vnd.android.cursor.item/contact_event").withValue("data2", 3).withValue("data1", jsonString2).build());
        }
        String jsonString3 = getJsonString(contact, "note");
        if (jsonString3 != null) {
            arrayList.add(ContentProviderOperation.newInsert(ContactsContract.Data.CONTENT_URI).withValueBackReference("raw_contact_id", 0).withValue("mimetype", "vnd.android.cursor.item/note").withValue("data1", jsonString3).build());
        }
        String jsonString4 = getJsonString(contact, "nickname");
        if (jsonString4 != null) {
            arrayList.add(ContentProviderOperation.newInsert(ContactsContract.Data.CONTENT_URI).withValueBackReference("raw_contact_id", 0).withValue("mimetype", "vnd.android.cursor.item/nickname").withValue("data1", jsonString4).build());
        }
        try {
            ContentProviderResult[] applyBatch = this.mApp.getContentResolver().applyBatch("com.android.contacts", arrayList);
            if (applyBatch.length >= 0) {
                for (int i8 = 0; i8 < arrayList2.size(); i8++) {
                    String lastPathSegment = applyBatch[i8].uri.getLastPathSegment();
                    JSONObject jSONObject7 = (JSONObject) arrayList2.get(i8);
                    if (jSONObject7 != null) {
                        jSONObject7.put("id", lastPathSegment);
                    }
                }
            }
            return true;
        } catch (OperationApplicationException e) {
            Log.e("ContactsAccessor", e.getMessage(), e);
            return false;
        } catch (RemoteException e2) {
            Log.e("ContactsAccessor", e2.getMessage(), e2);
            return false;
        } catch (JSONException e3) {
            Logger.e(e3.getMessage());
            return false;
        }
    }

    @Override // io.dcloud.feature.contacts.ContactAccessor
    public boolean remove(String id) {
        ArrayList<ContentProviderOperation> arrayList = new ArrayList<>();
        arrayList.add(ContentProviderOperation.newDelete(ContentUris.withAppendedId(ContactsContract.RawContacts.CONTENT_URI, Long.parseLong(id))).build());
        try {
            return this.mApp.getContentResolver().applyBatch("com.android.contacts", arrayList).length > 0;
        } catch (Exception unused) {
            return false;
        }
    }

    private int getPhoneType(String string) {
        if ("home".equals(string.toLowerCase(Locale.ENGLISH))) {
            return 1;
        }
        if ("mobile".equals(string.toLowerCase(Locale.ENGLISH))) {
            return 2;
        }
        if ("work".equals(string.toLowerCase(Locale.ENGLISH))) {
            return 3;
        }
        if ("work fax".equals(string.toLowerCase(Locale.ENGLISH))) {
            return 4;
        }
        if ("home fax".equals(string.toLowerCase(Locale.ENGLISH))) {
            return 5;
        }
        if ("fax".equals(string.toLowerCase(Locale.ENGLISH))) {
            return 4;
        }
        if ("pager".equals(string.toLowerCase(Locale.ENGLISH))) {
            return 6;
        }
        if ("other".equals(string.toLowerCase(Locale.ENGLISH))) {
            return 7;
        }
        if ("car".equals(string.toLowerCase(Locale.ENGLISH))) {
            return 9;
        }
        if ("company main".equals(string.toLowerCase(Locale.ENGLISH))) {
            return 10;
        }
        if ("isdn".equals(string.toLowerCase(Locale.ENGLISH))) {
            return 11;
        }
        if ("main".equals(string.toLowerCase(Locale.ENGLISH))) {
            return 12;
        }
        if ("other fax".equals(string.toLowerCase(Locale.ENGLISH))) {
            return 13;
        }
        if ("radio".equals(string.toLowerCase(Locale.ENGLISH))) {
            return 14;
        }
        if ("telex".equals(string.toLowerCase(Locale.ENGLISH))) {
            return 15;
        }
        if ("work mobile".equals(string.toLowerCase(Locale.ENGLISH))) {
            return 17;
        }
        if ("work pager".equals(string.toLowerCase(Locale.ENGLISH))) {
            return 18;
        }
        if ("assistant".equals(string.toLowerCase(Locale.ENGLISH))) {
            return 19;
        }
        if ("mms".equals(string.toLowerCase(Locale.ENGLISH))) {
            return 20;
        }
        if (WXBridgeManager.METHOD_CALLBACK.equals(string.toLowerCase(Locale.ENGLISH))) {
            return 8;
        }
        if ("tty ttd".equals(string.toLowerCase(Locale.ENGLISH))) {
            return 16;
        }
        return "custom".equals(string.toLowerCase(Locale.ENGLISH)) ? 0 : 7;
    }

    private int getContactType(String string) {
        if (string != null) {
            if ("home".equals(string.toLowerCase(Locale.ENGLISH))) {
                return 1;
            }
            if ("work".equals(string.toLowerCase(Locale.ENGLISH))) {
                return 2;
            }
            if ("other".equals(string.toLowerCase(Locale.ENGLISH))) {
                return 3;
            }
            if ("mobile".equals(string.toLowerCase(Locale.ENGLISH))) {
                return 4;
            }
            if ("custom".equals(string.toLowerCase(Locale.ENGLISH))) {
                return 0;
            }
        }
        return 3;
    }

    private int getOrgType(String string) {
        if (string != null) {
            if ("work".equals(string.toLowerCase(Locale.ENGLISH))) {
                return 1;
            }
            if (!"other".equals(string.toLowerCase(Locale.ENGLISH)) && "custom".equals(string.toLowerCase(Locale.ENGLISH))) {
                return 0;
            }
        }
        return 2;
    }

    private int getAddressType(String string) {
        if (string != null) {
            if ("work".equals(string.toLowerCase(Locale.ENGLISH))) {
                return 2;
            }
            if (!"other".equals(string.toLowerCase(Locale.ENGLISH)) && "home".equals(string.toLowerCase(Locale.ENGLISH))) {
                return 1;
            }
        }
        return 3;
    }
}
