package io.dcloud.feature.uniapp.dom;

import androidx.collection.ArrayMap;
import com.alibaba.fastjson.JSONObject;
import com.taobao.weex.dom.binding.ELUtils;
import com.taobao.weex.dom.binding.JSONUtils;
import java.io.Serializable;
import java.util.ArrayList;
import java.util.List;
/* loaded from: classes12.dex */
public abstract class AbsEvent extends ArrayList<String> implements Serializable, Cloneable {
    public static final String EVENT_KEY_ARGS = "params";
    public static final String EVENT_KEY_TYPE = "type";
    private static final long serialVersionUID = -8186587029452440107L;
    private ArrayMap mEventBindingArgs;
    private ArrayMap<String, List<Object>> mEventBindingArgsValues;

    @Override // java.util.ArrayList
    public abstract AbsEvent clone();

    public void setEventBindingArgsValues(ArrayMap<String, List<Object>> eventBindingArgsValues) {
        this.mEventBindingArgsValues = eventBindingArgsValues;
    }

    @Override // java.util.ArrayList, java.util.AbstractList, java.util.AbstractCollection, java.util.Collection, java.util.List
    public void clear() {
        ArrayMap arrayMap = this.mEventBindingArgs;
        if (arrayMap != null) {
            arrayMap.clear();
        }
        ArrayMap<String, List<Object>> arrayMap2 = this.mEventBindingArgsValues;
        if (arrayMap2 != null) {
            arrayMap2.clear();
        }
        super.clear();
    }

    public boolean remove(String o) {
        ArrayMap arrayMap = this.mEventBindingArgs;
        if (arrayMap != null) {
            arrayMap.remove(o);
        }
        ArrayMap<String, List<Object>> arrayMap2 = this.mEventBindingArgsValues;
        if (arrayMap2 != null) {
            arrayMap2.remove(o);
        }
        return super.remove((Object) o);
    }

    public ArrayMap getEventBindingArgs() {
        return this.mEventBindingArgs;
    }

    public ArrayMap<String, List<Object>> getEventBindingArgsValues() {
        return this.mEventBindingArgsValues;
    }

    public void addEvent(Object event) {
        if (event instanceof CharSequence) {
            if (JSONUtils.isJSON(event.toString())) {
                addEvent(JSONUtils.toJSON(event.toString()));
                return;
            }
            String obj = event.toString();
            if (contains(obj)) {
                return;
            }
            add(obj);
        } else if (event instanceof JSONObject) {
            addBindingEvent((JSONObject) event);
        }
    }

    public static String getEventName(Object event) {
        if (event instanceof CharSequence) {
            return event.toString();
        }
        if (event instanceof JSONObject) {
            return ((JSONObject) event).getString("type");
        }
        if (event == null) {
            return null;
        }
        return event.toString();
    }

    public void parseStatements() {
        if (isEmpty()) {
            return;
        }
        for (int i = 0; i < size(); i++) {
            String str = get(i);
            if (JSONUtils.isJSON(str)) {
                set(i, addBindingEvent(JSONUtils.toJSON(str)));
            }
        }
    }

    private String addBindingEvent(JSONObject bindings) {
        String string = bindings.getString("type");
        Object obj = bindings.get("params");
        if (string != null) {
            addBindingArgsEvent(string, obj);
        }
        return string;
    }

    public void setEventBindingArgs(ArrayMap eventBindingArgs) {
        this.mEventBindingArgs = eventBindingArgs;
    }

    private void addBindingArgsEvent(String eventName, Object args) {
        if (!contains(eventName)) {
            add(eventName);
        }
        if (args != null) {
            if (this.mEventBindingArgs == null) {
                this.mEventBindingArgs = new ArrayMap();
            }
            this.mEventBindingArgs.put(eventName, ELUtils.bindingBlock(args));
        }
    }

    public void putEventBindingArgsValue(String event, List<Object> value) {
        if (this.mEventBindingArgsValues == null) {
            this.mEventBindingArgsValues = new ArrayMap<>();
        }
        if (value == null) {
            this.mEventBindingArgsValues.remove(event);
        } else {
            this.mEventBindingArgsValues.put(event, value);
        }
    }
}
