package io.dcloud.feature.uniapp.ui.component;

import android.view.View;
import com.taobao.weex.dom.CSSShorthand;
import com.taobao.weex.ui.action.GraphicPosition;
import com.taobao.weex.ui.action.GraphicSize;
import io.dcloud.feature.uniapp.dom.AbsAttr;
import io.dcloud.feature.uniapp.dom.AbsCSSShorthand;
import io.dcloud.feature.uniapp.dom.AbsEvent;
import io.dcloud.feature.uniapp.dom.AbsStyle;
import io.dcloud.feature.uniapp.ui.action.AbsComponentData;
import java.util.Map;
import java.util.Set;
/* loaded from: classes12.dex */
public abstract class AbsBasicComponent<T extends View> {
    private AbsComponentData mBasicComponentData;
    private String mComponentType;
    private Object mExtra;
    private boolean mIsLayoutRTL;
    private GraphicPosition mLayoutPosition;
    private GraphicSize mLayoutSize;
    private String mRef;
    private float mViewPortWidth = 750.0f;

    public AbsBasicComponent(AbsComponentData basicComponentData) {
        this.mBasicComponentData = basicComponentData;
        this.mRef = basicComponentData.mRef;
        this.mComponentType = basicComponentData.mComponentType;
    }

    public AbsComponentData getBasicComponentData() {
        return this.mBasicComponentData;
    }

    /* JADX INFO: Access modifiers changed from: protected */
    public void bindComponent(AbsBasicComponent component) {
        this.mComponentType = component.getComponentType();
        this.mRef = component.getRef();
    }

    public AbsStyle getStyles() {
        return this.mBasicComponentData.getStyles();
    }

    public AbsAttr getAttrs() {
        return this.mBasicComponentData.getAttrs();
    }

    public AbsEvent getEvents() {
        return this.mBasicComponentData.getEvents();
    }

    public AbsCSSShorthand getMargin() {
        return this.mBasicComponentData.getMargin();
    }

    public AbsCSSShorthand getPadding() {
        return this.mBasicComponentData.getPadding();
    }

    public AbsCSSShorthand getBorder() {
        return this.mBasicComponentData.getBorder();
    }

    public final void setMargins(CSSShorthand margins) {
        this.mBasicComponentData.setMargins(margins);
    }

    public final void setPaddings(CSSShorthand paddings) {
        this.mBasicComponentData.setPaddings(paddings);
    }

    public final void setBorders(CSSShorthand borders) {
        this.mBasicComponentData.setBorders(borders);
    }

    public final void addAttr(Map<String, Object> attrs) {
        if (attrs == null || attrs.isEmpty()) {
            return;
        }
        this.mBasicComponentData.addAttr(attrs);
    }

    public final void addStyle(Map<String, Object> styles) {
        if (styles == null || styles.isEmpty()) {
            return;
        }
        this.mBasicComponentData.addStyle(styles);
    }

    public final void addStyle(Map<String, Object> styles, boolean byPesudo) {
        if (styles == null || styles.isEmpty()) {
            return;
        }
        this.mBasicComponentData.addStyle(styles, byPesudo);
    }

    public final void updateStyle(Map<String, Object> styles, boolean byPesudo) {
        if (styles == null || styles.isEmpty()) {
            return;
        }
        this.mBasicComponentData.getStyles().updateStyle(styles, byPesudo);
    }

    public final void addEvent(Set<String> events) {
        if (events == null || events.isEmpty()) {
            return;
        }
        this.mBasicComponentData.addEvent(events);
    }

    public final void addShorthand(Map<String, String> shorthand) {
        AbsComponentData absComponentData;
        if (shorthand.isEmpty() || (absComponentData = this.mBasicComponentData) == null) {
            return;
        }
        absComponentData.addShorthand(shorthand);
    }

    public float getViewPortWidthForFloat() {
        return this.mViewPortWidth;
    }

    public int getViewPortWidth() {
        return Math.round(this.mViewPortWidth);
    }

    public void setViewPortWidth(float mViewPortWidth) {
        this.mViewPortWidth = mViewPortWidth;
    }

    public Object getExtra() {
        return this.mExtra;
    }

    public void updateExtra(Object extra) {
        this.mExtra = extra;
    }

    public String getComponentType() {
        return this.mComponentType;
    }

    public String getRef() {
        return this.mRef;
    }

    public void setIsLayoutRTL(boolean isRTL) {
        this.mIsLayoutRTL = isRTL;
    }

    public boolean isLayoutRTL() {
        return this.mIsLayoutRTL;
    }

    public GraphicPosition getLayoutPosition() {
        if (this.mLayoutPosition == null) {
            this.mLayoutPosition = new GraphicPosition(0.0f, 0.0f, 0.0f, 0.0f);
        }
        return this.mLayoutPosition;
    }

    /* JADX INFO: Access modifiers changed from: protected */
    public void setLayoutPosition(GraphicPosition mLayoutPosition) {
        this.mLayoutPosition = mLayoutPosition;
    }

    public GraphicSize getLayoutSize() {
        if (this.mLayoutSize == null) {
            this.mLayoutSize = new GraphicSize(0.0f, 0.0f);
        }
        return this.mLayoutSize;
    }

    /* JADX INFO: Access modifiers changed from: protected */
    public void setLayoutSize(GraphicSize mLayoutSize) {
        this.mLayoutSize = mLayoutSize;
    }

    public float getCSSLayoutTop() {
        GraphicPosition graphicPosition = this.mLayoutPosition;
        if (graphicPosition == null) {
            return 0.0f;
        }
        return graphicPosition.getTop();
    }

    public float getCSSLayoutBottom() {
        GraphicPosition graphicPosition = this.mLayoutPosition;
        if (graphicPosition == null) {
            return 0.0f;
        }
        return graphicPosition.getBottom();
    }

    public float getCSSLayoutLeft() {
        GraphicPosition graphicPosition = this.mLayoutPosition;
        if (graphicPosition == null) {
            return 0.0f;
        }
        return graphicPosition.getLeft();
    }

    public float getCSSLayoutRight() {
        GraphicPosition graphicPosition = this.mLayoutPosition;
        if (graphicPosition == null) {
            return 0.0f;
        }
        return graphicPosition.getRight();
    }

    public float getLayoutWidth() {
        GraphicSize graphicSize = this.mLayoutSize;
        if (graphicSize == null) {
            return 0.0f;
        }
        return graphicSize.getWidth();
    }

    public float getLayoutHeight() {
        GraphicSize graphicSize = this.mLayoutSize;
        if (graphicSize == null) {
            return 0.0f;
        }
        return graphicSize.getHeight();
    }
}
