package io.dcloud.feature.uniapp.ui.component;

import android.content.Intent;
import android.util.Pair;
import android.view.Menu;
import android.view.View;
import android.view.ViewGroup;
import android.view.ViewParent;
import androidx.core.view.ViewCompat;
import com.taobao.weex.WXSDKInstance;
import com.taobao.weex.common.Constants;
import com.taobao.weex.ui.action.BasicComponentData;
import com.taobao.weex.ui.component.Scrollable;
import com.taobao.weex.ui.component.WXBaseScroller;
import com.taobao.weex.ui.component.WXComponent;
import com.taobao.weex.ui.component.WXImage;
import com.taobao.weex.ui.component.WXVContainer;
import com.taobao.weex.ui.view.WXImageView;
import com.taobao.weex.utils.WXUtils;
import io.dcloud.feature.uniapp.annotation.UniJSMethod;
import java.util.ArrayList;
import java.util.Iterator;
/* loaded from: classes26.dex */
public abstract class AbsVContainer<T extends ViewGroup> extends WXComponent<T> {
    protected ArrayList<WXComponent> mChildren;

    public void appendTreeCreateFinish() {
    }

    public abstract View getBoxShadowHost(boolean isClear);

    protected int getChildrenLayoutTopOffset() {
        return 0;
    }

    public abstract void removeBoxShadowHost();

    @Deprecated
    public AbsVContainer(WXSDKInstance instance, WXVContainer parent, String instanceId, boolean isLazy, BasicComponentData basicComponentData) {
        this(instance, parent, isLazy, basicComponentData);
    }

    @Deprecated
    public AbsVContainer(WXSDKInstance instance, WXVContainer parent, boolean lazy, BasicComponentData basicComponentData) {
        super(instance, parent, basicComponentData);
        this.mChildren = new ArrayList<>();
    }

    public AbsVContainer(WXSDKInstance instance, WXVContainer parent, BasicComponentData basicComponentData) {
        super(instance, parent, basicComponentData);
        this.mChildren = new ArrayList<>();
    }

    public void interceptFocus() {
        ViewGroup viewGroup = (ViewGroup) getHostView();
        if (viewGroup != null) {
            viewGroup.setFocusable(true);
            viewGroup.setFocusableInTouchMode(true);
            viewGroup.setDescendantFocusability(131072);
            viewGroup.requestFocus();
        }
    }

    public void ignoreFocus() {
        ViewGroup viewGroup = (ViewGroup) getHostView();
        if (viewGroup != null) {
            viewGroup.setFocusable(false);
            viewGroup.setFocusableInTouchMode(false);
            viewGroup.clearFocus();
        }
    }

    @Override // com.taobao.weex.ui.component.WXComponent
    @Deprecated
    public ViewGroup getView() {
        return (ViewGroup) getHostView();
    }

    @Override // com.taobao.weex.ui.component.WXComponent
    public void applyLayoutAndEvent(AbsBasicComponent component) {
        if (isLazy()) {
            return;
        }
        if (component == null) {
            component = this;
        }
        super.applyLayoutAndEvent(component);
        int childCount = childCount();
        for (int i = 0; i < childCount; i++) {
            getChild(i).applyLayoutAndEvent(((WXVContainer) component).getChild(i));
        }
    }

    public ViewGroup.LayoutParams getChildLayoutParams(WXComponent child, View childView, int width, int height, int left, int right, int top, int bottom) {
        ViewGroup.LayoutParams layoutParams = childView != null ? childView.getLayoutParams() : null;
        if (layoutParams == null) {
            return new ViewGroup.LayoutParams(width, height);
        }
        layoutParams.width = width;
        layoutParams.height = height;
        if (layoutParams instanceof ViewGroup.MarginLayoutParams) {
            setMarginsSupportRTL((ViewGroup.MarginLayoutParams) layoutParams, left, top, right, bottom);
            return layoutParams;
        }
        return layoutParams;
    }

    @Override // com.taobao.weex.ui.component.WXComponent
    public Scrollable getFirstScroller() {
        if (this instanceof Scrollable) {
            return (Scrollable) this;
        }
        for (int i = 0; i < getChildCount(); i++) {
            Scrollable firstScroller = getChild(i).getFirstScroller();
            if (firstScroller != null) {
                return firstScroller;
            }
        }
        return null;
    }

    @Override // com.taobao.weex.ui.component.WXComponent
    public void bindComponentData(AbsBasicComponent component) {
        if (isLazy()) {
            return;
        }
        if (component == null) {
            component = this;
        }
        super.bindComponentData(component);
        int childCount = childCount();
        for (int i = 0; i < childCount; i++) {
            getChild(i).bindData(((WXVContainer) component).getChild(i));
        }
    }

    @Override // com.taobao.weex.ui.component.WXComponent
    public void refreshData(WXComponent component) {
        if (component == null) {
            component = this;
        }
        super.refreshData(component);
        int childCount = childCount();
        for (int i = 0; i < childCount; i++) {
            getChild(i).refreshData(((WXVContainer) component).getChild(i));
        }
    }

    @Override // com.taobao.weex.ui.component.WXComponent
    public ViewGroup getRealView() {
        return (ViewGroup) super.getRealView();
    }

    @Override // com.taobao.weex.ui.component.WXComponent
    public void createViewImpl() {
        super.createViewImpl();
        int childCount = childCount();
        for (int i = 0; i < childCount; i++) {
            createChildViewAt(i);
        }
        if (getHostView() != 0) {
            ((ViewGroup) getHostView()).setClipToPadding(false);
        }
    }

    @Override // com.taobao.weex.ui.component.WXComponent
    public void destroy() {
        ArrayList<WXComponent> arrayList = this.mChildren;
        if (arrayList != null) {
            int size = arrayList.size();
            for (int i = 0; i < size; i++) {
                this.mChildren.get(i).destroy();
            }
            this.mChildren.clear();
        }
        super.destroy();
    }

    @Override // com.taobao.weex.ui.component.WXComponent
    public void recycled() {
        if (this.mChildren != null && !isFixed() && getAttrs().canRecycled()) {
            int size = this.mChildren.size();
            for (int i = 0; i < size; i++) {
                this.mChildren.get(i).recycled();
            }
        }
        super.recycled();
    }

    @Override // com.taobao.weex.ui.component.WXComponent
    public View detachViewAndClearPreInfo() {
        View detachViewAndClearPreInfo = super.detachViewAndClearPreInfo();
        if (this.mChildren != null) {
            int childCount = childCount();
            for (int i = 0; i < childCount; i++) {
                this.mChildren.get(i).detachViewAndClearPreInfo();
            }
        }
        return detachViewAndClearPreInfo;
    }

    public int childCount() {
        ArrayList<WXComponent> arrayList = this.mChildren;
        if (arrayList == null) {
            return 0;
        }
        return arrayList.size();
    }

    public WXComponent getChild(int index) {
        ArrayList<WXComponent> arrayList = this.mChildren;
        if (arrayList == null || index < 0 || index >= arrayList.size()) {
            return null;
        }
        return this.mChildren.get(index);
    }

    public int getChildCount() {
        return childCount();
    }

    public void addChild(WXComponent child) {
        addChild(child, -1);
    }

    public void addChild(WXComponent child, int index) {
        if (child == null || index < -1) {
            return;
        }
        child.mDeepInComponentTree = this.mDeepInComponentTree + 1;
        getInstance().setMaxDomDeep(child.mDeepInComponentTree);
        if (index >= this.mChildren.size()) {
            index = -1;
        }
        if (index == -1) {
            this.mChildren.add(child);
        } else {
            this.mChildren.add(index, child);
        }
    }

    public final int indexOf(WXComponent comp) {
        return this.mChildren.indexOf(comp);
    }

    public void createChildViewAt(int index) {
        Pair<WXComponent, Integer> rearrangeIndexAndGetChild = rearrangeIndexAndGetChild(index);
        if (rearrangeIndexAndGetChild.first != null) {
            WXComponent wXComponent = (WXComponent) rearrangeIndexAndGetChild.first;
            wXComponent.createView();
            if (wXComponent.isVirtualComponent()) {
                return;
            }
            addSubView(wXComponent.getHostView(), ((Integer) rearrangeIndexAndGetChild.second).intValue());
        }
    }

    /* JADX INFO: Access modifiers changed from: protected */
    public Pair<WXComponent, Integer> rearrangeIndexAndGetChild(int index) {
        if (index < 0) {
            index = childCount() - 1;
        }
        if (index < 0) {
            return new Pair<>(null, Integer.valueOf(index));
        }
        return new Pair<>(getChild(index), Integer.valueOf(index));
    }

    public void addSubView(View child, int index) {
        if (child == null || getRealView() == null) {
            return;
        }
        if (child.getParent() != null) {
            ((ViewGroup) child.getParent()).removeView(child);
        }
        if (index >= getRealView().getChildCount()) {
            index = -1;
        }
        if (index == -1) {
            getRealView().addView(child);
        } else {
            getRealView().addView(child, index);
        }
        WXSDKInstance absVContainer = getInstance();
        if (absVContainer != null) {
            absVContainer.getApmForInstance().hasAddView = true;
        }
    }

    public void remove(WXComponent child, boolean destroy) {
        ArrayList<WXComponent> arrayList;
        if (child == null || (arrayList = this.mChildren) == null || arrayList.size() == 0) {
            return;
        }
        this.mChildren.remove(child);
        if (getInstance() != null && getInstance().getRootView() != null && child.isFixed()) {
            getInstance().removeFixedView(child.getHostView());
        } else if (getRealView() != null) {
            if (!child.isVirtualComponent()) {
                ViewParent viewParent = null;
                if ((child.getParent() instanceof WXBaseScroller) && child.getHostView() != null) {
                    viewParent = child.getHostView().getParent();
                }
                if (viewParent != null && (viewParent instanceof ViewGroup)) {
                    ((ViewGroup) viewParent).removeView(child.getHostView());
                } else {
                    getRealView().removeView(child.getHostView());
                }
            } else {
                child.removeVirtualComponent();
            }
        }
        if (destroy) {
            child.destroy();
        }
    }

    @Override // com.taobao.weex.ui.component.WXComponent
    public void notifyAppearStateChange(String wxEventType, String direction) {
        ArrayList<WXComponent> arrayList;
        super.notifyAppearStateChange(wxEventType, direction);
        if (getHostView() == 0 || (arrayList = this.mChildren) == null) {
            return;
        }
        Iterator<WXComponent> it = arrayList.iterator();
        while (it.hasNext()) {
            WXComponent next = it.next();
            if (next.getHostView() != null && next.getHostView().getVisibility() != 0) {
                wxEventType = Constants.Event.DISAPPEAR;
            }
            next.notifyAppearStateChange(wxEventType, direction);
        }
    }

    @Override // com.taobao.weex.ui.component.WXComponent, com.taobao.weex.IWXActivityStateListener
    public void onActivityCreate() {
        super.onActivityCreate();
        int childCount = childCount();
        for (int i = 0; i < childCount; i++) {
            getChild(i).onActivityCreate();
        }
    }

    @Override // com.taobao.weex.ui.component.WXComponent, com.taobao.weex.IWXActivityStateListener
    public void onActivityStart() {
        super.onActivityStart();
        int childCount = childCount();
        for (int i = 0; i < childCount; i++) {
            getChild(i).onActivityStart();
        }
    }

    @Override // com.taobao.weex.ui.component.WXComponent, com.taobao.weex.IWXActivityStateListener
    public void onActivityPause() {
        super.onActivityPause();
        int childCount = childCount();
        for (int i = 0; i < childCount; i++) {
            getChild(i).onActivityPause();
        }
    }

    @Override // com.taobao.weex.ui.component.WXComponent, com.taobao.weex.IWXActivityStateListener
    public void onActivityResume() {
        super.onActivityResume();
        int childCount = childCount();
        for (int i = 0; i < childCount; i++) {
            getChild(i).onActivityResume();
        }
    }

    @Override // com.taobao.weex.ui.component.WXComponent, com.taobao.weex.IWXActivityStateListener
    public void onActivityStop() {
        super.onActivityStop();
        int childCount = childCount();
        for (int i = 0; i < childCount; i++) {
            getChild(i).onActivityStop();
        }
    }

    @Override // com.taobao.weex.ui.component.WXComponent, com.taobao.weex.IWXActivityStateListener
    public void onActivityDestroy() {
        super.onActivityDestroy();
        int childCount = childCount();
        for (int i = 0; i < childCount; i++) {
            getChild(i).onActivityDestroy();
        }
    }

    @Override // com.taobao.weex.ui.component.WXComponent, com.taobao.weex.IWXActivityStateListener
    public boolean onActivityBack() {
        super.onActivityBack();
        int childCount = childCount();
        for (int i = 0; i < childCount; i++) {
            getChild(i).onActivityBack();
        }
        return false;
    }

    @Override // com.taobao.weex.ui.component.WXComponent
    public void onActivityResult(int requestCode, int resultCode, Intent data) {
        super.onActivityResult(requestCode, resultCode, data);
        int childCount = childCount();
        for (int i = 0; i < childCount; i++) {
            getChild(i).onActivityResult(requestCode, resultCode, data);
        }
    }

    @Override // com.taobao.weex.ui.component.WXComponent
    public boolean onCreateOptionsMenu(Menu menu) {
        super.onCreateOptionsMenu(menu);
        int childCount = childCount();
        for (int i = 0; i < childCount; i++) {
            getChild(i).onCreateOptionsMenu(menu);
        }
        return false;
    }

    @Override // com.taobao.weex.ui.component.WXComponent
    public void onRequestPermissionsResult(int requestCode, String[] permissions, int[] grantResults) {
        super.onRequestPermissionsResult(requestCode, permissions, grantResults);
        int childCount = childCount();
        for (int i = 0; i < childCount; i++) {
            getChild(i).onRequestPermissionsResult(requestCode, permissions, grantResults);
        }
    }

    @Override // com.taobao.weex.ui.component.WXComponent
    public void onRenderFinish(int state) {
        for (int i = 0; i < getChildCount(); i++) {
            WXComponent child = getChild(i);
            if (child != null) {
                child.mTraceInfo.uiQueueTime = this.mTraceInfo.uiQueueTime;
                child.onRenderFinish(state);
            }
        }
        super.onRenderFinish(state);
    }

    /* JADX WARN: Type inference failed for: r0v1, types: [android.view.View] */
    @UniJSMethod
    public void releaseImageList(String viewTreeRecycle) {
        if (getHostView() != 0 && ViewCompat.isAttachedToWindow(getHostView()) && (getHostView() instanceof ViewGroup)) {
            if (WXUtils.getBoolean(viewTreeRecycle, false).booleanValue()) {
                doViewTreeRecycleImageView((ViewGroup) getHostView(), true);
                return;
            }
            int childCount = getChildCount();
            for (int i = 0; i < childCount; i++) {
                WXComponent child = getChild(i);
                if ((child instanceof WXImage) && (((WXImage) child).getHostView() instanceof WXImageView)) {
                    WXImageView wXImageView = (WXImageView) child.getHostView();
                    if (wXImageView != null && ViewCompat.isAttachedToWindow(wXImageView)) {
                        wXImageView.autoReleaseImage();
                    }
                } else if (child instanceof WXVContainer) {
                    ((WXVContainer) child).releaseImageList(viewTreeRecycle);
                }
            }
        }
    }

    /* JADX WARN: Type inference failed for: r0v1, types: [android.view.View] */
    @UniJSMethod
    public void recoverImageList(String viewTreeRecycle) {
        if (getHostView() != 0 && ViewCompat.isAttachedToWindow(getHostView()) && (getHostView() instanceof ViewGroup)) {
            if (WXUtils.getBoolean(viewTreeRecycle, false).booleanValue()) {
                doViewTreeRecycleImageView((ViewGroup) getHostView(), false);
                return;
            }
            int childCount = getChildCount();
            for (int i = 0; i < childCount; i++) {
                WXComponent child = getChild(i);
                if ((child instanceof WXImage) && (((WXImage) child).getHostView() instanceof WXImageView)) {
                    WXImageView wXImageView = (WXImageView) child.getHostView();
                    if (wXImageView != null && ViewCompat.isAttachedToWindow(wXImageView)) {
                        wXImageView.autoRecoverImage();
                    }
                } else if (child instanceof WXVContainer) {
                    ((WXVContainer) child).recoverImageList(viewTreeRecycle);
                }
            }
        }
    }

    private void doViewTreeRecycleImageView(ViewGroup viewGroup, boolean isRelease) {
        int childCount = viewGroup.getChildCount();
        for (int i = 0; i < childCount; i++) {
            View childAt = viewGroup.getChildAt(i);
            if (childAt instanceof WXImageView) {
                if (isRelease) {
                    ((WXImageView) childAt).autoReleaseImage();
                } else {
                    ((WXImageView) childAt).autoRecoverImage();
                }
            } else if (childAt instanceof ViewGroup) {
                doViewTreeRecycleImageView((ViewGroup) childAt, isRelease);
            }
        }
    }

    public void requestDisallowInterceptTouchEvent(boolean requestDisallowInterceptTouchEvent) {
        if (this.mGesture != null) {
            if (this.mGesture.isRequestDisallowInterceptTouchEvent()) {
                return;
            }
            this.mGesture.setRequestDisallowInterceptTouchEvent(requestDisallowInterceptTouchEvent);
        }
        if (getParent() != null) {
            getParent().requestDisallowInterceptTouchEvent(requestDisallowInterceptTouchEvent);
        }
    }
}
