package io.dcloud.feature.weex;

import android.content.Context;
import android.content.DialogInterface;
import android.content.res.Configuration;
import android.net.Uri;
import android.os.Handler;
import android.os.Message;
import android.os.Process;
import android.text.TextUtils;
import android.view.View;
import android.view.ViewGroup;
import android.widget.LinearLayout;
import androidx.recyclerview.widget.RecyclerView;
import com.taobao.weex.IWXInstanceContainerOnSizeListener;
import com.taobao.weex.IWXRenderListener;
import com.taobao.weex.R;
import com.taobao.weex.WXEnvironment;
import com.taobao.weex.WXSDKInstance;
import com.taobao.weex.WXSDKManager;
import com.taobao.weex.bridge.WXBridgeManager;
import com.taobao.weex.bridge.WXParams;
import com.taobao.weex.common.WXRenderStrategy;
import com.taobao.weex.el.parse.Operators;
import com.taobao.weex.ui.component.WXBasicComponentType;
import com.taobao.weex.ui.view.WXScrollView;
import com.taobao.weex.ui.view.listview.WXRecyclerView;
import com.taobao.weex.ui.view.refresh.wrapper.BounceRecyclerView;
import com.taobao.weex.utils.WXUtils;
import com.taobao.weex.utils.WXViewUtils;
import com.taobao.weex.utils.tools.LogDetail;
import io.dcloud.common.DHInterface.AbsMgr;
import io.dcloud.common.DHInterface.IActivityHandler;
import io.dcloud.common.DHInterface.IApp;
import io.dcloud.common.DHInterface.IEventCallback;
import io.dcloud.common.DHInterface.IMgr;
import io.dcloud.common.DHInterface.ITitleNView;
import io.dcloud.common.DHInterface.IWebview;
import io.dcloud.common.adapter.ui.AdaContainerFrameItem;
import io.dcloud.common.adapter.ui.AdaFrameView;
import io.dcloud.common.adapter.ui.AdaUniWebView;
import io.dcloud.common.adapter.ui.AdaWebview;
import io.dcloud.common.adapter.ui.webview.WebResUtil;
import io.dcloud.common.adapter.util.DeviceInfo;
import io.dcloud.common.adapter.util.Logger;
import io.dcloud.common.adapter.util.ViewOptions;
import io.dcloud.common.constant.AbsoluteConst;
import io.dcloud.common.util.BaseInfo;
import io.dcloud.common.util.ErrorDialogUtil;
import io.dcloud.common.util.IOUtil;
import io.dcloud.common.util.JSONUtil;
import io.dcloud.common.util.PdrUtil;
import io.dcloud.common.util.StringUtil;
import io.dcloud.common.util.ThreadPool;
import io.dcloud.common.util.TitleNViewUtil;
import io.dcloud.common.util.language.LanguageUtil;
import io.dcloud.feature.internal.sdk.SDK;
import io.dcloud.feature.uniapp.UniSDKInstance;
import io.dcloud.feature.weex.WeexInstanceMgr;
import io.dcloud.feature.weex_scroller.view.DCWXScrollView;
import io.dcloud.weex.WXDotDataUtil;
import java.io.File;
import java.io.IOException;
import java.io.InputStream;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;
import java.util.regex.Matcher;
import java.util.regex.Pattern;
import org.json.JSONException;
import org.json.JSONObject;
/* JADX INFO: Access modifiers changed from: package-private */
/* loaded from: classes26.dex */
public class WXViewWrapper extends WXBaseWrapper implements IWXRenderListener, IEventCallback, WeexInstanceMgr.IWXStatisticsCallBack {
    static final int LOAD_JS = 1000;
    String TAG;
    private boolean hasScrollListener;
    private boolean isChlid;
    private boolean isCompilerWithUniapp;
    boolean isDelayRender;
    private boolean isFrameShow;
    private boolean isPre;
    boolean isReady;
    boolean isService;
    JSONObject jsonObject;
    long lastTime;
    List<FireEvent> mFireCaches;
    int mFontSize;
    Handler mHandler;
    IWXInstanceContainerOnSizeListener mInstanceOnSizeListener;
    private float mLastScreenWidth;
    JSONObject mNvueCfgData;
    private List<Message> mRenderCaches;
    LogDetail mServiceLogDetail;
    private String mUniPagePath;
    float mViewPort;
    View mWXSDKView;
    private List<Message> mWaitServiceRenderList;
    private String readyJs;
    long time;

    @Override // io.dcloud.feature.weex.WXBaseWrapper, io.dcloud.common.DHInterface.IUniNView
    public String getType() {
        return WXBasicComponentType.VIEW;
    }

    @Override // com.taobao.weex.IWXRenderListener
    public void onRefreshSuccess(WXSDKInstance instance, int width, int height) {
    }

    public List<Message> getWaitServiceRenderList() {
        return this.mWaitServiceRenderList;
    }

    @Override // io.dcloud.feature.weex.WXBaseWrapper
    public void onReady() {
        this.isReady = true;
        runFireCache();
        if (this.isService) {
            if (!SDK.isUniMPSDK()) {
                WeexInstanceMgr.self().doForFeature(IMgr.MgrType.FeatureMgr, 10, new Object[]{this.mWebview.obtainApp(), WeexInstanceMgr.self().getUniMPFeature(), "onUniMPInit", new Object[0]});
            }
            LogDetail logDetail = this.mServiceLogDetail;
            if (logDetail != null) {
                logDetail.taskEnd();
                WXDotDataUtil.setValue(this.mServiceLogDetail.info.taskName, Long.valueOf(this.mServiceLogDetail.time.execTime));
            }
        }
    }

    private synchronized void runFireCache() {
        if (!this.mFireCaches.isEmpty()) {
            for (int i = 0; i < this.mFireCaches.size(); i++) {
                FireEvent fireEvent = this.mFireCaches.get(i);
                fireGlobalEvent(fireEvent.key, fireEvent.params);
            }
            this.mFireCaches.clear();
        }
    }

    /* JADX INFO: Access modifiers changed from: package-private */
    public WXViewWrapper(IWebview webview, ViewGroup viewGroup, JSONObject jsonObject, String wxId, int zIndex, boolean isPre) {
        super(viewGroup.getContext());
        this.TAG = "WXViewWrapper";
        this.lastTime = 0L;
        this.isService = false;
        this.readyJs = ";var plusModule = weex.requireModule('plus'); plusModule.uniReady();";
        this.isReady = false;
        this.mFontSize = -1;
        this.mNvueCfgData = null;
        this.isDelayRender = false;
        this.mRenderCaches = new ArrayList();
        this.mWaitServiceRenderList = new ArrayList();
        this.isFrameShow = false;
        this.isChlid = false;
        this.isPre = false;
        this.isCompilerWithUniapp = true;
        this.mHandler = new Handler() { // from class: io.dcloud.feature.weex.WXViewWrapper.1
            @Override // android.os.Handler
            public void handleMessage(Message msg) {
                super.handleMessage(msg);
                if (msg.what != 1000) {
                    return;
                }
                if (!WXViewWrapper.this.isService) {
                    WXViewWrapper.this.delayedRender(msg.obj, 10);
                } else if (WXViewWrapper.this.mWebview == null) {
                } else {
                    String obtainConfigProperty = WXViewWrapper.this.mWebview.obtainApp().obtainConfigProperty(AbsoluteConst.NVUE_LAUNCH_MODE);
                    if (TextUtils.isEmpty(obtainConfigProperty) || !obtainConfigProperty.equals("fast") || !WeexInstanceMgr.self().getControl().equals(AbsoluteConst.UNI_V3) || WXEnvironment.sRemoteDebugMode) {
                        WXViewWrapper.this.delayedRender(msg.obj, 10L);
                        return;
                    }
                    JSONObject obtainThridInfo = WXViewWrapper.this.mWebview.obtainApp().obtainThridInfo(IApp.ConfigProperty.ThridInfo.LaunchWebviewJsonData);
                    if (obtainThridInfo == null || !obtainThridInfo.has(AbsoluteConst.JSON_KEY_UNINVIEW)) {
                        WXViewWrapper.this.delayedRender(msg.obj, 10L);
                    } else {
                        WXViewWrapper.this.delayedRender(msg.obj, 100L);
                    }
                }
            }
        };
        this.mInstanceOnSizeListener = new IWXInstanceContainerOnSizeListener() { // from class: io.dcloud.feature.weex.WXViewWrapper.2
            @Override // com.taobao.weex.IWXInstanceContainerOnSizeListener
            public void onSizeChanged(String instanceId, float defaultWidth, float defaultHeight, boolean isWidthWrapContent, boolean isHeightWrapContent) {
                WXViewWrapper.this.updateDeviceDisplay(defaultWidth, defaultHeight, isWidthWrapContent, isHeightWrapContent);
            }
        };
        this.hasScrollListener = false;
        this.time = 0L;
        this.mLastScreenWidth = 0.0f;
        this.lastTime = System.currentTimeMillis();
        String str = this.TAG;
        Logger.e(str, "WXViewWrapper----------isPre=" + isPre + "  wxid=" + wxId);
        if (!WeexInstanceMgr.self().isJsFrameworkReady()) {
            WeexInstanceMgr.self().setWXStatisticsCallBack(this);
        }
        this.isCompilerWithUniapp = !WeexInstanceMgr.self().getComplier().equalsIgnoreCase("weex");
        this.mWebview = webview;
        this.isPre = isPre;
        this.mFireCaches = new ArrayList();
        if (this.mWebview instanceof AdaUniWebView) {
            this.isService = ((AdaUniWebView) this.mWebview).isUniService();
        }
        if (WeexInstanceMgr.self().isJSFKFileNotFound()) {
            boolean z = WeexInstanceMgr.self().getVueVersion() == 3;
            String string = webview.getContext().getString(R.string.dcloud_feature_weex_jsfk_not_found_tips);
            Object[] objArr = new Object[1];
            objArr[0] = z ? "VUE3" : "VUE2";
            ErrorDialogUtil.showErrorTipsAlert(webview.getActivity(), StringUtil.format(string, objArr), new DialogInterface.OnClickListener() { // from class: io.dcloud.feature.weex.WXViewWrapper.3
                @Override // android.content.DialogInterface.OnClickListener
                public void onClick(DialogInterface dialog, int which) {
                    Process.killProcess(Process.myPid());
                }
            });
            return;
        }
        viewGroup.addView(this, zIndex, new ViewGroup.LayoutParams(-1, -1));
        ((AdaFrameView) this.mWebview.obtainFrameView()).addFrameViewListener(this);
        this.jsonObject = jsonObject;
        this.lastTime = System.currentTimeMillis();
        this.mWxId = wxId;
        this.mNvueCfgData = JSONUtil.createJSONObject(this.mWebview.obtainApp().obtainConfigProperty(IApp.ConfigProperty.UNI_NVUE_DATA));
    }

    /* JADX INFO: Access modifiers changed from: private */
    public Map<String, Object> getInitOptions() {
        int indexOf;
        HashMap hashMap = new HashMap();
        if (this.mWebview != null) {
            hashMap.put("plus_appid", this.mWebview.obtainApp().obtainAppId());
        }
        if (this.mWebview != null) {
            hashMap.put("plus_web_id", this.mWebview.obtainFrameId());
        }
        String str = this.mSrcPath;
        if (!TextUtils.isEmpty(this.mPath) && str.indexOf(Operators.CONDITION_IF_STRING) == -1 && (indexOf = this.mPath.indexOf(Operators.CONDITION_IF_STRING)) > 0) {
            str = str + this.mPath.substring(indexOf);
        }
        hashMap.put("deviceLanguage", LanguageUtil.getDeviceDefLocalLanguage());
        hashMap.put("deviceCountry", LanguageUtil.getDeviceDefCountry());
        hashMap.put("isInternational", Boolean.valueOf(PdrUtil.checkIntl()));
        hashMap.put("bundleUrl", str);
        if (getWxId().equals("__uniapp__service")) {
            hashMap.put("plus_weex_id", "__uniapp__service");
        }
        return hashMap;
    }

    public String getSrcPath() {
        return this.mSrcPath;
    }

    public String getWxId() {
        return this.mWxId;
    }

    /* JADX INFO: Access modifiers changed from: private */
    public String getInitStringJsonData() {
        JSONObject jSONObject = new JSONObject();
        try {
            String originalUrl = this.mWebview.getOriginalUrl();
            if (originalUrl.startsWith(DeviceInfo.FILE_PROTOCOL)) {
                originalUrl = originalUrl.substring(7);
            }
            jSONObject.put("Plus_InitURL", this.mWebview.obtainApp().convert2RelPath(originalUrl));
        } catch (JSONException e) {
            e.printStackTrace();
        }
        return jSONObject.toString();
    }

    @Override // io.dcloud.feature.weex.WXBaseWrapper, io.dcloud.common.DHInterface.IUniNView
    public String evalJs(String js, int type) {
        return this.mWXSDKInstance != null ? WXBridgeManager.getInstance().syncExecJsOnInstanceWithResult(this.mWXSDKInstance.getInstanceId(), js, type) : "";
    }

    /* JADX INFO: Access modifiers changed from: private */
    public void render(Object template, Map<String, Object> options, String jsonInitData) {
        if (this.mWXSDKInstance != null) {
            recoveryInstance();
        }
        if (this.mWebview == null || this.mWebview.obtainFrameView() == null) {
            return;
        }
        if (this.isService && BaseInfo.SyncDebug) {
            if (this.mServiceLogDetail == null) {
                LogDetail logDetail = new LogDetail();
                this.mServiceLogDetail = logDetail;
                logDetail.name("initV3Service");
            }
            this.mServiceLogDetail.taskStart();
        }
        this.isChlid = ((AdaFrameView) this.mWebview.obtainFrameView()).isChildOfFrameView;
        this.isReady = false;
        if (this.isPre) {
            if (WeexInstanceMgr.self().getPreInstanceId() != null) {
                this.mWXSDKInstance = WXSDKManager.getInstance().getSDKInstance(WeexInstanceMgr.self().getPreInstanceId());
                if (this.mWXSDKInstance != null) {
                    this.mWXSDKInstance.init(this.mWebview.getContext());
                    onReady();
                    fireGlobalEvent("launchApp", new HashMap());
                }
            }
        } else {
            String str = (String) template;
            if (!WXEnvironment.sRemoteDebugMode) {
                str = str.replaceFirst(Pattern.quote("\"use weex:vue\""), Matcher.quoteReplacement(""));
            }
            template = str + this.readyJs;
        }
        if (!this.isPre) {
            if (this.mWebview.getActivity() instanceof IActivityHandler) {
                this.mWXSDKInstance = new UniSDKInstance(this.mWebview.getContext(), ((IActivityHandler) this.mWebview.getActivity()).getOriginalContext());
            } else {
                this.mWXSDKInstance = new UniSDKInstance(this.mWebview.getContext());
            }
        }
        if (this.mFontSize > 0) {
            this.mWXSDKInstance.setDefaultFontSize(this.mFontSize);
        }
        this.mWXSDKInstance.setPageKeepRawCssStyles();
        this.mWXSDKInstance.setImmersive(this.mWebview.obtainApp().obtainStatusBarMgr().isImmersive);
        this.mWXAnaly = new WXAnalyzerDelegate(this.mWebview.getContext());
        this.mWXSDKInstance.registerRenderListener(this);
        this.mWXSDKInstance.setBundleUrl(this.mSrcPath);
        this.mWXSDKInstance.setUniPagePath(this.isService ? "app-service.js" : this.mUniPagePath);
        this.mWXSDKInstance.setWXInstanceContainerOnSizeListener(this.mInstanceOnSizeListener);
        ((UniSDKInstance) this.mWXSDKInstance).setCompilerWithUniapp(this.isCompilerWithUniapp);
        int frameType = this.mWebview.obtainFrameView().getFrameType();
        if ((this.isFrameShow || frameType == 2 || frameType == 4) && this.mWXSDKInstance != null) {
            this.mWXSDKInstance.onShowAnimationEnd();
        }
        if (!this.isPre) {
            this.mWXSDKInstance.render(this.mWxId, String.valueOf(template), options, jsonInitData, WXRenderStrategy.APPEND_ASYNC);
        }
        if (!this.isService && (this.mWebview instanceof AdaWebview)) {
            ((AdaWebview) this.mWebview).dispatchWebviewStateEvent(0, this.mPath);
        }
        initViewPortWidth(false);
        initFlexDirection();
        initTitleNView();
        if (this.isService) {
            WeexInstanceMgr.self().setUniServiceCreated(true, this.mWebview.obtainApp());
        }
    }

    private void initTitleNView() {
        AdaFrameView adaFrameView = (AdaFrameView) this.mWebview.obtainFrameView();
        JSONObject jSONObject = adaFrameView.obtainFrameOptions().titleNView;
        if (jSONObject == null || adaFrameView.isChildOfFrameView || !jSONObject.has("type") || !"transparent".equals(jSONObject.optString("type"))) {
            return;
        }
        this.mWXSDKInstance.addOnInstanceVisibleListener(new WXSDKInstance.OnInstanceVisibleListener() { // from class: io.dcloud.feature.weex.WXViewWrapper.4
            @Override // com.taobao.weex.WXSDKInstance.OnInstanceVisibleListener
            public void onDisappear() {
            }

            @Override // com.taobao.weex.WXSDKInstance.OnInstanceVisibleListener
            public void onAppear() {
                WXViewWrapper.this.addScrollListener(this);
            }
        });
    }

    /* JADX WARN: Code restructure failed: missing block: B:24:0x005e, code lost:
        if ("tab".equals(r4.obtainWebView().obtainFrameId()) != false) goto L23;
     */
    /*
        Code decompiled incorrectly, please refer to instructions dump.
    */
    public void addScrollListener(WXSDKInstance.OnInstanceVisibleListener listener) {
        if (this.mWXSDKInstance == null || this.mWXSDKInstance.getRootView() == null || this.hasScrollListener) {
            return;
        }
        boolean z = true;
        this.hasScrollListener = true;
        final AdaFrameView adaFrameView = (AdaFrameView) this.mWebview.obtainFrameView();
        ViewOptions obtainFrameOptions = adaFrameView.obtainFrameOptions();
        ViewOptions obtainFrameOptions2 = adaFrameView.obtainWebviewParent().obtainFrameOptions();
        final JSONObject jSONObject = obtainFrameOptions.titleNView;
        if (jSONObject == null && obtainFrameOptions2.titleNView != null) {
            jSONObject = obtainFrameOptions2.titleNView;
        }
        if (jSONObject == null || !jSONObject.has("type")) {
            return;
        }
        AdaContainerFrameItem parentFrameItem = adaFrameView.getParentFrameItem();
        if (parentFrameItem instanceof AdaFrameView) {
            AdaFrameView adaFrameView2 = (AdaFrameView) parentFrameItem;
            if (adaFrameView2.obtainWebView() != null) {
            }
        }
        z = false;
        if (jSONObject != null) {
            if ((!adaFrameView.isChildOfFrameView || z) && jSONObject.has("type") && "transparent".equals(jSONObject.optString("type")) && this.mWXSDKInstance != null) {
                View rootView = this.mWXSDKInstance.getRootView();
                if (rootView != null && listener != null) {
                    this.mWXSDKInstance.removeOnInstanceVisibleListener(listener);
                }
                if (rootView instanceof DCWXScrollView) {
                    ((DCWXScrollView) rootView).addScrollViewListener(new DCWXScrollView.WXScrollViewListener() { // from class: io.dcloud.feature.weex.WXViewWrapper.5
                        @Override // io.dcloud.feature.weex_scroller.view.DCWXScrollView.WXScrollViewListener
                        public void onScroll(DCWXScrollView scrollView, int x, int y) {
                        }

                        @Override // io.dcloud.feature.weex_scroller.view.DCWXScrollView.WXScrollViewListener
                        public void onScrollStopped(DCWXScrollView scrollView, int x, int y) {
                        }

                        @Override // io.dcloud.feature.weex_scroller.view.DCWXScrollView.WXScrollViewListener
                        public void onScrollToBottom(DCWXScrollView scrollView, int x, int y) {
                        }

                        @Override // io.dcloud.feature.weex_scroller.view.DCWXScrollView.WXScrollViewListener
                        public void onScrollToTop(DCWXScrollView scrollView, int x, int y) {
                        }

                        @Override // io.dcloud.feature.weex_scroller.view.DCWXScrollView.WXScrollViewListener
                        public void onScrollChanged(DCWXScrollView scrollView, int x, int t, int oldx, int oldt) {
                            AdaFrameView adaFrameView3 = adaFrameView;
                            if (adaFrameView3 == null || jSONObject == null) {
                                return;
                            }
                            int i = adaFrameView3.obtainFrameOptions().coverage;
                            if (i >= oldt || i >= t) {
                                AbsMgr obtainWindowMgr = adaFrameView.obtainWindowMgr();
                                IWebview obtainWebView = adaFrameView.obtainWebView();
                                AdaFrameView adaFrameView4 = adaFrameView;
                                Object titleNView = TitleNViewUtil.getTitleNView(obtainWindowMgr, obtainWebView, adaFrameView4, TitleNViewUtil.getTitleNViewId(adaFrameView4));
                                if (titleNView instanceof ITitleNView) {
                                    TitleNViewUtil.updateTitleNViewStatus((ITitleNView) titleNView, adaFrameView.obtainWebView(), t, jSONObject, i);
                                }
                            }
                        }
                    });
                } else if (rootView instanceof WXScrollView) {
                    ((WXScrollView) rootView).addScrollViewListener(new WXScrollView.WXScrollViewListener() { // from class: io.dcloud.feature.weex.WXViewWrapper.6
                        @Override // com.taobao.weex.ui.view.WXScrollView.WXScrollViewListener
                        public void onScroll(WXScrollView scrollView, int x, int y) {
                        }

                        @Override // com.taobao.weex.ui.view.WXScrollView.WXScrollViewListener
                        public void onScrollStopped(WXScrollView scrollView, int x, int y) {
                        }

                        @Override // com.taobao.weex.ui.view.WXScrollView.WXScrollViewListener
                        public void onScrollToBottom(WXScrollView scrollView, int x, int y) {
                        }

                        @Override // com.taobao.weex.ui.view.WXScrollView.WXScrollViewListener
                        public void onScrollChanged(WXScrollView scrollView, int x, int t, int oldx, int oldt) {
                            AdaFrameView adaFrameView3 = adaFrameView;
                            if (adaFrameView3 == null || jSONObject == null) {
                                return;
                            }
                            int i = adaFrameView3.obtainFrameOptions().coverage;
                            if (i >= oldt || i >= t) {
                                AbsMgr obtainWindowMgr = adaFrameView.obtainWindowMgr();
                                IWebview obtainWebView = adaFrameView.obtainWebView();
                                AdaFrameView adaFrameView4 = adaFrameView;
                                Object titleNView = TitleNViewUtil.getTitleNView(obtainWindowMgr, obtainWebView, adaFrameView4, TitleNViewUtil.getTitleNViewId(adaFrameView4));
                                if (titleNView instanceof ITitleNView) {
                                    TitleNViewUtil.updateTitleNViewStatus((ITitleNView) titleNView, adaFrameView.obtainWebView(), t, jSONObject, i);
                                }
                            }
                        }
                    });
                } else if (rootView instanceof BounceRecyclerView) {
                    ((WXRecyclerView) ((BounceRecyclerView) rootView).getInnerView()).addOnScrollListener(new RecyclerView.OnScrollListener() { // from class: io.dcloud.feature.weex.WXViewWrapper.7
                        int oldx;
                        int oldy;

                        @Override // androidx.recyclerview.widget.RecyclerView.OnScrollListener
                        public void onScrolled(RecyclerView recyclerView, int dx, int dy) {
                            int i = this.oldx;
                            int i2 = this.oldy;
                            this.oldx = i + dx;
                            this.oldy = dy + i2;
                            AdaFrameView adaFrameView3 = adaFrameView;
                            if (adaFrameView3 == null || jSONObject == null) {
                                return;
                            }
                            int i3 = adaFrameView3.obtainFrameOptions().coverage;
                            if (i3 >= i2 || i3 >= this.oldy) {
                                AbsMgr obtainWindowMgr = adaFrameView.obtainWindowMgr();
                                IWebview obtainWebView = adaFrameView.obtainWebView();
                                AdaFrameView adaFrameView4 = adaFrameView;
                                Object titleNView = TitleNViewUtil.getTitleNView(obtainWindowMgr, obtainWebView, adaFrameView4, TitleNViewUtil.getTitleNViewId(adaFrameView4));
                                if (titleNView instanceof ITitleNView) {
                                    TitleNViewUtil.updateTitleNViewStatus((ITitleNView) titleNView, adaFrameView.obtainWebView(), this.oldy, jSONObject, i3);
                                }
                            }
                        }
                    });
                }
            }
        }
    }

    @Override // io.dcloud.feature.weex.WXBaseWrapper
    protected void onRefresh() {
        if (this.mWebview != null) {
            ((AdaFrameView) this.mWebview.obtainFrameView()).dispatchFrameViewEvents(AbsoluteConst.EVENTS_PULL_DOWN_EVENT, 3);
            ((AdaFrameView) this.mWebview.obtainFrameView()).dispatchFrameViewEvents(AbsoluteConst.EVENTS_PULL_TO_REFRESH, 3);
        }
    }

    @Override // io.dcloud.feature.weex.WXBaseWrapper, io.dcloud.common.DHInterface.IUniNView
    public void loadTemplate(JSONObject info) {
        JSONObject optJSONObject;
        try {
            this.jsonObject = info;
            this.mPath = info.optString("js");
            JSONObject jSONObject = this.jsonObject;
            if (jSONObject != null && jSONObject.has("data") && (optJSONObject = this.jsonObject.optJSONObject("data")) != null) {
                this.mFontSize = optJSONObject.optInt("defaultFontSize");
                if (optJSONObject.has("delayRender")) {
                    this.isDelayRender = optJSONObject.optBoolean("delayRender", this.isDelayRender);
                }
                if (optJSONObject.has(AbsoluteConst.XML_PATH)) {
                    this.mUniPagePath = optJSONObject.optString(AbsoluteConst.XML_PATH, "") + ".nvue";
                }
            }
            if (PdrUtil.isNetPath(this.mPath)) {
                return;
            }
            this.mSrcPath = initSrcPath(this.mPath);
            if (this.isPre) {
                render(null, getInitOptions(), getInitStringJsonData());
            } else {
                ThreadPool.self().addThreadTask(new Runnable() { // from class: io.dcloud.feature.weex.WXViewWrapper.8
                    @Override // java.lang.Runnable
                    public void run() {
                        InputStream encryptionInputStream;
                        if (WXViewWrapper.this.mWebview == null || (encryptionInputStream = WebResUtil.getEncryptionInputStream(WXViewWrapper.this.mSrcPath, WXViewWrapper.this.mWebview.obtainApp())) == null) {
                            return;
                        }
                        try {
                            String str = new String(IOUtil.toString(encryptionInputStream));
                            if (WXViewWrapper.this.isService) {
                                str = WXViewWrapper.this.getAllUniService(str);
                            }
                            Message message = new Message();
                            message.obj = str;
                            message.what = 1000;
                            if (!WXViewWrapper.this.isService && !WeexInstanceMgr.self().isUniServiceCreated(WXViewWrapper.this.mWebview.obtainApp())) {
                                if (!WXViewWrapper.this.mWaitServiceRenderList.contains(message)) {
                                    WXViewWrapper.this.mWaitServiceRenderList.add(message);
                                }
                            } else if (!WeexInstanceMgr.self().isJsFrameworkReady()) {
                                if (!WXViewWrapper.this.mRenderCaches.contains(message)) {
                                    WXViewWrapper.this.mRenderCaches.add(message);
                                }
                            } else if (WXViewWrapper.this.isDelayRender && !WXViewWrapper.this.isService && !WXViewWrapper.this.isFrameShow) {
                                if (!WXViewWrapper.this.mRenderCaches.contains(message)) {
                                    WXViewWrapper.this.mRenderCaches.add(message);
                                }
                            } else {
                                WXViewWrapper.this.mHandler.sendMessage(message);
                            }
                        } catch (Exception e) {
                            e.printStackTrace();
                        }
                        IOUtil.close(encryptionInputStream);
                    }
                }, true);
            }
        } catch (Exception e) {
            e.printStackTrace();
        }
    }

    @Override // io.dcloud.feature.weex.WXBaseWrapper, io.dcloud.common.DHInterface.IUniNView
    public void titleNViewRefresh() {
        addScrollListener(null);
    }

    /* JADX INFO: Access modifiers changed from: private */
    public String getAllUniService(String template) {
        if (this.mWebview == null || this.mWebview.obtainApp() == null) {
            return "";
        }
        IApp obtainApp = this.mWebview.obtainApp();
        String initSrcPath = initSrcPath("_www/app-config.js");
        String initSrcPath2 = initSrcPath("_www/app-confusion.js");
        InputStream encryptionInputStream = WebResUtil.getEncryptionInputStream(initSrcPath, obtainApp);
        InputStream encryptionInputStream2 = WebResUtil.getEncryptionInputStream(initSrcPath2, obtainApp);
        try {
            String iOUtil = IOUtil.toString(encryptionInputStream);
            String iOUtil2 = IOUtil.toString(encryptionInputStream2);
            return iOUtil + iOUtil2 + template;
        } catch (IOException e) {
            e.printStackTrace();
            return template;
        }
    }

    /* JADX INFO: Access modifiers changed from: private */
    public void delayedRender(final Object template, long delayMilllis) {
        postDelayed(new Runnable() { // from class: io.dcloud.feature.weex.WXViewWrapper.9
            @Override // java.lang.Runnable
            public void run() {
                if (WXViewWrapper.this.mWebview == null) {
                    return;
                }
                WXViewWrapper wXViewWrapper = WXViewWrapper.this;
                wXViewWrapper.render(template, wXViewWrapper.getInitOptions(), WXViewWrapper.this.getInitStringJsonData());
            }
        }, delayMilllis);
    }

    public String initSrcPath(String path) {
        if (this.mWebview == null) {
            return path;
        }
        int indexOf = path.indexOf(Operators.CONDITION_IF_STRING);
        String substring = indexOf > 1 ? path.substring(0, indexOf) : path;
        if (substring.startsWith("/")) {
            substring = substring.substring(1);
        }
        String[] split = path.split("\\.");
        if (split.length == 1) {
            substring = substring + ".js";
        } else if (split.length == 2) {
            substring = split[0] + ".js";
        }
        File file = new File(substring);
        if (file.exists()) {
            return Uri.fromFile(file).toString();
        }
        byte obtainRunningAppMode = this.mWebview.obtainApp().obtainRunningAppMode();
        String obtainFullUrl = this.mWebview instanceof AdaUniWebView ? null : this.mWebview.obtainFullUrl();
        if (!substring.startsWith("/storage") && obtainRunningAppMode == 1) {
            String convert2AbsFullPath = this.mWebview.obtainApp().convert2AbsFullPath(obtainFullUrl, substring);
            return convert2AbsFullPath.startsWith("/") ? convert2AbsFullPath.substring(1, convert2AbsFullPath.length()) : convert2AbsFullPath;
        }
        return this.mWebview.obtainApp().convert2WebviewFullPath(obtainFullUrl, substring);
    }

    @Override // com.taobao.weex.IWXRenderListener
    public void onViewCreated(final WXSDKInstance instance, View view) {
        if (this.mWXAnaly != null) {
            this.mWXAnaly.onWeexViewCreated(instance, view);
        }
        this.mWXSDKView = view;
        addView(this.mWXSDKView, new LinearLayout.LayoutParams(-1, -1));
        this.mWXSDKView.layout(0, 0, getWidth(), getHeight());
        if (isFocusableInTouchMode()) {
            this.mWXSDKView.setFocusable(true);
            this.mWXSDKView.setFocusableInTouchMode(true);
        }
        addScrollListener(null);
    }

    @Override // android.view.View
    public void setFocusable(int focusable) {
        super.setFocusable(focusable);
        View view = this.mWXSDKView;
        if (view != null) {
            view.setFocusable(focusable);
        }
    }

    @Override // android.view.View
    public void setFocusableInTouchMode(boolean focusableInTouchMode) {
        super.setFocusableInTouchMode(focusableInTouchMode);
        View view = this.mWXSDKView;
        if (view != null) {
            view.setFocusableInTouchMode(focusableInTouchMode);
        }
    }

    @Override // com.taobao.weex.IWXRenderListener
    public void onRenderSuccess(WXSDKInstance instance, int width, int height) {
        if (this.mWXAnaly != null) {
            this.mWXAnaly.onWeexRenderSuccess(instance);
        }
        if (this.isService || this.mWebview == null) {
            return;
        }
        if (this.mWebview instanceof AdaWebview) {
            ((AdaWebview) this.mWebview).dispatchWebviewStateEvent(1, this.mPath);
        }
        String obtainConfigProperty = this.mWebview.obtainApp().obtainConfigProperty(IApp.ConfigProperty.CONFIG_AUTOCLOSE);
        if (PdrUtil.isEmpty(obtainConfigProperty)) {
            obtainConfigProperty = AbsoluteConst.TRUE;
        }
        if (Boolean.parseBoolean(obtainConfigProperty)) {
            this.mWebview.obtainFrameView().obtainWindowMgr().processEvent(IMgr.MgrType.WindowMgr, 11, this.mWebview.obtainFrameView());
        }
    }

    @Override // com.taobao.weex.IWXRenderListener
    public void onException(WXSDKInstance instance, String errCode, String msg) {
        String str = this.TAG;
        Logger.e(str, "onException--errCode=" + errCode + "    msg=" + msg);
        if (this.mWXAnaly != null) {
            this.mWXAnaly.onException(instance, errCode, msg);
        }
    }

    @Override // io.dcloud.feature.weex.WXBaseWrapper, io.dcloud.common.DHInterface.IUniNView
    public void onDestroy() {
        super.onDestroy();
        WeexInstanceMgr.self().unWXStatisticsCallBack(this);
        this.mWebview = null;
    }

    @Override // io.dcloud.feature.weex.WXBaseWrapper, io.dcloud.common.DHInterface.IUniNView
    public void reload() {
        if (this.time == 0 || System.currentTimeMillis() - this.time >= 600) {
            this.time = System.currentTimeMillis();
            recoveryInstance();
            this.isFrameShow = true;
            if (TextUtils.isEmpty(this.mPath)) {
                return;
            }
            loadTemplate(this.jsonObject);
        }
    }

    @Override // io.dcloud.common.DHInterface.IEventCallback
    public Object onCallBack(String pEventType, Object pArgs) {
        if (PdrUtil.isEquals(pEventType, AbsoluteConst.EVENTS_CLOSE) && (pArgs instanceof IWebview)) {
            ((AdaFrameView) ((IWebview) pArgs).obtainFrameView()).removeFrameViewListener(this);
            WeexInstanceMgr.self().removeWeexView(this.mWxId);
            onDestroy();
            return null;
        } else if ((PdrUtil.isEquals(pEventType, AbsoluteConst.EVENTS_SHOW_ANIMATION_END) || PdrUtil.isEquals(pEventType, AbsoluteConst.EVENTS_CHILD_INITIALIZE_SHOW)) && !this.isFrameShow) {
            this.isFrameShow = true;
            if (this.mWXSDKInstance != null) {
                this.mWXSDKInstance.onShowAnimationEnd();
            }
            if (this.isDelayRender) {
                runDelayedRenderCaches(this.mRenderCaches);
                return null;
            }
            return null;
        } else {
            return null;
        }
    }

    @Override // android.view.View
    protected void onConfigurationChanged(Configuration newConfig) {
        String str;
        int i;
        super.onConfigurationChanged(newConfig);
        if (this.mWXSDKInstance == null || this.mWebview.getActivity() == null) {
            return;
        }
        int rotation = this.mWebview.getActivity().getWindowManager().getDefaultDisplay().getRotation();
        if (rotation == 1) {
            str = "landscape";
            i = 90;
        } else if (rotation == 2) {
            str = "portraitReverse";
            i = 180;
        } else if (rotation != 3) {
            str = "portrait";
            i = 0;
        } else {
            str = "landscapeReverse";
            i = -90;
        }
        WXUtils.getCache().evictAll();
        HashMap hashMap = new HashMap();
        hashMap.put("value", str);
        hashMap.put("orientation", Integer.valueOf(i));
        this.mWXSDKInstance.fireGlobalEventCallback("orientationchange", hashMap);
        if (this.isCompilerWithUniapp) {
            this.mWXSDKInstance.setInstanceViewPortWidth(this.mWebview.obtainApp().getInt(0) / this.mWebview.getScale(), true);
        }
    }

    private void updateInitDeviceParams(Context context) {
        WXParams initParams = WXBridgeManager.getInstance().getInitParams();
        if (initParams == null || TextUtils.equals(initParams.getDeviceWidth(), String.valueOf(WXViewUtils.getScreenWidth(context)))) {
            return;
        }
        initParams.setDeviceWidth(String.valueOf(WXViewUtils.getScreenWidth(context)));
        initParams.setDeviceHeight(String.valueOf(WXViewUtils.getScreenHeight(context)));
        float f = WXEnvironment.sApplication.getResources().getDisplayMetrics().density;
        WXEnvironment.addCustomOptions("scale", Float.toString(f));
        WXBridgeManager.getInstance().updateInitDeviceParams(initParams.getDeviceWidth(), initParams.getDeviceHeight(), Float.toString(f), WXViewUtils.getStatusBarHeight(context) > 0 ? String.valueOf(WXViewUtils.getStatusBarHeight(context)) : null);
        WXBridgeManager.getInstance().setDeviceDisplay(this.mWXSDKInstance.getInstanceId(), WXViewUtils.getScreenWidth(context), WXViewUtils.getScreenHeight(context), WXViewUtils.getScreenDensity(context));
    }

    @Override // io.dcloud.feature.weex.WXBaseWrapper, io.dcloud.common.DHInterface.IUniNView
    public synchronized boolean fireGlobalEvent(final String key, final Map<String, Object> params) {
        if (this.isReady) {
            return super.fireGlobalEvent(key, params);
        }
        this.mFireCaches.add(new FireEvent(key, params));
        return true;
    }

    @Override // io.dcloud.feature.weex.WeexInstanceMgr.IWXStatisticsCallBack
    public void onJsFrameworkReady() {
        runDelayedRenderCaches(this.mRenderCaches);
        if (this.mWXSDKInstance != null) {
            initViewPortWidth(true);
            initFlexDirection();
        }
    }

    public void runDelayedRenderCaches(List<Message> list) {
        if (list.size() > 0) {
            for (int size = list.size() - 1; size >= 0; size--) {
                this.mHandler.sendMessage(list.get(size));
            }
            list.clear();
        }
    }

    private void initViewPortWidth(boolean fromMetaModule) {
        if (!this.isCompilerWithUniapp || this.mWXSDKInstance == null) {
            return;
        }
        int i = this.mWebview.obtainApp().getInt(0);
        if (fromMetaModule) {
            i = WXViewUtils.getScreenWidth(getContext());
        }
        this.mViewPort = i / this.mWebview.getScale();
        this.mWXSDKInstance.setInstanceViewPortWidth(this.mViewPort, fromMetaModule);
    }

    private void initFlexDirection() {
        JSONObject jSONObject = this.mNvueCfgData;
        if (jSONObject == null || !jSONObject.has(AbsoluteConst.UNI_NVUE_FLEX_DIRECTION)) {
            return;
        }
        WXBridgeManager.getInstance().setFlexDirectionDef(this.mNvueCfgData.optString(AbsoluteConst.UNI_NVUE_FLEX_DIRECTION));
    }

    /* JADX INFO: Access modifiers changed from: package-private */
    /* loaded from: classes12.dex */
    public class FireEvent {
        String key;
        Map<String, Object> params;

        public FireEvent(String key, Map<String, Object> params) {
            this.key = key;
            this.params = params;
        }
    }

    @Override // io.dcloud.feature.weex.WXBaseWrapper
    public void recoveryInstance() {
        View currentFocus;
        if (this.mWXSDKView != null) {
            if (!this.isChlid && (currentFocus = this.mWebview.getActivity().getCurrentFocus()) != null) {
                DeviceInfo.hideIME(currentFocus);
            }
            this.mWXSDKView.clearFocus();
            clearFocus();
            removeView(this.mWXSDKView);
            this.mWXSDKView = null;
            this.isPre = false;
        }
        super.recoveryInstance();
        this.isFrameShow = false;
    }

    @Override // android.view.View
    protected void onSizeChanged(int w, int h, int oldw, int oldh) {
        super.onSizeChanged(w, h, oldw, oldh);
        if (this.mWebview == null || !(this.mWebview instanceof AdaUniWebView)) {
            return;
        }
        try {
            ((AdaUniWebView) this.mWebview).updateScreenAndDisplay();
        } catch (Exception e) {
            e.printStackTrace();
        }
    }

    /* JADX INFO: Access modifiers changed from: private */
    public void updateDeviceDisplay(float defaultWidth, float defaultHeight, boolean isWidthWrapContent, boolean isHeightWrapContent) {
        if (this.mWXSDKInstance == null || this.mWebview == null || this.mWebview.getActivity() == null) {
            return;
        }
        int i = this.mWebview.obtainApp().getInt(2);
        int i2 = this.mWebview.obtainApp().getInt(0);
        int i3 = this.mWebview.obtainApp().getInt(1);
        if (this.mWXSDKInstance.isOnSizeChangedRender() && this.mWXSDKInstance.isOnSizeChangedRender()) {
            HashMap hashMap = new HashMap();
            float scale = this.mWebview.getScale();
            hashMap.put("resolutionHeight", Integer.valueOf((int) (i / scale)));
            float f = i2;
            int i4 = (int) (f / scale);
            hashMap.put("resolutionWidth", Integer.valueOf(i4));
            hashMap.put("dpiX", Float.valueOf(DeviceInfo.dpiX));
            hashMap.put("dpiY", Float.valueOf(DeviceInfo.dpiY));
            HashMap hashMap2 = new HashMap();
            hashMap2.put("resolutionHeight", Integer.valueOf((int) (i3 / scale)));
            hashMap2.put("resolutionWidth", Integer.valueOf(i4));
            StringBuilder sb = new StringBuilder();
            for (String str : hashMap.keySet()) {
                sb.append("plus.screen.");
                sb.append(str);
                sb.append("=");
                sb.append(hashMap.get(str));
                sb.append(";");
            }
            for (String str2 : hashMap2.keySet()) {
                sb.append("plus.display.");
                sb.append(str2);
                sb.append("=");
                sb.append(hashMap2.get(str2));
                sb.append(";");
            }
            this.mWebview.evalJS(sb.toString());
            if (this.isCompilerWithUniapp) {
                this.mWXSDKInstance.setInstanceViewPortWidth(f / this.mWebview.getScale(), true);
            }
            if (this.isService) {
                return;
            }
            this.mWXSDKInstance.setDeviceDisplayOfPage(i2, i3);
            this.mWXSDKInstance.reloadPageLayout();
            WXBridgeManager.getInstance().setDefaultRootSize(this.mWXSDKInstance.getInstanceId(), defaultWidth, defaultHeight, isWidthWrapContent, isHeightWrapContent);
        }
    }
}
