package io.dcloud.feature.weex.adapter;

import android.content.Context;
import android.graphics.drawable.Drawable;
import android.os.Looper;
import android.text.TextUtils;
import android.util.DisplayMetrics;
import android.widget.ImageView;
import com.bumptech.glide.Glide;
import com.bumptech.glide.load.DataSource;
import com.bumptech.glide.load.engine.GlideException;
import com.bumptech.glide.load.resource.gif.GifDrawable;
import com.bumptech.glide.request.BaseRequestOptions;
import com.bumptech.glide.request.RequestListener;
import com.bumptech.glide.request.RequestOptions;
import com.bumptech.glide.request.target.Target;
import com.taobao.weex.WXSDKManager;
import com.taobao.weex.common.WXImageStrategy;
import com.taobao.weex.dom.WXImageQuality;
import java.util.HashMap;
import java.util.Map;
/* loaded from: classes12.dex */
public class GlideImageAdapter {
    public static void setImage(final String url, final ImageView view, WXImageQuality quality, final WXImageStrategy strategy) {
        Runnable runnable = new Runnable() { // from class: io.dcloud.feature.weex.adapter.GlideImageAdapter.1
            @Override // java.lang.Runnable
            public void run() {
                ImageView imageView = view;
                if (imageView == null || imageView.getLayoutParams() == null) {
                    return;
                }
                if (TextUtils.isEmpty(url)) {
                    view.setImageBitmap(null);
                    return;
                }
                String str = url;
                if (str.startsWith("//")) {
                    str = "http:" + url;
                }
                if (view.getLayoutParams().width <= 0) {
                    return;
                }
                RequestOptions requestOptions = new RequestOptions();
                DisplayMetrics displayMetrics = view.getResources().getDisplayMetrics();
                requestOptions.override(displayMetrics.widthPixels, displayMetrics.heightPixels);
                Context context = view.getContext();
                if (str.contains(".gif")) {
                    Glide.with(context).asGif().load(str).apply((BaseRequestOptions<?>) requestOptions).listener(new RequestListener<GifDrawable>() { // from class: io.dcloud.feature.weex.adapter.GlideImageAdapter.1.1
                        @Override // com.bumptech.glide.request.RequestListener
                        public boolean onLoadFailed(GlideException e, Object model, Target<GifDrawable> target, boolean isFirstResource) {
                            HashMap hashMap = new HashMap();
                            hashMap.put("errorMessage", e.getMessage());
                            GlideImageAdapter.onImageFinish(strategy, url, view, false, hashMap);
                            return false;
                        }

                        @Override // com.bumptech.glide.request.RequestListener
                        public boolean onResourceReady(GifDrawable resource, Object model, Target<GifDrawable> target, DataSource dataSource, boolean isFirstResource) {
                            HashMap hashMap = new HashMap();
                            hashMap.put("width", Integer.valueOf(resource.getIntrinsicWidth()));
                            hashMap.put("height", Integer.valueOf(resource.getIntrinsicHeight()));
                            GlideImageAdapter.onImageFinish(strategy, url, view, true, hashMap);
                            return false;
                        }
                    }).into(view);
                } else {
                    Glide.with(context).load(str).apply((BaseRequestOptions<?>) requestOptions).listener(new RequestListener<Drawable>() { // from class: io.dcloud.feature.weex.adapter.GlideImageAdapter.1.2
                        @Override // com.bumptech.glide.request.RequestListener
                        public boolean onLoadFailed(GlideException e, Object model, Target<Drawable> target, boolean isFirstResource) {
                            HashMap hashMap = new HashMap();
                            hashMap.put("errorMessage", e.getMessage());
                            GlideImageAdapter.onImageFinish(strategy, url, view, false, hashMap);
                            return false;
                        }

                        @Override // com.bumptech.glide.request.RequestListener
                        public boolean onResourceReady(Drawable resource, Object model, Target<Drawable> target, DataSource dataSource, boolean isFirstResource) {
                            HashMap hashMap = new HashMap();
                            hashMap.put("width", Integer.valueOf(resource.getIntrinsicWidth()));
                            hashMap.put("height", Integer.valueOf(resource.getIntrinsicHeight()));
                            GlideImageAdapter.onImageFinish(strategy, url, view, true, hashMap);
                            return false;
                        }
                    }).into(view);
                }
            }
        };
        if (Thread.currentThread() == Looper.getMainLooper().getThread()) {
            runnable.run();
        } else {
            WXSDKManager.getInstance().postOnUiThread(runnable, 0L);
        }
    }

    /* JADX INFO: Access modifiers changed from: private */
    public static void onImageFinish(WXImageStrategy strategy, String url, ImageView view, boolean result, Map extra) {
        if (strategy == null || strategy.getImageListener() == null) {
            return;
        }
        strategy.getImageListener().onImageFinish(url, view, result, extra);
    }
}
