package io.dcloud.feature.weex.extend;

import android.content.Context;
import android.text.TextUtils;
import android.view.GestureDetector;
import android.view.MotionEvent;
import android.view.View;
import android.view.ViewGroup;
import android.widget.FrameLayout;
import androidx.viewpager.widget.ViewPager;
import com.taobao.weex.WXEnvironment;
import com.taobao.weex.WXSDKInstance;
import com.taobao.weex.WXSDKManager;
import com.taobao.weex.annotation.Component;
import com.taobao.weex.common.Constants;
import com.taobao.weex.dom.WXEvent;
import com.taobao.weex.ui.ComponentCreator;
import com.taobao.weex.ui.action.BasicComponentData;
import com.taobao.weex.ui.component.WXComponent;
import com.taobao.weex.ui.component.WXComponentProp;
import com.taobao.weex.ui.component.WXIndicator;
import com.taobao.weex.ui.component.WXVContainer;
import com.taobao.weex.ui.component.list.template.TemplateDom;
import com.taobao.weex.ui.view.BaseFrameLayout;
import com.taobao.weex.ui.view.WXCircleIndicator;
import com.taobao.weex.ui.view.WXCirclePageAdapter;
import com.taobao.weex.ui.view.WXCircleViewPager;
import com.taobao.weex.ui.view.gesture.WXGestureType;
import com.taobao.weex.utils.WXLogUtils;
import com.taobao.weex.utils.WXUtils;
import com.taobao.weex.utils.WXViewUtils;
import io.dcloud.common.constant.AbsoluteConst;
import java.lang.ref.WeakReference;
import java.lang.reflect.InvocationTargetException;
import java.util.HashMap;
import java.util.Map;
@Component(lazyload = false)
/* loaded from: classes26.dex */
public class DCWXSlider extends WXVContainer<FrameLayout> {
    public static final String INDEX = "index";
    public static final String INFINITE = "infinite";
    public static final String SOURCE = "source";
    private int initIndex;
    private Runnable initRunnable;
    protected boolean isDrag;
    private boolean isInfinite;
    private boolean keepIndex;
    protected WXCirclePageAdapter mAdapter;
    protected WXIndicator mIndicator;
    protected ViewPager.OnPageChangeListener mPageChangeListener;
    protected boolean mShowIndicators;
    DCWXCircleViewPager mViewPager;
    private float offsetXAccuracy;
    Map<String, Object> params;

    /* loaded from: classes21.dex */
    public static class Creator implements ComponentCreator {
        @Override // com.taobao.weex.ui.ComponentCreator
        public WXComponent createInstance(WXSDKInstance instance, WXVContainer parent, BasicComponentData basicComponentData) throws IllegalAccessException, InvocationTargetException, InstantiationException {
            return new DCWXSlider(instance, parent, basicComponentData);
        }
    }

    @Deprecated
    public DCWXSlider(WXSDKInstance instance, WXVContainer parent, String instanceId, boolean isLazy, BasicComponentData basicComponentData) {
        this(instance, parent, basicComponentData);
    }

    public DCWXSlider(WXSDKInstance instance, WXVContainer parent, BasicComponentData basicComponentData) {
        super(instance, parent, basicComponentData);
        this.isInfinite = true;
        this.params = new HashMap();
        this.offsetXAccuracy = 0.1f;
        this.initIndex = -1;
        this.keepIndex = true;
        this.mShowIndicators = true;
        this.mPageChangeListener = new SliderPageChangeListener();
        this.isDrag = false;
    }

    /* JADX INFO: Access modifiers changed from: protected */
    @Override // com.taobao.weex.ui.component.WXComponent
    public BaseFrameLayout initComponentHostView(Context context) {
        BaseFrameLayout baseFrameLayout = new BaseFrameLayout(context);
        if (getAttrs() != null) {
            this.isInfinite = WXUtils.getBoolean(getAttrs().get("infinite"), true).booleanValue();
        }
        FrameLayout.LayoutParams layoutParams = new FrameLayout.LayoutParams(-1, -1);
        DCWXCircleViewPager dCWXCircleViewPager = new DCWXCircleViewPager(context);
        this.mViewPager = dCWXCircleViewPager;
        dCWXCircleViewPager.setCircle(this.isInfinite);
        this.mViewPager.setLayoutParams(layoutParams);
        WXCirclePageAdapter wXCirclePageAdapter = new WXCirclePageAdapter(this.isInfinite);
        this.mAdapter = wXCirclePageAdapter;
        this.mViewPager.setAdapter(wXCirclePageAdapter);
        baseFrameLayout.addView(this.mViewPager);
        this.mViewPager.addOnPageChangeListener(this.mPageChangeListener);
        registerActivityStateListener();
        return baseFrameLayout;
    }

    @Override // io.dcloud.feature.uniapp.ui.component.AbsVContainer
    public ViewGroup.LayoutParams getChildLayoutParams(WXComponent child, View childView, int width, int height, int left, int right, int top, int bottom) {
        ViewGroup.LayoutParams layoutParams = childView.getLayoutParams();
        if (layoutParams == null) {
            layoutParams = new FrameLayout.LayoutParams(width, height);
        } else {
            layoutParams.width = width;
            layoutParams.height = height;
        }
        if (layoutParams instanceof ViewGroup.MarginLayoutParams) {
            if (child instanceof WXIndicator) {
                setMarginsSupportRTL((ViewGroup.MarginLayoutParams) layoutParams, left, top, right, bottom);
            } else {
                setMarginsSupportRTL((ViewGroup.MarginLayoutParams) layoutParams, 0, 0, 0, 0);
            }
        }
        return layoutParams;
    }

    @Override // com.taobao.weex.ui.component.WXComponent
    public void addEvent(String type) {
        DCWXCircleViewPager dCWXCircleViewPager;
        super.addEvent(type);
        if (!"scroll".equals(type) || (dCWXCircleViewPager = this.mViewPager) == null) {
            return;
        }
        dCWXCircleViewPager.addOnPageChangeListener(new SliderOnScrollListener(this));
    }

    @Override // com.taobao.weex.ui.component.WXComponent
    public boolean containsGesture(WXGestureType WXGestureType) {
        return super.containsGesture(WXGestureType);
    }

    @Override // io.dcloud.feature.uniapp.ui.component.AbsVContainer, com.taobao.weex.ui.component.WXComponent
    public ViewGroup getRealView() {
        return this.mViewPager;
    }

    @Override // io.dcloud.feature.uniapp.ui.component.AbsVContainer
    public void addSubView(View view, int index) {
        WXCirclePageAdapter wXCirclePageAdapter;
        if (view == null || (wXCirclePageAdapter = this.mAdapter) == null || (view instanceof WXCircleIndicator)) {
            return;
        }
        wXCirclePageAdapter.addPageView(view);
        hackTwoItemsInfiniteScroll();
        if (this.initIndex != -1 && this.mAdapter.getRealCount() > this.initIndex) {
            if (this.initRunnable == null) {
                this.initRunnable = new Runnable() { // from class: io.dcloud.feature.weex.extend.DCWXSlider.1
                    @Override // java.lang.Runnable
                    public void run() {
                        DCWXSlider dCWXSlider = DCWXSlider.this;
                        dCWXSlider.initIndex = dCWXSlider.getInitIndex();
                        DCWXSlider dCWXSlider2 = DCWXSlider.this;
                        DCWXSlider.this.mViewPager.setCurrentItem(dCWXSlider2.getRealIndex(dCWXSlider2.initIndex));
                        DCWXSlider.this.initIndex = -1;
                        DCWXSlider.this.initRunnable = null;
                    }
                };
            }
            int initIndex = getInitIndex();
            this.initIndex = initIndex;
            this.mViewPager.setCurrentItem(getRealIndex(initIndex));
            this.mViewPager.removeCallbacks(this.initRunnable);
            this.mViewPager.postDelayed(this.initRunnable, 50L);
        } else if (!this.keepIndex) {
            this.mViewPager.setCurrentItem(getRealIndex(0));
        }
        WXIndicator wXIndicator = this.mIndicator;
        if (wXIndicator != null) {
            wXIndicator.getHostView().forceLayout();
            this.mIndicator.getHostView().requestLayout();
        }
    }

    @Override // com.taobao.weex.ui.component.WXComponent
    public void setLayout(WXComponent component) {
        WXCirclePageAdapter wXCirclePageAdapter = this.mAdapter;
        if (wXCirclePageAdapter != null) {
            wXCirclePageAdapter.setLayoutDirectionRTL(isLayoutRTL());
        }
        super.setLayout(component);
    }

    @Override // io.dcloud.feature.uniapp.ui.component.AbsVContainer
    public void remove(WXComponent child, boolean destroy) {
        WXCirclePageAdapter wXCirclePageAdapter;
        if (child == null || child.getHostView() == null || (wXCirclePageAdapter = this.mAdapter) == null) {
            return;
        }
        wXCirclePageAdapter.removePageView(child.getHostView());
        hackTwoItemsInfiniteScroll();
        super.remove(child, destroy);
    }

    @Override // io.dcloud.feature.uniapp.ui.component.AbsVContainer, com.taobao.weex.ui.component.WXComponent
    public void destroy() {
        super.destroy();
        DCWXCircleViewPager dCWXCircleViewPager = this.mViewPager;
        if (dCWXCircleViewPager != null) {
            dCWXCircleViewPager.stopAutoScroll();
            this.mViewPager.removeAllViews();
            this.mViewPager.destory();
        }
    }

    @Override // io.dcloud.feature.uniapp.ui.component.AbsVContainer, com.taobao.weex.ui.component.WXComponent, com.taobao.weex.IWXActivityStateListener
    public void onActivityResume() {
        super.onActivityResume();
        DCWXCircleViewPager dCWXCircleViewPager = this.mViewPager;
        if (dCWXCircleViewPager == null || !dCWXCircleViewPager.isAutoScroll()) {
            return;
        }
        this.mViewPager.startAutoScroll();
    }

    @Override // io.dcloud.feature.uniapp.ui.component.AbsVContainer, com.taobao.weex.ui.component.WXComponent, com.taobao.weex.IWXActivityStateListener
    public void onActivityStop() {
        super.onActivityStop();
        DCWXCircleViewPager dCWXCircleViewPager = this.mViewPager;
        if (dCWXCircleViewPager != null) {
            dCWXCircleViewPager.pauseAutoScroll();
        }
    }

    public int getCurrentIndex() {
        DCWXCircleViewPager dCWXCircleViewPager = this.mViewPager;
        if (dCWXCircleViewPager != null) {
            return dCWXCircleViewPager.superGetCurrentItem();
        }
        return -1;
    }

    public void addIndicator(WXIndicator indicator) {
        FrameLayout frameLayout = (FrameLayout) getHostView();
        if (frameLayout == null) {
            return;
        }
        this.mIndicator = indicator;
        indicator.setShowIndicators(this.mShowIndicators);
        WXCircleIndicator hostView = indicator.getHostView();
        if (hostView != null) {
            hostView.setCircleViewPager(this.mViewPager);
            frameLayout.addView(hostView);
        }
    }

    /* JADX INFO: Access modifiers changed from: private */
    public int getInitIndex() {
        Object obj = getAttrs().get("index");
        if (obj == null) {
            return 0;
        }
        int intValue = WXUtils.getInteger(obj, Integer.valueOf(this.initIndex)).intValue();
        WXCirclePageAdapter wXCirclePageAdapter = this.mAdapter;
        if (wXCirclePageAdapter == null || wXCirclePageAdapter.getCount() == 0) {
            return 0;
        }
        return intValue >= this.mAdapter.getRealCount() ? intValue % this.mAdapter.getRealCount() : intValue;
    }

    /* JADX INFO: Access modifiers changed from: private */
    public int getRealIndex(int idx) {
        if (this.mAdapter.getRealCount() > 0) {
            if (idx >= this.mAdapter.getRealCount()) {
                idx = this.mAdapter.getRealCount() - 1;
            }
            if (isLayoutRTL()) {
                idx = (this.mAdapter.getRealCount() - 1) - idx;
            }
        }
        return idx + 0;
    }

    /* JADX INFO: Access modifiers changed from: protected */
    @Override // com.taobao.weex.ui.component.WXComponent
    public boolean setProperty(String key, Object param) {
        key.hashCode();
        char c = 65535;
        switch (key.hashCode()) {
            case -1768064947:
                if (key.equals(Constants.Name.KEEP_INDEX)) {
                    c = 0;
                    break;
                }
                break;
            case 66669991:
                if (key.equals(Constants.Name.SCROLLABLE)) {
                    c = 1;
                    break;
                }
                break;
            case 100346066:
                if (key.equals("index")) {
                    c = 2;
                    break;
                }
                break;
            case 111972721:
                if (key.equals("value")) {
                    c = 3;
                    break;
                }
                break;
            case 570418373:
                if (key.equals("interval")) {
                    c = 4;
                    break;
                }
                break;
            case 996926241:
                if (key.equals(Constants.Name.SHOW_INDICATORS)) {
                    c = 5;
                    break;
                }
                break;
            case 1438608771:
                if (key.equals(Constants.Name.AUTO_PLAY)) {
                    c = 6;
                    break;
                }
                break;
            case 1565939262:
                if (key.equals(Constants.Name.OFFSET_X_ACCURACY)) {
                    c = 7;
                    break;
                }
                break;
        }
        switch (c) {
            case 0:
                this.keepIndex = WXUtils.getBoolean(param, false).booleanValue();
                return true;
            case 1:
                setScrollable(WXUtils.getBoolean(param, true).booleanValue());
                return true;
            case 2:
                Integer integer = WXUtils.getInteger(param, null);
                if (integer != null) {
                    setIndex(integer.intValue());
                }
                return true;
            case 3:
                String string = WXUtils.getString(param, null);
                if (string != null) {
                    setValue(string);
                }
                return true;
            case 4:
                Integer integer2 = WXUtils.getInteger(param, null);
                if (integer2 != null) {
                    setInterval(integer2.intValue());
                }
                return true;
            case 5:
                String string2 = WXUtils.getString(param, null);
                if (string2 != null) {
                    setShowIndicators(string2);
                }
                return true;
            case 6:
                String string3 = WXUtils.getString(param, null);
                if (string3 != null) {
                    setAutoPlay(string3);
                }
                return true;
            case 7:
                Float f = WXUtils.getFloat(param, Float.valueOf(0.1f));
                if (f.floatValue() != 0.0f) {
                    setOffsetXAccuracy(f.floatValue());
                }
                return true;
            default:
                return super.setProperty(key, param);
        }
    }

    @WXComponentProp(name = "value")
    @Deprecated
    public void setValue(String value) {
        if (value == null || getHostView() == 0) {
            return;
        }
        try {
            setIndex(Integer.parseInt(value));
        } catch (NumberFormatException e) {
            WXLogUtils.e("", e);
        }
    }

    @WXComponentProp(name = Constants.Name.AUTO_PLAY)
    public void setAutoPlay(String autoPlay) {
        if (TextUtils.isEmpty(autoPlay) || autoPlay.equals(AbsoluteConst.FALSE)) {
            this.mViewPager.stopAutoScroll();
            return;
        }
        this.mViewPager.stopAutoScroll();
        this.mViewPager.startAutoScroll();
    }

    @WXComponentProp(name = "vertical")
    public void setVertical(boolean vertical) {
        DCWXCircleViewPager dCWXCircleViewPager = this.mViewPager;
        if (dCWXCircleViewPager != null) {
            dCWXCircleViewPager.setVertical(vertical);
        }
    }

    @WXComponentProp(name = Constants.Name.SHOW_INDICATORS)
    public void setShowIndicators(String show) {
        if (TextUtils.isEmpty(show) || show.equals(AbsoluteConst.FALSE)) {
            this.mShowIndicators = false;
        } else {
            this.mShowIndicators = true;
        }
        WXIndicator wXIndicator = this.mIndicator;
        if (wXIndicator == null) {
            return;
        }
        wXIndicator.setShowIndicators(this.mShowIndicators);
    }

    @WXComponentProp(name = "interval")
    public void setInterval(int intervalMS) {
        DCWXCircleViewPager dCWXCircleViewPager = this.mViewPager;
        if (dCWXCircleViewPager == null || intervalMS <= 0) {
            return;
        }
        dCWXCircleViewPager.setIntervalTime(intervalMS);
    }

    @WXComponentProp(name = "index")
    public void setIndex(int index) {
        WXCirclePageAdapter wXCirclePageAdapter;
        WXCirclePageAdapter wXCirclePageAdapter2;
        if (this.mViewPager == null || (wXCirclePageAdapter = this.mAdapter) == null) {
            return;
        }
        if (index >= wXCirclePageAdapter.getRealCount() || index < 0) {
            this.initIndex = index;
            return;
        }
        int realIndex = getRealIndex(index);
        if (this.mAdapter.getRealCount() == 3 && realIndex == 2 && this.mViewPager.getCurrentItem() == 0) {
            this.mViewPager.setCurrentItem(1, false);
        }
        this.mViewPager.setCurrentItem(realIndex);
        WXIndicator wXIndicator = this.mIndicator;
        if (wXIndicator == null || wXIndicator.getHostView() == null || this.mIndicator.getHostView().getRealCurrentItem() == realIndex) {
            return;
        }
        WXLogUtils.d("setIndex >>>> correction indicator to " + realIndex);
        this.mIndicator.getHostView().setRealCurrentItem(realIndex);
        this.mIndicator.getHostView().invalidate();
        ViewPager.OnPageChangeListener onPageChangeListener = this.mPageChangeListener;
        if (onPageChangeListener == null || (wXCirclePageAdapter2 = this.mAdapter) == null) {
            return;
        }
        onPageChangeListener.onPageSelected(wXCirclePageAdapter2.getFirst() + realIndex);
    }

    @WXComponentProp(name = Constants.Name.SCROLLABLE)
    public void setScrollable(boolean scrollable) {
        DCWXCircleViewPager dCWXCircleViewPager = this.mViewPager;
        if (dCWXCircleViewPager == null || this.mAdapter == null) {
            return;
        }
        dCWXCircleViewPager.setScrollable(scrollable);
    }

    @WXComponentProp(name = Constants.Name.OFFSET_X_ACCURACY)
    public void setOffsetXAccuracy(float accuracy) {
        this.offsetXAccuracy = accuracy;
    }

    /* loaded from: classes21.dex */
    protected class SliderPageChangeListener implements ViewPager.OnPageChangeListener {
        private int lastPos = -1;

        @Override // androidx.viewpager.widget.ViewPager.OnPageChangeListener
        public void onPageScrolled(int position, float positionOffset, int positionOffsetPixels) {
        }

        protected SliderPageChangeListener() {
        }

        /* JADX WARN: Type inference failed for: r1v13, types: [android.view.View] */
        @Override // androidx.viewpager.widget.ViewPager.OnPageChangeListener
        public void onPageSelected(int pos) {
            if (DCWXSlider.this.mAdapter.getRealPosition(pos) == this.lastPos) {
                return;
            }
            if (WXEnvironment.isApkDebugable()) {
                WXLogUtils.d("onPageSelected >>>>" + DCWXSlider.this.mAdapter.getRealPosition(pos) + " lastPos: " + this.lastPos);
            }
            if (DCWXSlider.this.mAdapter == null || DCWXSlider.this.mAdapter.getRealCount() == 0) {
                return;
            }
            int realPosition = DCWXSlider.this.mAdapter.getRealPosition(pos);
            if (DCWXSlider.this.mChildren == null || realPosition >= DCWXSlider.this.mChildren.size() || DCWXSlider.this.getEvents().size() == 0) {
                return;
            }
            WXEvent events = DCWXSlider.this.getEvents();
            String ref = DCWXSlider.this.getRef();
            if (events.contains(Constants.Event.CHANGE) && WXViewUtils.onScreenArea(DCWXSlider.this.getHostView())) {
                DCWXSlider.this.params.put("index", Integer.valueOf(realPosition));
                DCWXSlider.this.params.put("source", DCWXSlider.this.isDrag ? "touch" : Constants.Name.AUTOPLAY);
                HashMap hashMap = new HashMap();
                HashMap hashMap2 = new HashMap();
                hashMap2.put("index", Integer.valueOf(realPosition));
                hashMap2.put("source", DCWXSlider.this.isDrag ? "touch" : Constants.Name.AUTOPLAY);
                hashMap.put(TemplateDom.KEY_ATTRS, hashMap2);
                DCWXSlider.this.getAttrs().putAll(hashMap2);
                WXSDKManager.getInstance().fireEvent(DCWXSlider.this.getInstanceId(), ref, Constants.Event.CHANGE, DCWXSlider.this.params, hashMap);
            }
            DCWXSlider.this.mViewPager.requestLayout();
            ((FrameLayout) DCWXSlider.this.getHostView()).invalidate();
            this.lastPos = DCWXSlider.this.mAdapter.getRealPosition(pos);
        }

        @Override // androidx.viewpager.widget.ViewPager.OnPageChangeListener
        public void onPageScrollStateChanged(int arg0) {
            FrameLayout frameLayout = (FrameLayout) DCWXSlider.this.getHostView();
            if (frameLayout != null) {
                frameLayout.invalidate();
            }
        }
    }

    /* loaded from: classes21.dex */
    protected static class SliderOnScrollListener implements ViewPager.OnPageChangeListener {
        private int selectedPosition;
        private DCWXSlider target;
        private float lastPositionOffset = 99.0f;
        private int scrollState = 0;
        private int preScrollstate = 0;
        private boolean pageSelected = false;
        private float lastValue = 0.0f;

        public SliderOnScrollListener(DCWXSlider target) {
            this.target = target;
            this.selectedPosition = target.mViewPager.superGetCurrentItem();
        }

        /* JADX WARN: Code restructure failed: missing block: B:34:0x0067, code lost:
            if (r9.pageSelected != false) goto L54;
         */
        /* JADX WARN: Code restructure failed: missing block: B:55:0x0093, code lost:
            if (r9.lastValue < 0.0f) goto L43;
         */
        /* JADX WARN: Code restructure failed: missing block: B:59:0x009d, code lost:
            if (r9.lastValue > 0.0f) goto L43;
         */
        @Override // androidx.viewpager.widget.ViewPager.OnPageChangeListener
        /*
            Code decompiled incorrectly, please refer to instructions dump.
        */
        public void onPageScrolled(int position, float positionOffset, int positionOffsetPixels) {
            float abs;
            float f = this.lastPositionOffset;
            if (f == 99.0f) {
                this.lastPositionOffset = positionOffset;
                this.lastValue = positionOffset;
                return;
            }
            float f2 = positionOffset - f;
            if (f2 == 0.0f) {
                this.lastPositionOffset = positionOffset;
                return;
            }
            int i = this.scrollState;
            if (i == 1) {
                this.pageSelected = false;
                if (positionOffset == 0.0f) {
                    return;
                }
                if (position == this.target.mViewPager.superGetCurrentItem()) {
                    abs = Math.abs(positionOffset);
                } else {
                    if (position < this.target.mViewPager.superGetCurrentItem()) {
                        abs = Math.abs(positionOffset);
                        abs = -abs;
                    }
                    abs = positionOffset;
                }
            } else {
                if (i == 2 || i == 0) {
                    int i2 = -1;
                    if (positionOffset == 0.0f) {
                        if (Math.abs(f2) > 0.9d) {
                            if (this.pageSelected) {
                                i2 = 1;
                                abs = i2;
                            }
                            i2 = 0;
                            abs = i2;
                        }
                    } else if (f2 > 0.0f) {
                        i2 = 1;
                        abs = i2 * Math.abs(positionOffset);
                    } else {
                        i2 = 1;
                        abs = i2 * Math.abs(positionOffset);
                    }
                    if (this.preScrollstate == 2) {
                        if (this.scrollState == 2) {
                            if (abs > 0.0f) {
                            }
                            if (abs < 0.0f) {
                            }
                        }
                    }
                }
                abs = positionOffset;
            }
            if (abs < 0.0f && abs > -1.0f) {
                abs = -(abs + 1.0f);
            }
            if (this.preScrollstate == 2 && this.scrollState == 1) {
                this.target.mViewPager.getmScroller().forceFinished(true);
                this.target.fireEvent(Constants.Event.SCROLL_END);
            }
            this.preScrollstate = this.scrollState;
            this.lastValue = abs;
            if (this.target.mViewPager.isVertical()) {
                HashMap hashMap = new HashMap(1);
                hashMap.put("offsetYRatio", Float.valueOf(-abs));
                hashMap.put("drag", Boolean.valueOf(this.target.mViewPager.getPointCounr() > 0));
                this.target.fireEvent("scroll", hashMap);
                this.lastPositionOffset = positionOffset;
                return;
            }
            HashMap hashMap2 = new HashMap(1);
            hashMap2.put(Constants.Name.OFFSET_X_RATIO, Float.valueOf(-abs));
            hashMap2.put("drag", Boolean.valueOf(this.target.mViewPager.getPointCounr() > 0));
            this.target.fireEvent("scroll", hashMap2);
            this.lastPositionOffset = positionOffset;
        }

        @Override // androidx.viewpager.widget.ViewPager.OnPageChangeListener
        public void onPageSelected(int position) {
            this.pageSelected = true;
            this.selectedPosition = position;
        }

        @Override // androidx.viewpager.widget.ViewPager.OnPageChangeListener
        public void onPageScrollStateChanged(int state) {
            this.scrollState = state;
            if (state != 0) {
                if (state != 1) {
                    return;
                }
                this.target.isDrag = true;
                this.target.fireEvent(Constants.Event.SCROLL_START);
                return;
            }
            this.lastPositionOffset = 99.0f;
            this.lastValue = 99.0f;
            if (this.preScrollstate != 2) {
                return;
            }
            this.preScrollstate = 0;
            this.target.isDrag = false;
            this.target.fireEvent(Constants.Event.SCROLL_END);
        }
    }

    private void hackTwoItemsInfiniteScroll() {
        WXCirclePageAdapter wXCirclePageAdapter;
        if (this.mViewPager == null || (wXCirclePageAdapter = this.mAdapter) == null || !this.isInfinite) {
            return;
        }
        if (wXCirclePageAdapter.getRealCount() == 2) {
            final GestureDetector gestureDetector = new GestureDetector(getContext(), new FlingGestureListener(this.mViewPager));
            this.mViewPager.setOnTouchListener(new View.OnTouchListener() { // from class: io.dcloud.feature.weex.extend.DCWXSlider.2
                @Override // android.view.View.OnTouchListener
                public boolean onTouch(View v, MotionEvent event) {
                    return gestureDetector.onTouchEvent(event);
                }
            });
            return;
        }
        this.mViewPager.setOnTouchListener(null);
    }

    /* JADX INFO: Access modifiers changed from: private */
    /* loaded from: classes12.dex */
    public static class FlingGestureListener extends GestureDetector.SimpleOnGestureListener {
        private WeakReference<WXCircleViewPager> pagerRef;
        private static final int SWIPE_MIN_DISTANCE = WXViewUtils.dip2px(50.0f);
        private static final int SWIPE_MAX_OFF_PATH = WXViewUtils.dip2px(250.0f);
        private static final int SWIPE_THRESHOLD_VELOCITY = WXViewUtils.dip2px(200.0f);

        FlingGestureListener(WXCircleViewPager pager) {
            this.pagerRef = new WeakReference<>(pager);
        }

        @Override // android.view.GestureDetector.SimpleOnGestureListener, android.view.GestureDetector.OnGestureListener
        public boolean onFling(MotionEvent e1, MotionEvent e2, float velocityX, float velocityY) {
            WXCircleViewPager wXCircleViewPager = this.pagerRef.get();
            if (wXCircleViewPager == null) {
                return false;
            }
            if (Math.abs(e1.getY() - e2.getY()) > SWIPE_MAX_OFF_PATH) {
                return false;
            }
            float x = e1.getX() - e2.getX();
            int i = SWIPE_MIN_DISTANCE;
            if (x > i && Math.abs(velocityX) > SWIPE_THRESHOLD_VELOCITY && wXCircleViewPager.superGetCurrentItem() == 1) {
                wXCircleViewPager.setCurrentItem(0, false);
                return true;
            }
            if (e2.getX() - e1.getX() > i && Math.abs(velocityX) > SWIPE_THRESHOLD_VELOCITY && wXCircleViewPager.superGetCurrentItem() == 0) {
                wXCircleViewPager.setCurrentItem(1, false);
                return true;
            }
            return false;
        }
    }
}
