package io.dcloud.feature.weex.extend;

import android.content.SharedPreferences;
import android.text.TextUtils;
import com.taobao.weex.annotation.JSMethod;
import com.taobao.weex.appfram.storage.StorageResultHandler;
import com.taobao.weex.bridge.JSCallback;
import com.taobao.weex.common.WXModule;
import io.dcloud.common.DHInterface.IWebview;
import io.dcloud.common.adapter.util.PlatformUtil;
import io.dcloud.feature.weex.WeexInstanceMgr;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;
/* loaded from: classes24.dex */
public class PlusStorageModule extends WXModule {
    HashMap<String, SharedPreferences> mAllAppNStorages = new HashMap<>(1);

    @JSMethod(uiThread = false)
    public void setItem(String key, String value, JSCallback callback) {
        Map<String, Object> itemResult;
        if (TextUtils.isEmpty(key) || value == null) {
            StorageResultHandler.handleInvalidParam(callback);
            return;
        }
        SharedPreferences appNStorage = getAppNStorage();
        if (appNStorage != null) {
            PlatformUtil.setBundleData(appNStorage, key, value);
            itemResult = StorageResultHandler.setItemResult(true);
        } else {
            itemResult = StorageResultHandler.setItemResult(false);
        }
        if (callback != null) {
            callback.invoke(itemResult);
        }
    }

    @JSMethod(uiThread = false)
    public void getItem(String key, JSCallback callback) {
        Map<String, Object> itemResult;
        if (TextUtils.isEmpty(key)) {
            StorageResultHandler.handleInvalidParam(callback);
            return;
        }
        SharedPreferences appNStorage = getAppNStorage();
        if (appNStorage != null) {
            itemResult = StorageResultHandler.getItemResult(appNStorage.getString(key, null));
        } else {
            itemResult = StorageResultHandler.getItemResult(null);
        }
        if (callback != null) {
            callback.invoke(itemResult);
        }
    }

    @JSMethod(uiThread = false)
    public void removeItem(String key, JSCallback callback) {
        Map<String, Object> removeItemResult;
        if (TextUtils.isEmpty(key)) {
            StorageResultHandler.handleInvalidParam(callback);
            return;
        }
        SharedPreferences appNStorage = getAppNStorage();
        if (appNStorage != null) {
            PlatformUtil.removeBundleData(appNStorage, key);
            removeItemResult = StorageResultHandler.removeItemResult(true);
        } else {
            removeItemResult = StorageResultHandler.removeItemResult(false);
        }
        if (callback != null) {
            callback.invoke(removeItemResult);
        }
    }

    @JSMethod(uiThread = false)
    public void length(JSCallback callback) {
        SharedPreferences appNStorage = getAppNStorage();
        if (appNStorage != null) {
            Map<String, Object> lengthResult = StorageResultHandler.getLengthResult(getBundleDataSize(appNStorage));
            if (callback != null) {
                callback.invoke(lengthResult);
                return;
            }
            return;
        }
        StorageResultHandler.handleNoHandlerError(callback);
    }

    @JSMethod(uiThread = false)
    public void getAllKeys(JSCallback callback) {
        SharedPreferences appNStorage = getAppNStorage();
        if (appNStorage != null) {
            Map<String, Object> allkeysResult = StorageResultHandler.getAllkeysResult(getBundleKeys(appNStorage));
            if (callback != null) {
                callback.invoke(allkeysResult);
                return;
            }
            return;
        }
        StorageResultHandler.handleNoHandlerError(callback);
    }

    private int getBundleDataSize(SharedPreferences bundle) {
        try {
            return bundle.getAll().size();
        } catch (Exception e) {
            e.printStackTrace();
            return 0;
        }
    }

    private List<String> getBundleKeys(SharedPreferences bundle) {
        Map<String, ?> all = bundle.getAll();
        if (all.size() > 0) {
            return new ArrayList(all.keySet());
        }
        return null;
    }

    private SharedPreferences initAppNStorages(String pAppid) {
        return PlatformUtil.getOrCreateBundle(pAppid + "_storages");
    }

    private SharedPreferences getAppNStorage() {
        IWebview findWebview = WeexInstanceMgr.self().findWebview(this.mWXSDKInstance);
        if (findWebview != null) {
            String obtainAppId = findWebview.obtainFrameView().obtainApp().obtainAppId();
            SharedPreferences sharedPreferences = this.mAllAppNStorages.get(obtainAppId);
            if (sharedPreferences == null) {
                SharedPreferences initAppNStorages = initAppNStorages(obtainAppId);
                this.mAllAppNStorages.put(obtainAppId, initAppNStorages);
                return initAppNStorages;
            }
            return sharedPreferences;
        }
        return null;
    }
}
