package io.dcloud.weex;

import android.app.Application;
import android.text.TextUtils;
import com.alibaba.fastjson.JSON;
import com.alibaba.fastjson.JSONArray;
import com.alibaba.fastjson.JSONObject;
import com.taobao.weex.WXSDKEngine;
import com.taobao.weex.bridge.WXBridgeManager;
import com.taobao.weex.ui.component.WXComponent;
import com.taobao.weex.utils.WXFileUtils;
import io.dcloud.common.adapter.io.DHFile;
import io.dcloud.common.util.AppRuntime;
import io.dcloud.common.util.PdrUtil;
import io.dcloud.common.util.RuningAcitvityUtil;
import io.dcloud.feature.uniapp.UniAppHookProxy;
import java.io.File;
import java.lang.reflect.Method;
/* loaded from: classes13.dex */
public class MoudlesLoader {
    private static MoudlesLoader sLoader;
    private boolean isInitHooksClass = false;

    public static MoudlesLoader getInstance() {
        if (sLoader == null) {
            synchronized (MoudlesLoader.class) {
                if (sLoader == null) {
                    sLoader = new MoudlesLoader();
                }
            }
        }
        return sLoader;
    }

    public void onCreate(Application application) {
        JSONArray jSONArray;
        JSONObject pluginsValue = getPluginsValue(application);
        initHooksClass(application, Boolean.valueOf(application.getPackageName().equals(RuningAcitvityUtil.getAppName(application))));
        if (pluginsValue == null || (jSONArray = pluginsValue.getJSONArray("nativePlugins")) == null || jSONArray.size() <= 0) {
            return;
        }
        for (int i = 0; i < jSONArray.size(); i++) {
            initMoudle(jSONArray.getJSONObject(i), application);
        }
    }

    public void onCreate(Application application, String configPath) {
        if (application == null || PdrUtil.isEmpty(configPath) || !DHFile.exists(configPath)) {
            return;
        }
        JSONObject parseObject = JSON.parseObject(new String(DHFile.readAll(new File(configPath))));
        if (PdrUtil.isEmpty(parseObject)) {
            return;
        }
        JSONArray jSONArray = parseObject.getJSONArray("components");
        if (PdrUtil.isEmpty(jSONArray)) {
            return;
        }
        for (int i = 0; i < jSONArray.size(); i++) {
            JSONObject jSONObject = jSONArray.getJSONObject(i);
            if (jSONObject != null) {
                registerMoudle(jSONObject.getString("name"), jSONObject.getString("class"), WXBridgeManager.COMPONENT);
            }
        }
    }

    private void initMoudle(JSONObject moudleJson, Application application) {
        JSONArray jSONArray;
        if (moudleJson == null || (jSONArray = moudleJson.getJSONArray("plugins")) == null || jSONArray == null || jSONArray.size() <= 0) {
            return;
        }
        for (int i = 0; i < jSONArray.size(); i++) {
            JSONObject jSONObject = jSONArray.getJSONObject(i);
            if (jSONObject != null) {
                registerMoudle(jSONObject.getString("name"), jSONObject.getString("class"), jSONObject.getString("type"));
            }
        }
    }

    private void executeOnCreateProcess(JSONObject moudleJson, Application application, boolean isMainProcess) {
        try {
            Class<?> cls = Class.forName(moudleJson.getString("hooksClass"));
            Object newInstance = cls.newInstance();
            if (!(newInstance instanceof AppHookProxy)) {
                Method method = cls.getMethod("onCreate", Application.class);
                if (method != null) {
                    method.setAccessible(true);
                    method.invoke(newInstance, application);
                }
            } else if (isMainProcess) {
                ((AppHookProxy) newInstance).onCreate(application);
            } else if (newInstance instanceof UniAppHookProxy) {
                ((UniAppHookProxy) newInstance).onSubProcessCreate(application);
            }
        } catch (Throwable unused) {
        }
    }

    private void registerMoudle(String moduleName, String moduleClasss, String moduleType) {
        try {
            Class<?> cls = Class.forName(moduleClasss);
            if (!TextUtils.isEmpty(moduleType) && !moduleType.equalsIgnoreCase("module")) {
                if (moduleType.equalsIgnoreCase(WXBridgeManager.COMPONENT)) {
                    WXSDKEngine.registerComponent(moduleName, (Class<? extends WXComponent>) cls);
                }
            }
            WXSDKEngine.registerModule(moduleName, cls);
        } catch (Throwable unused) {
        }
    }

    private JSONObject getPluginsValue(Application application) {
        String loadAsset = WXFileUtils.loadAsset("dcloud_uniplugins.json", application);
        if (TextUtils.isEmpty(loadAsset)) {
            return null;
        }
        return JSONObject.parseObject(loadAsset);
    }

    public void initHooksClass(Application application, Boolean isMainProcess) {
        JSONArray jSONArray;
        if (this.isInitHooksClass) {
            return;
        }
        JSONObject pluginsValue = getPluginsValue(application);
        if (pluginsValue != null && (jSONArray = pluginsValue.getJSONArray("nativePlugins")) != null && jSONArray.size() > 0) {
            this.isInitHooksClass = true;
            for (int i = 0; i < jSONArray.size(); i++) {
                executeOnCreateProcess(jSONArray.getJSONObject(i), application, isMainProcess.booleanValue());
            }
        }
        AppRuntime.initUTSHooksClassArray(application);
    }
}
