package io.dcloud.weex;

import android.os.Handler;
import android.view.MotionEvent;
import com.alibaba.fastjson.JSONObject;
import com.facebook.common.statfs.StatFsHelper;
import com.taobao.weex.ui.component.WXComponent;
import com.taobao.weex.ui.view.gesture.WXGestureType;
import io.dcloud.common.constant.AbsoluteConst;
import java.util.Map;
import java.util.Set;
/* loaded from: classes13.dex */
public class ViewHover {
    public static final String VIEW_HOVER_EVENT = "view_hover_event";
    private WXComponent component;
    private Handler handler;
    private JSONObject hoverClass;
    private int hoverStartTime;
    private int hoverStayTime;
    private boolean hoverStopPropagation;
    private boolean isHover;
    private boolean isReceiveTouch;
    private Map<String, Object> originalStyles;
    public Runnable touchEndRunnable;
    public Runnable touchStartRunnable;

    public ViewHover(WXComponent component) {
        this(component, null);
    }

    public ViewHover(WXComponent component, JSONObject data) {
        this.hoverStopPropagation = false;
        this.hoverClass = null;
        this.hoverStartTime = 50;
        this.hoverStayTime = StatFsHelper.DEFAULT_DISK_YELLOW_LEVEL_IN_MB;
        this.isHover = false;
        this.isReceiveTouch = true;
        this.handler = new Handler();
        this.touchStartRunnable = new Runnable() { // from class: io.dcloud.weex.ViewHover.1
            @Override // java.lang.Runnable
            public void run() {
                if (ViewHover.this.isHover || ViewHover.this.component == null || ViewHover.this.component.getInstance() == null) {
                    return;
                }
                ViewHover viewHover = ViewHover.this;
                viewHover.originalStyles = viewHover.component.getStyles().clone();
                ViewHover.this.component.setHoverClassStatus(true);
            }
        };
        this.touchEndRunnable = new Runnable() { // from class: io.dcloud.weex.ViewHover.2
            @Override // java.lang.Runnable
            public void run() {
                if (ViewHover.this.component == null || ViewHover.this.component.getInstance() == null) {
                    return;
                }
                ViewHover.this.component.setHoverClassStatus(false);
                ViewHover.this.isHover = false;
            }
        };
        update(data);
        this.component = component;
    }

    public void update(JSONObject data) {
        if (data == null) {
            return;
        }
        JSONObject jSONObject = this.hoverClass;
        if (jSONObject == null) {
            this.hoverClass = data;
        } else {
            jSONObject.putAll(data);
        }
    }

    public boolean isHoverStopPropagation() {
        return this.hoverStopPropagation;
    }

    public void setHoverStopPropagation(boolean hoverStopPropagation) {
        this.hoverStopPropagation = hoverStopPropagation;
    }

    public int getHoverStartTime() {
        return this.hoverStartTime;
    }

    public void setHoverStartTime(int hoverStartTime) {
        this.hoverStartTime = hoverStartTime;
    }

    public int getHoverStayTime() {
        return this.hoverStayTime;
    }

    public void setHoverStayTime(int hoverStayTime) {
        this.hoverStayTime = hoverStayTime;
    }

    public void handleMotionEvent(WXGestureType wxGestureType, MotionEvent motionEvent) {
        if (this.hoverClass == null || !this.isReceiveTouch) {
            return;
        }
        String obj = wxGestureType.toString();
        obj.hashCode();
        char c = 65535;
        switch (obj.hashCode()) {
            case -1578593149:
                if (obj.equals(AbsoluteConst.EVENTS_WEBVIEW_ONTOUCH_START)) {
                    c = 0;
                    break;
                }
                break;
            case -819532484:
                if (obj.equals("touchend")) {
                    c = 1;
                    break;
                }
                break;
            case 2127979129:
                if (obj.equals("touchcancel")) {
                    c = 2;
                    break;
                }
                break;
        }
        switch (c) {
            case 0:
                this.handler.removeCallbacks(this.touchEndRunnable);
                this.handler.removeCallbacks(this.touchStartRunnable);
                this.handler.postDelayed(this.touchStartRunnable, this.hoverStartTime);
                return;
            case 1:
                this.isHover = true;
                this.handler.removeCallbacks(this.touchEndRunnable);
                this.handler.postDelayed(this.touchEndRunnable, this.hoverStayTime);
                return;
            case 2:
                this.isHover = true;
                this.handler.removeCallbacks(this.touchEndRunnable);
                this.handler.postDelayed(this.touchEndRunnable, this.hoverStayTime);
                return;
            default:
                return;
        }
    }

    public Map<String, Object> updateStatusAndGetUpdateStyles(boolean status) {
        JSONObject jSONObject = new JSONObject();
        if (status) {
            return this.hoverClass;
        }
        if (this.originalStyles != null) {
            Set<String> keySet = this.hoverClass.keySet();
            JSONObject jSONObject2 = new JSONObject();
            for (String str : keySet) {
                if (this.originalStyles.containsKey(str)) {
                    jSONObject2.put((JSONObject) str, (String) this.originalStyles.get(str));
                } else {
                    jSONObject2.put((JSONObject) str, "");
                }
            }
            return jSONObject2;
        }
        return jSONObject;
    }

    public void setReceiveTouch(boolean receiveTouch) {
        this.isReceiveTouch = receiveTouch;
    }

    public void destroy() {
        this.component = null;
        this.originalStyles = null;
    }
}
